# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
%define _binary_payload w3T.xzdio

# For a kernel released for public testing, released_kernel should be 1.
# For internal testing builds during development, it should be 0.
%global released_kernel 0

%global distro_build 167

# Sign the x86_64 kernel for secure boot authentication
%ifarch x86_64 aarch64 s390x ppc64le
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.xz/'
%endif

# define buildid .local

%define rpmversion 4.18.0
%define pkgrelease 167.rt13.24.el8

# allow pkg_release to have configurable %%{?dist} tag
%define specrelease 167.rt13.24%{?dist}

%define pkg_release %{specrelease}%{?buildid}

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# realtime
%define with_realtime %{?_without_realtime:   0} %{?!_without_realtime:  1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-abi-whitelists
%define with_kernel_abi_whitelists %{?_without_kernel_abi_whitelists: 0} %{?!_without_kernel_abi_whitelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# kpatch_kcflags are extra compiler flags
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# The kernel tarball/base version
%define kversion 4.18

%define with_gcov %{?_with_gcov: 1} %{?!_with_gcov: 0}

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_whitelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

%if %{with_realtime}
# The preempt RT patch level
%global rttag .rt13
# realtimeN
%global rtbuild .24
%define with_doc 0
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_zfcpdump 0
%define with_kabichk  0
%define with_kernel_abi_whitelists 0
%define with_bpf_samples 0
%define with_kabidw_base 0
%define with_ipaclones 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%if %{with_realtime}
# The preempt RT patch level
%global rttag .rt13
# realtimeN
%global rtbuild .24
%define with_doc 0
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_zfcpdump 0
%define with_kabichk  0
%define with_kernel_abi_whitelists 0
%define with_bpf_samples 0
%define with_kabidw_base 0
%define with_ipaclones 0
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%ifnarch noarch
%define with_kernel_abi_whitelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs %{name}-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs %{name}-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define all_arch_configs %{name}-%{version}-ppc64le*.config
%define kcflags -O3
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs %{name}-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%endif

%ifarch aarch64
%define all_arch_configs %{name}-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%define nobuildarches i386 i686

%ifarch %nobuildarches
%define with_up 0
%define with_debug 0
%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%define cpupowerarchs x86_64 ppc64le aarch64


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel-rt%{?variant}
Group: System Environment/Kernel
License: GPLv2 and Redistributable, no modification permitted
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
Summary: The Linux kernel, based on version %{version}, heavily modified with backports
%if %{with_realtime}
ExclusiveArch: x86_64
%else
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch i386 i686 x86_64 s390x aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: %{name}-core-uname-r = %{KVERREL}%{?variant}
Requires: %{name}-modules-uname-r = %{KVERREL}%{?variant}
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, patch, bash, sh-utils, tar, git
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, python3-devel
BuildRequires: net-tools, hostname, bc, bison, flex, elfutils-devel, dwarves
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel
BuildRequires: java-devel
%ifnarch s390x
BuildRequires: numactl-devel
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: libcap-devel libcap-ng-devel llvm-toolset numactl-devel rsync
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
%global _find_debuginfo_opts -r
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl openssl-devel
%if %{signkernel}
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

Source0: linux-%{rpmversion}-%{pkgrelease}.tar.xz

Source11: x509.genkey

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

%if %{?released_kernel}

Source12: securebootca.cer
Source13: secureboot.cer
Source14: secureboot_s390.cer
Source15: secureboot_ppc.cer

%define secureboot_ca %{SOURCE12}
%ifarch x86_64 aarch64
%define secureboot_key %{SOURCE13}
%define pesign_name redhatsecureboot301
%endif
%ifarch s390x
%define secureboot_key %{SOURCE14}
%define pesign_name redhatsecureboot302
%endif
%ifarch ppc64le
%define secureboot_key %{SOURCE15}
%define pesign_name redhatsecureboot303
%endif

%else # released_kernel

Source12: redhatsecurebootca2.cer
Source13: redhatsecureboot003.cer

%define secureboot_ca %{SOURCE12}
%define secureboot_key %{SOURCE13}
%define pesign_name redhatsecureboot003

%endif # released_kernel

Source16: mod-extra.list
Source17: mod-blacklist.sh
Source18: mod-sign.sh
Source80: parallel_xz.sh
Source90: filter-x86_64.sh
Source93: filter-aarch64.sh
Source96: filter-ppc64le.sh
Source97: filter-s390x.sh
Source99: filter-modules.sh
%define modsign_cmd %{SOURCE18}

Source20: %{name}-aarch64.config
Source21: %{name}-aarch64-debug.config
Source32: %{name}-ppc64le.config
Source33: %{name}-ppc64le-debug.config
Source36: %{name}-s390x.config
Source37: %{name}-s390x-debug.config
Source38: %{name}-s390x-zfcpdump.config
Source39: %{name}-x86_64.config
Source40: %{name}-x86_64-debug.config
Source41: generate_all_configs.sh

Source42: process_configs.sh
Source43: generate_bls_conf.sh

Source44: mod-internal.list

%if %{with_kabichk}
Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-whitelists-%{rpmversion}-%{distro_build}.tar.bz2
Source301: kernel-kabi-dw-%{rpmversion}-%{distro_build}.tar.bz2
%endif

%if %{with_realtime}
Source400: mod-kvm.list
%endif

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config

## Patches needed for building this package

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/%{name}-%{KVERREL}-root

%description
This is the package which provides the Linux %{name} for Red Hat Enterprise
Linux. It is based on upstream Linux at version %{version} and maintains kABI
compatibility of a set of approved symbols, however it is heavily modified with
backports and fixes pulled from newer upstream Linux %{name} releases. This means
this is not a %{version} kernel anymore: it includes several components which come
from newer upstream linux versions, while maintaining a well tested and stable
core. Some of the components/backports that may be pulled in are: changes like
updates to the core kernel (eg.: scheduler, cgroups, memory management, security
fixes and features), updates to block layer, supported filesystems, major driver
updates for supported hardware in Red Hat Enterprise Linux, enhancements for
enterprise customers, etc.

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: %{name} = %{rpmversion}-%{pkg_release}\
Provides: %{name}-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:+%{1}}\
Provides: kernel-drm-nouveau = 16\
Provides: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20191202-96.gite8a0f4c9\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%if "0%{?variant}"
Obsoletes: kernel-headers < %{rpmversion}-%{pkg_release}
Provides: kernel-headers = %{rpmversion}-%{pkg_release}
%endif
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
Group: Development/System
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/traceevent/plugins/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}


%endif # with_perf

%if %{with_tools}
%package -n %{name}-tools
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: %{name}-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n %{name}-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n %{name}-tools-libs
Summary: Libraries for the %{name}-tools
Group: Development/System
License: GPLv2
%description -n %{name}-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n %{name}-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Requires: %{name}-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: %{name}-tools-libs = %{version}-%{release}
Provides: %{name}-tools-devel
%description -n %{name}-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n %{name}-tools-debuginfo
Summary: Debug information for package %{name}-tools
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n %{name}-tools-debuginfo
This package provides debug information for package %{name}-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|XXX' -o %{name}-tools-debuginfo.list}

%endif # with_tools

%if %{with_bpftool}

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
License: GPLv2
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

%endif # with_bpftool

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
License: GPLv2
Requires: binutils, bpftool, iproute-tc, nmap-ncat
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

%endif # with_selftests

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
Group: Development/System
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n %{name}-abi-whitelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol whitelists
Group: System Environment/Kernel
AutoReqProv: no
%description -n %{name}-abi-whitelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the Red Hat Enterprise
Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-devel-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-devel-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-internal = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat internal usage.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package <subpackage> <pretty-name>
#
%define kernel_modules_extra_package() \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-extra = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package <subpackage> <pretty-name>
#
%define kernel_modules_package() \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-modules-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-modules = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
group: system environment/kernel\
Requires: %{name}-%{1}-core-uname-r = %{KVERREL}%{?variant}+%{1}\
Requires: %{name}-%{1}-modules-uname-r = %{KVERREL}%{?variant}+%{1}\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package %{name}%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: %{name}%{?1:-%{1}} = %{version}-%{release}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n %{name}%{?1:-%{1}}-kvm\
This package provides KVM modules for package %{name}%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a %%{name}-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
Provides: %{name}-%{?1:%{1}-}core-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
%{expand:%%kernel_reqprovconf}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?-n:%{?1:%{1}}}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%if %{with_realtime} \
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%{nil}

# Now, each variant package.

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
%endif # with_zfcpdump

%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME%%%%%{?variant}}.spec ; then
    if [ "${patch:0:8}" != "patch-4." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n %{name}-%{rpmversion}-%{pkgrelease} -c
mv linux-%{rpmversion}-%{pkgrelease} linux-%{KVERREL}

cd linux-%{KVERREL}

ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

%if %{with_realtime}
# remove the localversion-rt file since it screws around with
# the uname output
if [ -f localversion-rt ]; then
   rm -f localversion-rt
fi
%endif

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Do not use "ambiguous" python shebangs. RHEL 8 now has a new script
# (/usr/lib/rpm/redhat/brp-mangle-shebangs), which forces us to specify a
# "non-ambiguous" python shebang for scripts we ship in buildroot. This
# script throws an error like below:
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i %{__python3} -p -n \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	tools/perf/tests/attr.py \
	tools/perf/scripts/python/stat-cpi.py \
	tools/perf/scripts/python/sched-migration.py \
	Documentation

%define make make %{?cross_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE41} .
VERSION=%{version} NAME=%{name} ./generate_all_configs.sh

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  ${RPM_OPT_FLAGS}
%define build_hostldflags %{__global_ldflags}
%endif

# enable GCOV kernel config options if gcov is on
%if %{with_gcov}
for i in *.config
do
  sed -i 's/# CONFIG_GCOV_KERNEL is not set/CONFIG_GCOV_KERNEL=y\nCONFIG_GCOV_PROFILE_ALL=y\n/' $i
done
%endif

cp %{SOURCE42} .
./process_configs.sh -w -c %{name} %{rpmversion}

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$4
    DoVDSO=$3
    Flav=${Flavour:++${Flavour}}
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Flavour" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # Pick the right config file for the kernel we're building
    Config=%{name}-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flav}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flav}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flav}/" Makefile

    # and now to start the build process

    %{make} -s %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp %{SOURCE11} certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Flavour" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi

    %{make} -s ARCH=$Arch oldnoconfig >/dev/null
    %{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch aarch64
    %{make} -s ARCH=$Arch V=1 dtbs dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f | xargs rm -f
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca} -c %{secureboot_key} -n %{pesign_name}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ $DoModules -eq 1 ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    %endif # signkernel

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} -s %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    if [ $DoVDSO -ne 0 ]; then
        %{make} -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ ! -s ldconfig-kernel.conf ]; then
          echo > ldconfig-kernel.conf "\
    # Placeholder file, no vDSO hwcap entries used in this kernel."
        fi
        %{__install} -D -m 444 ldconfig-kernel.conf \
            $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{name}-$KernelVer.conf
        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Flavour" != "zfcpdump" -a "$Flavour" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/whitelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/whitelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/whitelists/kabi-current/kabi_whitelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Flavour:+.${Flavour}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Flavour" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/whitelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/whitelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/whitelists/kabi-current/kabi_whitelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py
    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h

    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'
%if %{with_realtime}
    collect_modules_list kvm \
      'kvm_init|kvmgt_init'
%endif

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Identify modules in the kernel-modules-extras package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE16}
    # Identify modules in the kernel-modules-internal package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE44} internal
%if %{with_realtime}
    # Identify modules in the kernel-rt-kvm package
    %{SOURCE17} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE400} kvm
%endif

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if %{with_realtime}
    # don't include anything going into kernel-rt-kvm in the file lists
    xargs rm -rf < mod-kvm.list
%endif

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	cp $RPM_SOURCE_DIR/filter-*.sh .
	%{SOURCE99} modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    cp -r restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../%{name}${Flavour:+-${Flavour}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../%{name}${Flavour:+-${Flavour}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../%{name}${Flavour:+-${Flavour}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../%{name}${Flavour:+-${Flavour}}-modules-extra.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-internal.list >> ../%{name}${Flavour:+-${Flavour}}-modules-internal.list
%if %{with_realtime}
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-kvm.list >> ../%{name}${Flavour:+-${Flavour}}-kvm.list
%endif

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if %{with_realtime}
    rm -f $RPM_BUILD_ROOT/mod-kvm.list
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
	# Save the signing keys so we can sign the modules in __modsign_install_post
	cp certs/signing_key.pem certs/signing_key.pem.sign${Flav}
	cp certs/signing_key.x509 certs/signing_key.x509.sign${Flav}
    fi
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;

    # build a BLS config for this kernel
    %{SOURCE43} "$KernelVer" "$RPM_BUILD_ROOT" "%{?variant}"

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
    install -m 0644 %{secureboot_ca} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ $DoModules -eq 1 ]; then
	if [ -x /usr/bin/rpm-sign ]; then
	    install -m 0644 %{secureboot_key} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	else
	    install -m 0644 certs/signing_key.x509.sign${Flav} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
	    openssl x509 -in certs/signing_key.pem.sign${Flav} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	    chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
	fi
    fi
    %endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Flavour" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{with_vdso_install} debug
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{with_vdso_install} zfcpdump
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{with_vdso_install}
%endif

%global perf_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%global tools_make \
  %{make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" V=1

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
%endif #turbostat/x86_energy_perf_policy
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
%endif

%global bpftool_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT V=1
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} headers_install
%{make} -s ARCH=$Arch V=1 samples/bpf/
pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} -s ARCH=$Arch V=1 TARGETS="bpf net" INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests install
%{make} -s ARCH=$Arch V=1 TARGETS="bpf livepatch net" INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests install
popd
%endif

%if %{with_doc}
# Make the HTML pages.
make htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump flavour as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_debug}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | %{SOURCE80} %{?_smp_mflags}; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

%endif # with_doc

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

%endif

%if %{with_cross_headers}
HDR_ARCH_LIST='arm64 powerpc s390 x86'
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers
%{make} ARCH=%{hdrarch} HDR_ARCH_LIST="$HDR_ARCH_LIST" INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers headers_install_all

find $RPM_BUILD_ROOT/usr/tmp-headers/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
mv $RPM_BUILD_ROOT/usr/tmp-headers/include/arch-${arch}/asm $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-generic $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

# Remove the rest of the architectures
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/arch*
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-*

# Copy the rest of the headers over
for arch in $HDR_ARCH_LIST ; do
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_whitelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
%endif  # with_kernel_abi_whitelists

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin install-traceevent-plugins
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/examples/perf
# remove the stray header file that somehow got packaged in examples
rm -rf %{buildroot}/usr/lib/include/perf/bpf/bpf.h

# remove perf-bpf examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
%endif #turbostat/x86_energy_perf_policy
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/kvm/kvm_stat
make INSTALL_ROOT=%{buildroot} install-tools
make INSTALL_ROOT=%{buildroot} install-man
popd
%endif

%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
%endif

# We have to do the headers checksum calculation after the tools install because
# these might end up installing their own set of headers on top of kernel's
%if %{with_headers}
# compute a content hash to export as Provides: kernel-headers-checksum
HEADERS_CHKSUM=$(export LC_ALL=C; find $RPM_BUILD_ROOT/usr/include -type f -name "*.h" \
			! -path $RPM_BUILD_ROOT/usr/include/linux/version.h | \
		 sort | xargs cat | sha1sum - | cut -f 1 -d ' ');
# export the checksum via usr/include/linux/version.h, so the dynamic
# find-provides can grab the hash to update it accordingly
echo "#define KERNEL_HEADERS_CHECKSUM \"$HEADERS_CHKSUM\"" >> $RPM_BUILD_ROOT/usr/include/linux/version.h
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%if %{with_tools}
%post -n %{name}-tools-libs
/sbin/ldconfig

%postun -n %{name}-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f\
     done)\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1:%{1}-}core}\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
/bin/kernel-install add %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1:%{1}-}core}\
/bin/kernel-install remove %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
%{nil}

%kernel_variant_preun
%kernel_variant_post -r kernel-smp
%if %{with_realtime}
%kernel_kvm_post
%endif

%kernel_variant_preun debug
%kernel_variant_post -v debug
%if %{with_realtime}
%kernel_kvm_post debug
%endif

%if %{with_zfcpdump}
%kernel_variant_preun zfcpdump
%kernel_variant_post -v zfcpdump
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_cross_headers}
%files cross-headers
%defattr(-,root,root)
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_whitelists}
%files -n kernel-abi-whitelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/*
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%defattr(-,root,root)
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%defattr(-,root,root)
%endif
%endif # with_perf

%if %{with_tools}
%ifarch %{cpupowerarchs}
%defattr(-,root,root)
%files -n %{name}-tools -f cpupower.lang
%{_bindir}/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%endif
%else # !cpupowerarchs
%files -n %{name}-tools
%defattr(-,root,root)
%endif # cpupowerarchs
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat

%if %{with_debuginfo}
%files -f %{name}-tools-debuginfo.list -n %{name}-tools-debuginfo
%defattr(-,root,root)
%endif

%ifarch %{cpupowerarchs}
%files -n %{name}-tools-libs
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.1

%files -n %{name}-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif
%endif # with_tools

%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man7/bpf-helpers.7.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%ifnarch %nobuildarches noarch
%files
%defattr(-,root,root)
%endif

%if %{with_gcov}
%ifarch x86_64 s390x ppc64le aarch64
%files gcov
%defattr(-,root,root)
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage> <without_modules>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files -f %{name}-%{?3:%{3}-}core.list %{?3:%{3}-}core}\
%defattr(-,root,root)\
%{!?_licensedir:%global license %%doc}\
%license linux-%{KVERREL}/COPYING-%{version}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/bls.conf\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}/kernel-signing-ca.cer\
%ifarch s390x ppc64le\
%if 0%{!?4:1}\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}/%{signing_key_filename} \
%endif\
%endif\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
/etc/ld.so.conf.d/%{name}-%{KVERREL}%{?3:+%{3}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.*\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%defattr(-,root,root)\
%{expand:%%files %{?3:%{3}-}devel}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%defattr(-,root,root)\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-internal.list %{?3:%{3}-}modules-internal}\
%if %{with_realtime}\
%{expand:%%files -f %{name}-%{?3:%{3}-}kvm.list %{?3:%{3}-}kvm}\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%defattr(-,root,root)\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%defattr(-,root,root)\
%endif\
%endif\
%{nil}

%kernel_variant_files  %{with_vdso_install} %{with_up}
%kernel_variant_files  %{with_vdso_install} %{with_debug} debug
%if %{with_zfcpdump}
%kernel_variant_files  %{with_vdso_install} %{with_zfcpdump} zfcpdump 1
%endif

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Sun Dec 15 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-167.rt13.24.el8]
- [tools] libbpf: Refactor relocation handling (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix call relocation offset calculation bug (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix bpf_object name determination for bpf_object__open_file() (Yauheni Kaliuta) [1772081]
- [tools] libbpf: return previous print callback from libbpf_set_print (Yauheni Kaliuta) [1772081]
- [tools] libbpf: fix bpf_object__name() to actually return object name (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Make CO-RE reloc test impartial to test_progs flavor (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Add BPF_CORE_READ and BPF_CORE_READ_STR_INTO macro tests (Yauheni Kaliuta) [1772081]
- [tools] bpftool: Allow to read btf as raw data (Yauheni Kaliuta) [1772081]
- [tools] bpftool: implement "bpftool btf show|list" (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add bpf_btf_get_next_id() to cycle through BTF objects (Jiri Olsa) [1772081]
- [tools] libbpf: refactor bpf_*_get_next_id() functions (Yauheni Kaliuta) [1772081]
- [tools] bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1772081]
- [tools] libbpf: attempt to load kernel BTF from sysfs first (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add getter for program size (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add bpf_get_link_xdp_info() function to get more XDP information (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Use pr_warn() when printing netlink errors (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Propagate EPERM to caller on program load (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Unpin auto-pinned maps if loading fails (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add auto-pinning of maps when loading BPF objects (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Teach bpf_object__open to guess program types (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add bpf_program__get_{type, expected_attach_type) APIs (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Move directory creation into _pin() functions (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Store map pin path and status in struct bpf_map (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix error handling in bpf_map__reuse_fd() (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Make DECLARE_LIBBPF_OPTS macro strictly a variable declaration (Yauheni Kaliuta) [1772081]
- [tools] bpftool: Fix bpftool build by switching to bpf_object__open_file() (Yauheni Kaliuta) [1772081]
- [tools] bpf: Rename pr_warning to pr_warn to align with kernel logging (Yauheni Kaliuta) [1772081]
- [tools] libbpf: provide more helpful message on uninitialized global var (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Add field existence CO-RE relocs tests (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add support for field existance CO-RE relocation (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Update BTF reloc support to latest Clang format (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Add BPF_CORE_READ/BPF_CORE_READ_INTO helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Refactor bpf_object__open APIs to use common opts (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Move bpf_{helpers, helper_defs, endian, tracing}.h into libbpf (Jiri Olsa) [1772081]
- [tools] uapi/bpf: fix helper docs (Yauheni Kaliuta) [1772081]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1772081]
- [uapi] bpf: fix 'struct pt_reg' typo in documentation (Yauheni Kaliuta) [1772081]
- [tools] libbpf: Fix BTF-defined map's __type macro handling of arrays (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Print an error when known types list needs updating (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Emit an #error directive known types list needs updating (Yauheni Kaliuta) [1772081]
- [scripts] bpf: Fix xdp_md forward declaration typo (Yauheni Kaliuta) [1772081]
- [scripts] bpf: teach bpf_helpers_doc.py to dump BPF helper definitions (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Split off tracing-only helpers into bpf_tracing.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: samples/bpf: Split off legacy stuff from bpf_helpers.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Undo GCC-specific bpf_helpers.h changes (Yauheni Kaliuta) [1772081]
- [tools] libbpf: auto-generate list of BPF helper definitions (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add bpf-gcc support (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: bpf_tcp_gen_syncookie->bpf_helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: relicense bpf_helpers.h and bpf_endian.h (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: introduce bpf_cpu_to_be64 and bpf_be64_to_cpu (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: Adjust CO-RE reloc tests for new bpf_core_read() macro (Yauheni Kaliuta) [1772081]
- [tools] bpf: fix core_reloc.c compilation error (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add bpf_object__open_{file, mem} w/ extensible opts (Yauheni Kaliuta) [1772081]
- [tools] libbpf: make libbpf.map source of truth for libbpf version (Yauheni Kaliuta) [1772081]
- [tools] libbpf: stop enforcing kern_version, populate it for users (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs misc tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs ints tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs ptr-as-array tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs modifiers/typedef tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs enum/ptr/func_proto tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs array tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs nesting tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs struct flavors tests (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add CO-RE relocs testing setup (Yauheni Kaliuta) [1772081]
- [tools] selftests/bpf: add BPF_CORE_READ relocatable read macro (Yauheni Kaliuta) [1772081]
- [tools] libbpf: implement BPF CO-RE offset relocation algorithm (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add .BTF.ext offset relocation section loading (Yauheni Kaliuta) [1772081]
- [tools] libbpf: convert libbpf code to use new btf helpers (Yauheni Kaliuta) [1772081]
- [tools] libbpf: add helpers for working with BTF types (Yauheni Kaliuta) [1772081]
- [gpu] drm/i915: Add new CNL PCH ID seen on a CML platform (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: register gpu instance before fan boost feature enablment (Lyude Paul) [1771779]
- [gpu] drm/amd/swsmu: fix smu workload bit map error (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: dont schedule jobs while in reset (Lyude Paul) [1771779]
- [gpu] drm/i915/userptr: Try to acquire the page lock around set_page_dirty() (Lyude Paul) [1771779]
- [gpu] drm/i915/pmu: "Frequency" is reported as accumulated cycles (Lyude Paul) [1771779]
- [gpu] drm/i915: Don't oops in dumb_create ioctl if we have no crtcs (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on unsupported ASICs (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: disable gfxoff on original raven (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: disable gfxoff when using register read interface (Lyude Paul) [1771779]
- [gpu] revert "drm/i915/ehl: Update MOCS table for EHL" (Lyude Paul) [1771779]
- [gpu] drm/i915: update rawclk also on resume (Lyude Paul) [1771779]
- [gpu] dc.c:use kzalloc without test (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Passive DP->HDMI dongle detection fix (Lyude Paul) [1771779]
- [gpu] drm/amd/display: add 50us buffer as WA for pstate switch in active (Lyude Paul) [1771779]
- [gpu] drm/amd/display: do not synchronize "drr" displays (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: If amdgpu_ib_schedule fails return back the error (Lyude Paul) [1771779]
- [gpu] drm/sched: Set error to s_fence if HW job submission failed (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (Lyude Paul) [1771779]
- [gpu] drm/radeon: fix si_enable_smc_cac() failed issue (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix error handling in amdgpu_bo_list_create (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix potential VM faults (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix SDMA hang when performing VKexample test (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/powerplay/vega10: allow undervolting in p7 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/gfx10: update gfx golden settings (Lyude Paul) [1771779]
- [gpu] drm/i915: Fix PCH reference clock for FDI on HSW/BDW (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix memory leak (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: user pages array memory leak fix (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/uvd7: fix allocation size in enc ring test (v2) (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/uvd6: fix allocation size in enc ring test (v2) (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/vcn: fix allocation size in enc ring test (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/vce: fix allocation size in enc ring test (Lyude Paul) [1771779]
- [gpu] drm/i915: Favor last VBT child device with conflicting AUX ch/DDC pin (Lyude Paul) [1771779]
- [gpu] drm/i915/userptr: Never allow userptr into the mappable GGTT (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for pipe sync (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not set to 1 (Lyude Paul) [1771779]
- [gpu] drm/ttm: Restore ttm prefaulting (Lyude Paul) [1771779]
- [gpu] drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50 (Lyude Paul) [1771779]
- [gpu] drm/amd/display: memory leak (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: fix multiple memory leaks in acp_hw_init (Lyude Paul) [1771779]
- [gpu] drm: Clear the fence pointer when writeback job signaled (Lyude Paul) [1771779]
- [gpu] drm: Free the writeback_job when it with an empty fb (Lyude Paul) [1771779]
- [gpu] drm/i915: Mark contents as dirty on a write fault (Lyude Paul) [1771779]
- [gpu] drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (Lyude Paul) [1771779]
- [gpu] drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled (Lyude Paul) [1771779]
- [gpu] drm/i915: Perform GGTT restore much earlier during resume (Lyude Paul) [1771779]
- [gpu] drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Check for valid number of registers to read (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix KFD-related kernel oops on Hawaii (Lyude Paul) [1771779]
- [gpu] drm/i915: to make vgpu ppgtt notificaiton as atomic operation (Lyude Paul) [1771779]
- [gpu] drm/i915/gvt: update vgpu workload head pointer correctly (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay: change metrics update period from 1ms to 100ms (Lyude Paul) [1771779]
- [gpu] drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors (Lyude Paul) [1771779]
- [gpu] drm/atomic: Take the atomic toys away from X (Lyude Paul) [1771779]
- [gpu] drm/atomic: Reject FLIP_ASYNC unconditionally (Lyude Paul) [1771779]
- [gpu] drm/i915/dp: Fix dsc bpp calculations, v5 (Lyude Paul) [1771779]
- [dma-buf] sw_sync: Synchronize signal vs syncpt free (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/si: fix ASIC tests (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix trigger not generated for freesync (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix MPO HUBP underflow with Scatter Gather (Lyude Paul) [1771779]
- [gpu] drm/amd/powerpaly: fix navi series custom peak level value error (Lyude Paul) [1771779]
- [gpu] drm/amd/display: support spdif (Lyude Paul) [1771779]
- [gpu] drm/nouveau/volt: Fix for some cards having 0 maximum voltage (Lyude Paul) [1771779]
- [gpu] drm/nouveau/kms/tu102-: disable input lut when input is already FP16 (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2 (Lyude Paul) [1771779]
- [gpu] drm/amd/display: reprogram VM config when system resume (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Fix frames_to_insert math (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix issue where 252-255 values are clipped (Lyude Paul) [1771779]
- [gpu] drm: radeon: Fix a possible null-pointer dereference in radeon_connector_set_property() (Lyude Paul) [1771779]
- [gpu] revert "drm/radeon: Fix EEH during kexec" (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Use proper enum conversion functions (Lyude Paul) [1771779]
- [gpu] drm/amdgpu: Fix hard hang for S/G display BOs (Lyude Paul) [1771779]
- [gpu] drm/panel: check failure cases in the probe func (Lyude Paul) [1771779]
- [gpu] drm/bridge: sii902x: fix missing reference to mclk clock (Lyude Paul) [1771779]
- [gpu] drm/tinydrm/kconfig: Select BACKLIGHT_CLASS_DEVICE (Lyude Paul) [1771779]
- [video] ssd1307fb: Start page range at page_offset (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Copy GSL groups when committing a new context (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Clear FEC_READY shadow register if DPCD write fails (Lyude Paul) [1771779]
- [gpu] drm/amd/display: fix not calling ppsmu to trigger PME (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Power-gate all DSCs at driver init time (Lyude Paul) [1771779]
- [gpu] drm/amd/display: add monitor patch to add T7 delay (Lyude Paul) [1771779]
- [gpu] drm/panel: simple: fix AUO g185han01 horizontal blanking (Lyude Paul) [1771779]
- [gpu] drm/vkms: Avoid assigning 0 for possible_crtc (Lyude Paul) [1771779]
- [gpu] drm/bridge: tc358767: Increase AUX transfer length limit (Lyude Paul) [1771779]
- [gpu] drm/vkms: Fix crc worker races (Lyude Paul) [1771779]
- [gpu] drm/amdgpu/display: fix 64 bit divide (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Add missing HBM support and raise Vega20's uclk (Lyude Paul) [1771779]
- [gpu] drm/amd/display: dce11.x /dce12 update formula input (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Restore backlight brightness after system resume (Lyude Paul) [1771779]
- [gpu] drm: fix module name in edid_firmware log message (Lyude Paul) [1771779]
- [gpu] drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2) (Lyude Paul) [1771779]
- [gpu] drm/amd/display: readd -msse2 to prevent Clang from emitting libcalls to undefined SW FP routines (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Don't replace the dc_state for fast updates (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Skip determining update type for async updates (Lyude Paul) [1771779]
- [gpu] drm/amd/display: Allow cursor async updates for framebuffer swaps (Lyude Paul) [1771779]
- [include] sk_buff: fix skb_ext_put() and skb_ext_reset() calls (Ivan Vecera) [1779923]
- [net] openvswitch: fix flow command message size (Paolo Abeni) [1776765]
- [net] netfilter: nf_tables: add SECMARK support (Phil Sutter) [1715851]
- [net] netfilter: nf_tables: add requirements for connsecmark support (Phil Sutter) [1715851]
- [wireless] mwifiex: pcie: Fix memory leak in mwifiex_pcie_init_evt_ring (Jarod Wilson) [1781534] {CVE-2019-19057}
- [tools] selftests/powerpc: Disable basic EEH selftest (Steve Best) [1782232]
- [x86] kvm: x86: Remove a spurious export of a static function (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: vmx: use MSR_IA32_TSX_CTRL to hard-disable TSX on guest that lack it (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: vmx: implement MSR_IA32_TSX_CTRL disable RTM functionality (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: implement MSR_IA32_TSX_CTRL effect on CPUID (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: do not modify masked bits of shared MSRs (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm: x86: fix presentation of TSX feature in ARCH_CAPABILITIES (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [x86] kvm/x86: Export MDS_NO=0 to guests when TSX is enabled (Paolo Bonzini) [1779553] {CVE-2019-19338}
- [fs] cifs: Close open handle after interrupted close (Leif Sahlberg) [1771691]
- [fs] cifs: Do not miss cancelled OPEN responses (Leif Sahlberg) [1771691]
- [fs] cifs: Fix NULL pointer dereference in mid callback (Leif Sahlberg) [1771691]
- [fs] cifs: add a debug macro that prints \\server\share for errors (Leif Sahlberg) [1772630]
- [fs] cifs: add new debugging macro cifs_server_dbg (Leif Sahlberg) [1772630]

* Sat Dec 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-166.rt13.23.el8]
- [netdrv] wireless: fix nl80211 vendor commands (Jarod Wilson) [1776606]
- [net] nl80211: fix VENDOR_CMD_RAW_DATA (Jarod Wilson) [1776606]
- [netdrv] rt2x00: initialize last_reset (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't consider IV len in A-MSDU (Jarod Wilson) [1776606]
- [net] mac80211: fix station inactive_time shortly after boot (Jarod Wilson) [1776606]
- [net] mac80211: fix ieee80211_txq_setup_flows() failure path (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: support new API for scan config cmd (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: fix buffer unmap with non-linear skbs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2e: disable pcie_aspm by default (Jarod Wilson) [1776606]
- [net] nl80211: fix validation of mesh path nexthop (Jarod Wilson) [1776606]
- [net] nl80211: Disallow setting of HT for channel 14 (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Fix problem of too small skb->len (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: add workaround for power gating in integrated 22000 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: handle iwl_mvm_tvqm_enable_txq() error return (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix all 9460 entries for qnj (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: Fix potential overflow on P2P code (Jarod Wilson) [1775223 1776606] {CVE-2019-17666}
- [netdrv] iwlwifi: pcie: fix merge damage on making QnJ exclusive (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix latency issue for QCA988x (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: change qu with jf devices to use qu configuration (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: exclude GEO SAR support for 3168 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix memory leaks in iwl_pcie_ctxt_info_gen3_init (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix memory leak in alloc_sgtable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix rb_allocator workqueue allocation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix indexing in command dump for new HW (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix race in sync rx queue notification (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: force single phy init (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix ACPI table revision checks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't access trans_cfg via cfg (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove input-polldev.h header (Jarod Wilson) [1776606]
- [net] mac80211: Don't access sk_queue_head->next directly (Jarod Wilson) [1776606]
- [net] mac80211: fix scan when operating on DFS channels in ETSI domains (Jarod Wilson) [1776606]
- [net] mac80211: accept deauth frames in IBSS mode (Jarod Wilson) [1776606]
- [net] cfg80211: fix a bunch of RCU issues in multi-bssid code (Jarod Wilson) [1776606]
- [net] nl80211: fix memory leak in nl80211_get_ftm_responder_stats (Jarod Wilson) [1776606]
- [net] cfg80211: wext: avoid copying malformed SSIDs (Jarod Wilson) [1778634 1776606] {CVE-2019-17133}
- [net] mac80211: Reject malformed SSID elements (Jarod Wilson) [1776606]
- [net] mac80211: keep BHs disabled while calling drv_tx_wake_queue() (Jarod Wilson) [1776606]
- [net] mac80211: fix txq null pointer dereference (Jarod Wilson) [1776606]
- [net] nl80211: fix null pointer dereference (Jarod Wilson) [1776606]
- [net] cfg80211: initialize on-stack chandefs (Jarod Wilson) [1776606]
- [net] cfg80211: validate SSID/MBSSID element ordering assumption (Jarod Wilson) [1776606]
- [net] nl80211: validate beacon head (Jarod Wilson) [1776606]
- [net] cfg80211: Purge frame registrations on iftype change (Jarod Wilson) [1776606]
- [net] cfg80211: Do not compare with boolean in nl80211_common_reg_change_event (Jarod Wilson) [1776606]
- [net] cfg80211: always shut down on HW rfkill (Jarod Wilson) [1776606]
- [net] cfg80211: fix boundary value in ieee80211_frequency_to_channel() (Jarod Wilson) [1776606]
- [net] cfg80211: add local BSS receive time to survey information (Jarod Wilson) [1776606]
- [net] nl80211: add NL80211_CMD_UPDATE_FT_IES to supported commands (Jarod Wilson) [1776606]
- [netdrv] wireless: Fix Kconfig indentation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW version 36 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix mt7615 firmware path definitions (Jarod Wilson) [1776606]
- [netdrv] rtw88: configure firmware after HCI started (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: release tx skbs DMAed when stop (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: extract skbs free routine for trx rings (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix build w/o CONFIG_THERMAL (Jarod Wilson) [1776606]
- [netdrv] rtw88: report RX power for each antenna (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix wrong rx power calculation (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192de: replace _rtl92d_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: replace _rtl92c_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: replace _rtl92c_evm_db_to_percentage with generic version (Jarod Wilson) [1776606]
- [netdrv] rtw88: allows to receive AMSDU in AMPDU (Jarod Wilson) [1776606]
- [netdrv] rtw88: add dynamic cck pd mechanism (Jarod Wilson) [1776606]
- [netdrv] rtw88: move IQK/DPK into phy_calibration (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add SW DPK support (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add FW IQK support (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: Enable interrupt migration (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update pwr_seq to v13 (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update PHY parameter to v38 (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: rtl8192ce: rtl8192de: rtl8723ae: rtl8821ae: Remove some unused bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723be: Remove unused SET_XXX and GET_XXX macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8723ae: Remove unused GET_XXX and SET_XXX macros (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: Use DIV_ROUND_CLOSEST directly to make it readable (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: make array static const and remove redundant assignment (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: don't realloc wiphy during PCIe reset (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: split brcmf_attach() and brcmf_detach() functions (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: move "cfg80211_ops" pointer to another struct (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix channel info parsing for non tlv target (Jarod Wilson) [1776606]
- [netdrv] ath10k: adjust skb length in ath10k_sdio_mbox_rx_packet (Jarod Wilson) [1776606]
- [netdrv] ath10k: free beacon buf later in vdev teardown (Jarod Wilson) [1776606]
- [net] mac80211: allow drivers to set max MTU (Jarod Wilson) [1776606]
- [net] mac80211: ibss: send deauth when expiring inactive STAs (Jarod Wilson) [1776606]
- [net] mac80211: don't check if key is NULL in ieee80211_key_link() (Jarod Wilson) [1776606]
- [net] mac80211: clear crypto tx tailroom counter upon keys enable (Jarod Wilson) [1776606]
- [net] mac80211: remove unnecessary key condition (Jarod Wilson) [1776606]
- [net] mac80211: list features in WEP/TKIP disable in better order (Jarod Wilson) [1776606]
- [net] mac80211: vht: add support VHT EXT NSS BW in parsing VHT (Jarod Wilson) [1776606]
- [netdrv] ath9k: release allocated buffer if timed out (Jarod Wilson) [1778582 1776606] {CVE-2019-19074}
- [netdrv] ath9k_htc: release allocated buffer if timed out (Jarod Wilson) [1778572 1776606] {CVE-2019-19073}
- [netdrv] ath9k: Remove unneeded variable to store return value (Jarod Wilson) [1776606]
- [netdrv] ath10k: add reorder and change PN check logic for mac80211 (Jarod Wilson) [1776606]
- [netdrv] ath10k: add mic bytes for pmf management packet (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use *ph to print small buffer (Jarod Wilson) [1776606]
- [netdrv] hostap: use *ph to print small buffer (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: Fix file release memory leak (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix seq_file memory leak (Jarod Wilson) [1776606]
- [netdrv] hostap: remove set but not used variable 'copied' in prism2_io_debug_proc_read (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add "reset" debugfs entry for testing reset (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add stub version of brcmf_debugfs_get_devdir() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: remove iwl_fw_cancel_dumps function (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove periodic trigger (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix dump structs doc (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: add DRAM buffer allocation command (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove apply point, switch to time point API (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add iwl_tlv_array_len() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: don't log un-decrypted frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add support for single antenna diversity (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: handle BAR_FRAME_RELEASE (0xc2) notification (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: drop BA sessions on too many old-SN frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add sta_id to WOWLAN_CONFIG_CMD (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add support for suspend-resume flow for new device generation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix warning iwl-trans.h is included more than once (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: always access the trans configuration via trans (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pass the iwl_trans instead of cfg to some functions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add a pointer to the trans_cfg directly in trans (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pass the iwl_config_trans_params when needed (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: set iwl_trans->cfg later in the probe function (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: move some cfg mangling from trans_pcie_alloc to probe (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: use the cfg we passed to iwl_trans_pcie_alloc() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: separate elements from cfg that are needed by trans_alloc (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use regions ops array instead of switch case in dump flow (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: make a single ops struct for paging collect (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move tx fifo data into fw runtime (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use linked list for dump TLVs during dump creation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: separate cfg and dump flows to different modules (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: look for the first supported channel when add/remove phy ctxt (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: allocate bigger nvm data in case of UHB (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove unnecessary IWL_DEVICE_AX200_COMMON definition (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: align wrt log prints to the same format (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove debug flow TLV (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: verify debug TLVs at allocation phase (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use function to check if ini dbg mode is on (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove duplicate FW string definitions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: bump FW API to 50 for 22000 series (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: api: fix FTM struct documentation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: support per-platform antenna gain (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove check for lq_sta in __iwl_mvm_rs_tx_status() (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: simplify the channel switch flow for newer firmware (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: stop passing bogus gfp flags arguments to dma_alloc_coherent (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove periphery phy and aux regions handling (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use linked list to store debug TLVs (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: maintain buffer allocations from trans instead of TLVs buffer (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: add debug periphery registers to 9000 device family (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove unused regdb_ptrs allocation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: align dbg tlv functions names to a single format (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: scan: don't pass large argument by value (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove pm_runtime completely (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the d0i3 related module parameters (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: remove some more d0i3 code from the transport (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: remove the refs / unrefs from the transport (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the opmode's d0i3 handlers (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove runtime_pm_mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Set w-pointer upon resume according to SN (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: use FW thermal monitoring regardless of CONFIG_THERMAL (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: name magic numbers with enum (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: scan: add support for new scan request command version (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: LTR updates (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove the code under IWLWIFI_PCIE_RTPM (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: trans: remove suspending flag (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove CMD_HIGH_PRIO (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove last leftovers of d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove iwl_mvm_update_d0i3_power_mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove d0i3_ap_sta_id (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: iwl_mvm_wowlan_config_key_params is for wowlan only (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove the d0i3 entry/exit flow (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove the tx defer for d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove all the d0i3 references (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: start to remove the code for d0i3 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add the skb length to a print (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix scan config command size (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add ldbg config cmd debug print (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: support debug recording suspend resume command (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move debug recording stop from trans to op mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move monitor recording functionality from header file (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove unnecessary forward declarations (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Block 26-tone RU OFDMA transmissions (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove redundant condition in iwl_mvm_set_hw_rfkill_state (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Send DQA enable command only if TVL is on (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: bump FW API to 49 for 22000 series (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support to read temperature from mcu (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_txwi_to_txp utility routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use devm_platform_ioremap_resource() to simplify code (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: remove unneeded return value on set channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: remove redundant chandef copy (Jarod Wilson) [1776606]
- [netdrv] mt76: make mt76_rx_convert static (Jarod Wilson) [1776606]
- [netdrv] mt76: remove offchannel check in tx scheduling (Jarod Wilson) [1776606]
- [netdrv] mt76: do not send BAR frame on tx aggregation flush stop (Jarod Wilson) [1776606]
- [netdrv] mt76: stop rx aggregation on station removal (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: reset q->rx_head on rx reset (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: apply calibration-free data from OTP (Jarod Wilson) [1776606]
- [netdrv] mt76: add default implementation for mt76_sw_scan/mt76_sw_scan_complete (Jarod Wilson) [1776606]
- [netdrv] mt76: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add BIP_CMAC_128 cipher support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: remove unnecessary mcu queue initialization (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_tx_tasklet in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: enable survey support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: move survey_time in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: enable survey support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: enable multi-vif support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: do not copy beacon skb in mt76x02_mac_set_beacon_enable (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: introduce mt76x02_pre_tbtt_enable and mt76x02_beacon_enable macros (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add Smart Carrier Sense support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rework locking scheme for mt7615_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: switch to SPDX tag instead of verbose boilerplate text (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix some checkpatch warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: Add paragraphs to describe the config symbols fully (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: update cw_min/max related settings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add 4 WMM sets support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix watchdog rescheduling in mt7603_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix MT7615_WATCHDOG_TIME definition (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_mmio_read_copy routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add set_key_cmd and mt76_wcid to mt7615_mac_wtbl_set_key signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove wtbl_sec_key definition (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_mac_wtbl_set_key routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add mt7615_mac_wtbl_addr routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: move mt7615_mac_get_key_info in mac.c (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add missing register initialization (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0u: add support to TP-Link T2UHP (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: remove unneeded {put,get}_unaligned (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: fix endian in mt76u_copy (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix invalid fallback rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix invalid fallback rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix PS buffering of action frames (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix using VHT STBC rates (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: fix typo in mt76u_fill_rx_sg (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: sync with mt7603 rate control changes (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: reset rate index/counters on rate table update (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: move mt7615_mcu_set_rates to mac.c (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: enable hardware rate up/down selection (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_mcu_send_ram_firmware routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: always release sem in mt7615_load_patch (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fall back to sw encryption for unsupported ciphers (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: clean up FWDL TXQ during/after firmware upload (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add radar pattern test knob to debugfs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add csa support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: do not perform txcalibration before cac is complited (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add hw dfs pattern detector support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: introduce mt7615_regd_notifier (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: warning: restricted __le16 degrades to integer (Jarod Wilson) [1776606]
- [netdrv] mt76: round up length on mt76_wr_copy (Jarod Wilson) [1776606]
- [netdrv] ath6kl: fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe() (Jarod Wilson) [1776606]
- [netdrv] ath6kl: Fix a possible null-pointer dereference in ath6kl_htc_mbox_create() (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: set ackto to max timeout in ath_dynack_reset (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: set max timeout according to channel width (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: properly set last timeout timestamp in ath_dynack_reset (Jarod Wilson) [1776606]
- [netdrv] ath9k: dyanck: introduce ath_dynack_set_timeout routine (Jarod Wilson) [1776606]
- [netdrv] ath9k: dynack: fix possible deadlock in ath_dynack_node_{de}init (Jarod Wilson) [1776606]
- [netdrv] ath9k: add loader for AR92XX (and older) pci(e) (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: get chip's default RAM info during PCIe setup (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: replace strncpy() by strscpy() (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not set IEEE80211_TX_STAT_AMPDU_NO_BACK on tx status (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove redundant assignment to pointer hash (Jarod Wilson) [1776606]
- [netdrv] brcm80211: Avoid possible null-pointer dereferences in wlc_phy_radio_init_2056() (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: enable MSI interrupt (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Move a mass of jobs in hw IRQ to soft IRQ (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove redundant assignment to pointer debugfs_topdir (Jarod Wilson) [1776606]
- [netdrv] rtw88: drop unused rtw_coex_coex_dm_reset() (Jarod Wilson) [1776606]
- [netdrv] rtw88: Fix an error message (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Fix incorrect returned values (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Remove some variable initializations (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ee: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Fix memory leak when hardware init fails (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove unused variables 'RTL8712_SDIO_EFUSE_TABLE' and 'MAX_PGPKT_SIZE' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: Fix value set in descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: fix non-kerneldoc comment in usb.c (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix infinite loop because supported is not being shifted (Jarod Wilson) [1776606]
- [netdrv] mt76: Remove dev_err() usage after platform_get_irq() (Jarod Wilson) [1776606]
- [net] mac80211: Do not send Layer 2 Update frame before authorization (Jarod Wilson) [1776606]
- [netdrv] revert "rt2800: enable TX_PIN_CFG_LNA_PE_ bits per band" (Jarod Wilson) [1776606]
- [netdrv] rt2x00: clear up IV's on key removal (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: assign directly to iwl_trans->cfg in QuZ detection (Jarod Wilson) [1776606]
- [netdrv] mwifiex: Fix three heap overflow at parsing element in cfg80211_ap_settings (Jarod Wilson) [1776244 1775484 1775475 1776606]
- [netdrv] mt76: mt76x0e: disable 5GHz band for MT7630E (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0e: don't use hw encryption for MT7630E (Jarod Wilson) [1776606]
- [net] nl80211: fill all policy .type entries (Jarod Wilson) [1776606]
- [net] cfg80211: Add support to set tx power for a station associated (Jarod Wilson) [1776606]
- [net] cfg80211: Fix Extended Key ID key install checks (Jarod Wilson) [1776606]
- [net] mac80211: AMPDU handling for rekeys with Extended Key ID (Jarod Wilson) [1776606]
- [net] mac80211: Simplify Extended Key ID API (Jarod Wilson) [1776606]
- [net] nl80211: require and validate vendor command policy (Jarod Wilson) [1776606]
- [net] mac80211: AMPDU handling for Extended Key ID (Jarod Wilson) [1776606]
- [net] mac80211: IEEE 802.11 Extended Key ID support (Jarod Wilson) [1776606]
- [net] nl80211/cfg80211: Extended Key ID support (Jarod Wilson) [1776606]
- [net] nl80211/cfg80211: Specify band specific min RSSI thresholds with sched scan (Jarod Wilson) [1776606]
- [net] cfg80211: Use const more consistently in for_each_element macros (Jarod Wilson) [1776606]
- [net] nl80211: use for_each_element() in validate_ie_attr() (Jarod Wilson) [1776606]
- [net] cfg80211: add peer measurement with FTM initiator API (Jarod Wilson) [1776606]
- [net] nl80211: use netlink policy validation function for elements (Jarod Wilson) [1776606]
- [net] nl80211: use policy range validation where applicable (Jarod Wilson) [1776606]
- [net] cfg80211: support FTM responder configuration/statistics (Jarod Wilson) [1776606]
- [net] lib80211: move TKIP handling to ARC4 library code (Jarod Wilson) [1776606]
- [net] lib80211: move WEP handling to ARC4 library code (Jarod Wilson) [1776606]
- [net] mac80211: move WEP handling to ARC4 library interface (Jarod Wilson) [1776606]
- [netdrv] rt2x00: clear IV's on start to fix AP mode regression (Jarod Wilson) [1776606]
- [netdrv] rt2800usb: Add new rt2800usb device PLANEX GW-USMicroN (Jarod Wilson) [1776606]
- [netdrv] rt2x00: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [netdrv] rt2x00usb: remove unnecessary rx flag checks (Jarod Wilson) [1776606]
- [netdrv] rt2x00usb: fix rx queue hang (Jarod Wilson) [1776606]
- [netdrv] rt2800: do not enable watchdog by default (Jarod Wilson) [1776606]
- [netdrv] rt2x00: add restart hw (Jarod Wilson) [1776606]
- [netdrv] rt2800: do not nullify initialization vector data (Jarod Wilson) [1776606]
- [netdrv] rt2800: add pre_reset_hw callback (Jarod Wilson) [1776606]
- [netdrv] rt2800: initial watchdog implementation (Jarod Wilson) [1776606]
- [netdrv] rt2800: add helpers for reading dma done index (Jarod Wilson) [1776606]
- [netdrv] rt2x00: allow to specify watchdog interval (Jarod Wilson) [1776606]
- [netdrv] rt2x00: add RT3883 support (Jarod Wilson) [1776606]
- [netdrv] rt2x00mmio: remove legacy comment (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove not used entry field (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove last_nostatus_check (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: use timer and work for handling tx statuses timeouts (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: fetch tx status changes (Jarod Wilson) [1776606]
- [netdrv] rt2800: move txstatus pending routine (Jarod Wilson) [1776606]
- [netdrv] rt2800: new flush implementation for SoC devices (Jarod Wilson) [1776606]
- [netdrv] rt2800: partially restore old mmio txstatus behaviour (Jarod Wilson) [1776606]
- [netdrv] rt2x00: code-style fix in rt2800usb.c (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not print error when queue is full (Jarod Wilson) [1776606]
- [netdrv] rt2x00: check number of EPROTO errors (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use ratelimited variants dev_warn/dev_err (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not increment sequence number while re-transmitting (Jarod Wilson) [1776606]
- [netdrv] rt2800: comment and simplify AGC init for RT6352 (Jarod Wilson) [1776606]
- [netdrv] rt2800: enable TX_PIN_CFG_RFRX_EN only for MT7620 (Jarod Wilson) [1776606]
- [netdrv] rt2800: enable TX_PIN_CFG_LNA_PE_ bits per band (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove confusing AGC register (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove unneeded check (Jarod Wilson) [1776606]
- [netdrv] rt2x00: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [netdrv] rt2x00: Work around a firmware bug with shared keys (Jarod Wilson) [1776606]
- [netdrv] rt2x00: reduce tx power to nominal level on RT6352 (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt61pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2800lib: mark expected switch fall-throughs (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2500pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2x00: rt2400pci: mark expected switch fall-through (Jarod Wilson) [1776606]
- [netdrv] rt2800: flush and txstatus rework for rt2800mmio (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use different txstatus timeouts when flushing (Jarod Wilson) [1776606]
- [netdrv] rt2x00: do not check for txstatus timeout every time on tasklet (Jarod Wilson) [1776606]
- [netdrv] rt2800mmio: use txdone/txstatus routines from lib (Jarod Wilson) [1776606]
- [netdrv] rt2800: move usb specific txdone/txstatus routines to rt2800lib (Jarod Wilson) [1776606]
- [netdrv] rt2x00: use simple_read_from_buffer() (Jarod Wilson) [1776606]
- [netdrv] rt2x00: remove redundant functions rt2x00mac_sta_{add/remove} (Jarod Wilson) [1776606]
- [net] mac80211: Correctly set noencrypt for PAE frames (Jarod Wilson) [1776606]
- [net] mac80211: Don't memset RXCB prior to PAE intercept (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: handle switching killer Qu B0 NICs to C0 (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: improve rate probing for devices with static fallback (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix default max throughput rate indexes (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: reduce unnecessary rate probing attempts (Jarod Wilson) [1776606]
- [net] mac80211: minstrel_ht: fix per-group max throughput rate initialization (Jarod Wilson) [1776606]
- [net] nl80211: Add support for EDMG channels (Jarod Wilson) [1776606]
- [net] mac80211: fix possible NULL pointerderef in obss pd code (Jarod Wilson) [1776606]
- [net] mac80211: add assoc-at support (Jarod Wilson) [1776606]
- [uapi] cfg80211: Support assoc-at timer in sta-info (Jarod Wilson) [1776606]
- [net] cfg80211: apply same mandatory rate flags for 5GHz and 6GHz (Jarod Wilson) [1776606]
- [net] cfg80211: ibss: use 11a mandatory rates for 6GHz band operation (Jarod Wilson) [1776606]
- [net] cfg80211: use same IR permissive rules for 6GHz band (Jarod Wilson) [1776606]
- [net] cfg80211: add 6GHz in code handling array with NUM_NL80211_BANDS entries (Jarod Wilson) [1776606]
- [net] cfg80211: extend ieee80211_operating_class_to_band() for 6GHz (Jarod Wilson) [1776606]
- [net] cfg80211: util: add 6GHz channel to freq conversion and vice versa (Jarod Wilson) [1776606]
- [net] cfg80211: add 6GHz UNII band definitions (Jarod Wilson) [1776606]
- [uapi] nl80211: add 6GHz band definition to enum nl80211_band (Jarod Wilson) [1776606]
- [net] revert "cfg80211: fix processing world regdomain when non modular" (Jarod Wilson) [1776606]
- [net] mac80211: add missing length field increment when generating Radiotap header (Jarod Wilson) [1776606]
- [net] mac80211: 80Mhz was not reported properly when using tx_status_ext (Jarod Wilson) [1776606]
- [net] mac80211: fix bad guard when reporting legacy rates (Jarod Wilson) [1776606]
- [net] mac80211: fix TX legacy rate reporting when tx_status_ext is used (Jarod Wilson) [1776606]
- [net] mac80211: fix possible sta leak (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix recognition of QuZ devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't switch FW to qnj when ax201 is detected (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix the byte count table format for 22560 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Allow multicast data frames only when associated (Jarod Wilson) [1776606]
- [netdrv] revert "mwifiex: fix system hang problem after resume" (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192ce: Remove unused GET_XXX and SET_XXX (Jarod Wilson) [1776606]
- [netdrv] rtw88: add BT co-existence support (Jarod Wilson) [1776606]
- [netdrv] rtw88: enclose c2h cmd handle with mutex (Jarod Wilson) [1776606]
- [netdrv] rtw88: allow c2h operation in irq context (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Remove local configuration variable (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl88188ee: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: Remove unused GET_XXX and SET_XXX descriptor macros (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: remove set but not used variable 'ip_sel' (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: remove three set but not used variables (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove set but not used variable 'dtim_period' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove unneeded function _rtl_dump_channel_map() (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl_pci: Use dev_get_drvdata (Jarod Wilson) [1776606]
- [netdrv] mwifiex: pcie: Use dev_get_drvdata (Jarod Wilson) [1776606]
- [netdrv] mwifiex: make error values consistent in mwifiex_update_bss_desc_with_ie() (Jarod Wilson) [1776606]
- [netdrv] rtw88: use txpwr_lmt_cfg_pair struct, not arrays (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix compile time assert build errors (Jarod Wilson) [1776606]
- [net] mac80211: HE STA disassoc due to QOS NULL not sent (Jarod Wilson) [1776606]
- [net] mac80211: allow setting spatial reuse parameters from bss_conf (Jarod Wilson) [1776606]
- [net] nl80211: add strict start type (Jarod Wilson) [1776606]
- [net] cfg80211: add support for parsing OBBS_PD attributes (Jarod Wilson) [1776606]
- [net] mac80211: reject zero MAC address in add station (Jarod Wilson) [1776606]
- [net] cfg80211: use parallel_ops for genl (Jarod Wilson) [1776606]
- [net] mac80211: add missing null return check from call to ieee80211_get_sband (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix a use-after-free bug in iwl_mvm_tx_tso_segment (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix an out-of-bound access (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't unmap as page memory that was mapped as single (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix version check for GEO_TX_POWER_LIMIT support (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add 3 new IDs for the 9000 series (iwl9260_2ac_160_cfg) (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix possible out-of-bounds read when accessing lq_info (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix frame drop from the reordering buffer (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: replace RS mutex with a spin_lock (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: send LQ command always ASYNC (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: fix comparison of u32 variable with less than zero (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix locking in delayed GTK setting (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of debugfs ifdef (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: move iwl_dbg_tlv_load_bin out of debug override ifdef (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a wrapper around rs_tx_status to handle locks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a loose synchronization of the NSSN across Rx queues (Jarod Wilson) [1776606]
- [netdrv] iwlwiif: mvm: refactor iwl_mvm_notify_rx_queue (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a new RSS sync notification for NSSN sync (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: prepare the ground for more RSS notifications (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: don't send GEO_TX_POWER_LIMIT on version < 41 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: avoid races in rate init and rate perform (Jarod Wilson) [1776606]
- [net] revert "mac80211: set NETIF_F_LLTX when using intermediate tx queues" (Jarod Wilson) [1776606]
- [net] mac80211: add support for the ADDBA extension element (Jarod Wilson) [1776606]
- [net] mac80211: propagate HE operation info into bss_conf (Jarod Wilson) [1776606]
- [net] cfg80211: fix dfs channels remain DFS_AVAILABLE after ch_switch (Jarod Wilson) [1776606]
- [net] cfg80211: fix duplicated scan entries after channel switch (Jarod Wilson) [1776606]
- [net] cfg80211: refactor cfg80211_bss_update (Jarod Wilson) [1776606]
- [net] mac80211: don't WARN on short WMM parameters from AP (Jarod Wilson) [1776606]
- [net] nl80211: Include wiphy address setup in NEW_WIPHY (Jarod Wilson) [1776606]
- [net] mac80211: implement HE support for mesh (Jarod Wilson) [1776606]
- [net] mac80211: add IEEE80211_KEY_FLAG_GENERATE_MMIE to ieee80211_key_flags (Jarod Wilson) [1776606]
- [kernel] mac80211: he: add Spatial Reuse element parsing support (Jarod Wilson) [1776606]
- [net] mac80211: add struct ieee80211_tx_status support to ieee80211_add_tx_radiotap_header (Jarod Wilson) [1776606]
- [net] {nl, mac}80211: fix interface combinations on crypto controlled devices (Jarod Wilson) [1776606]
- [net] mac80211: propagate struct ieee80211_tx_status into ieee80211_tx_monitor() (Jarod Wilson) [1776606]
- [net] mac80211: add xmit rate to struct ieee80211_tx_status (Jarod Wilson) [1776606]
- [kernel] mac80211: add support for parsing ADDBA_EXT IEs (Jarod Wilson) [1776606]
- [net] cfg80211: give all multi-BSSID BSS entries the same timestamp (Jarod Wilson) [1776606]
- [net] cfg80211: don't parse MBSSID if transmitting BSS isn't created (Jarod Wilson) [1776606]
- [net] cfg80211: clean up cfg80211_inform_single_bss_frame_data() (Jarod Wilson) [1776606]
- [net] cfg80211: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: add tx dequeue function for process context (Jarod Wilson) [1776606]
- [net] mac80211: run late dequeue late tx handlers without holding fq->lock (Jarod Wilson) [1776606]
- [net] lib80211: use crypto API ccm(aes) transform for CCMP processing (Jarod Wilson) [1776606]
- [net] mac80211: remove unused and unneeded remove_sta_debugfs callback (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove unused .remove_sta_debugfs callback (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dvm: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: pass the vif to cancel_remain_on_channel (Jarod Wilson) [1776606]
- [netdrv] mwifiex: use eth_broadcast_addr() to assign broadcast address (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove assignment to itself (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: don't net_ratelimit() CONSOLE messages on firmware crash (Jarod Wilson) [1776606]
- [netdrv] rtw88: debug: dump tx power indexes in use (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: fix issue possible condition with no effect (if == else) (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: remove unnecessary strlcpy() upon obtaining "ver" iovar (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: simply remove flowring if bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: avoid firmware commands when bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: clear events in brcmf_fweh_detach() will always fail (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: avoid firmware command in brcmf_netdev_open() when bus is down (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: change the order of things in brcmf_detach() (Jarod Wilson) [1776606]
- [netdrv] revert "brcmfmac: fix NULL pointer derefence during USB disconnect" (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: allow 160MHz in custom regulatory rules (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: enable DFS_OFFLOAD extended feature if supported (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: add 160MHz in chandef_to_chanspec() (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Use DMA sync instead of remapping in RX ISR (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: Rearrange the memory usage for skb in RX ISR (Jarod Wilson) [1776606]
- [netdrv] rtw88: Fix misuse of GENMASK macro (Jarod Wilson) [1776606]
- [netdrv] rtl8xxxu: Fix wifi low signal strength issue of RTL8723BU (Jarod Wilson) [1776606]
- [net] mac80211: don't warn about CW params when not using them (Jarod Wilson) [1776606]
- [net] mac80211: fix possible memory leak in ieee80211_assign_beacon (Jarod Wilson) [1776606]
- [kernel] fix typos and some coding style in comments (Jarod Wilson) [1776606]
- [netdrv] ath10k: work around uninitialized vht_pfr variable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: add support for qu c-step devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 9000 and 20000 series (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: clear rfkill_safe_init_done when we start the firmware (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: don't WARN when calling iwl_get_shared_mem_conf with RF-Kill (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: don't service an interrupt that was masked (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix RF-Kill interrupt while FW load for gen2 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: fix ALIVE interrupt handling for gen2 devices w/o MSI-X (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: delay GTK setting in FW in AP mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove MAC_FILTER_IN_11AX for AP mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: debug recording stop and restart command remove (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: don't stop dbg recording before entering D3 from 9000 devices (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: fix debug monitor stop and restart in ini mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: make the usage of TWT configurable (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: support FSEQ TLV even when FMAC is not compiled (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: move trans debug fields to a separate struct (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: remove redundant checking of ini mode (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: enforce apply point early on buffer allocation tlv (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: fix debug monitor stop and restart delays (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: pcie: increase the size of PCI dumps (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Drop large non sta frames (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: Add log information about SAR status (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: Add support for SAR South Korea limitation (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fix module init error paths (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: convert to FW AC when configuring MU EDCA (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: correctly fill the ac array in the iwl_mac_ctx_cmd (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: remove some unnecessary NULL checks (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: d3: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: lib: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: fw api: support adwell HB default APs number api (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: remove multiple debugfs entries (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: implement dump info collection (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: mvm: add a debugfs entry to set a fixed size AMSDU for all TX packets (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: support debug info TLV (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: use different barker for ini dump (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: add consecutive trigger firing support (Jarod Wilson) [1776606]
- [kernel] ieee80211: Add a missing extended capability flag definition (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: abort region collection in case the size is 0 (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: update CSI API (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg_ini: dump headers cleanup (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: dbg: allow dump collection in case of an early error (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: iwl_mvm_tx_mpdu() must be called with BH disabled (Jarod Wilson) [1776606]
- [netdrv] ath10k: pci: remove unnecessary casts (Jarod Wilson) [1776606]
- [netdrv] ath10k: remove unnecessary 'out of memory' message (Jarod Wilson) [1776606]
- [netdrv] ath10k: destroy sdio workqueue while remove sdio module (Jarod Wilson) [1776606]
- [netdrv] ath10k: Move non-fatal warn logs to dbg level for SDIO chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix memory leak in qmi (Jarod Wilson) [1776606]
- [netdrv] ath10k: add new hw_ops for sdio chip (Jarod Wilson) [1776606]
- [netdrv] ath9k: correctly handle short radar pulses (Jarod Wilson) [1776606]
- [netdrv] rtw88: refine flow to get tx power index (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove all RTW_MAX_POWER_INDEX macro (Jarod Wilson) [1776606]
- [netdrv] rtw88: update tx power limit table to RF v20 (Jarod Wilson) [1776606]
- [netdrv] rtw88: correct power limit selection (Jarod Wilson) [1776606]
- [netdrv] rtw88: choose the lowest as world-wide power limit (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix incorrect tx power limit at 5G (Jarod Wilson) [1776606]
- [netdrv] rtw88: remove unused variable (Jarod Wilson) [1776606]
- [netdrv] rtw88: unify prefixes for tx power setting routine (Jarod Wilson) [1776606]
- [netdrv] rtw88: do not use (void *) as argument (Jarod Wilson) [1776606]
- [netdrv] rtw88: resolve order of tx power setting routines (Jarod Wilson) [1776606]
- [netdrv] ath: fix SPDX tags (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add WMI diag fw logging support for WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: add report MIC error for sdio chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: add support for controlling tx power to a station (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add peer delete response event (Jarod Wilson) [1776606]
- [netdrv] ath10k: wait for vdev delete response from firmware (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix PCIE device wake up failed (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix failure to set multiple fixed rate (Jarod Wilson) [1776606]
- [netdrv] ath10k: Change the warning message string (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix fw crash by moving chip reset after napi disabled (Jarod Wilson) [1776606]
- [netdrv] ath10k: add missing error handling (Jarod Wilson) [1776606]
- [netdrv] ath10k: enabling tx stats support over pktlog (Jarod Wilson) [1776606]
- [netdrv] ath10k: acquire lock to fix lockdep's warning (Jarod Wilson) [1776606]
- [netdrv] ath10k: change firmware file name for UTF mode of SDIO/USB (Jarod Wilson) [1776606]
- [netdrv] ath10k: add support for firmware crash recovery on SDIO chip (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wrapper function to ath10k debug (Jarod Wilson) [1776606]
- [netdrv] ath10k: add htt_h2t_aggr_cfg_msg op for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add inline wrapper for htt_h2t_aggr_cfg_msg (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix sparse warnings: warning: incorrect type in assignment (different base types) (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: warning: cast from restricted __le16 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix sparse warnings: incorrect type in assignment (different base types) (Jarod Wilson) [1776606]
- [netdrv] mt76: move nl80211_dfs_regions in mt76_dev data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove cfg80211_chan_def from mt7615_set_channel signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: update peer's bssid when state transition occurs (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix incorrect settings in mesh mode (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: take into account extPA when configuring tx power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: init per-channel target power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support for per-chain signal strength reporting (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: simplify mt7615_mcu_set_sta_rec routine (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: improve hardware rate switching configuration (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: rework and fix tx status reporting (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove key check in mt7615_mcu_set_wtbl_key (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: remove unused variable in mt7615_mcu_set_bcn (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: fix slow performance when enable encryption (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: enable support for mesh (Jarod Wilson) [1776606]
- [netdrv] mt76: Remove set but not used variables 'pid' and 'final_mpdu' (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_get_rate in mt76-module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rearrange locking in mt7615_config (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: init get_txpower mac80211 callback (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add the capability to configure tx power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: select wifi band according to eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add support for mtd eeprom parsing (Jarod Wilson) [1776606]
- [netdrv] mt76: move mt76_insert_ccmp_hdr in mt76-module (Jarod Wilson) [1776606]
- [netdrv] mt76: fix setting chan->max_power (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix reading target tx power from eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: do not process rx packets if the device is not initialized (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: add debugfs knob to enable/disable edcca (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: add static qualifier to mt7615_rx_poll_complete (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: rearrange cleanup operations in mt7615_unregister_device (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: stop mac80211 queues before setting the channel (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: run __mt76_mcu_send_msg in mt7615_mcu_send_firmware (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: init mcu_restart function pointer (Jarod Wilson) [1776606]
- [netdrv] mt7615: initialize mt76_mcu_ops data structure (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use standard signature for mt7615_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove unused structure in mcu.h (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: do not use function pointers whenever possible (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: unify __mt7615_mcu_set_dev_info and mt7615_mcu_set_dev_info (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove skb_ret from mt7615_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt7615: remove dest from mt7615_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt7615: remove query from mt7615_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove unused parameter in mt7615_mcu_del_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: unify mt7615_mcu_add_wtbl_bmc and mt7615_mcu_del_wtbl_bmc (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use proper msg size in mt7615_mcu_add_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: use proper msg size in mt7615_mcu_add_wtbl_bmc (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: remove bss_info_convert_vif_type routine (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: simplify __mt7615_mcu_set_sta_rec (Jarod Wilson) [1776606]
- [netdrv] mt7615: mcu: simplify __mt7615_mcu_set_wtbl (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: Make mt7615_irq_handler static (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: Use after free in mt7615_mcu_set_bcn() (Jarod Wilson) [1776606]
- [netdrv] mt76: Fix a signedness bug in mt7615_add_interface() (Jarod Wilson) [1776606]
- [netdrv] mt76: move netif_napi_del in mt76_dma_cleanup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use napi polling for tx cleanup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use napi polling for tx cleanup (Jarod Wilson) [1776606]
- [netdrv] wireless/mediatek: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: dynamically alloc mcu req in mt7603_mcu_set_eeprom (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: enable/disable pre_tbtt_tasklet in mt7603_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: move pre_tbtt_tasklet in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: move beacon_mask in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: move beacon_int in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: report firmware version using ethtool (Jarod Wilson) [1776606]
- [netdrv] mt76: fix endianness sparse warnings (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7615: use sizeof instead of sizeof_field (Jarod Wilson) [1776606]
- [netdrv] mt76: add mac80211 driver for MT7615 PCIe-based chipsets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: run __mt76_mcu_send_msg in mt7603_mcu_send_firmware (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: init mcu_restart function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: initialize mt76_mcu_ops data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use standard signature for mt7603_mcu_msg_send (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: remove query from mt7603_mcu_msg_send signature (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix initialization of max rx length (Jarod Wilson) [1776606]
- [netdrv] mt76: use macro for sn and seq_ctrl conversion (Jarod Wilson) [1776606]
- [netdrv] mt76: add skb pointer to mt76_tx_info (Jarod Wilson) [1776606]
- [netdrv] mt76: move mac_work in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: only schedule txqs from the tx tasklet (Jarod Wilson) [1776606]
- [netdrv] mt76: move tx tasklet to struct mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: store wcid tx rate info in one u32 reduce locking (Jarod Wilson) [1776606]
- [netdrv] mt76: use readl/writel instead of ioread32/iowrite32 (Jarod Wilson) [1776606]
- [netdrv] mt76: fix tx power issues (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_free_device routine (Jarod Wilson) [1776606]
- [netdrv] mt76: unify set_tim (Jarod Wilson) [1776606]
- [netdrv] mt7603: core: do not use magic numbers in mt7603_reg_map (Jarod Wilson) [1776606]
- [netdrv] mt7603: remove mt7603_mcu_init routine (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: add static qualifier to mt76_dma_tx_queue_skb (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_tx_info data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: introduce mt76_sw_queue data structure (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_complete_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_prepare_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: remove mt76_queue dependency from tx_queue_skb function pointer (Jarod Wilson) [1776606]
- [netdrv] mt76: dma: move mt76x02_init_{tx, rx}_queue in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mmio: move mt76x02_set_irq_mask in mt76 module (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: send BAR after powersave wakeup (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix sequence number assignment (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: add missing initialization for dev->ps_lock (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: use the correct hweight8() function (Jarod Wilson) [1776606]
- [netdrv] mt76: fix return value check in mt76_wmac_probe() (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: set moredata flag when queueing ps-filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: clear the service period on releasing PS filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: notify mac80211 about buffered frames in ps queue (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix up hardware queue index for PS filtered packets (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: clear ps filtering mode before releasing buffered frames (Jarod Wilson) [1776606]
- [netdrv] mt76: mt7603: fix tx status HT rate validation (Jarod Wilson) [1776606]
- [netdrv] mt76: add driver for MT7603E and MT7628/7688 (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0u: do not reset radio on resume (Jarod Wilson) [1776606]
- [netdrv] mt7601u: null check the allocation (Jarod Wilson) [1776606]
- [netdrv] mt7601u: use params->ssn value directly (Jarod Wilson) [1776606]
- [netdrv] mt76: usb: fix rx A-MSDU support (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: get rid of {out,in}_max_packet (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76u: reduce rx memory footprint (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02u: fix sparse warnings: should it be static? (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x0: fix RF frontend initialization for external PA (Jarod Wilson) [1776606]
- [netdrv] mt76: generalize mt76_get_txpower for 4x4:4 devices (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix tx reordering on rate control probing without a-mpdu (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix tx status reporting issues (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: fix edcca file permission (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: run mt76x02_edcca_init atomically in mt76_edcca_set (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2: move mutex_lock inside mt76x2_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x2u: remove mt76x02_edcca_init in mt76x2u_set_channel (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: remove enable from mt76x02_edcca_init signature (Jarod Wilson) [1776606]
- [netdrv] mt76: move tx_napi in mt76_dev (Jarod Wilson) [1776606]
- [netdrv] mt76: mt76x02: remove useless return in mt76x02_resync_beacon_timer (Jarod Wilson) [1776606]
- [netdrv] mt7601u: fix possible memory leak when the device is disconnected (Jarod Wilson) [1776606]
- [netdrv] mt7601u: do not schedule rx_tasklet when the device has been disconnected (Jarod Wilson) [1776606]
- [netdrv] mwifiex: don't disable hardirqs; just softirqs (Jarod Wilson) [1776606]
- [netdrv] mwifiex: dispatch/rotate from reorder table atomically (Jarod Wilson) [1776606]
- [netdrv] mwifiex: ignore processing invalid command response (Jarod Wilson) [1776606]
- [netdrv] mwifiex: update set_mac_address logic (Jarod Wilson) [1776606]
- [netdrv] mwifiex: print PCI mmap with pK (Jarod Wilson) [1776606]
- [netdrv] mwifiex: drop 'set_consistent_dma_mask' log message (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add support for hr1 RF ID (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: change 0x02F0 fw from qu to quz (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 22000 and change wrong structs (Jarod Wilson) [1776606]
- [netdrv] iwlwifi: add new cards for 22000 and fix struct name (Jarod Wilson) [1776606]
- [net] mac80211: notify offchannel expire on mgmt_tx (Jarod Wilson) [1776606]
- [net] nl80211: send event when CMD_FRAME duration expires (Jarod Wilson) [1776606]
- [net] mac80211: no need to check return value of debugfs_create functions (Jarod Wilson) [1776606]
- [net] mac80211: extend __rate_control_send_low warning (Jarod Wilson) [1776606]
- [net] mac80211: fill low rate even for HAS_RATE_CONTROL (Jarod Wilson) [1776606]
- [net] mac80211: use STA info in rate_control_send_low() (Jarod Wilson) [1776606]
- [net] mac80211: call rate_control_send_low() internally (Jarod Wilson) [1776606]
- [net] cfg80211: Add a function to iterate all BSS entries (Jarod Wilson) [1776606]
- [net] mac80211: allow turning TWT responder support on and off via netlink (Jarod Wilson) [1776606]
- [net] mac80211: dynamically enable the TWT requester support on STA interfaces (Jarod Wilson) [1776606]
- [net] mac80211: add ieee80211_get_he_iftype_cap() helper (Jarod Wilson) [1776606]
- [uapi] nl80211: add support for SAE authentication offload (Jarod Wilson) [1776606]
- [net] nl80211: add WPA3 definition for SAE authentication (Jarod Wilson) [1776606]
- [net] nl80211: add NL80211_ATTR_IFINDEX to port authorized event (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8188ee: remove redundant assignment to rtstatus (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove redundant assignment to variable k (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: remove redundant assignment to variable badworden (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8192cu: fix error handle when usb probe failed (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: remove unused function exhalbtc_stack_operation_notify (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: btcoex: Remove set but not used variable 'len' and 'asso_type_v2' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Remove set but not used variables 'cur_txokcnt' and 'b_last_is_cur_rdl_state' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Convert inline routines to little-endian words (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Convert macros that set descriptor (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Replace local bit manipulation macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: rtl8821ae: Remove unused GET_XXX and SET_XXX descriptor macros (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: use le32 to access cckswing tables (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: Fix used uninitialized variables in power tracking (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: make tables to be 'static const' (Jarod Wilson) [1776606]
- [netdrv] rtlwifi: 8192de: Reduce indentation and fix coding style (Jarod Wilson) [1776606]
- [netdrv] rtw88: fix typo rtw_writ16_set (Jarod Wilson) [1776606]
- [netdrv] rtw88: rsvd page should go though management queue (Jarod Wilson) [1776606]
- [netdrv] rtw88: restore DACK results to save time (Jarod Wilson) [1776606]
- [netdrv] rtw88: power on again if it was already on (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: use more accurate ofdm fa counting (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: disable rx clock gating before counter reset (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: update channel and bandwidth BB setting (Jarod Wilson) [1776606]
- [netdrv] rtw88: 8822c: add rf write protection when switching channel (Jarod Wilson) [1776606]
- [netdrv] rtw88: add beacon function setting (Jarod Wilson) [1776606]
- [netdrv] rtw88: add support for random mac scan (Jarod Wilson) [1776606]
- [netdrv] rtw88: add fast xmit support (Jarod Wilson) [1776606]
- [netdrv] rtw88: more descriptions about LPS (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: check if queue mapping exceeds size of ac_to_hwq (Jarod Wilson) [1776606]
- [netdrv] rtw88: pci: use ieee80211_ac_numbers instead of 0-3 (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use strlcpy() instead of strcpy() (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: fix typos in code comments (Jarod Wilson) [1776606]
- [netdrv] brcm80211: select WANT_DEV_COREDUMP conditionally for brcmfmac (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: use separate Kconfig file for brcmfmac (Jarod Wilson) [1776606]
- [netdrv] brcmfmac: switch source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcmsmac: switch phy source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcmutil: switch source files to using SPDX license identifier (Jarod Wilson) [1776606]
- [netdrv] brcm80211: switch common header files to using SPDX license identifier (Jarod Wilson) [1776606]
- [net] cfg80211: Handle bss expiry during connection (Jarod Wilson) [1776606]
- [netdrv] ath10k: Check tx_stats before use it (Jarod Wilson) [1776606]
- [netdrv] ath10k: add peer id check in ath10k_peer_find_by_id (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wmi tlv service map for mesh 11s (Jarod Wilson) [1776606]
- [netdrv] ath10k: Do not send probe response template for mesh (Jarod Wilson) [1776606]
- [netdrv] ath10k: Add wmi tlv vdev subtype for mesh in WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: change swap mail box config for UTF mode of SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix the wrong value of enums for wmi tlv stats id (Jarod Wilson) [1776606]
- [netdrv] ath10k: coredump: use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix encoding for protected management frames (Jarod Wilson) [1776606]
- [netdrv] ath10k: rx_duration update for fw_stats debugfs entry (Jarod Wilson) [1776606]
- [netdrv] ath10k: Fix the tx stats bytes & packets parsing (Jarod Wilson) [1776606]
- [netdrv] ath10k: Modify CE4 src buffer entries to 2048 for WCN3990 (Jarod Wilson) [1776606]
- [netdrv] ath10k: Move board id and fw version logging to info level (Jarod Wilson) [1776606]
- [netdrv] ath10k: Added support to reset HTT stats in debugfs (Jarod Wilson) [1776606]
- [netdrv] ath10k: Extended the HTT stats support to retrieve Mu-MIMO related stats (Jarod Wilson) [1776606]
- [netdrv] ath: DFS JP domain W56 fixed pulse type 3 RADAR detection (Jarod Wilson) [1776606]
- [netdrv] ath9k: drop redundant code in ar9003_hw_set_channel (Jarod Wilson) [1776606]
- [netdrv] ath: drop duplicated define (Jarod Wilson) [1776606]
- [netdrv] ath9k: Remove some set but not used variables (Jarod Wilson) [1776606]
- [netdrv] ath9k: Differentiate between max combined and per chain power (Jarod Wilson) [1776606]
- [netdrv] ath9k: Check for errors when reading SREV register (Jarod Wilson) [1776606]
- [netdrv] ath9k: Don't trust TX status TID number when reporting airtime (Jarod Wilson) [1776606]
- [netdrv] ath6kl: remove redundant check of status != 0 (Jarod Wilson) [1776606]
- [netdrv] ath6kl: add some bounds checking (Jarod Wilson) [1776606]
- [netdrv] ath6kl: wmi: use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath6kl: debug: Use struct_size() helper (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix incorrect multicast/broadcast rate setting (Jarod Wilson) [1776606]
- [netdrv] ath10k: enable QCA6174 hw3.2 SDIO hardware (Jarod Wilson) [1776606]
- [netdrv] ath10k: add fragmentation handler for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add PN replay protection for high latency devices (Jarod Wilson) [1776606]
- [netdrv] ath10k: add handler for HTT_T2H_MSG_TYPE_SEC_IND event (Jarod Wilson) [1776606]
- [netdrv] ath10k: add struct for high latency PN replay protection (Jarod Wilson) [1776606]
- [netdrv] ath10k: sdio: add missing error check (Jarod Wilson) [1776606]
- [netdrv] ath10k: add initialization of HTC header (Jarod Wilson) [1776606]
- [netdrv] ath10k: fix use-after-free on SDIO data frames (Jarod Wilson) [1776606]
- [netdrv] ath10k: htt: support MSDU ids with SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: initialise struct ath10k_bus params to zero (Jarod Wilson) [1776606]
- [netdrv] ath10k: htt: don't use txdone_fifo with SDIO (Jarod Wilson) [1776606]
- [netdrv] ath10k: don't disable interrupts in ath10k_sdio_remove() (Jarod Wilson) [1776606]
- [netdrv] ath10k: sdio: workaround firmware UART pin configuration bug (Jarod Wilson) [1776606]
- [net] cfg80211: Add airtime statistics and settings (Jarod Wilson) [1776606]
- [base] depend on HAS_IOMEM for devm_platform_ioremap_resource() (Jarod Wilson) [1776606]
- [base] provide devm_platform_ioremap_resource() (Jarod Wilson) [1776606]
- [lib] crypto: arc4 - refactor arc4 core code into separate library (Jarod Wilson) [1776606]
- [crypto] export arc4 defines (Jarod Wilson) [1776606]
- [crypto] arc4 - convert to skcipher API (Jarod Wilson) [1776606]
- [kernel] bitfield: add u8 helpers (Jarod Wilson) [1776606]

* Fri Dec 13 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-165.rt13.22.el8]
- [md] raid5: need to set STRIPE_HANDLE for batch head (Nigel Croxon) [1774840]
- [scsi] lpfc: remove left-over BUILD_NVME defines (Ewan Milne) [1782235]
- [block] fix memleak of bio integrity data (Ming Lei) [1779898]
- [fs] xfs: attach dquots and reserve quota blocks during unwritten conversion (Carlos Maiolino) [1782094]
- [nvme] nvme-fc: fix double-free scenarios on hw queues (Ewan Milne) [1781390]
- [tools] power turbostat: Add Cometlake support (David Arcari) [1759661]
- [mm] hugetlbfs: take read_lock on i_mmap for PMD sharing (Waiman Long) [1731295]
- [documentation] powerpc/pseries: Add documentation for vcpudispatch_stats (Gustavo Duarte) [1723870]
- [powerpc] pseries: Protect against hogging the cpu while setting up the stats (Gustavo Duarte) [1723870]
- [powerpc] pseries: Provide vcpu dispatch statistics (Gustavo Duarte) [1723870]
- [powerpc] pseries: Move mm/book3s64/vphn.c under platforms/pseries/ (Gustavo Duarte) [1723870]
- [powerpc] pseries: Generalize hcall_vphn() (Gustavo Duarte) [1723870]
- [powerpc] mm: Move book3s64 specifics in subdirectory mm/book3s64 (Gustavo Duarte) [1723870]
- [powerpc] pseries: Introduce rwlock to gatekeep DTLB usage (Gustavo Duarte) [1723870]
- [powerpc] pseries: Factor out DTL buffer allocation and registration routines (Gustavo Duarte) [1723870]
- [powerpc] pseries: Do not save the previous DTL mask value (Gustavo Duarte) [1723870]
- [powerpc] pseries: Use macros for referring to the DTL enable mask (Gustavo Duarte) [1723870]
- [powerpc] mm: change #include "mmu_decl.h" to <mm/mmu_decl.h> (Gustavo Duarte) [1723870]
- [fs] devpts_pty_kill(): don't bother with d_delete() (Eric Sandeen) [1772718]
- [fs] devpts: always delete dcache dentry-s in dput() (Eric Sandeen) [1772718]
- [infiniband] rdma/siw: Fix post_recv QP state locking (Kamal Heib) [1779625]
- [infiniband] rdma/siw: Fix SQ/RQ drain logic (Kamal Heib) [1779625]
- [infiniband] rdma/siw: Relax from kmap_atomic() use in TX path (Kamal Heib) [1779625]
- [netdrv] nfp: flower: cmsg rtnl locks can timeout reify messages (Pablo Cascon) [1729154]
- [netdrv] nfp: Drop unnecessary continue in nfp_net_pf_alloc_vnics (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: handle neighbour events on internal ports (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: prevent ingress block binds on internal ports (Pablo Cascon) [1729154]
- [netdrv] nfp: add AMDA0058 boards to firmware list (Pablo Cascon) [1729154]
- [netdrv] nfp: no need to check return value of debugfs_create functions (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: encode mac indexes with pre-tunnel rule check (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: remove offloaded MACs when reprs are applied to OvS bridges (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: verify pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: detect potential pre-tunnel rules (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: push vlan after tunnel in merge (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS set action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS pop action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: offload MPLS push action (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: ensure ip protocol is specified for L4 matches (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: fix ethernet check on match fields (Pablo Cascon) [1729154]
- [netdrv] nfp: ccm: increase message limits (Pablo Cascon) [1729154]
- [netdrv] nfp: Use spinlock_t instead of struct spinlock (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add GRE encap action support (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add GRE decap classification support (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: rename tunnel related functions in action offload (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: add helper functions for tunnel classification (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: refactor tunnel key layer calculation (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: extend extack messaging for flower match and actions (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: use extack messages in flower offload (Pablo Cascon) [1729154]
- [netdrv] nfp: flower: check L4 matches on unknown IP protocols (Pablo Cascon) [1729154]
- [netdrv] nfp: print a warning when binding VFs to PF driver (Pablo Cascon) [1729154]
- [netdrv] nfp: update the old flash error message (Pablo Cascon) [1729154]
- [netdrv] nfp: prepare for more TX metadata prepend (Pablo Cascon) [1729154]
- [netdrv] nfp: add tls init code (Pablo Cascon) [1729154]
- [netdrv] nfp: parse crypto opcode TLV (Pablo Cascon) [1729154]
- [netdrv] nfp: add support for sending control messages via mailbox (Pablo Cascon) [1729154]
- [netdrv] nfp: parse the mailbox cmsg TLV (Pablo Cascon) [1729154]
- [netdrv] nfp: make bar_lock a semaphore (Pablo Cascon) [1729154]
- [netdrv] nfp: count all failed TX attempts as errors (Pablo Cascon) [1729154]
- [netdrv] nfp: ensure skb network header is set for packet redirect (Pablo Cascon) [1728773]
- [netdrv] nfp: reintroduce ndo_get_port_parent_id for representor ports (Pablo Cascon) [1728773]
- [netdrv] nfp: implement PCI driver shutdown callback (Pablo Cascon) [1728773]
- [netdrv] nfp: add SR-IOV trusted VF support (Pablo Cascon) [1728773]
- [netdrv] nfp: split out common control message handling code (Pablo Cascon) [1728773]
- [netdrv] nfp: move vNIC reset before netdev init (Pablo Cascon) [1728773]
- [netdrv] nfp: add a mutex lock for the vNIC ctrl BAR (Pablo Cascon) [1728773]
- [netdrv] nfp: opportunistically poll for reconfig result (Pablo Cascon) [1728773]
- [netdrv] nfp: remove ndo_get_port_parent_id implementation (Pablo Cascon) [1728773]
- [netdrv] nfp: pass switch ID through devlink_port_attrs_set() (Pablo Cascon) [1728773]
- [netdrv] nfp: implement ethtool get module EEPROM (Pablo Cascon) [1728773]
- [netdrv] nfp: nsp: implement read SFF module EEPROM (Pablo Cascon) [1728773]
- [netdrv] nfp: do not handle nn->port defined case in nfp_net_get_phys_port_name() (Pablo Cascon) [1728773]
- [netdrv] nfp: register devlink port before netdev (Pablo Cascon) [1728773]
- [netdrv] nfp: remove defines for unused control bits (Pablo Cascon) [1728773]
- [netdrv] replace ndo_get_devlink with ndo_get_devlink_port (Pablo Cascon) [1728773]
- [netdrv] nfp: add .ndo_get_devlink (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: add rcu locks when accessing netdev for tunnels (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: add qos offload stats request and reply (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: fix size_t compile warning (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: fix implicit fallthrough warning (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: offload merge flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: support stats update for merge flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: generate merge flow rule (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: validate merge hint flows (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: handle merge hint messages (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: get flows by host context (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: allow tunnels to output to internal port (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: support fallback packets from internal ports (Pablo Cascon) [1728773]
- [netdrv] nfp: allow fallback packets from non-reprs (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: allow offloading of matches on 'internal' ports (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: turn on recirc and merge hint support in firmware (Pablo Cascon) [1728773]
- [netdrv] nfp: flower: reduce action list size by coalescing mangle actions (Pablo Cascon) [1728773]
- [fs] xfs: properly serialise fallocate against AIO+DIO (Eric Sandeen) [1765547]
- [fs] xfs: fix attr leaf header freemap.size underflow (Brian Foster) [1728989]
- [mm] maintain randomization of page free lists (Rafael Aquini) [1620349]
- [mm] move buddy list manipulations into helpers (Rafael Aquini) [1620349]
- [mm] shuffle initial free memory to improve memory-side-cache utilization (Rafael Aquini) [1620349]
- [powerpc] kvm: ppc: book3s hv: Flush link stack on guest exit to host kernel (Gustavo Duarte) [1777686]
- [powerpc] book3s64: Fix link stack flush on context switch (Gustavo Duarte) [1777686]
- [powerpc] 64s: support nospectre_v2 cmdline option (Gustavo Duarte) [1777686]
- [powerpc] fsl: Update Spectre v2 reporting (Gustavo Duarte) [1777686]
- [powerpc] fsl: Add nospectre_v2 command line argument (Gustavo Duarte) [1777686]
- [powerpc] fsl: Fix spectre_v2 mitigations reporting (Gustavo Duarte) [1777686]
- [powerpc] 64: Make meltdown reporting Book3S 64 specific (Gustavo Duarte) [1777686]
- [powerpc] 64: Disable the speculation barrier from the command line (Gustavo Duarte) [1777686]
- [x86] kprobes: Avoid kretprobe recursion bug (Jiri Olsa) [1779235]
- [x86] kprobes: Verify stack frame on kretprobe (Jiri Olsa) [1779235]

* Wed Dec 11 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-164.rt13.21.el8]
- [fs] iomap: Fix pipe page leakage during splicing (Andreas Grunbacher) [1622634]
- [fs] iomap: fix return value of iomap_dio_bio_actor on 32bit systems (Andreas Grunbacher) [1622634]
- [fs] iomap: iomap_bmap should check iomap_apply return value (Andreas Grunbacher) [1622634]
- [fs] iomap: Fix overflow in iomap_page_mkwrite (Andreas Grunbacher) [1622634]
- [fs] splice: only read in as much information as there is pipe buffer space (Andreas Grunbacher) [1622634]
- [fs] gfs2: Always mark inode dirty in fallocate (Andreas Grunbacher) [1622634]
- [fs] dax: Fix pmd vs pte conflict detection (Jeff Moyer) [1777250]
- [fs] xfs: move local to extent inode logging into bmap helper (Brian Foster) [1737677]
- [fs] xfs: remove broken error handling on failed attr sf to leaf change (Brian Foster) [1737677]
- [fs] xfs: log the inode on directory sf to block format change (Brian Foster) [1737677]
- [block] bfq: deschedule empty bfq_queues not referred by any process (Ming Lei) [1773831]
- [scsi] revert "scsi: qla2xxx: Fix memory leak when sending I/O fails" (Himanshu Madhani) [1759275]
- [infiniband] rdma/iw_cxgb4: Report correct port speed/width (Vishal Kulkarni) [1757806]
- [infiniband] rdma/iw_cxgb4: fix SRQ access from dump_qp() (Vishal Kulkarni) [1779997]
- [net] nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds (Vladis Dronov) [1778898]
- [atm] iphase: Fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [x86] tls: Fix possible spectre-v1 in do_get_thread_area() (Vladis Dronov) [1778898]
- [x86] ptrace: Fix possible spectre-v1 in ptrace_get_debugreg() (Vladis Dronov) [1778898]
- [net] atm: Fix potential Spectre v1 vulnerabilities (Vladis Dronov) [1778898]
- [powerpc] ptrace: Mitigate potential Spectre v1 (Vladis Dronov) [1778898]
- [char] applicom: Fix potential Spectre v1 vulnerabilities (Vladis Dronov) [1778898]
- [char] mwave: fix potential Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [misc] misc/sgi-gru: fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [usb] gadget: storage: Fix Spectre v1 vulnerability (Vladis Dronov) [1778898]
- [misc] hmc6352: fix potential Spectre v1 (Vladis Dronov) [1778898]
- [s390] qeth: ensure linear access to packet headers (Philipp Rudo) [1781085]
- [s390] qeth: guard against runt packets (Philipp Rudo) [1781085]
- [s390] qeth: handle skb allocation error gracefully (Philipp Rudo) [1781085]
- [s390] qeth: drop unwanted packets earlier in RX path (Philipp Rudo) [1781085]
- [s390] qeth: support per-frame invalidation (Philipp Rudo) [1781085]
- [s390] qeth: gather more detailed RX dropped/error statistics (Philipp Rudo) [1781085]
- [s390] Mark expected switch fall-throughs (Philipp Rudo) [1781085]
- [sched] fair: Scale bandwidth quota and period without losing quota/period ratio precision (Phil Auld) [1706247]
- [sched] fair: Fix -Wunused-but-set-variable warnings (Phil Auld) [1706247]
- [sched] fair: Fix low cpu usage with high throttling by removing expiration of cpu-local slices (Phil Auld) [1706247]
- [kernel] sched/core: Remove double update_max_interval() call on CPU startup (Phil Auld) [1757535]
- [kernel] sched/core: Fix migration to invalid CPU in __set_cpus_allowed_ptr() (Phil Auld) [1757535]
- [kernel] sched/fair: Don't assign runtime for throttled cfs_rq (Phil Auld) [1757535]
- [kernel] cpufreq: schedutil: Don't skip freq update when limits change (Phil Auld) [1757535]
- [kernel] sched/deadline: Fix double accounting of rq/running bw in push & pull (Phil Auld) [1757535]
- [kernel] sched/fair: Fix imbalance due to CPU affinity (Phil Auld) [1757535]
- [kernel] sched/fair: Use RCU accessors consistently for ->numa_group (Phil Auld) [1757535]
- [kernel] sched/fair: Don't free p->numa_faults with concurrent readers (Phil Auld) [1757535]
- [kernel] sched/fair: Rename weighted_cpuload() to cpu_runnable_load() (Phil Auld) [1757535]
- [kernel] sched/topology: Remove unused 'sd' parameter from arch_scale_cpu_capacity() (Phil Auld) [1757535]
- [kernel] sched/fair: Don't push cfs_bandwith slack timers forward (Phil Auld) [1757535]
- [documentation] sched/fair: Fix "runnable_avg_yN_inv" not used warnings (Phil Auld) [1757535]
- [kernel] sched/fair: Clean up definition of NOHZ blocked load functions (Phil Auld) [1757535]
- [kernel] sched/core: Add __sched tag for io_schedule() (Phil Auld) [1757535]
- [kernel] sched/fair: Remove sgs->sum_weighted_load (Phil Auld) [1757535]
- [kernel] sched/core: Remove sd->*_idx (Phil Auld) [1757535]
- [kernel] sched/core: Remove rq->cpu_load[] (Phil Auld) [1757535]
- [kernel] sched/debug: Remove sd->*_idx range on sysctl (Phil Auld) [1757535]
- [kernel] sched/fair: Replace source_load() & target_load() with weighted_cpuload() (Phil Auld) [1757535]
- [kernel] sched/fair: Remove the rq->cpu_load[] update code (Phil Auld) [1757535]
- [kernel] sched/fair: Remove rq->load (Phil Auld) [1757535]
- [kernel] sched/core: Unify p->on_rq updates (Phil Auld) [1757535]
- [kernel] sched/core: Remove ttwu_activate() (Phil Auld) [1757535]
- [kernel] sched/cpufreq: Fix 32-bit math overflow (Phil Auld) [1757535]
- [kernel] sched/fair: Update scale invariance of PELT (Phil Auld) [1757535]
- [kernel] sched/pelt: Skip updating util_est when utilization is higher than CPU's capacity (Phil Auld) [1757535]
- [kernel] sched/fair: Move the rq_of() helper function (Phil Auld) [1757535]
- [kernel] sched/core: Use READ_ONCE()/WRITE_ONCE() in move_queued_task()/task_rq_lock() (Phil Auld) [1757535]
- [kernel] sched/numa: Remove unused numa_stats::nr_running field (Phil Auld) [1757535]
- [kernel] sched/fair: Add lsub_positive() and use it consistently (Phil Auld) [1706247 1757535]
- [kernel] sched/fair: Mask UTIL_AVG_UNCHANGED usages (Phil Auld) [1706247 1757535]
- [cpuidle] teo: Avoid using "early hits" incorrectly (Al Stone) [1725618]
- [cpuidle] teo: Fix "early hits" handling for disabled idle states (Al Stone) [1725618]
- [cpuidle] teo: Consider hits and misses metrics of disabled states (Al Stone) [1725618]
- [cpuidle] teo: Rename local variable in teo_select() (Al Stone) [1725618]
- [cpuidle] teo: Ignore disabled idle states that are too deep (Al Stone) [1725618]
- [cpuidle] teo: Get rid of redundant check in teo_update() (Al Stone) [1725618]
- [cpuidle] teo: Allow tick to be stopped if PM QoS is used (Al Stone) [1725618]
- [cpuidle] governors: unify last_state_idx (Al Stone) [1725618]
- [powerpc] powernv/cpuidle: Fix idle states all being marked invalid (Al Stone) [1725618]
- [cpuidle] menu: Avoid overflows when computing variance (Al Stone) [1725618]
- [cpuidle] dt: bail out if the idle-state DT node is not compatible (Al Stone) [1725618]
- [kernel] cpuidle: use BIT() for idle state flags and remove CPUIDLE_DRIVER_FLAGS_MASK (Al Stone) [1725618]
- [cpuidle] New timer events oriented governor for tickless systems (Al Stone) [1725618]
- [cpuidle] Add 'above' and 'below' idle state metrics (Al Stone) [1725618]
- [cpuidle] big.little: fix refcount leak (Al Stone) [1725618]
- [documentation] documentation: admin-guide: pm: Add cpuidle document (Al Stone) [1725618]
- [cpuidle] powerpc/pseries/cpuidle: Fix preempt warning (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: Convert to use cpuidle_register|unregister() (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: Don't register the driver when back-end init returns -ENXIO (Al Stone) [1725618]
- [cpuidle] menu: Remove get_loadavg() from the performance multiplier (Al Stone) [1725618]
- [kernel] sched: Factor out nr_iowait and nr_iowait_cpu (Al Stone) [1725618]
- [kernel] sched/core: Fix comment regarding nr_iowait_cpu() and get_iowait_load() (Al Stone) [1725618]
- [cpuidle] menu: Avoid computations when result will be discarded (Al Stone) [1725618]
- [cpuidle] menu: Drop redundant comparison (Al Stone) [1725618]
- [cpuidle] menu: Simplify checks related to the polling state (Al Stone) [1725618]
- [cpuidle] menu: Move the latency_req == 0 special case check (Al Stone) [1725618]
- [cpuidle] menu: Avoid computations for very close timers (Al Stone) [1725618]
- [cpuidle] menu: Do not update last_state_idx in menu_select() (Al Stone) [1725618]
- [cpuidle] menu: Get rid of first_idx from menu_select() (Al Stone) [1725618]
- [cpuidle] menu: Compute first_idx when latency_req is known (Al Stone) [1725618]
- [cpuidle] menu: Replace data->predicted_us with local variable (Al Stone) [1725618]
- [cpuidle] enter_state: Don't needlessly calculate diff time (Al Stone) [1725618]
- [kernel] cpuidle: Remove unnecessary wrapper cpuidle_get_last_residency() (Al Stone) [1725618]
- [cpuidle] menu: Update stale polling override comment (Al Stone) [1725618]
- [cpuidle] menu: Fix white space (Al Stone) [1725618]
- [cpuidle] powernv/cpuidle: Use parsed device tree values for cpuidle_init (Al Stone) [1725618]
- [powerpc] powernv/cpuidle: Parse dt idle properties into global structure (Al Stone) [1725618]
- [cpuidle] arm: cpuidle: silence error on driver registration failure (Al Stone) [1725618]

* Wed Dec 11 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-163.rt13.20.el8]
- [documentation] docs: admin-guide: Remove threads-max auto-tuning (Joe Lawrence) [1771270]
- [documentation] docs: admin-guide: Fix min value of threads-max in kernel.rst (Joe Lawrence) [1771270]
- [kernel] sysctl.c: do not override max_threads provided by userspace (Joe Lawrence) [1771270]
- [fs] ext4: fix integer overflow when calculating commit interval (Lukas Czerner) [1775166]
- [fs] ext4: fix punch hole for inline_data file systems (Lukas Czerner) [1775166]
- [fs] ext4: fix warning inside ext4_convert_unwritten_extents_endio (Lukas Czerner) [1775166]
- [fs] ext4: set error return correctly when ext4_htree_store_dirent fails (Lukas Czerner) [1775166]
- [fs] ext4: fix warning when turn on dioread_nolock and inline_data (Lukas Czerner) [1775166]
- [fs] ext4: use jbd2_inode dirty range scoping (Lukas Czerner) [1775166]
- [fs] jbd2: introduce jbd2_inode dirty range scoping (Lukas Czerner) [1775166]
- [mm] add filemap_fdatawait_range_keep_errors() (Lukas Czerner) [1775166]
- [fs] ext4: enforce the immutable flag on open files (Lukas Czerner) [1775166]
- [fs] ext4: don't allow any modifications to an immutable file (Lukas Czerner) [1775166]
- [fs] jbd2: fix typo in comment of journal_submit_inode_data_buffers (Lukas Czerner) [1775166]
- [fs] jbd2: fix some print format mistakes (Lukas Czerner) [1775166]
- [fs] ext4: do not delete unlinked inode from orphan list on failed truncate (Lukas Czerner) [1775166]
- [fs] ext4: wait for outstanding dio during truncate in nojournal mode (Lukas Czerner) [1775166]
- [fs] ext4: don't perform block validity checks on the journal inode (Lukas Czerner) [1775166]
- [fs] ext4: fix block validity checks for journal inodes using indirect blocks (Lukas Czerner) [1775166]
- [fs] ext4: fix miscellaneous sparse warnings (Lukas Czerner) [1775166]
- [fs] jbd2: fix potential double free (Lukas Czerner) [1775166]
- [fs] quota: fix condition for resetting time limit in do_set_dqblk() (Lukas Czerner) [1778119]
- [fs] quota: honor quota type in Q_XGETQSTAT[V] calls (Lukas Czerner) [1778119]
- [fs] quota: fix a problem about transfer quota (Lukas Czerner) [1778119]
- [fs] quota: add dqi_dirty_list description to comment of Dquot List Management (Lukas Czerner) [1778119]
- [fs] quota: check time limit when back out space/inode change (Lukas Czerner) [1778119]
- [fs] quota: fix wrong indentation (Lukas Czerner) [1778119]
- [fs] quota: remove trailing whitespaces (Lukas Czerner) [1778119]
- [fs] quota: code cleanup for __dquot_alloc_space() (Lukas Czerner) [1778119]
- [fs] quota: Lock s_umount in exclusive mode for Q_XQUOTA{ON, OFF} quotactls (Lukas Czerner) [1778119]
- [fs] quota: Replace XQM_MAXQUOTAS usage with MAXQUOTAS (Lukas Czerner) [1778119]
- [hv] vmbus: Fix harmless building warnings without CONFIG_PM_SLEEP (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Resume after fixing up old primary channels (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Suspend after cleaning up hv_sock and sub channels (Mohammed Gamal) [1774675]
- [kernel] hv: vmbus: Add a helper function is_sub_channel() (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Clean up hv_sock channels by force upon suspend (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Suspend/resume the vmbus itself for hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Ignore the offers when resuming from hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Implement suspend/resume for VSC drivers for hibernation (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Fix virt_to_hvpfn() for X86_PAE (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Remove the unused "tsc_page" from struct hv_context (Mohammed Gamal) [1774675]
- [hv] tools: hv: Use the correct style for SPDX License Identifier (Mohammed Gamal) [1774675]
- [hv] hv_balloon: Reorganize the probe function (Mohammed Gamal) [1774675]
- [hv] hv_balloon: Use a static page for the balloon_up send buffer (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Replace page definition with Hyper-V specific one (Mohammed Gamal) [1774675]
- [hv] hv: Add a module description line to the hv_vmbus driver (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Remove the undesired put_cpu_ptr() in hv_synic_cleanup() (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Fix race condition with new ring_buffer_info mutex (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Set ring_info field to 0 and remove memset (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Refactor chan->state if statement (Mohammed Gamal) [1774675]
- [hv] hv: vmbus: Expose monitor data only when monitor pages are used (Mohammed Gamal) [1774675]
- [netdrv] hv_netvsc: Fix error handling in netvsc_attach() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix error handling in netvsc_set_features() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Sync offloading features to VF NIC (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Allow scatter-gather feature to be tunable (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix a warning of suspicious RCU usage (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Fix extra rcu_read_unlock in netvsc_recv_callback() (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: Set probe mode to sync (Mohammed Gamal) [1774687]
- [netdrv] hv_netvsc: fix race that may miss tx queue wakeup (Mohammed Gamal) [1774687]
- [netdrv] nfp: bpf: fix latency bug when updating stack index register (Pablo Cascon) [1729156]
- [netdrv] nfp: bpf: eliminate zero extension code-gen (Pablo Cascon) [1729156]
- [netdrv] bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during suspend/resume (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during error recovery (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Improve bnxt_ulp_stop()/bnxt_ulp_start() call sequence (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: flow_offload: offload tunnel decap rules via indirect callbacks (Jonathan Toppins) [1773724]
- [netdrv] bnxt: Avoid logging an unnecessary message when a flow can't be offloaded (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Add support to collect crash dump via ethtool (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Add support to invoke OP-TEE API to reset firmware (Jonathan Toppins) [1773724]
- [netdrv] broadcom: bnxt: Fix use true/false for bool (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Avoid disabling pci device in bnxt_remove_one() for already disabled device (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Minor formatting changes in FW devlink_health_reporter (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Adjust the time to wait before polling firmware readiness (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Fix devlink NVRAM related byte order related issues (Jonathan Toppins) [1773724]
- [netdrv] bnxt_en: Fix the size of devlink MSIX parameters (Jonathan Toppins) [1773724]
- [nvme] Fix parsing of ANA log page (Ewan Milne) [1769028]
- [nvme] nvme-multipath: fix ana log nsid lookup when nsid is not found (Ewan Milne) [1769028]
- [nvme] nvme-multipath: fix possible I/O hang when paths are updated (Ewan Milne) [1769028]
- [nvme] revert "nvme: update node paths after adding new path" (Ewan Milne) [1769028]
- [netdrv] mlx5: Update the list of the PCI supported devices (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fix auto group size calculation (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Do not use non-EXT link modes in EXT mode (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix set vf link state error flow (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Limit STE hash table enlarge based on bytemask (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix invalid EQ vector number on CQ creation (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Skip rehash for tables with byte mask zero (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix error flow cleanup in mlx5e_tc_tun_create_header_ipv4/6 (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix matcher builders select check (Mohammad Heib) [1776921]
- [netdrv] mlx5: Read num_vfs before disabling SR-IOV (Mohammad Heib) [1776921]
- [netdrv] mlx5: Clear VF's configuration on disabling SRIOV (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix memory leak during rule creation (Mohammad Heib) [1776921]
- [netdrv] mlx5: DR, Fix memory leak in modify action destroy (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix eswitch debug print of max fdb flow (Mohammad Heib) [1776921]
- [netdrv] mlx5: LAG, Use affinity type enumerators (Mohammad Heib) [1776921]
- [netdrv] mlx5: E-switch, Enable metadata on own vport (Mohammad Heib) [1776921]
- [netdrv] mlx5: Correct comment for legacy fields (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fixed a typo in a comment in esw_del_uc_addr() (Mohammad Heib) [1776921]
- [netdrv] mlx5: Fix rtable reference leak (Mohammad Heib) [1776921]
- [netdrv] mlx5: fix a -Wstringop-truncation warning (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix a race with XSKICOSQ in XSK wakeup flow (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Fix wrong max num channels indication (Mohammad Heib) [1776921]
- [netdrv] mlx5e: Add XSK zero-copy support (Mohammad Heib) [1776921]

* Tue Dec 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-162.rt13.19.el8]
- [mm] memremap: drop unused SECTION_SIZE and SECTION_MASK (Don Dutile) [1754737]
- [mm] memremap: Fix reuse of pgmap instances with internal references (Don Dutile) [1754737]
- [mm] memunmap: don't access uninitialized memmap in memunmap_pages() (Don Dutile) [1754737]
- [mm] memremap: move from kernel/ to mm/ (Don Dutile) [1754737]
- [kernel] memremap: provide an optional internal refcount in struct dev_pagemap (Don Dutile) [1754737]
- [kernel] memremap: replace the altmap_valid field with a PGMAP_ALTMAP_VALID flag (Don Dutile) [1754737]
- [mm] memremap: remove the data field in struct dev_pagemap (Don Dutile) [1754737]
- [kernel] memremap: add a migrate_to_ram method to struct dev_pagemap_ops (Don Dutile) [1754737]
- [kernel] memremap: lift the devmap_enable manipulation into devm_memremap_pages (Don Dutile) [1754737]
- [nvdimm] memremap: pass a struct dev_pagemap to ->kill and ->cleanup (Don Dutile) [1754737]
- [kernel] memremap: move dev_pagemap callbacks into a separate structure (Don Dutile) [1754737]
- [kernel] memremap: validate the pagemap type passed to devm_memremap_pages (Don Dutile) [1754737]
- [mm] remove MEMORY_DEVICE_PUBLIC support (Don Dutile) [1754737]
- [mm] migrate.c: cleanup expected_page_refs() (Don Dutile) [1754737]
- [mm] migration: factor out code to compute expected number of page references (Don Dutile) [1754737]
- [kernel] mm/devm_memremap_pages: fix final page put race (Don Dutile) [1754737]
- [kernel] mm/devm_memremap_pages: introduce devm_memunmap_pages (Don Dutile) [1754737]
- [kernel] memremap.c: remove the unused device_private_entry_fault() export (Don Dutile) [1754737]
- [base] devres: introduce devm_release_action() (Don Dutile) [1754737]
- [base] devres: Align data[] to ARCH_KMALLOC_MINALIGN (Don Dutile) [1754737]
- [base] devres: provide devm_kstrdup_const() (Don Dutile) [1754737]
- [base] devres: constify p in devm_kfree() (Don Dutile) [1754737]
- [kernel] mm: move is_kernel_rodata() to asm-generic/sections.h (Don Dutile) [1754737]
- [kernel] mm: fix vm_fault_t cast in VM_FAULT_GET_HINDEX() (Don Dutile) [1754737]
- [kernel] mm: create the new vm_fault_t type (Don Dutile) [1754737]
- [kernel] mm/hmm: convert to use vm_fault_t (Don Dutile) [1754737]
- [kernel] mm/hmm: fix memremap.h, move dev_page_fault_t callback to hmm (Don Dutile) [1754737]
- [fs] proc/vmcore.c: Convert to use vmf_error() (Don Dutile) [1754737]
- [fs] proc/vmcore.c: use new typedef vm_fault_t (Don Dutile) [1754737]
- [s390] vdso_fault return type (Don Dutile) [1754737]
- [mm] inline vm_insert_pfn_prot() into caller (Don Dutile) [1754737]
- [mm] remove vm_insert_pfn() (Don Dutile) [1754737]
- [mm] make vm_insert_pfn_prot() static (Don Dutile) [1754737]
- [x86] convert vdso to use vm_fault_t (Don Dutile) [1754737]
- [mm] introduce vmf_insert_pfn_prot() (Don Dutile) [1754737]
- [mm] convert __vm_insert_mixed() to vm_fault_t (Don Dutile) [1754737]
- [kernel] mm: remove vm_insert_mixed() (Don Dutile) [1754737]
- [fs] cramfs: convert to use vmf_insert_mixed (Don Dutile) [1754737]
- [scsi] cxlflash: Change return type for fault handler (Don Dutile) [1754737]
- [misc] ocxl: Change return type for fault handler (Don Dutile) [1754737]
- [kernel] fs/iomap.c: change return type to vm_fault_t (Don Dutile) [1754737]
- [mm] swap.c: remove duplicated include (Don Dutile) [1754737]
- [kernel] perf/aux: Fix the aux_output group inheritance fix (Michael Petlan) [1743210]
- [kernel] perf/core: Fix inheritance of aux_output groups (Michael Petlan) [1743210]
- [kernel] perf/aux: Disallow aux_output for kernel events (Michael Petlan) [1743210]
- [kernel] perf/core: Reattach a misplaced comment (Michael Petlan) [1743210]
- [kernel] perf/aux: Fix AUX output stopping (Michael Petlan) [1743210]
- [tools] perf vendor events s390: Add JSON transaction for machine type 8561 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Fix use of TRUE with SQLite (Michael Petlan) [1743210]
- [tools] objtool: Fix build by linking against tools/lib/ctype.o sources (Michael Petlan) [1743210]
- [tools] perf list: Allow plurals for metric, metricgroup (Michael Petlan) [1743210]
- [tools] perf vendor events: Minor fixes to the README (Michael Petlan) [1743210]
- [tools] perf vendor events amd: Remove redundant '[' (Michael Petlan) [1743210]
- [tools] perf vendor events amd: Add L3 cache events for Family 17h (Michael Petlan) [1743210]
- [tools] tools include uapi: Update copy of files related to new fspick, fsmount, fsconfig, fsopen, move_mount and open_tree syscalls (Michael Petlan) [1743210]
- [tools] perf pmu-events: Fix missing "cpu_clk_unhalted.core" event (Michael Petlan) [1743210]
- [tools] perf annotate: Fix s390 gap between kernel end and module start (Michael Petlan) [1743210]
- [tools] perf record: Fix module size on s390 (Michael Petlan) [1743210]
- [tools] perf tools: Fix include paths in ui directory (Michael Petlan) [1743210]
- [tools] perf tools: Fix a typo in a variable name in the Documentation Makefile (Michael Petlan) [1743210]
- [tools] perf cpumap: Fix writing to illegal memory in handling cpumap mask (Michael Petlan) [1743210]
- [tools] perf ftrace: Fix failure to set cpumask when only one cpu is present (Michael Petlan) [1743210]
- [tools] perf db-export: Fix thread__exec_comm() (Michael Petlan) [1743210]
- [tools] perf annotate: Fix printing of unaugmented disassembled instructions from BPF (Michael Petlan) [1743210]
- [tools] perf bench numa: Fix cpu0 binding (Michael Petlan) [1743210]
- [tools] perf tools: Fix perf.data documentation units for memory size (Michael Petlan) [1743210]
- [tools] perf header: Fix use of unitialized value warning (Michael Petlan) [1743210]
- [tools] perf header: Fix divide by zero error if f_header.attr_size==0 (Michael Petlan) [1743210]
- [tools] tools perf beauty: Fix usbdevfs_ioctl table generator to handle _IOC() (Michael Petlan) [1743210]
- [tools] perf build: Do not use -Wshadow on gcc < 4.8 (Michael Petlan) [1743210]
- [tools] perf probe: Avoid calling freeing routine multiple times for same pointer (Michael Petlan) [1743210]
- [tools] perf probe: Set pev->nargs to zero after freeing pev->args entries (Michael Petlan) [1743210]
- [tools] perf session: Fix loading of compressed data split across adjacent records (Michael Petlan) [1743210]
- [tools] perf stat: Always separate stalled cycles per insn (Michael Petlan) [1743210]
- [tools] perf stat: Fix segfault for event group in repeat mode (Michael Petlan) [1743210]
- [tools] perf tools: Fix proper buffer size for feature processing (Michael Petlan) [1743210]
- [tools] perf script: Fix off by one in brstackinsn IPC computation (Michael Petlan) [1743210]
- [tools] perf script: Improve man page description of metrics (Michael Petlan) [1743210]
- [tools] perf script: Fix --max-blocks man page description (Michael Petlan) [1743210]
- [tools] perf vendor events s390: Add JSON files for machine type 8561 (Michael Petlan) [1743210]
- [tools] perf cs-etm: Return errcode in cs_etm__process_auxtrace_info() (Michael Petlan) [1743210]
- [tools] perf cs-etm: Remove errnoeous ERR_PTR() usage in cs_etm__process_auxtrace_info (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export switch events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export switch events (Michael Petlan) [1743210]
- [tools] perf db-export: Export switch events (Michael Petlan) [1743210]
- [tools] perf db-export: Factor out db_export__threads() (Michael Petlan) [1743210]
- [tools] perf script: Add scripting operation process_switch() (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Use new 'has_calls' column (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Remove redundant semi-colons (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Add has_calls column to comms table (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Add has_calls column to comms table (Michael Petlan) [1743210]
- [tools] perf db-export: Also export thread's current comm (Michael Petlan) [1743210]
- [tools] perf db-export: Factor out db_export__comm() (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export comm details (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export comm details (Michael Petlan) [1743210]
- [tools] perf db-export: Export comm details (Michael Petlan) [1743210]
- [tools] perf db-export: Fix a white space issue in db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Move export__comm_thread into db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Export comm before exporting thread (Michael Petlan) [1743210]
- [tools] perf db-export: Export main_thread in db_export__sample() (Michael Petlan) [1743210]
- [tools] perf db-export: Pass main_thread to db_export__thread() (Michael Petlan) [1743210]
- [tools] perf db-export: Rename db_export__comm() to db_export__exec_comm() (Michael Petlan) [1743210]
- [tools] perf db-export: Get rid of db_export__deferred() (Michael Petlan) [1743210]
- [tools] perf trace: Auto bump rlimit(MEMLOCK) for eBPF maps sake (Michael Petlan) [1743210]
- [tools] perf test: Auto bump rlimit(MEMLOCK) for BPF test sake (Michael Petlan) [1743210]
- [tools] perf tools: Introduce rlimit__bump_memlock() helper (Michael Petlan) [1743210]
- [tools] perf-probe: Add user memory access attribute support (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf intel-bts: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf script: Assume native_arch for pipe mode (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Fix DROP VIEW power_events_view (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Fix DROP VIEW power_events_view (Michael Petlan) [1743210]
- [tools] perf hists browser: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf cs-etm: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf parse-events: remove unused variable: error (Michael Petlan) [1743210]
- [tools] perf parse-events: Remove unused variable 'i' (Michael Petlan) [1743210]
- [tools] perf metricgroup: Add missing list_del_init() when flushing egroups list (Michael Petlan) [1743210]
- [tools] perf tools: Use list_del_init() more thorougly (Michael Petlan) [1743210]
- [tools] perf tools: Use zfree() where applicable (Michael Petlan) [1743210]
- [tools] tools lib: Adopt zalloc()/zfree() from tools/perf (Michael Petlan) [1743210]
- [tools] perf tools: Move get_current_dir_name() cond prototype out of util.h (Michael Petlan) [1743210]
- [tools] perf namespaces: Move the conditional setns() prototype to namespaces.h (Michael Petlan) [1743210]
- [tools] perf tools: Add missing headers, mostly stdlib.h (Michael Petlan) [1743210]
- [tools] perf evsel: perf_evsel__name(NULL) is valid, no need to check evsel (Michael Petlan) [1743210]
- [tools] perf session: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf inject: The tool->read() call may pass a NULL evsel, handle it (Michael Petlan) [1743210]
- [tools] perf map: Fix potential NULL pointer dereference found by smatch tool (Michael Petlan) [1743210]
- [tools] perf trace: Fix potential NULL pointer dereference found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf annotate: Fix dereferencing freed memory found by the smatch tool (Michael Petlan) [1743210]
- [tools] perf top: Fix potential NULL pointer dereference detected by the smatch tool (Michael Petlan) [1743210]
- [tools] perf stat: Fix use-after-freed pointer detected by the smatch tool (Michael Petlan) [1743210]
- [tools] perf test mmap-thread-lookup: Initialize variable to suppress memory sanitizer warning (Michael Petlan) [1743210]
- [tools] perf script: Allow specifying the files to process guest samples (Michael Petlan) [1743210]
- [tools] perf tools metric: Don't include duration_time in group (Michael Petlan) [1743210]
- [tools] perf list: avoid extra : for --raw metrics (Michael Petlan) [1743210]
- [tools] perf vendor events intel: Metric fixes for SKX/CLX (Michael Petlan) [1743210]
- [tools] perf tools: Fix typos / broken sentences (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 L3C PMU aliasing (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 HHA PMU aliasing (Michael Petlan) [1743210]
- [tools] perf jevents: Add support for Hisi hip08 DDRC PMU aliasing (Michael Petlan) [1743210]
- [tools] perf pmu: Support more complex PMU event aliasing (Michael Petlan) [1743210]
- [tools] perf diff: Documentation -c cycles option (Michael Petlan) [1743210]
- [tools] perf diff: Print the basic block cycles diff (Michael Petlan) [1743210]
- [tools] perf diff: Link same basic blocks among different data (Michael Petlan) [1743210]
- [tools] perf diff: Use hists to manage basic blocks per symbol (Michael Petlan) [1743210]
- [tools] perf diff: Check if all data files with branch stacks (Michael Petlan) [1743210]
- [tools] perf hists: Add block_info in hist_entry (Michael Petlan) [1743210]
- [tools] perf symbol: Create block_info structure (Michael Petlan) [1743210]
- [tools] perf jevents: Use nonlocal include statements in pmu-events.c (Michael Petlan) [1743210]
- [tools] perf annotate: Add csky support (Michael Petlan) [1743210]
- [tools] perf stat: Fix metrics with --no-merge (Michael Petlan) [1743210]
- [tools] perf stat: Fix group lookup for metric group (Michael Petlan) [1743210]
- [tools] perf stat: Don't merge events in the same PMU (Michael Petlan) [1743210]
- [tools] perf stat: Make metric event lookup more robust (Michael Petlan) [1743210]
- [tools] tools lib: Move argv_{split, free} from tools/perf/util/ (Michael Petlan) [1743210]
- [tools] perf tools: Drop strxfrchar(), use strreplace() equivalent from kernel (Michael Petlan) [1743210]
- [tools] tools lib: Adopt strreplace() from the kernel (Michael Petlan) [1743210]
- [tools] perf tools: Ditch rtrim(), use strim() from tools/lib (Michael Petlan) [1743210]
- [tools] perf tools: Remove trim() implementation, use tools/lib's strim() (Michael Petlan) [1743210]
- [tools] tools lib: Adopt strim() from the kernel (Michael Petlan) [1743210]
- [tools] perf tools: Ditch rtrim(), use skip_spaces() to get closer to the kernel (Michael Petlan) [1743210]
- [tools] perf report: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf metricgroup: Use strsep() (Michael Petlan) [1743210]
- [tools] perf strfilter: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf probe: Use skip_spaces() for argv handling (Michael Petlan) [1743210]
- [tools] perf time-utils: Use skip_spaces() (Michael Petlan) [1743210]
- [tools] perf header: Use skip_spaces() in __write_cpudesc() (Michael Petlan) [1743210]
- [tools] perf stat: Use recently introduced skip_spaces() (Michael Petlan) [1743210]
- [tools] tools lib: Adopt skip_spaces() from the kernel sources (Michael Petlan) [1743210]
- [tools] perf tools: Use linux/ctype.h in more places (Michael Petlan) [1743210]
- [tools] tools perf: Move from sane_ctype.h obtained from git to the Linux's original (Michael Petlan) [1743210]
- [tools] perf tools: Add missing util.h to pick up 'page_size' variable (Michael Petlan) [1743210]
- [tools] perf tools: Remove old baggage that is util/include/linux/ctype.h (Michael Petlan) [1743210]
- [tools] perf symbols: We need util.h in symbol-elf.c for zfree() (Michael Petlan) [1743210]
- [tools] perf kallsyms: Adopt hex2u64 from tools/perf/util/util.h (Michael Petlan) [1743210]
- [tools] tools x86 machine: Add missing util.h to pick up 'page_size' (Michael Petlan) [1743210]
- [tools] perf string: Move 'dots' and 'graph_dotted_line' out of sane_ctype.h (Michael Petlan) [1743210]
- [tools] perf ctype: Remove now unused 'spaces' variable (Michael Petlan) [1743210]
- [tools] perf ui stdio: No need to use 'spaces' to left align (Michael Petlan) [1743210]
- [tools] perf ctype: Remove unused 'graph_line' variable (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export Intel PT power and ptwrite events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export Intel PT power and ptwrite events (Michael Petlan) [1743210]
- [tools] perf db-export: Export synth events (Michael Petlan) [1743210]
- [tools] perf intel-pt: Synthesize CBR events when last seen value changes (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add CBR value to decoder state (Michael Petlan) [1743210]
- [tools] perf intel-pt: Cater for CBR change in PSB+ (Michael Petlan) [1743210]
- [tools] perf intel-pt: Decoder to output CBR changes immediately (Michael Petlan) [1743210]
- [tools] perf thread-stack: Eliminate code duplicating thread_stack__pop_ks() (Michael Petlan) [1743210]
- [tools] perf thread-stack: Fix thread stack return from kernel for kernel-only case (Michael Petlan) [1743210]
- [tools] perf tools: Fix cache.h include directive (Michael Petlan) [1743210]
- [tools] tools build: Fix the zstd test in the test-all.c common case feature test (Michael Petlan) [1743210]
- [tools] perf build: Handle slang being in /usr/include and in /usr/include/slang/ (Michael Petlan) [1743210]
- [tools] tools build: Add test to check if slang.h is in /usr/include/slang/ (Michael Petlan) [1743210]
- [tools] perf tools: Don't hardcode host include path for libslang (Michael Petlan) [1743210]
- [tools] perf evsel: Make perf_evsel__name() accept a NULL argument (Michael Petlan) [1743210]
- [tools] perf trace: Fixup pointer arithmetic when consuming augmented syscall args (Michael Petlan) [1743210]
- [tools] perf pmu: Fix uncore PMU alias list for ARM64 (Michael Petlan) [1743210]
- [tools] perf tests: Add missing SPDX headers (Michael Petlan) [1743210]
- [tools] tools build feature tests: Add missing SPDX headers (Michael Petlan) [1743210]
- [tools] perf trace: Streamline validation of select syscall names list (Michael Petlan) [1743210]
- [tools] perf trace: Fix exclusion of not available syscall names from selector list (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add callchain to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add memory information to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add LBR information to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add XMM registers to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add gp registers to synthesized PEBS sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Synthesize PEBS sample basic information (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out common sample preparation for re-use (Michael Petlan) [1743210]
- [tools] perf intel-pt: Prepare to synthesize PEBS samples (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add decoder support for PEBS via PT (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add Intel PT packet decoder test (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add new packets for PEBS via PT (Michael Petlan) [1743210]
- [tools] perf tests arm64: Compile tests unconditionally (Michael Petlan) [1743210]
- [tools] perf trace: Skip unknown syscalls when expanding strace like syscall groups (Michael Petlan) [1743210]
- [tools] perf report: Support s390 diag event display on x86 (Michael Petlan) [1743210]
- [tools] perf report: Fix OOM error in TUI mode on s390 (Michael Petlan) [1743210]
- [tools] perf test 6: Fix missing kvm module load for s390 (Michael Petlan) [1743210]
- [tools] perf time-utils: Add support for multiple explicit time intervals (Michael Petlan) [1743210]
- [tools] perf tests: Add a test for time-utils (Michael Petlan) [1743210]
- [tools] perf time-utils: Make perf_time__parse_for_ranges() more logical (Michael Petlan) [1743210]
- [tools] perf time-utils: Simplify perf_time__parse_for_ranges() error paths slightly (Michael Petlan) [1743210]
- [tools] perf time-utils: Fix --time documentation (Michael Petlan) [1743210]
- [tools] perf time-utils: Prevent percentage time range overlap (Michael Petlan) [1743210]
- [tools] perf time-utils: Factor out set_percent_time() (Michael Petlan) [1743210]
- [tools] perf time-utils: Treat time ranges consistently (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for efficient time interval filtering (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for lookahead (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_get_buffer() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add intel_pt_fast_forward() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add reposition parameter to intel_pt_get_data() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_reposition() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_8b_tsc() (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add lookahead callback (Michael Petlan) [1743210]
- [tools] perf report: Set perf time interval in itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf script: Set perf time interval in itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf auxtrace: Add perf time interval to itrace_synth_ops (Michael Petlan) [1743210]
- [tools] perf config: Update default value for llvm.clang-bpf-cmd-template (Michael Petlan) [1743210]
- [tools] perf cs-etm: Properly set the value of 'old' and 'head' in snapshot mode (Michael Petlan) [1743210]
- [tools] perf data: Fix perf.data documentation for HEADER_CPU_TOPOLOGY (Michael Petlan) [1743210]
- [tools] perf tools: Apply new CPU topology sysfs attributes (Michael Petlan) [1743210]
- [tools] perf header: Rename "sibling cores" to "sibling sockets" (Michael Petlan) [1743210]
- [tools] perf stat: Support per-die aggregation (Michael Petlan) [1743210]
- [tools] perf header: Add die information in CPU topology (Michael Petlan) [1743210]
- [tools] perf cpumap: Retrieve die id information (Michael Petlan) [1743210]
- [tools] perf evsel: Remove superfluous nthreads system_wide setup in alloc_fd() (Michael Petlan) [1743210]
- [tools] perf record: Add support to collect callchains from kernel or user space only (Michael Petlan) [1743210]
- [tools] perf config: Bail out when a handler returns failure for a key-value pair (Michael Petlan) [1743210]
- [tools] perf trace: Exit when failing to build eBPF program (Michael Petlan) [1743210]
- [tools] perf trace: Associate more argument names with the filename beautifier (Michael Petlan) [1743210]
- [tools] perf trace: Consume the augmented_raw_syscalls payload (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Move reading filename to the loop (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Change helper to consider just the augmented_filename part (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Move the probe_read_str to a separate function (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Tell which args are filenames and how many bytes to copy (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Select find text when find bar is activated (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to Call Tree (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to Call Graph Graph (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add CallGraphModelParams (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add IPC information to the Branch reports (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Export IPC information (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Export IPC information (Michael Petlan) [1743210]
- [tools] perf db-export: Export IPC information (Michael Petlan) [1743210]
- [tools] perf db-export: Add brief documentation (Michael Petlan) [1743210]
- [tools] perf thread-stack: Accumulate IPC information (Michael Petlan) [1743210]
- [tools] perf intel-pt: Document IPC usage (Michael Petlan) [1743210]
- [tools] perf intel-pt: Accumulate cycle count from TSC/TMA/MTC packets (Michael Petlan) [1743210]
- [tools] perf intel-pt: Re-factor TIP cases in intel_pt_walk_to_ip (Michael Petlan) [1743210]
- [tools] perf intel-pt: Record when decoding PSB+ packets (Michael Petlan) [1743210]
- [tools] perf script: Add output of IPC ratio (Michael Petlan) [1743210]
- [tools] perf intel-pt: Add support for samples to contain IPC ratio (Michael Petlan) [1743210]
- [tools] perf tools: Add IPC information to perf_sample (Michael Petlan) [1743210]
- [tools] perf intel-pt: Accumulate cycle count from CYC packets (Michael Petlan) [1743210]
- [tools] perf intel-pt: Factor out intel_pt_update_sample_time (Michael Petlan) [1743210]
- [tools] perf record: Allow mixing --user-regs with --call-graph=dwarf (Michael Petlan) [1743210]
- [tools] perf symbols: Remove unused variable 'err' (Michael Petlan) [1743210]
- [tools] perf data: document directory format header: HEADER_DIR_FORMAT (Michael Petlan) [1743210]
- [tools] perf data: document clockid header: HEADER_CLOCKID (Michael Petlan) [1743210]
- [tools] perf data: document memory topology header: HEADER_MEM_TOPOLOGY (Michael Petlan) [1743210]
- [tools] perf data: Add description of header HEADER_BPF_PROG_INFO and HEADER_BPF_BTF (Michael Petlan) [1743210]
- [tools] perf intel-pt: Rationalize intel_pt_sync_switch()'s use of next_tid (Michael Petlan) [1743210]
- [tools] perf intel-pt: Improve sync_switch by processing PERF_RECORD_SWITCH* in events (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-postgresql.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: export-to-sqlite.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Add support for pyside2 (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Use argparse module for argument parsing (Michael Petlan) [1743210]
- [tools] perf scripts python: exported-sql-viewer.py: Change python2 to python (Michael Petlan) [1743210]
- [tools] perf top: Lower message level for failure on synthesizing events for pre-existing BPF programs (Michael Petlan) [1743210]
- [tools] perf machine: Return NULL instead of null-terminating /proc/version array (Michael Petlan) [1743210]
- [tools] perf version: Append 12 git SHA chars to the version string (Michael Petlan) [1743210]
- [tools] perf script: Remove superfluous BPF event titles (Michael Petlan) [1743210]
- [tools] perf script: Add --show-bpf-events to show eBPF related events (Michael Petlan) [1743210]
- [tools] perf tests: Add map_groups__merge_in test (Michael Petlan) [1743210]
- [tools] perf script: Pad DSO name for --call-trace (Michael Petlan) [1743210]
- [tools] perf dso: Add BPF DSO read and size hooks (Michael Petlan) [1743210]
- [tools] perf dso: Simplify dso_cache__read function (Michael Petlan) [1743210]
- [tools] perf dso: Separate generic code in dso_cache__read (Michael Petlan) [1743210]
- [tools] perf dso: Separate generic code in dso__data_file_size() (Michael Petlan) [1743210]
- [tools] perf tools: Remove const from thread read accessors (Michael Petlan) [1743210]
- [tools] perf top: Add --namespaces option (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for sync_file_range's 'flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fsmount' arguments (Michael Petlan) [1743210]
- [tools] perf trace: Introduce syscall_arg__scnprintf_strarray_flags (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fsmount's 'attr_flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fsconfig' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fsconfig's 'cmd' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'fspick' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for fspick's 'flags' arg values (Michael Petlan) [1743210]
- [tools] perf trace: Beautify 'move_mount' arguments (Michael Petlan) [1743210]
- [tools] perf beauty: Add generator for 'move_mount' flags argument (Michael Petlan) [1743210]
- [tools] perf augmented_raw_syscalls: Fix up comment (Michael Petlan) [1743210]
- [tools] perf tools: Preserve eBPF maps when loading kcore (Michael Petlan) [1743210]
- [tools] perf machine: Keep zero in pgoff BPF map (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix itrace defaults for perf script intel-pt documentation (Michael Petlan) [1743210]
- [tools] perf auxtrace: Fix itrace defaults for perf script (Michael Petlan) [1743210]
- [tools] perf intel-pt: Fix itrace defaults for perf script (Michael Petlan) [1743210]
- [tools] perf-with-kcore.sh: Always allow fix_buildid_cache_permissions (Michael Petlan) [1743210]
- [tools] tools build: Check if gettid() is available before providing helper (Michael Petlan) [1743210]
- [tools] tools build feature: Check if get_current_dir_name() is available (Michael Petlan) [1743210]
- [tools] perf jvmti: Address gcc string overflow warning for strncpy() (Michael Petlan) [1743210]
- [tools] perf python: Remove -fstack-protector-strong if clang doesn't have it (Michael Petlan) [1743210]
- [tools] perf annotate tui browser: Do not use member from variable within its own initialization (Michael Petlan) [1743210]
- [tools] perf thread: Allow references to thread objects after machine__exit() (Michael Petlan) [1743210]
- [fs] sysfs: Fix internal_create_group() for named group updates (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Support PEBS output to PT (Michael Petlan) [1743210]
- [kernel] perf: Allow normal events to output AUX data (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Handle erratum #420 only on the affected CPU family (10h) (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Fix reading of the IBS OpData register and thus precise RIP validity (Michael Petlan) [1743210]
- [kernel] perf/hw_breakpoint: Fix arch_hw_breakpoint use-before-initialization (Michael Petlan) [1743210]
- [x86] perf/x86/amd/ibs: Fix sample bias for dispatched micro-ops (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Restrict period on Nehalem (Michael Petlan) [1743210]
- [x86] perf/x86: Fix typo in comment (Michael Petlan) [1743210]
- [kernel] perf/core: Fix creating kernel counters for PMUs that override event->cpu (Michael Petlan) [1743210]
- [x86] perf/x86: Apply more accurate check on hypervisor platform (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Fix invalid Bit 13 for Icelake MSR_OFFCORE_RSP_x register (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Fix SLOTS PEBS event constraint (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Mark expected switch fall-throughs (Michael Petlan) [1743210]
- [kernel] perf_event_get(): don't bother with fget_raw() (Michael Petlan) [1743210]
- [kernel] perf/core: Fix exclusive events' grouping (Michael Petlan) [1743210]
- [x86] perf/x86/amd/uncore: Set the thread mask for F17h L3 PMCs (Michael Petlan) [1743210]
- [perf] x86/amd/uncore: Do not set 'ThreadMask' and 'SliceMask' for non-L3 PMCs (Michael Petlan) [1743210]
- [kernel] perf/core: Fix race between close() and fork() (Michael Petlan) [1743210]
- [perf] cgroups: Don't rotate events for cgroups unnecessarily (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get quirk state from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get attributes from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get MSR values from new probe framework (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Get rapl_cntr_mask from new probe framework (Michael Petlan) [1743210]
- [x86] intel: Aggregate big core client naming (Michael Petlan) [1743210]
- [x86] perf/x86/rapl: Use new MSR detection interface (Michael Petlan) [1743210]
- [x86] perf/x86/cstate: Use new probe function (Michael Petlan) [1743210]
- [x86] perf/x86/msr: Use new probe function (Michael Petlan) [1743210]
- [x86] perf/x86: Add MSR probe interface (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Disable check_msr for real HW (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Use ->is_visible callback for default group (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add IMC uncore support for Snow Ridge (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Clean up client IMC (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Support MMIO type uncore blocks (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Factor out box ref/unref functions (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add uncore support for Snow Ridge server (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Handle invalid event coding for free-running counter (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Add more Icelake CPUIDs (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Add Icelake desktop CPUID (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for default attributes (Michael Petlan) [1743210]
- [x86] perf/x86/intel: Use update attributes for skylake format (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for extra format (Michael Petlan) [1743210]
- [x86] perf/x86: Use update attribute groups for caps (Michael Petlan) [1743210]
- [x86] perf/x86: Add is_visible attribute_group callback for base events (Michael Petlan) [1743210]
- [x86] perf/x86: Use the new pmu::update_attrs attribute group (Michael Petlan) [1743210]
- [x86] perf/x86: Get rid of x86_pmu::event_attrs (Michael Petlan) [1743210]
- [x86] perf/x86/regs: Check reserved bits (Michael Petlan) [1743210]
- [fs] sysfs: Add sysfs_update_groups function (Michael Petlan) [1743210]
- [kernel] perf/core: Add attr_groups_update into struct pmu (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add new IMC PCI IDs for KabyLake, AmberLake and WhiskeyLake CPUs (Michael Petlan) [1743210]
- [x86] perf/x86/intel/uncore: Add tabs to Uncore IMC PCI IDs (Michael Petlan) [1743210]
- [kernel] perf/core: Allow non-privileged uprobe for user processes (Michael Petlan) [1743210]
- [x86] perf/x86: Add Intel Ice Lake NNPI uncore support (Michael Petlan) [1743210]
- [perf] arm_pmu: acpi: spe: Add initial MADT/SPE probing (Michael Petlan) [1743210]
- [netdrv] mwifiex: fix possible heap overflow in mwifiex_process_country_ie() (Jarod Wilson) [1776210] {CVE-2019-14895}
- [kernel] crash_core: Make S390 share the same crashkernel=auto reservation policy as X86_64 (Baoquan He) [1780432]
- [s390] kasan: avoid report in get_wchan (Philipp Rudo) [1780112 1780111]
- [s390] process: avoid potential reading of freed stack (Philipp Rudo) [1780112]
- [fs] cifs: don't use 'pre:' for MODULE_SOFTDEP (Leif Sahlberg) [1767094]
- [hwmon] Do not output deprecated warning for hwmon_device_register() (Prarit Bhargava) [1778295]
- [scsi] lpfc: size cpu map by last cpu id set (Dick Kennedy) [1778912]
- [scsi] lpfc: use hdwq assigned cpu for allocation (Dick Kennedy) [1778908]
- [scsi] be2iscsi: Include null char in SET_HOST_DATA (Maurizio Lombardi) [1776358]
- [netdrv] vmxnet3: turn off lro when rxcsum is disabled (Neil Horman) [1776056]
- [mmc] sdhci-pci: Add another Id for Intel CML (Alexander Beregalov) [1766718]
- [x86] kvm: untaint kernel for tech-preview when using nested VMX (Paolo Bonzini) [1726756]
- [powerpc] kvm: ppc: book3s hv: xive: Fix potential page leak on error path (Laurent Vivier) [1760202]
- [powerpc] kvm: ppc: book3s hv: xive: Free previous EQ page when setting up a new one (Laurent Vivier) [1760202]
- [virt] kvm: arm/arm64: vgic: Don't rely on the wrong pending table (Auger Eric) [1777059]
- [x86] kvm: x86: remove set but not used variable 'called' (Nitesh Narayan Lal) [1773677]
- [x86] kvm: x86: Zero the IOAPIC scan request dest vCPUs bitmap (Nitesh Narayan Lal) [1773677]
- [x86] kvm: x86: deliver KVM IOAPIC scan request to target vCPUs (Nitesh Narayan Lal) [1773677]
- [kernel] kvm: remember position in kvm->vcpus array (Nitesh Narayan Lal) [1773677]
- [kernel] watchdog: Reduce message verbosity (Vitaly Kuznetsov) [1774915]

* Fri Dec 06 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-161.rt13.18.el8]
- [fs] binfmt_elf: Do not move brk for INTERP-less ET_EXEC (Waiman Long) [1749633]
- [fs] binfmt_elf: move brk out of mmap when doing direct loader exec (Waiman Long) [1749633]
- [gpu] drm/i915/cmdparser: Fix jump whitelist clearing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/gen8+: Add RC6 CTX corruption WA (Dave Airlie) [1756805] {CVE-2019-0154}
- [gpu] drm/i915: Lower RM timeout to avoid DSI hard hangs (Dave Airlie) [1756805] {CVE-2019-0154}
- [gpu] drm/i915/cmdparser: Ignore Length operands during command matching (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/cmdparser: Add support for backward jumps (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915/cmdparser: Use explicit goto for error paths (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Add gen9 BCS cmdparsing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Allow parsing of unsized batches (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Support ro ppgtt mapped cmdparser shadow buffers (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Add support for mandatory cmdparsing (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Remove Master tables from cmdparser (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Disable Secure Batches for gen6+ (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] drm/i915: Rename gen7 cmdparser tables (Dave Airlie) [1756873] {CVE-2019-0155}
- [gpu] [drm] radeon: fix bad DMA from INTERRUPT_CNTL2 (Sam Bobroff) [1293697]
- [netdrv] mwifiex: Fix heap overflow in mmwifiex_process_tdls_action_frame() (Jarod Wilson) [1776162] {CVE-2019-14901}
- [netdrv] mlx4_en: Fix wrong limitation for number of TX rings (Mohammad Heib) [1776822]
- [netdrv] mlx4_en: fix mlx4 ethtool -N insertion (Mohammad Heib) [1776822]
- [netdrv] mlx4_core: fix wrong comment about the reason of subtract one from the max_cqes (Mohammad Heib) [1776822]
- [netdrv] ibmvnic: Serialize device queries (Steve Best) [1778037]
- [netdrv] ibmvnic: Bound waits for device queries (Steve Best) [1778037]
- [netdrv] ibmvnic: Terminate waiting device threads after loss of service (Steve Best) [1778037]
- [netdrv] ibmvnic: Fix completion structure initialization (Steve Best) [1778037]
- [netdrv] ibmvnic: Ignore H_FUNCTION return from H_EOI to tolerate XIVE mode (Steve Best) [1778037]
- [netdrv] revert "net/ibmvnic: Fix EOI when running in XIVE mode" (Steve Best) [1778037]
- [netdrv] cnic: Set fp_hsi_ver as part of CLIENT_SETUP ramrod (Manish Chopra) [1770797]
- [netdrv] bnx2x: Fix PF-VF communication over multi-cos queues (Manish Chopra) [1770797]
- [netdrv] bnx2x: Enable Multi-Cos feature (Manish Chopra) [1770797]
- [netdrv] bnx2x: Utilize FW 7.13.15.0 (Manish Chopra) [1770797]
- [fs] seq_file: fix problem when seeking mid-record (Bill O'Donnell) [1753822]
- [documentation] fs/seq_file.c: simplify seq_file iteration code and interface (Bill O'Donnell) [1753822]
- [scripts] kbuild: replace BASH-specific ${@:2} with shift and ${@} (Jiri Olsa) [1739493]
- [scripts] btf: do not use CONFIG_OUTPUT_FORMAT (Jiri Olsa) [1739493]
- [kernel] btf: fix return value check in btf_vmlinux_init() (Jiri Olsa) [1739493]
- [kernel] btf: rename /sys/kernel/btf/kernel into /sys/kernel/btf/vmlinux (Jiri Olsa) [1739493]
- [scripts] btf: expose BTF info through sysfs (Jiri Olsa) [1739493]
- [netdrv] qede: fix NULL pointer deref in __qede_remove() (Manish Chopra) [1769203]
- [gpu] cleanup: Remove .rej files (Prarit Bhargava) [1779738]
- [lib] string: Add strscpy_pad() function (Josef Oskera) [1764588]
- [char] virtio_console: allocate inbufs in add_port() only if it is needed (Pankaj Gupta) [1612795]
- [fs] xfs: add kmem_alloc_io() (Bill O'Donnell) [1583556]
- [fs] xfs: make mem_to_page available outside of xfs_buf.c (Bill O'Donnell) [1583556]
- [fs] xfs: get allocation alignment from the buftarg (Bill O'Donnell) [1583556]
- [fs] xfs: add kmem_alloc_io() (Bill O'Donnell) [1583556]
- [fs] cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs (Leif Sahlberg) [1765979]
- [fs] cifs: avoid using MID 0xFFFF (Leif Sahlberg) [1765979]
- [fs] cifs: Fix retry mid list corruption on reconnects (Leif Sahlberg) [1765979]
- [fs] nfsd: allow fh_want_write to be called twice ("J. Bruce Fields") [1699222]
- [net] revert "sunrpc: Fix up task signalling" (Dave Wysochanski) [1776067]
- [s390] kasan: support memcpy_real with TRACE_IRQFLAGS (Philipp Rudo) [1777468]
- [s390] kasan: add kdump support (Philipp Rudo) [1777468]
- [s390] idle: fix cpu idle time calculation (Philipp Rudo) [1777361]
- [s390] kaslr: add support for R_390_GLOB_DAT relocation type (Philipp Rudo) [1777467]
- [x86] jump_label: Make tp_vec_nr static (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Batch jump label updates (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Batch updates if arch supports it (Daniel Bristot de Oliveira) [1731860]
- [x86] alternative: Batch of patch operations (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Sort entries of the same key by the code (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Add a __jump_label_set_jump_code() helper (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Don't warn on __exit jump entries (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Add a jump_label_can_update() helper (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Remove the return value of text_poke_*() (Daniel Bristot de Oliveira) [1731860]
- [x86] jump-label: Remove support for custom text poker (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Use text_poke_early() during early init (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Add text_poke_kgdb() to not assert the lock when debugging (Daniel Bristot de Oliveira) [1731860]
- [x86] kprobes: Prohibit probing on functions before kprobe_int3_handler() (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Fix NULL dereference bug in __jump_label_mod_update() (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Annotate entries that operate on __init code earlier (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Switch to jump_entry accessors (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Implement generic support for relative references (Daniel Bristot de Oliveira) [1731860]
- [kernel] jump_label: Abstract jump_entry member accessors (Daniel Bristot de Oliveira) [1731860]
- [x86] alternatives: Lockdep-enforce text_mutex in text_poke*() (Daniel Bristot de Oliveira) [1731860]
- [x86] revert "x86/paravirt: Set up the virt_spin_lock_key after static keys get initialized" (Daniel Bristot de Oliveira) [1731860]
- [x86] jump_label: Initialize static branching early (Vitaly Kuznetsov) [1777260]
- [x86] speculation: Fix redundant MDS mitigation message (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation: Fix incorrect MDS/TAA mitigation status (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Fix printing of TAA_MSG_SMT on IBRS_ALL CPUs (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] tsx: Add config options to set tsx=on|off|auto (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [documentation] x86/speculation/taa: Add documentation for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] tsx: Add "auto" option to the tsx= cmdline parameter (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Add sysfs reporting for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] speculation/taa: Add mitigation for TSX Async Abort (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] cpu: Add a "tsx=" cmdline option with TSX disabled by default (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] cpu: Add a helper function x86_read_arch_cap_msr() (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [x86] msr: Add the IA32_TSX_CTRL MSR (Josh Poimboeuf) [1766551] {CVE-2019-11135}
- [powerpc] xive: Prevent page fault issues in the machine crash handler (Diego Domingos) [1756116]
- [tools] Fix memcpy_mcsafe_64.S link on selftests (Desnes Augusto Nunes do Rosario) [1775570]

* Wed Dec 04 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-160.rt13.17.el8]
- [powerpc] perf: Fix loop exit condition in nest_imc_event_init (Steve Best) [1778609]
- [net] netfilter: nf_tables: Add missing nft_tproxy Makefile line (Phil Sutter) [1762977]

* Sat Nov 30 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-159.rt13.16.el8]
- [x86] kdump: Remove the backup region handling (Lianbo Jiang) [1730143]
- [x86] kdump: Always reserve the low 1M when the crashkernel option is specified (Lianbo Jiang) [1730143]
- [x86] crash: Add a forward declaration of struct kimage (Lianbo Jiang) [1730143]
- [x86] kdump: Remove the unused crash_copy_backup_region() (Lianbo Jiang) [1730143]
- [pci] p2pdma: Fix missing check for dma_virt_ops (Don Dutile) [1754734]
- [pci] p2pdma: use the dev_pagemap internal refcount (Don Dutile) [1754734]
- [pci] memremap: pass a struct dev_pagemap to ->kill and ->cleanup (Don Dutile) [1754734]
- [pci] memremap: move dev_pagemap callbacks into a separate structure (Don Dutile) [1754734]
- [pci] mm/devm_memremap_pages: fix final page put race (Don Dutile) [1754734]
- [pci] p2pdma: track pgmap references per resource, not globally (Don Dutile) [1754734]
- [pci] p2pdma: fix the gen_pool_add_virt() failure path (Don Dutile) [1754734]
- [pci] mm, hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL (Don Dutile) [1754734]
- [lib] genalloc.c: Add algorithm, align and zeroed family of DMA allocators (Don Dutile) [1754732]
- [lib] genalloc.c: include vmalloc.h (Don Dutile) [1754732]
- [lib] genalloc.c: use vzalloc_node() to allocate the bitmap (Don Dutile) [1754732]
- [md] dm table: propagate BDI_CAP_STABLE_WRITES to fix sporadic checksum errors (Mike Snitzer) [1770210]
- [fs] gfs2: fix race between gfs2_freeze_func and unmount (Abhijith Das) [1676972]
- [fs] cifs: smbd: Retry on memory registration failure (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Indicate to retry on transport sending failure (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Return EINTR when interrupted (Leif Sahlberg) [1771772]
- [fs] cifs: smbd: Don't destroy transport on RDMA disconnect (Leif Sahlberg) [1771772]
- [lib] crc-t10dif: crc_t10dif_mutex can be static (Vladis Dronov) [1769462]
- [lib] crc-t10dif: Allow current transform to be inspected in sysfs (Vladis Dronov) [1769462]
- [lib] crc-t10dif: Pick better transform if one becomes available (Vladis Dronov) [1769462]
- [crypto] api - Introduce notifier for new crypto algorithms (Vladis Dronov) [1769462]
- [netdrv] e1000e: Drop unnecessary __E1000_DOWN bit twiddling (Ken Cox) [1748256]
- [netdrv] e1000e: Use rtnl_lock to prevent race conditions between net and pci/pm (Ken Cox) [1748256]

* Fri Nov 29 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-158.rt13.15.el8]
- [rt] lockdep: Increase MAX_LOCK_[ENTRIES|CHAIN_BITS] (Daniel Bristot de Oliveira) [1768730]
- [rt] Clean up rejected hunks (Juri Lelli)
- [powerpc] pseries: safely roll back failed DLPAR cpu add (Steve Best) [1772341]
- [powerpc] pseries: address checkpatch warnings in dlpar_offline_cpu (Steve Best) [1772341]
- [scsi] storvsc: setup 1:1 mapping between hardware queue and CPU queue (Cathy Avery) [1771503]
- [scsi] storvsc: Add ability to change scsi queue depth (Cathy Avery) [1771503]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 320 (Cathy Avery) [1771503]
- [scsi] smartpqi: bump version (Don Brace) [1725045]
- [scsi] smartpqi: Align driver syntax with oob (Don Brace) [1725045]
- [scsi] smartpqi: remove unused manifest constants (Don Brace) [1725045]
- [scsi] smartpqi: fix problem with unique ID for physical device (Don Brace) [1725045]
- [scsi] smartpqi: correct syntax issue (Don Brace) [1725045]
- [scsi] smartpqi: change TMF timeout from 60 to 30 seconds (Don Brace) [1725045]
- [scsi] smartpqi: fix LUN reset when fw bkgnd thread is hung (Don Brace) [1725045]
- [scsi] smartpqi: add inquiry timeouts (Don Brace) [1725045]
- [scsi] smartpqi: fix call trace in device discovery (Don Brace) [1725045]
- [scsi] smartpqi: fix controller lockup observed during force reboot (Don Brace) [1725045]
- [scsi] smartpqi: clean up an indentation issue (Don Brace) [1725045]
- [scsi] smartpqi: remove set but not used variable 'ctrl_info' (Don Brace) [1725045]
- [scsi] smartpqi: clean up indentation of a statement (Don Brace) [1725045]
- [scsi] smartpqi: bump version (Don Brace) [1725045]
- [scsi] smartpqi: update copyright (Don Brace) [1725045]
- [scsi] smartpqi: add new pci ids (Don Brace) [1725045]
- [scsi] smartpqi: correct REGNEWD return status (Don Brace) [1725045]
- [scsi] smartpqi: add gigabyte controller (Don Brace) [1725045]
- [scsi] smartpqi: correct hang when deleting 32 lds (Don Brace) [1725045]
- [scsi] smartpqi: add bay identifier (Don Brace) [1725045]
- [scsi] smartpqi: add sysfs entries (Don Brace) [1725045]
- [scsi] smartpqi: add module param to hide vsep (Don Brace) [1725045]
- [scsi] smartpqi: add pci ids for fiberhome controller (Don Brace) [1725045]
- [scsi] smartpqi: add module param for exposure order (Don Brace) [1725045]
- [scsi] smartpqi: unlock on error in pqi_submit_raid_request_synchronous() (Don Brace) [1725045]
- [scsi] smartpqi: Reporting unhandled SCSI errors (Don Brace) [1725045]
- [scsi] mpt3sas: Bump mpt3sas driver version to 32.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix module parameter max_msix_vectors (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reject NVMe Encap cmnds to unsupported HBA (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use Component img header to get Package ver (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fail release cmnd if diag buffer is released (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add app owned flag support for diag buffer (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reuse diag buffer allocated at load time (Tomas Henzl) [1725737]
- [scsi] mpt3sas: clear release bit when buffer reregistered (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Maintain owner of buffer through UniqueID (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Free diag buffer without any status check (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix clear pending bit in ioctl status (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Display message before releasing diag buffer (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Register trace buffer based on NVDATA settings (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Introduce module parameter to override queue depth (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update driver version to 31.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Run SAS DEVICE STATUS CHANGE EVENT from ISR (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Reduce the performance drop (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Handle fault during HBA initialization (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add sysfs to know supported features (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Support MEMORY MOVE Tool box command (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Allow ioctls to blocked access status NVMe (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Enumerate SES of a managed PCIe switch (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update MPI headers to 2.6.8 spec (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Gracefully handle online firmware update (Tomas Henzl) [1725737]
- [scsi] mpt3sas: memset request frame before reusing (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add support for PCIe Lane margin (Tomas Henzl) [1725737]
- [scsi] mpt3sas: support target smid for [abort|query] task (Tomas Henzl) [1725737]
- [scsi] mpt3sas: clean up a couple sizeof() uses (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Fix msix load balance on and off settings (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Determine smp affinity on per HBA basis (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use configured PCIe link speed, not max (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Remove CPU arch check to determine perf_mode (Tomas Henzl) [1725737]
- [scsi] mpt3sas: use DEVICE_ATTR_{RO, RW} (Tomas Henzl) [1725737]
- [scsi] mpt3sas: make driver options visible in sys (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Mark expected switch fall-through (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Update driver version to 29.100.00.00 (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Introduce perf_mode module parameter (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Enable interrupt coalescing on high iops (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Affinity high iops queues IRQs to local node (Tomas Henzl) [1725737]
- [scsi] mpt3sas: save and use MSI-X index for posting RD (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Use high iops queues under some circumstances (Tomas Henzl) [1725737]
- [scsi] mpt3sas: change _base_get_msix_index prototype (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add flag high_iops_queues (Tomas Henzl) [1725737]
- [scsi] mpt3sas: Add Atomic RequestDescriptor support on Aero (Tomas Henzl) [1725737]
- [scsi] mpt3sas: function pointers of request descriptor (Tomas Henzl) [1725737]
- [scsi] mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main() (Tomas Henzl) [1725737]
- [md] revert "dm crypt: use WQ_HIGHPRI for the IO and crypt workqueues" (Mike Snitzer) [1775756]
- [md] dm thin: wakeup worker only when deferred bios exist (Mike Snitzer) [1775756]
- [md] dm raid: Remove unnecessary negation of a shift in raid10_format_to_md_layout (Mike Snitzer) [1775756]
- [md] dm writecache: handle REQ_FUA (Mike Snitzer) [1775756]
- [md] dm writecache: fix uninitialized variable warning (Mike Snitzer) [1775756]
- [md] dm stripe: use struct_size() in kmalloc() (Mike Snitzer) [1775756]
- [md] dm table: do not allow request-based DM to stack on partitions (Mike Snitzer) [1775756]
- [md] dm cache: fix bugs when a GFP_NOWAIT allocation fails (Mike Snitzer) [1775756]
- [md] dm writecache: skip writecache_wait for pmem mode (Mike Snitzer) [1775756]
- [md] dm stats: use struct_size() helper (Mike Snitzer) [1775756]
- [md] dm space map common: remove check for impossible sm_find_free() return value (Mike Snitzer) [1775756]
- [md] dm raid1: use struct_size() with kzalloc() (Mike Snitzer) [1775756]
- [md] dm writecache: optimize performance by sorting the blocks for writeback_all (Mike Snitzer) [1775756]
- [md] dm writecache: add unlikely for getting two block with same LBA (Mike Snitzer) [1775756]
- [md] dm writecache: remove unused member pointer in writeback_struct (Mike Snitzer) [1775756]
- [md] dm: make dm_table_find_target return NULL (Mike Snitzer) [1775756]
- [md] dm table: fix invalid memory accesses with too high sector number (Mike Snitzer) [1775756]
- [md] dm space map metadata: fix missing store of apply_bops() return value (Mike Snitzer) [1775756]
- [md] dm btree: fix order of block initialization in btree_split_beneath (Mike Snitzer) [1775756]
- [md] dm raid: add missing cleanup in raid_ctr() (Mike Snitzer) [1775756]
- [md] dm kcopyd: always complete failed jobs (Mike Snitzer) [1775756]
- [md] dm crypt: remove obsolete comment about plumb IV (Mike Snitzer) [1775756]
- [md] dm crypt: wipe private IV struct after key invalid flag is set (Mike Snitzer) [1775756]
- [md] dm: update stale comment in end_clone_bio() (Mike Snitzer) [1775756]
- [md] dm log writes: fix incorrect comment about the logged sequence example (Mike Snitzer) [1775756]
- [md] dm log writes: use struct_size() to calculate size of pending_block (Mike Snitzer) [1775756]
- [md] dm crypt: use struct_size() when allocating encryption context (Mike Snitzer) [1775756]
- [md] dm thin metadata: check if in fail_io mode when setting needs_check (Mike Snitzer) [1775756]
- [md] dm verity: use message limit for data block corruption message (Mike Snitzer) [1775756]
- [md] dm log writes: make sure super sector log updates are written in order (Mike Snitzer) [1775756]
- [md] dm: fix a couple brace coding style issues (Mike Snitzer) [1775756]
- [md] dm crypt: print device name in integrity error message (Mike Snitzer) [1775756]
- [documentation] dm integrity: update documentation (Mike Snitzer) [1775756]
- [md] dm integrity: don't report unused options (Mike Snitzer) [1775756]
- [md] dm integrity: don't check null pointer before kvfree and vfree (Mike Snitzer) [1775756]
- [md] dm integrity: correctly calculate the size of metadata area (Mike Snitzer) [1775756]
- [md] dm mpath: always free attached_handler_name in parse_path() (Mike Snitzer) [1775756]
- [md] dm writecache: avoid unnecessary lookups in writecache_find_entry() (Mike Snitzer) [1775756]
- [md] dm writecache: remove unused member page_offset in writeback_struct (Mike Snitzer) [1775756]
- [md] dm delay: fix a crash when invalid device is specified (Mike Snitzer) [1775756]
- [md] dm: only initialize md->dax_dev if CONFIG_DAX_DRIVER is enabled (Mike Snitzer) [1775756]
- [md] dm writecache: add unlikely for returned value of rb_next_prev (Mike Snitzer) [1775756]
- [md] dm writecache: remove needless dereferences in __writecache_writeback_pmem() (Mike Snitzer) [1775756]
- [md] dm crypt: fix endianness annotations around org_sector_of_dmreq (Mike Snitzer) [1775756]
- [md] dm integrity: fix deadlock with overlapping I_O (Mike Snitzer) [1775756]
- [md] dm: disable DISCARD if the underlying storage no longer supports it (Mike Snitzer) [1775756]
- [md] dm: revert 8f50e358153d ("dm: limit the max bio size as BIO_MAX_PAGES * PAGE_SIZE") (Mike Snitzer) [1775756]
- [md] dm integrity: make dm_integrity_init and dm_integrity_exit static (Mike Snitzer) [1775756]
- [md] dm integrity: change memcmp to strncmp in dm_integrity_ctr (Mike Snitzer) [1775756]
- [x86] platform/uv: Account for UV Hubless in is_uvX_hub Ops (Frank Ramsay) [1757510]
- [x86] platform/uv: Check EFI Boot to set reboot type (Frank Ramsay) [1757510]
- [x86] platform/uv: Decode UVsystab Info (Frank Ramsay) [1757510]
- [x86] platform/uv: Add UV Hubbed/Hubless Proc FS Files (Frank Ramsay) [1757510]
- [x86] platform/uv: Setup UV functions for Hubless UV Systems (Frank Ramsay) [1757510]
- [x86] platform/uv: Add return code to UV BIOS Init function (Frank Ramsay) [1757510]
- [x86] platform/uv: Return UV Hubless System Type (Frank Ramsay) [1757510]
- [x86] platform/uv: Save OEM_ID from ACPI MADT probe (Frank Ramsay) [1757510]
- [x86] mm: Handle physical-virtual alignment mismatch in phys_p4d_init() (Baoquan He) [1685383]
- [x86] mm/kaslr: Reduce randomization granularity for 5-level paging to 1GB (Baoquan He) [1685383]
- [x86] mm/kaslr: Use only one PUD entry for real mode trampoline (Baoquan He) [1685383]
- [documentation] documentation/stackprotector: powerpc supports stack protector (Bhupesh Sharma) [1714310]
- [makefile] kbuild: mark prepare0 as PHONY to fix external module build (Bhupesh Sharma) [1714310]
- [makefile] kbuild: fix single target build for external module (Bhupesh Sharma) [1714310]
- [arm64] enable per-task stack canaries (Bhupesh Sharma) [1714310]
- [powerpc] Fix stack protector crashes on CPU hotplug (Bhupesh Sharma) [1714310]
- [powerpc] 64: properly initialise the stackprotector canary on SMP (Bhupesh Sharma) [1714310]
- [powerpc] Fix stackprotector detection for non-glibc toolchains (Bhupesh Sharma) [1714310]
- [powerpc] 64: add stack protector support (Bhupesh Sharma) [1714310]
- [powerpc] 32: add stack protector support (Bhupesh Sharma) [1714310]
- [pci] vmd: Fix shadow offsets to reflect spec changes (Myron Stowe) [1757896]
- [pci] vmd: Fix config addressing when using bus offsets (Myron Stowe) [1757896]
- [pci] Fix typos and whitespace errors (Myron Stowe) [1757896]
- [pci] vmd: use the proper dma_* APIs instead of direct methods calls (Myron Stowe) [1757896]
- [powerpc] powernv: Disable native PCIe port management (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix eeh eeh_debugfs_break_device() with SRIOV devices (Gustavo Duarte) [1524642]
- [tools] selftests/powerpc: Add basic EEH selftest (Gustavo Duarte) [1524642]
- [powerpc] eeh: Add a eeh_dev_break debugfs interface (Gustavo Duarte) [1524642]
- [powerpc] eeh: Add debugfs interface to run an EEH check (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix debugfs_simple_attr.cocci warnings (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix build with STACKTRACE=n (Gustavo Duarte) [1524642]
- [powerpc] eeh: Set attention indicator while recovering (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add attention indicator support (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add support for IODA3 Power9 PHBs (Gustavo Duarte) [1524642]
- [pci] pci-hotplug/pnv_php: Add a reset_slot() callback (Gustavo Duarte) [1524642]
- [powerpc] powernv/eeh: Use generic code to handle hot resets (Gustavo Duarte) [1524642]
- [powerpc] eeh: Remove stale CAPI comment (Gustavo Duarte) [1524642]
- [powerpc] eeh: Defer printing stack trace (Gustavo Duarte) [1524642]
- [powerpc] eeh: Check slot presence state in eeh_handle_normal_event() (Gustavo Duarte) [1524642]
- [powerpc] eeh: Make permanently failed devices non-actionable (Gustavo Duarte) [1524642]
- [powerpc] eeh: Fix race when freeing PDNs (Gustavo Duarte) [1524642]
- [powerpc] eeh: Clean up EEH PEs after recovery finishes (Gustavo Duarte) [1524642]
- [netdrv] be2net: disable bh with spin_lock in be_process_mcc (Petr Oros) [1724777]
- [netdrv] be2net: Synchronize be_update_queues with dev_watchdog (Petr Oros) [1724777]
- [netdrv] be2net: Signal that the device cannot transmit during reconfiguration (Petr Oros) [1724777]
- [netdrv] be2net: fix link failure after ethtool offline test (Petr Oros) [1724777]
- [netdrv] be2net: Fix number of Rx queues used for flow hashing (Petr Oros) [1724777]
- [netdrv] benet: remove broken and unused macro (Petr Oros) [1724777]
- [netdrv] benet: use skb_vlan_tag_get_prio() (Petr Oros) [1724777]
- [netdrv] benet: use __vlan_hwaccel helpers (Petr Oros) [1724777]
- [netdrv] revert "[netdrv] be2net: Disable queue dump in be_tx_timeout handler" (Petr Oros) [1724777]
- [infiniband] rdma/i40iw: Set queue pair state when being queried (Stefan Assmann) [1721712]
- [infiniband] ib/i40iw: Use kmemdup rather than open coding (Stefan Assmann) [1721712]
- [infiniband] rdma/i40iw: Handle workqueue allocation failure (Stefan Assmann) [1721712]
- [nvdimm] libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: Fix namespace creation on misaligned addresses (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: stop padding pmem namespaces to section alignment (Baoquan He) [1724969]
- [nvdimm] libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields" (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock" (Baoquan He) [1724969]
- [nvdimm] revert "libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change" (Baoquan He) [1724969]
- [mm] sparsemem: cleanup 'section number' data types (Baoquan He) [1724969]
- [kernel] mm/devm_memremap_pages: enable sub-section remap (Baoquan He) [1724969]
- [mm] sparsemem: support sub-section hotplug (Baoquan He) [1724969]
- [mm] sparsemem: prepare for sub-section ranges (Baoquan He) [1724969]
- [kernel] mm: kill is_dev_zone() helper (Baoquan He) [1724969]
- [mm] hotplug: kill is_dev_zone() usage in __remove_pages() (Baoquan He) [1724969]
- [mm] sparsemem: convert kmalloc_section_memmap() to populate_section_memmap() (Baoquan He) [1724969]
- [mm] hotplug: prepare shrink_{zone, pgdat}_span for sub-section removal (Baoquan He) [1724969]
- [mm] sparsemem: add helpers track active portions of a section at boot (Baoquan He) [1724969]
- [mm] sparsemem: introduce a SECTION_IS_EARLY flag (Baoquan He) [1724969]
- [mm] sparsemem: introduce struct mem_section_usage (Baoquan He) [1724969]
- [base] base/memory.c: get rid of find_memory_block_hinted() (Baoquan He) [1724969]
- [mm] memory_hotplug: move and simplify walk_memory_blocks() (Baoquan He) [1724969]
- [mm] memory_hotplug: rename walk_memory_range() and pass start+size instead of pfns (Baoquan He) [1724969]
- [mm] hotplug: make remove_memory() interface usable (Baoquan He) [1724969]
- [kernel] mm: make register_mem_sect_under_node() static (Baoquan He) [1724969]
- [base] base/memory: use "unsigned long" for block ids (Baoquan He) [1724969]
- [base] mm: section numbers use the type "unsigned long" (Baoquan He) [1724969]
- [base] base/memory.c: Use DEVICE_ATTR_RO and friends (Baoquan He) [1724969]
- [mm] sparse.c: set section nid for hot-add memory (Baoquan He) [1724969]
- [mm] memory_hotplug: remove "zone" parameter from sparse_remove_one_section (Baoquan He) [1724969]
- [base] mm/memory_hotplug: make unregister_memory_block_under_nodes() never fail (Baoquan He) [1724969]
- [base] mm/memory_hotplug: remove memory block devices before arch_remove_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: drop MHP_MEMBLOCK_API (Baoquan He) [1724969]
- [base] mm/memory_hotplug: create memory block devices after arch_add_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: allow arch_remove_memory() without CONFIG_MEMORY_HOTREMOVE (Baoquan He) [1724969]
- [arm64] mm: add temporary arch_remove_memory() implementation (Baoquan He) [1724969]
- [mm] sparse.c: clean up obsolete code comment (Baoquan He) [1724969]
- [base] base/memory: pass a block_id to init_memory_block() (Baoquan He) [1724969]
- [base] base/memory.c: remove an unnecessary check on NR_MEM_SECTIONS (Baoquan He) [1724969]
- [s390] s390x/mm: implement arch_remove_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: make __remove_section() never fail (Baoquan He) [1724969]
- [base] mm/memory_hotplug: make unregister_memory_section() never fail (Baoquan He) [1724969]
- [base] base/memory.c: clean up relics in function parameters (Baoquan He) [1724969]
- [base] mm, memory_hotplug: update a comment in unregister_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: release memory resource after arch_remove_memory() (Baoquan He) [1724969]
- [kernel] mm, memory_hotplug: provide a more generic restrictions for memory hotplug (Baoquan He) [1724969]
- [kernel] linux/memory_hotplug.h: remove duplicate declaration of offline_pages() (Baoquan He) [1724969]
- [mm] x86: respect memory size limiting via mem= parameter (Baoquan He) [1724969]
- [arm64] Add memory hotplug support (Baoquan He) [1724969]
- [arm64] mm: check for upper PAGE_SHIFT bits in pfn_valid() (Baoquan He) [1724969]
- [powerpc] mm: Fix section mismatch warning (Baoquan He) [1724969]
- [base] mm/memory_hotplug: do not unlock after failing to take the device_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: drop "online" parameter from add_memory_resource() (Baoquan He) [1724969]
- [s390] s390x/mm: fail when an altmap is used for arch_add_memory() (Baoquan He) [1724969]
- [mm] memory_hotplug: simplify and fix check_hotplug_memory_range() (Baoquan He) [1724969]
- [mm] memory_hotplug: add nid parameter to arch_remove_memory (Baoquan He) [1724969]
- [mm] sparse: pass nid instead of pgdat to sparse_add_one_section() (Baoquan He) [1724969]
- [mm] sparse: drop pgdat_resize_lock in sparse_add/remove_one_section() (Baoquan He) [1724969]
- [documentation] memory-hotplug.rst: add some details about locking internals (Baoquan He) [1724969]
- [powerpc] powernv: hold device_hotplug_lock when calling memtrace_offline_pages() (Baoquan He) [1724969]
- [powerpc] powernv: hold device_hotplug_lock when calling device_online() (Baoquan He) [1724969]
- [powerpc] powernv: Allow memory that has been hot-removed to be hot-added (Baoquan He) [1724969]
- [powerpc] powernv/memtrace: Remove memtrace mmap() (Baoquan He) [1724969]
- [mm] memory_hotplug: fix online/offline_pages called w.o. mem_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: make add_memory() take the device_hotplug_lock (Baoquan He) [1724969]
- [mm] memory_hotplug: make remove_memory() take the device_hotplug_lock (Baoquan He) [1724969]
- [powerpc] memtrace: Remove memory in chunks (Baoquan He) [1724969]
- [base] mm/memory_hotplug.c: drop unnecessary checks from register_mem_sect_under_node() (Baoquan He) [1724969]
- [base] mm/memory_hotplug.c: make register_mem_sect_under_node() a callback of walk_memory_range() (Baoquan He) [1724969]
- [mm] memory_hotplug.c: call register_mem_sect_under_node() (Baoquan He) [1724969]
- [mm] memory_hotplug.c: make add_memory_resource use __try_online_node (Baoquan He) [1724969]
- [pci] Always allow probing with driver_override (Myron Stowe) [1702178]
- [pci] Return error if cannot probe VF (Myron Stowe) [1702178]
- [target] scsi: target: core: Do not overwrite CDB byte 1 (Maurizio Lombardi) [1764579]
- [target] scsi: target: tcmu: clean the nl_cmd of the udev when nl send fails (Maurizio Lombardi) [1764579]
- [target] scsi: target: tcmu: avoid use-after-free after command timeout (Maurizio Lombardi) [1764579]
- [target] scsi: tcmu: Simplify tcmu_update_uio_info() (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: fix possible condition with no effect (if == else) (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Make sure PDU processing continues if parsing a command fails (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Make iscsit_map_iovec() more robust (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Handle too large immediate data buffers correctly (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Only send R2T if needed (Maurizio Lombardi) [1764579]
- [target] scsi: target/iscsi: Detect conn_cmd_list corruption early (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Make the XCOPY setup code easier to read by inlining two functions (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Simplify LUN initialization in XCOPY implementation (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Remove a set-but-not-used member variable from the XCOPY implementation (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Rework the SPC-2 reservation handling code (Maurizio Lombardi) [1764579]
- [target] scsi: target/core: Fix a race condition in the LUN lookup code (Maurizio Lombardi) [1764579]
- [target] scsi: target: alua: fix the tg_pt_gps_count (Maurizio Lombardi) [1764579]
- [target] scsi: target: iscsi: Free conn_ops when zalloc_cpumask_var failed (Maurizio Lombardi) [1764579]
- [target] scsi: target: iscsi: Fix np_ip_proto and np_sock_type in iscsit_setup_np (Maurizio Lombardi) [1764579]
- [target] scsi: target: fix unsigned comparision with less than zero (Maurizio Lombardi) [1764579]
- [target] scsi: target: Add device product id and revision configfs attributes (Maurizio Lombardi) [1764579]
- [kernel] genirq/affinity: Remove const qualifier from node_to_cpumask argument (Ming Lei) [1743064]
- [kernel] genirq/affinity: Spread vectors on node according to nr_cpu ratio (Ming Lei) [1743064]
- [kernel] genirq/affinity: Improve __irq_build_affinity_masks() (Ming Lei) [1743064]
- [kernel] genirq/affinity: Remove unused argument from [__]irq_build_affinity_masks() (Ming Lei) [1743064]
- [kernel] workqueue, lockdep: Fix a memory leak in wq->lock_name (Waiman Long) [1736654]
- [kernel] workqueue, lockdep: Fix an alloc_workqueue() error path (Waiman Long) [1736654]
- [kernel] locking/lockdep: Report more stack trace statistics (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reduce space occupied by stack traces (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make it clear that what lock_class::key points at is not modified (Waiman Long) [1736654]
- [kernel] lockdep: Make print_lock() address visible (Waiman Long) [1736654]
- [kernel] locking/lockdep: Clean up #ifdef checks (Waiman Long) [1736654]
- [kernel] locking/lockdep: Hide unused 'class' variable (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix lock used or unused stats error (Waiman Long) [1736654]
- [kernel] locking/lockdep: increase size of counters for lockdep statistics (Waiman Long) [1736654]
- [kernel] locking/lockdep: Move mark_lock() inside CONFIG_TRACE_IRQFLAGS && CONFIG_PROVE_LOCKING (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unnecessary DEBUG_LOCKS_WARN_ON() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix merging of hlocks with non-zero references (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix OOO unlock when hlocks need merging (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove !dir in lock irq usage check (Waiman Long) [1736654]
- [kernel] locking/lockdep: Adjust new bit cases in mark_lock (Waiman Long) [1736654]
- [kernel] locking/lockdep: Consolidate lock usage bit initialization (Waiman Long) [1736654]
- [kernel] locking/lockdep: Check redundant dependency only when CONFIG_LOCKDEP_SMALL (Waiman Long) [1736654]
- [kernel] locking/lockdep: Refactorize check_noncircular and check_redundant (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unused argument in __lock_release (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove redundant argument in check_deadlock (Waiman Long) [1736654]
- [documentation] locking/lockdep: Add explanation to lock usage rules in lockdep design doc (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update comments on dependency search (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid constant checks in __bfs by using offset reference (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change the return type of __cq_dequeue() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change type of the element field in circular_queue (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update comment (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unused argument in validate_chain() and check_deadlock() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change the range of class_idx in held_lock struct (Waiman Long) [1736654]
- [kernel] locking/lockdep: Define INITIAL_CHAIN_KEY for chain keys to start with (Waiman Long) [1736654]
- [kernel] locking/lockdep: Use lockdep_init_task for task initiation consistently (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update obsolete struct field description (Waiman Long) [1736654]
- [kernel] locking/lockdep: Print the right depth for chain key collision (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove useless conditional macro (Waiman Long) [1736654]
- [kernel] locking/lockdep: Adjust lock usage bit character checks (Waiman Long) [1736654]
- [documentation] locking/lockdep: Add description and explanation in lockdep design doc (Waiman Long) [1736654]
- [kernel] locking/lockdep: Change all print_*() return type to void (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove the unused print_lock_trace() function (Waiman Long) [1736654]
- [kernel] locking/lockdep: Don't complain about incorrect name for no validate class (Waiman Long) [1736654]
- [kernel] lockdep: Add assertion to check if in an interrupt (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove unnecessary unlikely() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Test all incompatible scenarios at once in check_irq_usage() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid bogus Clang warning (Waiman Long) [1736654]
- [kernel] locking/lockdep: Generate LOCKF_ bit composites (Waiman Long) [1736654]
- [kernel] locking/lockdep: Use expanded masks on find_usage_*() functions (Waiman Long) [1736654]
- [kernel] locking/lockdep: Map remaining magic numbers to lock usage mask names (Waiman Long) [1736654]
- [kernel] locking/lockdep: Move valid_state() inside CONFIG_TRACE_IRQFLAGS && CONFIG_PROVE_LOCKING (Waiman Long) [1736654]
- [kernel] lockdep: Simplify stack trace handling (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make lockdep_unregister_key() honor 'debug_locks' again (Waiman Long) [1736654]
- [kernel] locking/lockdep: Zap lock classes even with lock debugging disabled (Waiman Long) [1736654]
- [kernel] locking/lockdep: Only call init_rcu_head() after RCU has been initialized (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid a Clang warning (Waiman Long) [1736654]
- [kernel] locking/lockdep: Shrink struct lock_class_key (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add module_param to enable consistency checks (Waiman Long) [1736654]
- [tools] lockdep/lib/tests: Test dynamic key registration (Waiman Long) [1736654]
- [tools] lockdep/lib/tests: Fix run_tests.sh (Waiman Long) [1736654]
- [kernel] workqueue: Use dynamic lockdep keys for workqueues (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add support for dynamic keys (Waiman Long) [1736654]
- [kernel] locking/lockdep: Verify whether lock objects are small enough to be used as class keys (Waiman Long) [1736654]
- [kernel] locking/lockdep: Check data structure consistency (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reuse lock chains that have been freed (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix a comment in add_chain_cache() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Introduce lockdep_next_lockchain() and lock_chain_count() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reuse list entries that are no longer in use (Waiman Long) [1736654]
- [kernel] locking/lockdep: Free lock classes that are no longer in use (Waiman Long) [1736654]
- [kernel] locking/lockdep: Update two outdated comments (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make it easy to detect whether or not inside a selftest (Waiman Long) [1736654]
- [kernel] locking/lockdep: Split lockdep_free_key_range() and lockdep_reset_lock() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Initialize the locks_before and locks_after lists earlier (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make zap_class() remove all matching lock order entries (Waiman Long) [1736654]
- [kernel] locking/lockdep: Reorder struct lock_class members (Waiman Long) [1736654]
- [kernel] locking/lockdep: Avoid that add_chain_cache() adds an invalid chain to the cache (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix reported required memory size (2/2) (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix reported required memory size (1/2) (Waiman Long) [1736654]
- [kernel] locking/lockdep: Fix two 32-bit compiler warnings (Waiman Long) [1736654]
- [kernel] locking/lockdep: Rename lockdep_info() to lockdep_init() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add debug_locks check in __lock_downgrade() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Provide enum lock_usage_bit mask names (Waiman Long) [1736654]
- [kernel] locking/lockdep: Simplify mark_held_locks() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Add debug_locks check in __lock_downgrade() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Stop using RCU primitives to access 'all_lock_classes' (Waiman Long) [1736654]
- [kernel] locking/lockdep: Make concurrent lockdep_reset_lock() calls safe (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove a superfluous INIT_LIST_HEAD() statement (Waiman Long) [1736654]
- [kernel] locking/lockdep: Introduce lock_class_cache_is_registered() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Inline __lockdep_init_map() (Waiman Long) [1736654]
- [kernel] locking/lockdep: Declare local symbols static (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Test the lockdep_reset_lock() implementation (Waiman Long) [1736654]
- [tools] lib/lockdep: Add dummy print_irqtrace_events() implementation (Waiman Long) [1736654]
- [tools] lib/lockdep: Rename "trywlock" into "trywrlock" (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Run lockdep tests a second time under Valgrind (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Improve testing accuracy (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Fix shellcheck warnings (Waiman Long) [1736654]
- [tools] lib/lockdep/tests: Display compiler warning and error messages (Waiman Long) [1736654]
- [kernel] locking/lockdep: Remove ::version from lock_class structure (Waiman Long) [1736654]
- [init] kconfig: disable io_uring support (Jeff Moyer) [1758680]
- [virt] kvm: arm64: pmu: Reset sample period on overflow handling (Auger Eric) [1760872]
- [virt] kvm: arm64: pmu: Set the CHAINED attribute before creating the in-kernel event (Auger Eric) [1760872]
- [arm64] kvm: Handle PMCR_EL0.LC as RES1 on pure AArch64 systems (Auger Eric) [1760872]
- [virt] kvm: arm64: pmu: Fix cycle counter truncation (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Introduce kvm_pmu_vcpu_init() to setup PMU counter index (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Support chained PMU counters (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Remove pmc->bitmask (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Re-create event when setting counter value (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Extract duplicated code to own function (Auger Eric) [1760872]
- [virt] kvm: arm/arm64: Rename kvm_pmu_{enable/disable}_counter functions (Auger Eric) [1760872]
- [arm64] perf: Hook up new events (Auger Eric) [1760872]
- [arm64] perf: Move event definitions into perf_event.h (Auger Eric) [1760872]
- [arm64] perf: Remove duplicate generic cache events (Auger Eric) [1760872]
- [arm64] perf: Terminate PMU assignment statements with semicolons (Auger Eric) [1760872]
- [arm64] Allow CAVIUM_TX2_ERRATUM_219 to be selected (Auger Eric) [1771633]
- [arm64] Avoid Cavium TX2 erratum 219 when switching TTBR (Auger Eric) [1771633]
- [arm64] Enable workaround for Cavium TX2 erratum 219 when running SMT (Auger Eric) [1771633]
- [arm64] kvm: Trap VM ops when ARM64_WORKAROUND_CAVIUM_TX2_219_TVM is set (Auger Eric) [1771633]
- [arm64] sysreg: fix incorrect definition of SYS_PAR_EL1_F (Auger Eric) [1771633]
- [arm64] Force SSBS on context switch (Mark Salter) [1756103]
- [arm64] enable pointer authentication (Mark Salter) [1756103]
- [arm64] add ptrace regsets for ptrauth key management (Mark Salter) [1756103]
- arm64: cpufeature: Rework ptr auth hwcaps using multi_entry_cap_matches (Mark Salter) [1756103]
- [arm64] capabilities: Merge duplicate entries for Qualcomm erratum 1003 (Mark Salter) [1756103]
- [arm64] cpufeature: Reduce number of pointer auth CPU caps from 6 to 4 (Mark Salter) [1756103]
- [documentation] arm64: docs: document pointer authentication (Mark Salter) [1756103]
- [documentation] arm64: docs: Document SSBS HWCAP (Mark Salter) [1756103]
- [documentation] arm64: docs: Fix typos in ELF hwcaps (Mark Salter) [1756103]
- [arm64] ptr auth: Move per-thread keys from thread_info to thread_struct (Mark Salter) [1756103]
- [arm64] add prctl control for resetting ptrauth keys (Mark Salter) [1756103]
- [arm64] perf: strip PAC when unwinding userspace (Mark Salter) [1756103]
- [arm64] expose user PAC bit positions via ptrace (Mark Salter) [1756103]
- [arm64] add basic pointer authentication support (Mark Salter) [1756103]
- arm64/cpufeature: detect pointer authentication (Mark Salter) [1756103]
- [arm64] cpufeature: Convert hook_lock to raw_spin_lock_t in cpu_enable_ssbs() (Mark Salter) [1756103]
- [arm64] entry: Allow handling of undefined instructions from EL1 (Mark Salter) [1756103]
- [arm64] Fix silly typo in comment (Mark Salter) [1756103]
- [fs] smb3: fix signing verification of large reads (Dave Wysochanski) [1753114]
- [fs] revert "nfs4: Fix v4.0 client state corruption when mount" (Benjamin Coddington) [1767012]
- [kernel] svcrdma: Increase the default connection credit limit (Benjamin Coddington) [1771430]
- [x86] quirks: Disable HPET on Intel Coffe Lake platforms (David Arcari) [1773774]
- [sched] core: Fix CPU controller for !RT_GROUP_SCHED (Phil Auld) [1774652]
- [x86] Add comment for x86 processor OS version support (David Arcari) [1709878]
- [x86] kvm: svm: taint module and print taint message iff nested is enabled (Bandan Das) [1775410]
- [x86] cpu: Add Tiger Lake to Intel family (Steve Best) [1773790]
- [fs] Fix the locking in dcache_readdir() and friends (Miklos Szeredi) [1761746]
- [infiniband] rdma/mlx5: Return proper error value (Mohammad Heib) [1772101]
- [scsi] mpt3sas: change allocation option (Tomas Henzl) [1770264]
- [scsi] qla2xxx: Initialized mailbox to prevent driver load failure (Himanshu Madhani) [1770309]
- [mfd] intel-lpss: Add Intel Comet Lake PCH-H PCI IDs (David Arcari) [1773307]
- [powercap] intel_rapl: add support for Cometlake desktop (David Arcari) [1759664]
- [powercap] intel_rapl: add support for CometLake Mobile (David Arcari) [1746265]
- [kernel] intel_rapl: need linux/cpuhotplug.h for enum cpuhp_state (Alexander Beregalov) [1732604]
- [thermal] int340x/processor_thermal_device: Fix proc_thermal_rapl_remove() (Alexander Beregalov) [1732604]
- [thermal] int340x/processor_thermal_device: add support for MMIO RAPL (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal_device: Fix build warning (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal: Read PPCC on resume (Alexander Beregalov) [1732604]
- [thermal] thermal: processor_thermal: Downgrade error message (Alexander Beregalov) [1732604]
- [thermal] intel: int340x: processor_thermal_device: simplify to get driver data (Alexander Beregalov) [1732604]
- [thermal] int3403_thermal: favor _TMP instead of PTYP (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: fix mode setting (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: Add additional UUIDs (Alexander Beregalov) [1732604]
- [thermal] thermal: int340x_thermal: Fix sysfs race condition (Alexander Beregalov) [1732604]
- [thermal] thermal: int340x_thermal: Make PCI dependency explicit (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: Fix a NULL vs IS_ERR() check (Alexander Beregalov) [1732604]
- [thermal] int340x_thermal: int3400_thermal: simplify getting .driver_data (Alexander Beregalov) [1732604]
- [powercap] Invoke powercap_init() and rapl_init() earlier (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: Fix module autoloading issue (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: support two power limits for every RAPL domain (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: support 64 bit register (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract RAPL common code (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: cleanup hardcoded MSR access (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: cleanup some functions (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract register access operations (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: abstract register address (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: introduce struct rapl_if_private (Alexander Beregalov) [1732604]
- [kernel] intel_rapl: introduce intel_rapl.h (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: remove hardcoded register index (Alexander Beregalov) [1732604]
- [powercap] intel_rapl: use reg instead of msr (Alexander Beregalov) [1732604]
- [security] ima: Differentiate auditing policy rules from "audit" actions (Richard Guy Briggs) [1479911]
- [security] ima: Do not audit if CONFIG_INTEGRITY_AUDIT is not set (Richard Guy Briggs) [1479911]
- [security] ima: Use audit_log_format() rather than audit_log_string() (Richard Guy Briggs) [1479911]
- [security] ima: Call audit_log_string() rather than logging it untrusted (Richard Guy Briggs) [1479911]
- [security] selinux: avoid atomic_t usage in sidtab (Ondrej Mosnacek) [1741182]
- [security] selinux: always return a secid from the network caches if we find one (Ondrej Mosnacek) [1741182]
- [security] selinux: policydb - rename type_val_to_struct_array (Ondrej Mosnacek) [1741182]
- [security] selinux: policydb - fix some checkpatch.pl warnings (Ondrej Mosnacek) [1741182]
- [security] selinux: shuffle around policydb.c to get rid of forward declarations (Ondrej Mosnacek) [1741182]
- [security] selinux: fix memory leak in policydb_init() (Ondrej Mosnacek) [1741182]
- [security] selinux: check sidtab limit before adding a new entry (Ondrej Mosnacek) [1741182]
- [security] selinux: format all invalid context as untrusted (Ondrej Mosnacek) [1479914 1741182]
- [security] selinux: remove some no-op BUG_ONs (Ondrej Mosnacek) [1741182]
- [security] selinux: provide __le variables explicitly (Ondrej Mosnacek) [1741182]
- [security] selinux: avoid uninitialized variable warning (Ondrej Mosnacek) [1741182]
- [security] selinux: remove useless assignments (Ondrej Mosnacek) [1741182]
- [security] selinux: fix NULL dereference in policydb_destroy() (Ondrej Mosnacek) [1741182]
- [security] selinux: convert to kvmalloc (Ondrej Mosnacek) [1741182]
- [kernel] lsm: generalize flag passing to security_capable (Ondrej Mosnacek) [1741182]
- [kernel] selinux: Remove unused selinux_is_enabled (Ondrej Mosnacek) [1741182]
- [kernel] selinux: Remove cred security blob poisoning (Ondrej Mosnacek) [1741182]
- [security] selinux: Remove SECURITY_SELINUX_BOOTPARAM_VALUE (Ondrej Mosnacek) [1741182]

* Thu Nov 28 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-157.rt13.14.el8]
- [tools] selftests: mlxsw: Add a test for leftover DSCP rule (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Fix local variable declarations in DSCP tests (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Add counters for GC events (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Bump firmware version to 13.2000.1886 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Prevent auto negotiation on number of lanes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove 56G speed support (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Keep unmatched entries in a linked list (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Further reduce pool size on Spectrum-2 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Fix error path in mlxsw_sp_module_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: fix duplicated check on orig_egr_types (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Increase parsing depth when PTP is enabled (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Fix typo in qos_mc_aware.sh (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Do not process learned records with a dummy FID (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_dcb: Configure DSCP map as the last rule is removed (Ivan Vecera) [1737368]
- [netdrv] remove redundant memset (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Apply the PTP shaper enable/disable logic (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Set up PTP shaper when port status has changed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Enable/disable PTP shaper on a port when getting HWTSTAMP on/off (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add new operation for getting the port's speed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Set the PTP shaper parameters (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add QoS PTP Shaper Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add note about the PTP shaper (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add ptps field in QoS ETS Element Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Fix validation in mlxsw_sp1_ptp_packet_finish() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support ethtool get_ts_info (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support SIOCGHWTSTAMP, SIOCSHWTSTAMP ioctls (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Configure PTP traps and FIFO events (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Garbage-collect unmatched entries (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Support timestamping on Spectrum-1 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Disable BH when working with PHC (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Add PTP initialization / finalization (Ivan Vecera) [1737368]
- [netdrv] mlxsw: pci: ptp: Hook into packet transmit path (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for using SKB control buffer (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: ptp: Hook into packet receive path (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Add support for traps specific to Spectrum-1 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Extract a helper for trap registration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Global Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Time Precision Packet Timestamping Reading (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Precision Time Protocol Trap Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Monitoring Time Precision Packet Port Configuration Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for negative temperature readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add the hottest thermal zone detection (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend thermal core with per inter-connect device thermal zones (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_flower: Implement support for ingress device matching (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Fix SRC_SYS_PORT element size (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Avoid size check for RX_ACL_SYSTEM_PORT element (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Write RX_ACL_SYSTEM_PORT acl element correctly (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Fix compilation on 32-bit ARM (Ivan Vecera) [1737368]
- [tools] selftests: ptp: Add Physical Hardware Clock test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: PTP physical hardware clock initialization (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_ptp: Add implementation for physical hardware clock operations (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management Pulse Per Second Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management UTC Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: pci: Query free running clock PCI BAR and offsets (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add a new interface for reading the hardware free running clock (Ivan Vecera) [1737368]
- [netdrv] mlxsw: cmd: Free running clock PCI BAR and offsets via query firmware (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Implement flash update status notifications (Ivan Vecera) [1737368]
- [netdrv] mlxfw: Introduce status_notify op and call it to notify about the status (Ivan Vecera) [1737368]
- [netdrv] mlxfw: Propagate error messages through extack (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Move firmware flash implementation to devlink (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Reduce buffer size in transactions for SFP modules temperature readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend the index size for temperature sensors readout (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Extend hwmon interface with inter-connect temperature attributes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Management General Peripheral Information Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Extend sensor index field size of Management Temperature Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Re-order initialization sequence (Ivan Vecera) [1737368]
- [netdrv] mlxsw: i2c: Allow flexible setting of I2C transactions size (Ivan Vecera) [1737368]
- [netdrv] mlxsw: i2c: Extend initialization with querying firmware info (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Disallow prio-tagged packets when PVID is removed (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Reduce pool size on Spectrum-2 (Ivan Vecera) [1737368]
- [tools] selftests: tc_flower: Add TOS matching test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_flower: Fix TOS matching (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Test nexthop offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Refresh nexthop neighbour when it becomes dead (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Use different seeds for ECMP and LAG hash (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Prevent force of 56G (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Avoid warning after identical rules insertion (Ivan Vecera) [1737368]
- [tools] selftests: Add loopback test (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Implement loopback ethtool feature (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add Port Physical Loopback Register (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: split base on local_ports_in_{1x, 2x} resources (Ivan Vecera) [1737368]
- [netdrv] mlxsw: resources: Add local_ports_in_{1x, 2x} (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Bump firmware version to 13.2000.1122 (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove obsolete dependency on THERMAL=m (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Prevent ipv6 gateway with v4 route via replace and append (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Adjust CPU port shared buffer egress quotas (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Allow skipping ingress port quota configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Split business logic from mlxsw_sp_port_sb_pms_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Use new CPU ingress pool for control packets (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add pools for CPU traffic (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Remove assumption about pool order (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid changing multicast TCs' attributes (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid changing threshold type of first egress pool (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Forbid configuration of multicast pool (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add ability to veto TC's configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add ability to veto pool's configuration (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Use defines for pool indices (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_buffers: Add extack messages for invalid configurations (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Relax FIB rule validation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum: Use a stable ECMP/LAG seed (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Test neighbour offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Add neighbour offload indication (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_router: Propagate neighbour update errors (Ivan Vecera) [1737368]
- [documentation] documentation: networking: devlink-info-versions: Add fw.psid (Ivan Vecera) [1737368]
- [netdrv] mlxsw: core: Add support for devlink info command (Ivan Vecera) [1737368]
- [netdrv] mlxsw: reg: Add MGIR register (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: test for bridge mcast traffic after report and leave (Ivan Vecera) [1737368]
- [netdrv] mlxsw: switch_ib: Pass valid HW id down to mlxsw_core_port_init() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove ndo_get_port_parent_id implementation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Pass switch ID through devlink_port_attrs_set() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Rename rehash_dis trace (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Remove failed_rollback dead end (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Move rehash_dis trace call and err msg to vregion_migrate() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: spectrum_acl: Remove redundant failed_rollback from migrate_start() (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Remove ndo_get_phys_port_name implementation (Ivan Vecera) [1737368]
- [netdrv] mlxsw: Implement ndo_get_devlink_port (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Add a new test for strict priority (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: Add qos_lib.sh (Ivan Vecera) [1737368]
- [tools] selftests: mlxsw: qos_mc_aware: Configure shared buffers (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Add shared buffer helpers (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Simplify deduction of DEVLINK_DEV (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: devlink_lib: Avoid double sourcing of lib.sh (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: Test action VLAN modify (Ivan Vecera) [1737368]
- [tools] selftests: forwarding: Add PCP match and VLAN match tests (Ivan Vecera) [1737368]
- [infiniband] rdma/mlx5: Use irq xarray locking for mkey_table (Alaa Hleihel) [1724336]
- [netdrv] mlx4_core: Dynamically set guaranteed amount of counters per VF (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Initialize on stack link modes bitmap (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: fix ethtool self test: link speed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix handling of compressed CQEs in case of low NAPI budget (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Don't store direct pointer to action's tunnel info (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix NULL pointer dereference in extended destination (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only skip encap flows update when encap init failed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Determine source port properly for vlan push action (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix flow counter list auto bits struct (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Clear old rate limit when closing QP (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Remove dead code (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix memory leak in mlx5_fw_fatal_reporter_dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: prevent memory leak in mlx5_fpga_conn_create_cq (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: TX, Fix consumer index of error cqe dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Zero-memset WQE info struct upon update (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Fix assumption of single WQEBB of NOP in cleanup flow (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Add missing synchronize_srcu() for MW cases (Alaa Hleihel) [1724307 1724336]
- [infiniband] rdma/mlx5: Order num_pending_prefetch properly with synchronize_srcu (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Do not allow rereg of a ODP MR (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix matching on tunnel addresses type (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add device ID of upcoming BlueField-2 (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Free mpi in mp_slave mode (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Use the original address for the page during free_pages (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: FWTrace, Reduce stack usage (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Remove unnecessary clear_bit()s (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix spelling mistake "offlaods" -> "offloads" (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Remove leftover declaration (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: ethtool, Fix a typo in WOL function names (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add missing include file to lib/crypto.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: remove self-assignment on esw->dev (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support MLX5_CMD_OP_QUERY_LAG as a DEVX general command (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Fix mlx5_ifc_query_lag_out_bits (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix formats with line continuation whitespace (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix mlx5e_tx_reporter_create return value (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix offset of tisc bits reserved field (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix -Wtype-limits compilation warnings (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support per device q counters in switchdev mode (Alaa Hleihel) [1659186 1724336]
- [infiniband] ib/mlx5: Refactor code for counters allocation (Alaa Hleihel) [1659186 1724336]
- [netdrv] mlx5: DR, Replace CRC32 implementation to use kernel lib (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Support IPv4 and IPv6 mixed matcher (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Allow insertion of duplicate rules (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: avoid 64-bit division in dr_icm_pool_mr_create() (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5e: Fix traffic duplication in ethtool steering (Alaa Hleihel) [1724336]
- [netdrv] mlx5: DR, Allow matching on vport based on vhca_id (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Fix getting incorrect prev node in ste_free (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Remove redundant vport number from action (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: DR, Fix SW steering HW bits and definitions (Alaa Hleihel) [1724336]
- [netdrv] mlx5: fix missing assignment of variable err (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Fix rt's type in dr_action_create_reformat_action (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Fix error return code in dr_domain_init_resources() (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Fix addr's type in mlx5dr_icm_dm (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add devlink flow_steering_mode parameter (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add support to use SMFS in switchdev mode (Alaa Hleihel) [1760284 1724327 1724336]
- [netdrv] mlx5: Add API to set the namespace steering mode (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add direct rule fs_cmd implementation (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add CONFIG_MLX5_SW_STEERING for software steering support (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose APIs for direct rule managing (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add required FW steering functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering rule functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering action functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering matcher functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering table functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose steering domain functionality (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add Steering entry (STE) utilities (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Expose an internal API to issue RDMA operations (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, ICM pool memory allocator (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add direct rule command utilities (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: DR, Add the internal direct rule types definitions (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Add flow steering actions to fs_cmd shim layer (Alaa Hleihel) [1760284 1724327 1724336]
- [netdrv] mlx5: Set only stag for match untagged packets (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: Add stub for mlx5_eswitch_mode (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Avoid disabling RoCE when uninitialized (Alaa Hleihel) [1760284 1724336]
- [kernel] mlx5: Add HW bits and definitions required for SW steering (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5: Move device memory management to mlx5_core (Alaa Hleihel) [1760284 1724336]
- [netdrv] mlx5e: Support LAG TX port affinity distribution (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Expose new function for TIS destroy loop (Alaa Hleihel) [1760285 1724336]
- [kernel] mlx5: Add lag_tx_port_affinity capability bit (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Add device out of buffer counter (Alaa Hleihel) [1760291 1724336]
- [netdrv] mlx5: Fix the order of fc_stats cleanup (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix deallocation of non-fully init encap entries (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only access fully initialized flows in neigh update (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor neigh update for concurrent execution (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor neigh used value update for concurrent execution (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect neigh hash encap list with spinlock and rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Refactor mlx5e_neigh_update_table->encap_lock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend neigh hash entry with rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Always take reference to neigh entry (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extract code that queues neigh update work into function (Alaa Hleihel) [1663231 1724336]
- [kernel] mlx5: Add support for VNIC_ENV internal rq counter (Alaa Hleihel) [1760291 1724336]
- [netdrv] mlx5e: Use refcount_t for refcount (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Use vhca_id in generating representor port_index (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Simplify querying port representor parent id (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5: E-switch, Removed unused hwid (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Allow concurrent creation of encap entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect encap hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend encap entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Allow concurrent creation of mod_hdr entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect mod_hdr hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect mod header entry flows list with spinlock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend mod header entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Allow concurrent creation of hairpin entries (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect hairpin hash table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect hairpin entry flows list with spinlock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend hairpin entry with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5: E-switch, Tide up eswitch config sequence (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Remove redundant mc_promisc NULL check (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, remove redundant error handling (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Introduce helper function to enable/disable vports (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Initialize TSAR Qos hardware block before its user vports (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-switch, Combine metadata enable/disable functionality (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Verify support QoS element type (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Make load_one() and unload_one() symmetric (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add flow counter pool (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5: Add flow counter bulk infrastructure (Alaa Hleihel) [1760297 1724336]
- [kernel] mlx5: Add flow counter bulk allocation hardware bits and command (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5: Refactor and optimize flow counter bulk query (Alaa Hleihel) [1760297 1724336]
- [netdrv] mlx5e: Protect tc flow table with mutex (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Rely on rcu instead of rtnl lock when getting upper dev (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Eswitch, use state_lock to synchronize vlan change (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Eswitch, change offloads num_flows type to atomic64 (Alaa Hleihel) [1663231 1724327 1724336]
- [netdrv] mlx5e: Protect unready flows with dedicated lock (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Protect tc flows hashtable with rcu (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Change flow flags type to unsigned long (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Extend tc flow struct with reference counter (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Simplify get_route_and_out_devs helper function (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Improve ethtool rxnfc callback structure (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Avoid warning print when not required (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Print a warning when LRO feature is dropped or not allowed (Alaa Hleihel) [1663231 1724336]
- [netdrv] mlx5e: Remove ethernet segment from dump WQE (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Add num bytes metadata to WQE info (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix delay in fw fatal report handling due to fw report (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Fix crdump chunks print (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Block MR WR if UMR is not possible (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix MR re-registration flow to use UMR properly (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Report and handle ODP support properly (Alaa Hleihel) [1724308 1724336]
- [infiniband] ib/mlx5: Consolidate use_umr checks into single function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix compatibility issue with ethtool flash device (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix use-after-free error while accessing ev_file pointer (Alaa Hleihel) [1724307 1724336]
- [netdrv] mlx5e: Remove redundant check in CQE recovery flow of tx reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix error flow of CQE recovery on tx reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix false negative indication on tx reporter CQE recovery (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix tisn field placement (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix tisn field name (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: kTLS, Fix progress params context WQE layout (Alaa Hleihel) [1724336]
- [kernel] mlx5: kTLS, Fix wrong TIS opmod constants (Alaa Hleihel) [1724336]
- [netdrv] mlx5: crypto, Fix wrong offset in encryption key command (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: ethtool, Avoid setting speed to 56GBASE when autoneg off (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Only support tx/rx pause setting for port owner (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Support inner header match criteria for non decap flow action (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Use flow keys dissector to parse packets for ARFS (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Check the correct variable in error handling code (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Fix implicit MR release flow (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5e: always initialize frag->last_in_page (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Release locks during notifier unregister (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix MR registration flow to use UMR properly (Alaa Hleihel) [1764207 1724336]
- [netdrv] mlx5e: kTLS, Call WARN_ONCE on netdev mismatch (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Prevent encap flow counter update async to user query (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix matching of speed to PRM link modes (Alaa Hleihel) [1724336]
- [kernel] mlx5: Fix modify_cq_in alignment (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add missing RDMA_RX capabilities (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Use reversed order when unregister devices (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix RSS Toeplitz setup to be aligned with the HW specification (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Prevent concurrent MR updates during invalidation (Alaa Hleihel) [1724308 1724336]
- [infiniband] ib/mlx5: Fix clean_mr() to work in the expected order (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Move MRs to a kernel PD when freeing them to the MR cache (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Use direct mkey destroy command upon UMR unreg failure (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Fix unreg_umr to ignore the mkey state (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Replace kfree with kvfree (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Replace kfree with kvfree (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Rely on filter_dev instead of dissector keys for tunnels (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Verify encapsulation is supported (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Convert single case statement switch statements into if statements (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Reduce ingress acl modify metadata stack usage (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Fix compilation error in TLS code (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: IPoIB, Add error path in mlx5_rdma_setup_rn (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix error flow in tx reporter diagnose (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix return value from timeout recover function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Rx, Fix checksum calculation for new hardware (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Fix port tunnel GRE entropy control (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Fix default encap mode (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Return in default case statement in tx_post_resync_params (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Register devlink ports for physical link, PCI PF, VFs (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Set RDMA DIM to be enabled by default (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Report correctly tag matching rendezvous capability (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Implement VHCA tunnel mechanism in DEVX (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Introduce VHCA tunnel device capability (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Add kTLS TX HW offload support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Introduce a fenced NOP WQE posting function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Re-work TIS creation functions (Alaa Hleihel) [1760285 1724336]
- [netdrv] mlx5e: Tx, Unconstify SQ stop room (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Don't implicitly assume SKB-less wqe has one WQEBB (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Make SQ WQE fetch function type generic (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Tx, Enforce L4 inline copy when needed (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move helper functions to a new txrx datapath header (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Accel, Add core TLS support for the Connect-X family (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add crypto library to support create/destroy encryption key (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Kconfig, Better organize compilation flags (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Accel, Expose accel wrapper for IPsec FPGA function (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Add counter_alloc_stats() and counter_update_stats() support (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support statistic q counter configuration (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Add counter set id as a parameter for mlx5_ib_query_q_counters() (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: Support set qp counter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Added devlink info callback (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Added fw version query command (Alaa Hleihel) [1724336]
- [kernel] mlx5: Add rts2rts_qp_counters_set_id field in hca cap (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Use proper allocation API to get zeroed memory (Alaa Hleihel) [1724336]
- [infiniband] ib/mlx5: DEVX cleanup mdev (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Add DEVX support for CQ events (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Implement DEVX dispatching event (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Enable subscription for device events over DEVX (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Register DEVX with mlx5_core to get async events (Alaa Hleihel) [1724307 1724336]
- [infiniband] ib/mlx5: Introduce MLX5_IB_OBJECT_DEVX_ASYNC_EVENT_FD (Alaa Hleihel) [1724307 1724336]
- [kernel] mlx5: Properly name the generic WQE control field (Alaa Hleihel) [1724336]
- [kernel] mlx5: Introduce TLS TX offload hardware bits and structures (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Refactor mlx5_esw_query_functions for modularity (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch prepare functions change handler to be modular (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Introduce and use mlx5_eswitch_get_total_vports() (Alaa Hleihel) [1724327 1724336]
- [infiniband] ib/mlx5: Fixed reporting counters on 2nd port for Dual port RoCE (Alaa Hleihel) [1724336]
- [kernel] mlx5: Expose device definitions for object events (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report EQE data upon CQ completion (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report a CQ error event only when a handler was set (Alaa Hleihel) [1724336]
- [netdrv] mlx5: mlx5_core_create_cq() enhancements (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Expose the API to register for ANY event (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Use event mask based on device capabilities (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Fix mlx5_core_destroy_cq() error flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Handle UC address change in switchdev mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Consider host PF for inline mode and vlan pop (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use iterator for vlan and min-inline setups (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Reg/unreg function changed event at correct stage (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Consolidate eswitch function number of VFs (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Refactor eswitch SR-IOV interface (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Handle host PF vport mac/guid for ECPF (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use correct flags when configuring vlan (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Reduce dependency on enabled_vfs counter and num_vfs (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Don't handle VF func change if host PF is disabled (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Limit scope of mlx5_get_next_phys_dev() to PCI PF devices (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move pci status reg access mutex to mlx5_pci_init (Alaa Hleihel) [1724336]
- [kernel] mlx5: Rename mlx5_pci_dev_type to mlx5_coredev_type (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Cleanup rep when doing unload (Alaa Hleihel) [1724336]
- [infiniband] {ib, net}/mlx5: E-Switch, Use index of rep for vport to IB port mapping (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Use vport index when init rep (Alaa Hleihel) [1724327 1724336]
- [kernel] mlx5: Added MCQI and MCQS registers' description to ifc (Alaa Hleihel) [1724336]
- [kernel] mlx5: Add hardware definitions for sub functions (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Disallow tc redirect offload cases we don't support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Expose same physical switch_id for all representors (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Don't refresh TIRs when updating representor SQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: reduce stack usage in mlx5_eswitch_termtbl_create (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Set drvinfo in generic manner (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Correct phys_port_name for PF port (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Report netdevice MPLS features (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move to HW checksumming advertising (Alaa Hleihel) [1724336]
- [netdrv] mlx5: MPFS, Allow adding the same MAC more than once (Alaa Hleihel) [1724336]
- [netdrv] mlx5: MPFS, Cleanup add MAC flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Move queue param structs to en/params.h (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Encapsulate open/close queues into a function (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Consider XSK in XDP MTU limit calculation (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: XDP_TX from UMEM support (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Share the XDP SQ for XDP_TX between RQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Refactor struct mlx5e_xdp_info (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Allow ICO SQ to be used by multiple RQs (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Calculate linear RX frag size considering XSK (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Replace deprecated PCI_DMA_TODEVICE (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Attach/detach XDP program safely (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Enable vport metadata matching if firmware supports it (Alaa Hleihel) [1724327 1724336]
- [infiniband] rdma/mlx5: Add vport metadata matching for IB representors (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Add match on vport metadata for rule in slow path (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Pass metadata from FDB to eswitch manager (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Add query and modify esw vport context functions (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Add match on vport metadata for rule in fast path (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Specifying known origin of packets matching the flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Tag packet with vport number in VF vports and uplink ingress ACLs (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Add flow context for flow tag (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Introduce a helper API to check VF vport (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Support allocating modify header context from ingress ACL (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Get vport ACL namespace by vport index (Alaa Hleihel) [1724336]
- [kernel] mlx5: Introduce vport metadata matching bits and enum constants (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Convert mkey_table to XArray (Alaa Hleihel) [1724308 1724307 1724336]
- [infiniband] rdma/mlx5: Refactor MR descriptors allocation (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Use PA mapping for PI handover (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Improve PI handover performance (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Remove unused IB_WR_REG_SIG_MR code (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Enable decap and packet reformat on FDB (Alaa Hleihel) [1724336]
- [infiniband] rdma/mlx5: Consider eswitch encap mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: add missing void argument to function mlx5_devlink_alloc (Alaa Hleihel) [1724336]
- [kernel] mlx5: Expose eswitch encap mode (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Declare more strictly devlink encap mode (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: use indirect calls wrapper for the rx packet handler (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: use indirect calls wrapper for skb allocation (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report devlink health on FW fatal issues (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add support for FW fatal reporter dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add fw fatal devlink_health_reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Report devlink health on FW issues (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add support for FW reporter dump (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Create FW devlink_health_reporter (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Issue SW reset on FW assert (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Control CR-space access by different PFs (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Handle SW reset of FW in error flow (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add Crdump support (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add Vendor Specific Capability access gateway (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move all devlink related functions calls to devlink.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Add EQ enable/disable API (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Use a single IRQ for all async EQs (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Rename mlx5_irq_info to mlx5_irq (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move all IRQ logic to pci_irq.c (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Generalize IRQ interface to work with irq_table (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ table creation from EQ table creation (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move IRQ affinity set to IRQ allocation phase (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move IRQ rmap creation to IRQ allocation phase (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ data from EQ table data (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Separate IRQ request/free from EQ life cycle (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Change interrupt handler to call chain notifier (Alaa Hleihel) [1724308 1724336]
- [netdrv] mlx5: Introduce EQ polling budget (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Support querying max VFs from device (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Return raw output for query esw functions (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Handle representors creation in handler context (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: Increase wait time for fw initialization (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Move firmware flash implementation to devlink (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: TX, Improve performance under GSO workload (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Use termination table for VLAN push actions (Alaa Hleihel) [1722647 1724327 1724336]
- [netdrv] mlx5e: Geneve, Add support for encap/decap flows offload (Alaa Hleihel) [1725582 1724336]
- [netdrv] mlx5e: Rearrange tc tunnel code in a modular way (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Geneve, Keep tunnel info as pointer to the original struct (Alaa Hleihel) [1724336]
- [netdrv] mlx5: Geneve, Manage Geneve TLV options (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Enable setting multiple match criteria for flow group (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5e: Allow matching only enc_key_id/enc_dst_port for decapsulation action (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Generalize vport type in vport representor (Alaa Hleihel) [1724336]
- [netdrv] {ib, net}/mlx5: Constify rep ops functions pointers (Alaa Hleihel) [1724327 1724336]
- [netdrv] {ib, net}/mlx5: No need to typecast from void* to mlx5_ib_dev* (Alaa Hleihel) [1724336]
- [netdrv] mlx5: E-Switch, Honor eswitch functions changed event cap (Alaa Hleihel) [1724327 1724336]
- [netdrv] mlx5: E-Switch, Replace host_params event with functions_changed event (Alaa Hleihel) [1724327 1724336]
- [kernel] mlx5: Introduce termination table bits (Alaa Hleihel) [1722647 1724336]
- [kernel] mlx5: Add core dump register access HW bits (Alaa Hleihel) [1724336]
- [netdrv] mlx5: potential error pointer dereference in error handling (Alaa Hleihel) [1724336]
- [netdrv] mlx5e: Support tagged tunnel over bond (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Avoid detaching non-existing netdev under switchdev mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix source port matching in fdb peer flow rule (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace reciprocal_scale in TX select queue function (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid reloading already removed devices (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Update pci error handler entries and command translation (Alaa Hleihel) [1724335]
- [infiniband] mlx5: avoid 64-bit division (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Disable rxhash when CQE compress is enabled (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: restrict the real_dev of vlan device is the same as uplink device (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Allocate root ns memory using kzalloc to match kfree (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid double free in fs init error unwinding path (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Avoid double free of root ns in the error flow path (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Fix error handling in mlx5_load() (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix possible modify header actions memory leak (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix no rewrite fields with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Additional check for flow destination comparison (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Add missing ethtool driver info for representors (Alaa Hleihel) [1766306 1724335]
- [netdrv] mlx5e: Fix number of vports for ingress ACL configuration (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Fix ethtool rxfh commands when CONFIG_MLX5_EN_RXNFC is disabled (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Fix peer pf disable hca command (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Correct type to u16 for vport_num and int for vport_index (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add meaningful return codes to status_to_err function (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Imply MLXFW in mlx5_core (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Set completion EQs as shared resources (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Verify DEVX general object type correctly (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Remove MAYEXEC flag (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Device resource control for privileged DEVX user (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Add steering SW ICM device memory type (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Warn on allocated MEMIC buffers during cleanup (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Support device memory type attribute (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Add missing XRC options to QP optional params mask (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Use atomic rep state to serialize state change (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Fix the check of legal vport (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Use getter to access all vport array (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Use available mlx5_vport struct (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Reuse mlx5_esw_for_each_vf_vport macro in two files (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Remove unused mlx5_query_nic_vport_vlans (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: remove meaningless CFLAGS_tracepoint.o (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Put the common XDP code into a function (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: ethtool, Add support for EEPROM high pages query (Alaa Hleihel) [1724322 1724335]
- [netdrv] mlx5e: Return error when trying to insert existing flower filter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace TC VLAN pop with VLAN 0 rewrite in prio tag mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: ACLs for priority tag mode (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Turn on HW tunnel offload in all TIRs (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Take common TIR context settings into a function (Alaa Hleihel) [1724335]
- [kernel] mlx5: Fix broken hca cap offset (Alaa Hleihel) [1725554 1724335]
- [kernel] mlx5: Geneve, Add flow table capabilities for Geneve decap with TLV options (Alaa Hleihel) [1725554 1724335]
- [kernel] mlx5: Geneve, Add basic Geneve encap/decap flow table capabilities (Alaa Hleihel) [1725554 1724335]
- [netdrv] mlx5: Eswitch, enable RoCE loopback traffic (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add new miss flow table action (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add support in RDMA RX steering (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Pass flow steering objects to fs_cmd (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Enable general events on all interfaces (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Restrict 'DELAY_DROP_TIMEOUT' subtype to Ethernet interfaces (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Separate and generalize dma device from pci device (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Get rid of storing copy of device name (Alaa Hleihel) [1724335]
- [kernel] mlx5: e-switch: Introduce prio tag mode (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Expose TIR ICM address to user space (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Introduce new TIR creation core API (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose TIR ICM address in command outbox (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose SW ICM related device memory capabilities (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Use #define for the WQE wait timeout constant (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused rx_page_reuse stat (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Take HW interrupt trigger into a function (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused parameter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Add an underflow warning comment (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Move parameter calculation functions to en/params.c (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Report mlx5e_xdp_set errors (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove unused parameter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Inline small packets into the TX MPWQE in XDP xmit flow (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Add TX MPWQE session counter (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Enhance RQ indication for XDP redirect flush (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: XDP, Fix shifted flag index in RQ bitmap (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: RX, Support multiple outstanding UMR posts (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Don't create IB representors when in multiport RoCE mode (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Initialize roce port info before multiport master init (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Allow DEVX and raw creation flow on reps (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Add query e-switch vport context to devx white list (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Allow inserting a steering rule to the FDB (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Create flow table with max size supported (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Access the prio bypass inside the FDB flow table namespace (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Check for error return in flow_rule rather than err (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Remove VF representor profile (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move to single device multiport ports in switchdev mode (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move SMI caps logic (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Refactor netdev affinity code (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move default representors SQ steering to rule to modify QP (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move rep into port struct (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Use correct size for device resources (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move ports allocation to outside of INIT stage (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Free IB device on remove (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Move netdev info into the port struct (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, add a new prio to be used by the RDMA side (Alaa Hleihel) [1724335]
- [kernel] mlx5: E-Switch, don't use hardcoded values for FDB prios (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Remove references to uboject->context (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Unify logic of MTU boundaries (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Obsolete param field holding a constant value (Alaa Hleihel) [1724335]
- [netdrv] mlx5: A write memory barrier is sufficient in EQ ci update (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Do not rewrite fields with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Offload TC e-switch rules with ingress VLAN device (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Offload TC e-switch rules with egress VLAN device (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Allow VLAN rewrite of prio field with the same match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Deny VLAN rewrite if there is no VLAN header match (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Use helpers to get headers criteria and value pointers (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Return -EOPNOTSUPP when attempting to offload an unsupported action (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Deletes unnecessary setting of esw_attr->parse_attr (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Remove 'parse_attr' argument in parse_tc_fdb_actions() (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Make the log friendly when decapsulation offload not supported (Alaa Hleihel) [1724335]
- [netdrv] mlx5: E-Switch, Fix double mutex initialization (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Handle event of power detection in the PCIE slot (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Cleanup WQE page fault handler (Alaa Hleihel) [1724335]
- [kernel] mlx5: Expose MPEIN (Management PCIE INfo) register layout (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Add rate limit print macros (Alaa Hleihel) [1724335]
- [infiniband] mlx5: Add explicit bar address field (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Replace dev_err/warn/info by mlx5_core_err/warn/info (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Use dev->priv.name instead of dev_name (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Make mlx5_core messages independent from mdev->pdev (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Break load_one into three stages (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Function setup/teardown procedures (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Move health and page alloc init to mdev_init (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Split mdev init and pci init (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Remove redundant init functions parameter (Alaa Hleihel) [1724335]
- [kernel] mlx5: Remove spinlock support from mlx5_write64 (Alaa Hleihel) [1724335]
- [kernel] mlx5: Remove unused MLX5_*_DOORBELL_LOCK macros (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Declare devx_async_cmd_event_fops static (Alaa Hleihel) [1724335]
- [infiniband] ib/mlx5: Compare only index part of a memory window rkey (Alaa Hleihel) [1724335]
- [infiniband] mlx5: Convert mlx5_srq_table to XArray (Alaa Hleihel) [1724335]
- [netdrv] mlx5e: Replace TC VLAN pop and push actions with VLAN modify (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: Support VLAN modify action (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: Add VLAN ID rewrite fields (Alaa Hleihel) [1722646 1724335]
- [netdrv] mlx5e: TX, Add geneve tunnel stateless offload support (Alaa Hleihel) [1722661 1724335]
- [netdrv] mlx5e: Take SW parser code to a separate function (Alaa Hleihel) [1722661 1724335]
- [netdrv] mlx5e: Fix port buffer function documentation format (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Simplify mlx5_sriov_is_enabled() by using pci core API (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Rename total_vfs to total_vports (Alaa Hleihel) [1724335]
- [netdrv] mlx5: Simplify sriov enable/disable flow (Alaa Hleihel) [1724335]
- [infiniband] rdma/mlx5: Use rdma_user_map_io for mapping BAR pages (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: ethtool, Remove unsupported SFP EEPROM high pages query (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Switch to Toeplitz RSS hash by default (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Protect against non-uplink representor for encap (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Rx, Fixup skb checksum for packets with tail padding (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: XDP, Avoid checksum complete when XDP prog is loaded (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Use fail-safe channels reopen in tx reporter recover (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Skip un-needed tx recover if interface state is down (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update xon formula (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update xoff formula (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, fix syndrome (0x678139) when turn on vepa (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5: E-Switch, Protect from invalid memory access in offload fdb table (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Fix access to invalid memory when toggling esw modes (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5e: Add a lock on tir list (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix error handling when refreshing TIRs (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Decrease default mr cache size (Alaa Hleihel) [1748518 1724333]
- [infiniband] ib/mlx5: Reset access mask when looping inside page fault handler (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Avoid panic when setting vport rate (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Avoid panic when setting vport mac, getting vport config (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: IPoIB, Fix RX checksum statistics update (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Remove redundant lag function to get pf num (Alaa Hleihel) [1724333]
- [netdrv] mlx5: ODP support for XRC transport is not enabled by default in FW (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Update tx reporter status in case channels were successfully opened (Alaa Hleihel) [1722274 1724333]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Set correct write permissions for implicit ODP MR (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Declare mlx5e_tx_reporter_recover_from_ctx as static (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Support ndo bridge_setlink and getlink (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5: E-Switch, Add support for VEPA in legacy mode (Alaa Hleihel) [1722659 1724333]
- [netdrv] mlx5e: Fix mlx5e_tx_reporter_create return value (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix return status of TX reporter timeout recover (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Re-add support for TX timeout when TX reporter is not valid (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Fix warn print in case of TX reporter creation failure (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Disable esw manager vport correctly (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Fix the warning on vport index out of range (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Delete unused FPGA QPN variable (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Wrap the open and apply of channels in one fail-safe function (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Factor out HCA capabilities functions (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Allow transition to offloads mode for ECPF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Load/unload VF reps according to event from host PF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Consider ECPF vport depends on eswitch ownership (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Assign a different position for uplink rep and vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Centralize repersentor reg/unreg to eswitch driver (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Support load/unload reps of specific vport types (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Add state to eswitch vport representors (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Use getter and iterator to access vport/rep (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Split VF and special vports for offloads mode (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Refactor offloads flow steering init/cleanup (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Properly refer to host PF vport as other vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Properly refer to the esw manager vport (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Correctly set LAG mode for ECPF (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Avoid magic numbers when initializing offloads mode (Alaa Hleihel) [1724333]
- [kernel] mlx5: Relocate vport macros to the vport header file (Alaa Hleihel) [1724333]
- [netdrv] mlx5: E-Switch, Normalize the name of uplink vport number (Alaa Hleihel) [1724333]
- [kernel] mlx5: Provide an alternative VF upper bound for ECPF (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add host params change event (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add query host params command (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Update enable HCA dependency (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Introduce Mellanox SmartNIC and modify page management logic (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Use unified register/load function for uplink and VF vports (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Use consistent vport num argument type (Alaa Hleihel) [1724333]
- [kernel] mlx5: Use void pointer as the type in address_of macro (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Align ODP capability function with netdev coding style (Alaa Hleihel) [1724333]
- [netdrv] mlx5: use RCU lock in mlx5_eq_cq_get() (Alaa Hleihel) [1724333]
- [infiniband] rdma/mlx5: Fix memory leak in case we fail to add an IB device (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Simplify WQE count power of two check (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Add tx timeout support for mlx5e tx reporter (Alaa Hleihel) [1722274 1724333]
- [netdrv] mlx5e: Add tx reporter support (Alaa Hleihel) [1722274 1724333]
- [infiniband] ib/mlx5: Advertise XRC ODP support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Advertise SRQ ODP support for supported transports (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Add ODP SRQ support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Let read user wqe also from SRQ buffer (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Add XRC initiator ODP support (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Clean mlx5_ib_mr_responder_pfault_handler() signature (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Remove useless check in ODP handler (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Set ODP SRQ support in firmware (Alaa Hleihel) [1724333]
- [kernel] mlx5: Add XRC transport to ODP device capabilities layout (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Implement DEVX hot unplug for async command FD (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Implement the file ops of DEVX async command FD (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Reuse fold sw stats in representors (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Present the representors SW stats when state is not opened (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Separate between ethtool and netdev software stats folding (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Add trace points for flow tables create/destroy (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Expand XPS cpumask to cover all online cpus (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: Take CQ decompress fields into a separate structure (Alaa Hleihel) [1724333]
- [netdrv] mlx5e: RX, Make sure packet header does not cross page boundary (Alaa Hleihel) [1724333]
- [infiniband] mlx5: no need to check return value of debugfs_create functions (Alaa Hleihel) [1724333]
- [netdrv] mlx5: Add pci AtomicOps request (Alaa Hleihel) [1724333]
- [infiniband] ib/mlx5: Don't override existing ip_protocol (Alaa Hleihel) [1724333]
- [infiniband] rdma/mlx5: Replace kzalloc with kcalloc (Alaa Hleihel) [1724333]
- [documentation] netfilter: doc: Add nf_tables part in tproxy.txt (Phil Sutter) [1762977]
- [net] netfilter: nft_socket: fix erroneous socket assignment (Phil Sutter) [1762977]
- [net] netfilter: nft_socket: Break evaluation if no socket found (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Fix missing-braces warning (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Add missing config check (Phil Sutter) [1762977]
- [net] netfilter: nf_tables: Add native tproxy support (Phil Sutter) [1762977]
- [net] netfilter: nft_tproxy: Move nf_tproxy_assign_sock() to nf_tproxy.h (Phil Sutter) [1762977]
- [net] sched: ensure opts_len <= IP_TUNNEL_OPTS_MAX in act_tunnel_key (Ivan Vecera) [1774706]
- [net] ipmr: Fix skb headroom in ipmr_get_route(). (Guillaume Nault) [1773692]
- [net] netns: fix GFP flags in rtnl_net_notifyid() (Guillaume Nault) [1763661]
- [net] netns: fix NLM_F_ECHO mechanism for RTM_NEWNSID (Guillaume Nault) [1763661]
- [netdrv] ptp: ptp_clock: Publish scaled_ppm_to_ppb (Ivan Vecera) [1772085]
- [kernel] rh_features: move rh_features entry to sys/kernel (Hangbin Liu) [1660583]
- [net] netfilter: nf_tables: Make nft_meta expression more robust (Phil Sutter) [1725169]
- [tools] selftests/tls: add test for concurrent recv and send (Sabrina Dubroca) [1760375]
- [net] tls: add a TX lock (Sabrina Dubroca) [1760375]
- [net] tls: don't pay attention to sk_write_pending when pushing partial records (Sabrina Dubroca) [1760375]
- [net] tls: fix sk_msg trim on fallback to copy mode (Sabrina Dubroca) [1760375]
- [net] tls: align non temporal copy to cache lines (Sabrina Dubroca) [1760375]
- [net] tls: remove the record tail optimization (Sabrina Dubroca) [1760375]
- [net] tls: use RCU for the adder to the offload record list (Sabrina Dubroca) [1760375]
- [net] tls: unref frags in order (Sabrina Dubroca) [1760375]
- [net] tcp: ulp: fix possible crash in tcp_diag_get_aux_size() (Sabrina Dubroca) [1760375]
- [net] tls: dedup the record cleanup (Sabrina Dubroca) [1760375]
- [net] tls: clean up the number of #ifdefs for CONFIG_TLS_DEVICE (Sabrina Dubroca) [1760375]
- [net] tls: narrow down the critical area of device_offload_lock (Sabrina Dubroca) [1760375]
- [net] tls: don't jump to return (Sabrina Dubroca) [1760375]
- [net] tls: export protocol version, cipher, tx_conf/rx_conf to socket diag (Sabrina Dubroca) [1760375]
- [net] tcp: ulp: add functions to dump ulp-specific information (Sabrina Dubroca) [1760375]
- [net] tls: use RCU protection on icsk->icsk_ulp_data (Sabrina Dubroca) [1760375]
- [net] core/skmsg: Delete an unnecessary check before the function call "consume_skb" (Sabrina Dubroca) [1760375]
- [net] tls, fix sk_write_space NULL write when tx disabled (Sabrina Dubroca) [1760375]
- [net] tls: swap sk_write_space on close (Sabrina Dubroca) [1760375]
- [net] tls: prevent skb_orphan() from leaking TLS plain text with offload (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a litmus test for the socket reuse through shutdown (Sabrina Dubroca) [1760375]
- [net] tls: partially revert fix transition through disconnect with close (Sabrina Dubroca) [1760375]
- [documentation] TLS: fix stat counters description (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: fix TLS tests with CONFIG_TLS=n (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add shutdown tests (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: close the socket with open record (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a bidirectional test (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: test error codes around TLS ULP installation (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add a test for ULP but no keys (Sabrina Dubroca) [1760375]
- [net] bpf: sockmap/tls, close can race with map free (Sabrina Dubroca) [1760375]
- [net] tls: fix transition through disconnect with close (Sabrina Dubroca) [1760375]
- [net] tls: remove sock unlock/lock around strp_done() (Sabrina Dubroca) [1760375]
- [net] tls: remove close callback sock unlock/lock around TX work flush (Sabrina Dubroca) [1760375]
- [net] tls: don't call tls_sk_proto_close for hw record offload (Sabrina Dubroca) [1760375]
- [net] tls: don't arm strparser immediately in tls_set_sw_offload() (Sabrina Dubroca) [1760375]
- [net] tls: add missing prot info init (Sabrina Dubroca) [1760375]
- [netdrv] mlx5: Return -EINVAL when WARN_ON_ONCE triggers in mlx5e_tls_resync(). (Sabrina Dubroca) [1760375]
- [net] tls: don't clear TX resync flag on error (Sabrina Dubroca) [1760375]
- [tools] selftests/tls: add test for poll() with data in TLS ULP (Sabrina Dubroca) [1760375]
- [net] tls: add kernel-driven resync mechanism for TX (Sabrina Dubroca) [1760375]
- [net] tls: generalize the resync callback (Sabrina Dubroca) [1760375]
- [net] tls: add kernel-driven TLS RX resync (Sabrina Dubroca) [1760375]
- [net] tls: rename handle_device_resync() (Sabrina Dubroca) [1760375]
- [net] tls: pass record number as a byte array (Sabrina Dubroca) [1760375]
- [net] tls: simplify seq calculation in handle_device_resync() (Sabrina Dubroca) [1760375]
- [net] tls: export TLS per skb encryption (Sabrina Dubroca) [1760375]
- [include] net/tls: simplify driver context retrieval (Sabrina Dubroca) [1760375]
- [include] net/tls: split the TLS_DRIVER_STATE_SIZE and bump TX to 16 bytes (Sabrina Dubroca) [1760375]
- [net] tls: don't pass version to tls_advance_record_sn() (Sabrina Dubroca) [1760375]
- [include] net/tls: reorganize struct tls_context (Sabrina Dubroca) [1760375]
- [net] tls: use version from prot (Sabrina Dubroca) [1760375]
- [net] tls: don't re-check msg decrypted status in tls_device_decrypted() (Sabrina Dubroca) [1760375]
- [net] tls: don't look for decrypted frames on non-offloaded sockets (Sabrina Dubroca) [1760375]
- [net] tls: remove false positive warning (Sabrina Dubroca) [1760375]
- [net] tls: check return values from skb_copy_bits() and skb_store_bits() (Sabrina Dubroca) [1760375]
- [net] tls: fully initialize the msg wrapper skb (Sabrina Dubroca) [1760375]
- [net] tls: replace the sleeping lock around RX resync with a bit lock (Sabrina Dubroca) [1760375]
- [net] revert "net/tls: avoid NULL-deref on resync during device removal" (Sabrina Dubroca) [1760375]
- [net] tls: avoid NULL-deref on resync during device removal (Sabrina Dubroca) [1760375]
- [net] tls: Add support of AES128-CCM based ciphers (Sabrina Dubroca) [1760375]
- [documentation] add TLS offload documentation (Sabrina Dubroca) [1760375]
- [documentation] tls: RSTify the ktls documentation (Sabrina Dubroca) [1760375]
- [net] xdp: increase kABI version (Jiri Benc) [1749817]
- [tools] selftests: bpf: disable test_seg6_loop test (Jiri Benc) [1749817]
- [tools] selftests: bpf: fix test_tc_tunnel hanging (Jiri Benc) [1749817]
- [tools] selftests: bpf: xdping is not meant to be run standalone (Jiri Benc) [1749817]
- [tools] libbpf: Use implicit XSKMAP lookup from AF_XDP XDP program (Jiri Benc) [1749817]
- [lib] bpf, testing: Introduce 'gso_linear_no_head_frag' skb_segment test (Jiri Benc) [1749817]
- [lib] bpf, testing: Refactor test_skb_segment() for testing skb_segment() on different skbs (Jiri Benc) [1749817]
- [tools] selftests/bpf: test_progs: Don't leak server_fd in tcp_rtt (Jiri Benc) [1749817]
- [tools] selftests/bpf: test_progs: fix client/server race in tcp_rtt (Jiri Benc) [1749817]
- [net] flow_dissector: Fix potential use-after-free on BPF_PROG_DETACH (Jiri Benc) [1749817]
- [tools] selftests/bpf: fix race in test_tcp_rtt test (Jiri Benc) [1749817]
- [net] xdp: unpin xdp umem pages in error path (Jiri Benc) [1749817]
- [net] sock: make cookie generation global instead of per netns (Jiri Benc) [1749817]
- [net] bpfilter: add "WITH Linux-syscall-note" to SPDX tag of uapi headers (Jiri Benc) [1749817]
- [net] bpf: sockmap, only create entry if ulp is not already enabled (Jiri Benc) [1749817]
- [net] bpf: sockmap, synchronize_rcu before free'ing map (Jiri Benc) [1749817]
- [net] bpf: sockmap, sock_map_delete needs to use xchg (Jiri Benc) [1749817]
- [net] core: page_pool: add user refcnt and reintroduce page_pool_destroy (Jiri Benc) [1749817]
- [net] bpf: avoid unused variable warning in tcp_bpf_rtt() (Jiri Benc) [1749817]
- [net] xdp: fix potential deadlock on socket mutex (Jiri Benc) [1749817]
- [net] bpfilter: print umh messages to /dev/kmsg (Jiri Benc) [1749817]
- [net] xdp: fix possible cq entry leak (Jiri Benc) [1749817]
- [net] xdp: fix race on generic receive path (Jiri Benc) [1749817]
- [samples] bpf: fix tcp_bpf.readme detach command (Jiri Benc) [1749817]
- [samples] bpf: add sample program that periodically dumps TCP stats (Jiri Benc) [1749817]
- [tools] selftests/bpf: test BPF_SOCK_OPS_RTT_CB (Jiri Benc) [1749817]
- [tools] bpf/tools: sync bpf.h (Jiri Benc) [1749817]
- [net] bpf: add icsk_retransmits to bpf_tcp_sock (Jiri Benc) [1749817]
- [net] bpf: add dsack_dups/delivered{, _ce} to bpf_tcp_sock (Jiri Benc) [1749817]
- [net] bpf: split shared bpf_tcp_sock and bpf_sock_ops implementation (Jiri Benc) [1749817]
- [net] bpf: add BPF_CGROUP_SOCK_OPS callback that is executed on every RTT (Jiri Benc) [1749817]
- [net] init/kconfig: add CONFIG_CC_CAN_LINK (Jiri Benc) [1749817]
- [net] page_pool: add helper function for retrieving dma direction (Jiri Benc) [1749817]
- [net] xdp: fix hang while unregistering device bound to xdp socket (Jiri Benc) [1749817]
- [net] xdp: hold device for umem regardless of zero-copy mode (Jiri Benc) [1749817]
- [net] xsk: Change the default frame size to 4096 and allow controlling it (Jiri Benc) [1749817]
- [tools] libbpf: Support getsockopt XDP_OPTIONS (Jiri Benc) [1749817]
- [net] xsk: Add getsockopt XDP_OPTIONS (Jiri Benc) [1749817]
- [net] xsk: Add API to check for available entries in FQ (Jiri Benc) [1749817]
- [net] xsk: Properly terminate assignment in xskq_produce_flush_desc (Jiri Benc) [1749817]
- [net] xdp: Make __mem_id_disconnect static (Jiri Benc) [1749817]
- [net] xsk: sample kernel code is now in libbpf (Jiri Benc) [1749817]
- [net] page_pool: fix compile warning when CONFIG_PAGE_POOL is disabled (Jiri Benc) [1749817]
- [net] page_pool: make sure struct device is stable (Jiri Benc) [1749817]
- [net] page_pool: add tracepoints for page_pool with details need by XDP (Jiri Benc) [1749817]
- [net] xdp: add tracepoints for XDP mem (Jiri Benc) [1749817]
- [net] xdp: force mem allocator removal and periodic warning (Jiri Benc) [1749817]
- [net] xdp: tracking page_pool resources and safe removal (Jiri Benc) [1749817]
- [netdrv] mlx5: more strict use of page_pool API (Jiri Benc) [1749817]
- [net] page_pool: introduce page_pool_free and use in mlx5 (Jiri Benc) [1749817]
- [net] veth: use xdp_release_frame for XDP_PASS (Jiri Benc) [1749817]
- [net] xdp: page_pool related fix to cpumap (Jiri Benc) [1749817]
- [net] xdp: fix leak of IDA cyclic id if rhashtable_insert_slow fails (Jiri Benc) [1749817]
- [net] page_pool: add helper function to unmap dma addresses (Jiri Benc) [1749817]
- [net] page_pool: add helper function to retrieve dma addresses (Jiri Benc) [1749817]
- [net] page_pool: use DMA_ATTR_SKIP_CPU_SYNC for DMA mappings (Jiri Benc) [1749817]
- [net] page_pool: don't use page->private to store dma_addr_t (Jiri Benc) [1749817]
- [mm] add dma_addr_t to struct page (Jiri Benc) [1749817]
- [tools] bpf: Sync asm-generic/socket.h to tools/ (Jiri Benc) [1749817]
- [net] bpf: net: Add SO_DETACH_REUSEPORT_BPF (Jiri Benc) [1749817]
- [net] veth: Support bulk XDP_TX (Jiri Benc) [1749817]
- [net] flow_dissector: remove unused FLOW_DISSECTOR_F_STOP_AT_L3 flag (Jiri Benc) [1749817]
- [tools] selftests/bpf: fix compilation error for flow_dissector.c (Jiri Benc) [1749817]
- [net] bpf: Update BPF_CGROUP_RUN_PROG_INET_EGRESS calls (Jiri Benc) [1749817]
- [net] signal/bpfilter: Fix bpfilter_kernl to use send_sig not force_sig (Jiri Benc) [1749817]
- [net] arch: Use asm-generic/socket.h when possible (Jiri Benc) [1749817]
- [net] flow_dissector: correct comments on enum flow_dissector_key_id (Jiri Benc) [1749817]
- [net] tcp: add stat of data packet reordering events (Jiri Benc) [1749817]
- [net] tcp: add dsack blocks received stats (Jiri Benc) [1749817]
- [net] tcp: add data bytes retransmitted stats (Jiri Benc) [1749817]
- [net] tcp: add data bytes sent stats (Jiri Benc) [1749817]
- [net] tcp: add a helper to calculate size of opt_stats (Jiri Benc) [1749817]
- [net] netfilter: Support iif matches in POSTROUTING (Phil Sutter) [1775961]
- [tools] selftests: add basic netdevsim devlink flash testing (Petr Oros) [1770359]
- [netdrv] netdevsim: implement fake flash updating with notifications (Petr Oros) [1770359]
- [net] devlink: allow driver to update progress of flash update (Petr Oros) [1770359]
- [net] devlink: Add extack to shared buffer operations (Petr Oros) [1770347]
- [net] xfrm: policy: avoid warning splat when merging nodes (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix bydst hlist corruption on hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix infinite loop when merging src-nodes (Sabrina Dubroca) [1758100]
- [tools] selftests: xfrm: alter htresh to trigger move of policies to hash table (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix reinsertion on node merge (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: delete inexact policies from inexact list on hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: use hlist rcu variants on inexact insert, part 2 (Sabrina Dubroca) [1758100]
- [tools] selftests: xfrm: add block rules with adjacent/overlapping subnets (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: remove set but not used variable 'priority' (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix policy hash rebuild (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: fix netlink/pf_key policy lookups (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: add 2nd-level saddr trees for inexact policies (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in a tree ordered by source address (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: check reinserted policies match their node (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in a tree ordered by destination address (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: add inexact policy search tree infrastructure (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: consider if_id when hashing inexact policy (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: store inexact policies in an rhashtable (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: return NULL when inexact search needed (Sabrina Dubroca) [1758100]
- [net] xfrm: policy: split list insertion into a helper (Sabrina Dubroca) [1758100]
- [net] xfrm: security: iterate all, not inexact lists (Sabrina Dubroca) [1758100]
- [tools] selftests: add xfrm policy test script (Sabrina Dubroca) [1758100]
- [net] af_packet: fix the tx skb protocol in raw sockets with ETH_P_ALL (Ivan Vecera) [1765561]
- [netdrv] mlx5e: Trust kernel regarding transport offset (Ivan Vecera) [1765561]
- [netdrv] net/mlx5e: Remove the wrong assumption about transport offset (Ivan Vecera) [1765561]
- [net] packet: Remove redundant skb->protocol set (Ivan Vecera) [1765561]
- [net] packet: Ask driver for protocol if not provided by user (Ivan Vecera) [1765561]
- [net] ethernet: Add parse_protocol header_ops support (Ivan Vecera) [1765561]
- [include] net: Introduce parse_protocol header_ops callback (Ivan Vecera) [1765561]
- [net] Don't set transport offset to invalid value (Ivan Vecera) [1765561]
- [netdrv] Fix Kconfig indentation (Josef Oskera) [1764592]
- [netdrv] be2net: make two arrays static const, makes object smaller (Josef Oskera) [1764592]
- [netdrv] be2net: eliminate enable field from be_aic_obj (Josef Oskera) [1764592]
- [netdrv] Use skb_frag_off accessors (Josef Oskera) [1764592]
- [netdrv] Use skb accessors in network drivers (Josef Oskera) [1764592]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 338 (Josef Oskera) [1764592]
- [netdrv] treewide: Add SPDX license identifier - Makefile/Kconfig (Josef Oskera) [1764592]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Josef Oskera) [1764592]
- [documentation] networking: switchdev: Update port parent ID section (Ivan Vecera) [1757840]
- [net] Get rid of SWITCHDEV_ATTR_ID_PORT_PARENT_ID (Ivan Vecera) [1757840]
- [net] dsa: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [drivers] staging: fsl-dpaa2: ethsw: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] mscc: ocelot: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] net/mlx5e: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [netdrv] liquidio: Implement ndo_get_port_parent_id() (Ivan Vecera) [1757840]
- [net] tipc: fix unlimited bundling of small messages (Jon Maloy) [1761969]
- [net] tipc: clean up skb list lock handling on send path (Jon Maloy) [1761969]
- [net] tipc: fix false detection of retransmit failures (Jon Maloy) [1761969]
- [net] tipc: reduce risk of wakeup queue starvation (Jon Maloy) [1761969]
- [net] tipc: fix changeover issues due to large packet (Jon Maloy) [1761969]
- [net] tipc: optimize link synching mechanism (Jon Maloy) [1761969]
- [net] tipc: Fix a typo (Jon Maloy) [1761969]
- [net] tipc: use rcu dereference functions properly (Jon Maloy) [1761969]
- [net] tipc: remove ub->ubsock checks (Jon Maloy) [1761969]
- [net] tipc: embed jiffies in macro TIPC_BC_RETR_LIM (Jon Maloy) [1761969]
- [net] tipc: add dst_cache support for udp media (Jon Maloy) [1761969]
- [net] tipc: rename function msg_get_wrapped() to msg_inner_hdr() (Jon Maloy) [1761969]
- [net] tipc: eliminate unnecessary skb expansion during retransmission (Jon Maloy) [1761969]
- [net] tipc: simplify stale link failure criteria (Jon Maloy) [1761969]
- [net] tipc: check msg->req data len in tipc_nl_compat_bearer_disable (Jon Maloy) [1761969]
- [net] tipc: remove the unnecessary msg->req check from tipc_nl_compat_bearer_set (Jon Maloy) [1761969]
- [net] tipc: fix issues with early FAILOVER_MSG from peer (Jon Maloy) [1761969]
- [net] tipc: include retrans failure detection for unicast (Jon Maloy) [1761969]
- [net] tipc: purge deferredq list for each grp member in tipc_group_delete (Jon Maloy) [1761969]
- [net] devlink: remove redundant rtnl lock assert (Marcelo Leitner) [1774694]

* Wed Nov 27 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-156.rt13.13.el8]
- [gpu] drm/i915/aml: Allow SPT PCH for all AML devices (Lyude Paul) [1761469 1731110]
- [gpu] drm/i915/cml: Add second PCH ID for CMP (Lyude Paul) [1731110]
- [drm] i915/cml: Add Missing PCI IDs (Lyude Paul) [1727949 1731110]
- [gpu] DRM Backport 5.2 -> 5.3 (Lyude Paul) [1731110]
- [xen] mm/pgtable: drop pgtable_t variable from pte_fn_t functions (Lyude Paul) [1731110]
- [gpu] DRM Backport 5.1 -> 5.2 (Lyude Paul) [1731110]
- [s390] bus_find_device: Unify the match callback with class_find_device (Lyude Paul) [1731110]
- [kernel] i2c: algo-bit: include main i2c header (Lyude Paul) [1731110]
- [extcon] axp288: Add a depends on ACPI to the Kconfig entry (Lyude Paul) [1731110]
- [extcon] axp288: Convert to use acpi_dev_get_first_match_dev() (Lyude Paul) [1731110]
- [acpi] gpio: merrifield: Fix build err without CONFIG_ACPI (Lyude Paul) [1731110]
- [gpio] merrifield: Convert to use acpi_dev_get_first_match_dev() (Lyude Paul) [1731110]
- [kernel] proc/sysctl: add shared variables for range check (Lyude Paul) [1731110]
- [gpu] drm/i915: Split Pineview device info into desktop and mobile (Lyude Paul) [1731110]
- [gpu] snd/hda, drm/i915: Track the display_power_status using a cookie (Lyude Paul) [1731110]
- [video] hdmi: Dropped static functions from kernel doc (Lyude Paul) [1731110]
- [video] hdmi: Add Unpack function for DRM infoframe (Lyude Paul) [1731110]
- [video] drm: Enable HDR infoframe support (Lyude Paul) [1731110]
- [kernel] drm: Add HDR source metadata property (Lyude Paul) [1731110]
- [gpu] drm: Add colorspace info to AVI Infoframe (Lyude Paul) [1731110]
- [gpu] drm: Add HDMI colorspace property (Lyude Paul) [1731110]
- [kernel] video/hdmi: Add an enum for HDMI packet types (Lyude Paul) [1731110]
- [video] hdmi: Constify infoframe passed to the pack functions (Lyude Paul) [1731110]
- [video] hdmi: Constify infoframe passed to the log functions (Lyude Paul) [1731110]
- [video] hdmi: Pass buffer size to infoframe unpack functions (Lyude Paul) [1731110]
- [video] hdmi: Constify 'buffer' to the unpack functions (Lyude Paul) [1731110]
- [video] media: hdmi.h: rename ADOBE_RGB to OPRGB and ADOBE_YCC to OPYCC (Lyude Paul) [1731110]
- [media] replace ADOBERGB by OPRGB (Lyude Paul) [1731110]
- [dma-buf] add show_fdinfo handler (Lyude Paul) [1731110]
- [dma-buf] dma-fence: Signal all callbacks from dma_fence_release() (Lyude Paul) [1731110]
- [dma-buf] udmabuf: actually unmap the scatterlist (Lyude Paul) [1731110]
- [dma-buf] Make mmap callback actually optional (Lyude Paul) [1731110]
- [dma-buf] Remove unused sync_dump() (Lyude Paul) [1731110]
- [kernel] dma-buf: explicitely note that dma-fence-chains use 64bit seqno (Lyude Paul) [1731110]
- [dma-buf] fix stack corruption in dma_fence_chain_release (Lyude Paul) [1731110]
- [dma-buf] add new dma_fence_chain container v7 (Lyude Paul) [1731110]
- [dma-buf] add some lockdep asserts to the reservation object implementation (Lyude Paul) [1731110]
- [iommu] arm-smmu-v3: Fix build error without CONFIG_PCI_ATS (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Avoid locking on invalidation path when not using ATS (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Fix ATC invalidation ordering wrt main TLBs (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Rework enabling/disabling of ATS for PCI masters (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Don't issue CMD_SYNC for zero-length invalidations (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Remove boolean bitfield for 'ats_enabled' flag (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Document ordering guarantees of command insertion (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Defer TLB invalidation until ->iotlb_sync() (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Reduce contention during command-queue insertion (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Operate directly on low-level queue where possible (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Move low-level queue fields out of arm_smmu_queue (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Drop unused 'q' argument from Q_OVF macro (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Separate s/w and h/w views of prod and cons indexes (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Pass struct iommu_iotlb_gather to ->tlb_add_page() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Pass struct iommu_iotlb_gather to ->unmap() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Remove unused ->tlb_sync() callback (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Replace ->tlb_add_flush() with ->tlb_add_page() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable-arm: Call ->tlb_flush_walk() and ->tlb_flush_leaf() (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Hook up ->tlb_flush_walk() and ->tlb_flush_leaf() in drivers (Jerry Snitselaar) [1729845]
- [kernel] iommu/io-pgtable: Introduce tlb_flush_walk() and tlb_flush_leaf() (Jerry Snitselaar) [1729845]
- [iommu] Pass struct iommu_iotlb_gather to ->unmap() and ->iotlb_sync() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Introduce iommu_iotlb_gather_add_page() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Introduce struct iommu_iotlb_gather for batching TLB flushes (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable: Rename iommu_gather_ops to iommu_flush_ops (Jerry Snitselaar) [1729845]
- [iommu] io-pgtable-arm: Remove redundant call to io_pgtable_tlb_sync() (Jerry Snitselaar) [1729845]
- [kernel] iommu: Remove empty iommu_tlb_range_add() callback from iommu_ops (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Invalidate ATC when detaching a device (Jerry Snitselaar) [1729845]
- [iommu] arm-smmu-v3: Add support for PCI ATS (Jerry Snitselaar) [1729845]
- [iommu] Introduce iotlb_sync_map callback (Jerry Snitselaar) [1742234]
- [kernel] dma-mapping: fix page attributes for dma_mmap_* (Jerry Snitselaar) [1754727]
- [kernel] dma-mapping: check pfn validity in dma_common_{mmap, get_sgtable} (Jerry Snitselaar) [1754727]
- [kernel] swiotlb: checking whether swiotlb buffer is full with io_tlb_used (Jerry Snitselaar) [1754727]
- [kernel] dma-direct: fix zone selection after an unaddressable CMA allocation (Jerry Snitselaar) [1754727]
- [kernel] dma-contiguous: page-align the size in dma_free_contiguous() (Jerry Snitselaar) [1754727]
- [kernel] dma-contiguous: do not overwrite align in dma_alloc_contiguous() (Jerry Snitselaar) [1754727]
- [kernel] dma-mapping: fix panic caused by passing empty cma command line argument (Jerry Snitselaar) [1754727]
- [iommu] dma: Handle SG length overflow better (Jerry Snitselaar) [1742234]
- [iommu] dma: Handle MSI mappings separately (Jerry Snitselaar) [1742234]
- [iommu] dma: Apply dma_{alloc, free}_contiguous functions (Jerry Snitselaar) [1742234]
- [iommu] dma: Don't depend on CONFIG_DMA_DIRECT_REMAP (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_mmap (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_get_sgtable (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_alloc, part 2 (Jerry Snitselaar) [1742234]
- [iommu] dma: Cleanup variable naming in iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [iommu] dma: Split iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Merge the CMA and alloc_pages allocation paths (Jerry Snitselaar) [1742234]
- [iommu] dma: Don't remap CMA unnecessarily (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Remove __iommu_dma_free (Jerry Snitselaar) [1742234]
- [iommu] dma: Refactor the page array remapping allocator (Jerry Snitselaar) [1742234]
- [iommu] dma: Factor out remapped pages lookup (Jerry Snitselaar) [1742234]
- [iommu] dma: Squash __iommu_dma_{map, unmap}_page helpers (Jerry Snitselaar) [1742234]
- [iommu] dma: Move domain lookup into __iommu_dma_{map, unmap} (Jerry Snitselaar) [1742234]
- [iommu] dma: Move __iommu_dma_map (Jerry Snitselaar) [1742234]
- [iommu] dma: Use for_each_sg in iommu_dma_alloc (Jerry Snitselaar) [1742234]
- [clk] Make clk_bulk_get_all() return a valid "id" (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Support all Mali configurations (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Correct Mali attributes (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Fix panic after kexec -p for kdump (Jerry Snitselaar) [1742234]
- [kernel] iommu/iova: Fix compilation error with !CONFIG_IOMMU_IOVA (Jerry Snitselaar) [1742234]
- [iommu] amd: Check PM_LEVEL_SIZE() condition in locked section (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix incorrect PASID decoding from event log (Jerry Snitselaar) [1742234]
- [iommu] amd: Lock code paths traversing protection_domain->dev_list (Jerry Snitselaar) [1742234]
- [iommu] amd: Lock dev_data in attach/detach code paths (Jerry Snitselaar) [1742234]
- [iommu] amd: Check for busy devices earlier in attach_device() (Jerry Snitselaar) [1742234]
- [iommu] amd: Take domain->lock for complete attach/detach path (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove amd_iommu_devtable_lock (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove domain->updated (Jerry Snitselaar) [1742234]
- [iommu] iova: Avoid false sharing on fq_timer_on (Jerry Snitselaar) [1742234]
- [iommu] Don't use sme_active() in generic code (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix wrong analysis whether devices share the same bus (Jerry Snitselaar) [1742234]
- [iommu] amd: Wait for completion of IOTLB flush in attach_device (Jerry Snitselaar) [1742234]
- [iommu] amd: Unmap all L7 PTEs when downgrading page-sizes (Jerry Snitselaar) [1742234]
- [iommu] amd: Introduce first_pte_l7() helper (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix downgrading default page-sizes in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix pages leak in free_pagetable() (Jerry Snitselaar) [1742234]
- [documentation] documentation: Update Documentation for iommu.passthrough (Jerry Snitselaar) [1745844]
- [iommu] Disable passthrough mode when SME is active (Jerry Snitselaar) [1745844]
- [iommu] Set default domain type at runtime (Jerry Snitselaar) [1745844]
- [iommu] Print default domain type on boot (Jerry Snitselaar) [1745844]
- [x86] dma: Get rid of iommu_pass_through (Jerry Snitselaar) [1745844]
- [iommu] vt-d: Request passthrough mode from IOMMU core (Jerry Snitselaar) [1745844]
- [iommu] amd: Request passthrough mode from IOMMU core (Jerry Snitselaar) [1745844]
- [iommu] Use Functions to set default domain type in iommu_set_def_domain_type() (Jerry Snitselaar) [1745844]
- [iommu] Add helpers to set/get default domain type (Jerry Snitselaar) [1745844]
- [iommu] Remember when default domain type was set on kernel command line (Jerry Snitselaar) [1745844]
- [iommu] amd: Flush old domains in kdump kernel (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix race in increase_address_space() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove global page flush support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix possible use-after-free of private domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Detach domain before using a private one (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Correctly check format of page table in debugfs (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Detach domain when move device out of group (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Mark expected switch fall-through (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Print pasid table entries MSB to LSB in debugfs (Jerry Snitselaar) [1742234]
- [iommu] iova: Remove stale cached32_node (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Check if domain->pgd was allocated (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't queue_iova() if there is no flush queue (Jerry Snitselaar) [1742234]
- [iommu] amd: fix a crash in iova_magazine_free_pfns (Jerry Snitselaar) [1742234]
- [iommu] Use right function to get group for device (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Fix compilation when CONFIG_CMA=n (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Support non-coherent page tables (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Replace IO_PGTABLE_QUIRK_NO_DMA with specific flag (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm-v7s: request DMA32 memory, and improve debugging (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Add support to use system cache (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Increase maximum size of queues (Jerry Snitselaar) [1722978]
- [iommu] amd: Flush not present cache in iommu_map_page (Jerry Snitselaar) [1742234]
- [iommu] amd: Only free resources once on init error (Jerry Snitselaar) [1742234]
- [iommu] amd: Move gart fallback to amd_iommu_init (Jerry Snitselaar) [1742234]
- [iommu] amd: Make iommu_disable safer (Jerry Snitselaar) [1742234]
- [iommu] amd: Add missed 'tag' to error msg in iommu_print_event (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove redundant assignment to variable npages (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup unused variable (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Silence a variable set but not used (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove an unused variable "length" (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup after delegating DMA domain to generic iommu (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix suspicious RCU usage in probe_acpi_namespace_devices() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Allow DMA domain attaching to rmrr locked device (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't enable iommu's which have been ignored (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set domain type for a private domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't return error when device gets right domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix a variable set but not used (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Fix typo in SVM code comment (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove static identity map code (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove duplicated code for device hotplug (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove startup parameter from device_def_domain_type() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Cleanup get_valid_domain_for_dev() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Implement is_attach_deferred iommu ops entry (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Probe DMA-capable ACPI name space devices (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Handle 32bit device with identity default domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Identify default domains replaced with private (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Delegate the dma domain to upper layer (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Delegate the identity domain to upper layer (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add device_def_domain_type() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enable DMA remapping after rmrr mapped (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Expose ISA direct mapping region via iommu_get_resv_regions (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Implement apply_resv_region iommu ops entry (Jerry Snitselaar) [1742234]
- [iommu] Add API to request DMA domain for device (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show scalable mode DMAR table internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Introduce macros useful for dumping DMAR table (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Modify the format of intel DMAR tables dump (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unnecessary rcu_read_locks (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix bind svm with multiple devices (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Avoid constant zero in TLBI writes (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Set the right field for Page Walk Snoop (Jerry Snitselaar) [1742234]
- [iommu] Add missing new line for dma type (Jerry Snitselaar) [1742234]
- [kernel] iommu/iova: Separate atomic variables to improve performance (Jerry Snitselaar) [1742234]
- [iommu] Remove iommu_callback_data (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove amd_iommu_pd_list (Jerry Snitselaar) [1742234]
- [iommu] amd: Use pci_prg_resp_pasid_required() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix leak in intel_pasid_alloc_table on error path (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Make kernel parameter igfx_off work with vIOMMU (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set intel_iommu_gfx_mapped correctly (Jerry Snitselaar) [1742234]
- [iommu] vt-d: cleanup: no spaces at the start of a line (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Don't request page request irq under dmar_global_lock (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Use struct_size() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Flush IOTLB for untrusted device in time (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Clean up iommu_no_mapping (Jerry Snitselaar) [1742234]
- [vfio] type1: Add domain at(de)taching group helpers (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Return ID associated with an auxiliary domain (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Aux-domain specific domain attach/detach (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Move common code out of iommu_attch_device() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add per-device IOMMU feature ops entries (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Make intel_iommu_enable_pasid() more generic (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Switch to bitmap_zalloc() (Jerry Snitselaar) [1742234]
- [iommu] Bind process address spaces to devices (Jerry Snitselaar) [1742234]
- [iommu] Add APIs for multiple domains per device (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Log CBFRSYNRA register on context fault (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Don't disable SMMU in kdump kernel (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Disable tagged pointers (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Link domains and devices (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Add a master->domain pointer (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Store SteamIDs in master (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Rename arm_smmu_master_data to arm_smmu_master (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable: Add ARM Mali midgard MMU page table format (Jerry Snitselaar) [1722978]
- [iommu] vt-d: Save the right domain ID used by hardware (Jerry Snitselaar) [1742234]
- [iommu] iova: Fix tracking of recently failed iova address (Jerry Snitselaar) [1742234]
- [iommu] Fix IOMMU debugfs fallout (Jerry Snitselaar) [1742234]
- [kernel] iommu: Document iommu_ops.is_attach_deferred() (Jerry Snitselaar) [1742234]
- [kernel] iommu: Document iommu_ops.iotlb_sync_map() (Jerry Snitselaar) [1742234]
- [kernel] iommu: Fix flush_tlb_all typo (Jerry Snitselaar) [1742234]
- [iommu] io-pgtable-arm-v7s: Only kmemleak_ignore L2 tables (Jerry Snitselaar) [1722978]
- [iommu] Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [kernel] iommu: Allow io-pgtable to be used outside of iommu/ (Jerry Snitselaar) [1722978]
- [iommu] iova: Allow compiling the library without IOMMU support (Jerry Snitselaar) [1742234]
- [iommu] amd: Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove clear_flush_young notifier (Jerry Snitselaar) [1742234]
- [iommu] amd: Print reason for iommu_map_page failure in map_sg (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Get domain ID before clear pasid entry (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Set context field after value initialized (Jerry Snitselaar) [1742234]
- [kernel] pci/ats: Add inline to pci_prg_resp_pasid_required() (Jerry Snitselaar) [1724921 1724927]
- [iommu] vt-d: Enable ATS only if the device uses page aligned address (Jerry Snitselaar) [1724922]
- [pci] ats: Add pci_ats_page_aligned() interface (Jerry Snitselaar) [1724922]
- [iommu] vt-d: Fix PRI/PASID dependency issue (Jerry Snitselaar) [1724921 1724927]
- [pci] ats: Add pci_prg_resp_pasid_required() interface (Jerry Snitselaar) [1724921 1724927]
- [iommu] vt-d: Allow interrupts from the entire bus for aliased devices (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add helper to set an IRTE to verify only the bus number (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove misleading "domain 0" test from domain_exit() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unused dmar_remove_one_dev_info() argument (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove unnecessary local variable initializations (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Use dev_printk() when possible (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove change_pte notifier (Jerry Snitselaar) [1742234]
- iommu/vt-d: Implement dma_[un]map_resource() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Support page request in scalable mode (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Leave scalable mode default off (Jerry Snitselaar) [1742234]
- [iommu] of: Fix probe-deferral (Jerry Snitselaar) [1742234]
- [iommu] Check for iommu_ops == NULL in iommu_probe_device() (Jerry Snitselaar) [1742234]
- [iommu] of: Don't call iommu_ops->add_device directly (Jerry Snitselaar) [1742234]
- powerpc/iommu: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [powerpc] iommu: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [iommu] of: Use device_iommu_mapped() (Jerry Snitselaar) [1742234]
- [iommu] of: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1742234]
- [iommu] dma: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Use helper functions to access dev->iommu_fwspec (Jerry Snitselaar) [1722978]
- [acpi] iort: Fix rc_dma_get_range() (Jerry Snitselaar) [1722978]
- [kernel] iommu: Change tlb_range_add to iotlb_range_add and tlb_sync to iotlb_sync (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu: Make arm-smmu-v3 explicitly non-modular (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Make arm-smmu explicitly non-modular (Jerry Snitselaar) [1722978]
- [iommu] Audit and remove any unnecessary uses of module.h (Jerry Snitselaar) [1742234]
- [iommu] irq_remapping: Remove unused header files (Jerry Snitselaar) [1742234]
- [iommu] Do physical merging in iommu_map_sg() (Jerry Snitselaar) [1742234]
- [iommu] amd: Remove leading 0s in error log messages (Jerry Snitselaar) [1742234]
- [iommu] amd: Fix line-break in error log reporting (Jerry Snitselaar) [1742234]
- [iommu] amd: Use pr_fmt() (Jerry Snitselaar) [1742234]
- [iommu] amd: Allow to upgrade page-size (Jerry Snitselaar) [1742234]
- [iommu] amd: Restart loop if cmpxchg64 succeeded in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Allow downgrading page-sizes in alloc_pte() (Jerry Snitselaar) [1742234]
- [iommu] amd: Ignore page-mode 7 in free_sub_pt() (Jerry Snitselaar) [1742234]
- [iommu] amd: Introduce free_sub_pt() function (Jerry Snitselaar) [1742234]
- [iommu] amd: Collect page-table pages in freelist (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove deferred invalidation (Jerry Snitselaar) [1724930]
- [iommu] vt-d: Shared virtual address in scalable mode (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add first level page table interface (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Setup context and enable RID2PASID support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Pass pasid table to context mapping (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Setup pasid entry for RID2PASID support (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add second level page table interface (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Reserve a domain id for FL and PT modes (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add 256-bit invalidation descriptor support (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Move page table helpers into header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Manage scalalble mode PASID tables (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enumerate the scalable mode capability (Jerry Snitselaar) [1742234]
- [kernel] iommu/vtd: Cleanup dma_remapping.h header (Jerry Snitselaar) [1742234]
- [documentation] dt-bindings: arm-smmu: Add binding doc for Qcom smmu-500 (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add support for qcom, smmu-v2 variant (Jerry Snitselaar) [1722978]
- [documentation] dt-bindings: arm-smmu: Add bindings for qcom, smmu-v2 (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add the device_link between masters and smmu (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Invoke pm_runtime across the driver (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu: Add pm_runtime/sleep ops (Jerry Snitselaar) [1722978]
- [clk] add managed version of clk_bulk_get_all (Jerry Snitselaar) [1722978]
- [clk] add new APIs to operate on all available clocks (Jerry Snitselaar) [1722978]
- [clk] bulk: add of_clk_bulk_get() (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Use explicit mb() when moving cons pointer (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Avoid memory corruption from Hisilicon MSI payloads (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Fix big-endian CMD_SYNC writes (Jerry Snitselaar) [1722978]
- [iommu] revert "iommu/io-pgtable-arm: Check for v7s-incapable systems" (Jerry Snitselaar) [1722978]
- [iommu] Fix a typo (Jerry Snitselaar) [1742234]
- [iommu] Tidy up window attributes (Jerry Snitselaar) [1742234]
- [iommu] amd: Add default branch in amd_iommu_capable() (Jerry Snitselaar) [1742234]
- [iommu] amd: Move iommu_init_pci() to .init section (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show context internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support for Interrupt remapping (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add debugfs support to show register contents (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Enable base Intel IOMMU debugfs support (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Update register definitions to VT-d 3.0 specification (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Relocate struct/function declarations to its header files (Jerry Snitselaar) [1742234]
- [of] iommu/of: make of_pci_map_rid() available for other devices too (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Remove unnecessary wrapper function (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Add SPDX header (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Fix a couple of minor comment typos (Jerry Snitselaar) [1722978]
- [kernel] iommu/shmobile: Remove unused linux/platform_data/sh_ipmmu.h header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Handle memory shortage on pasid table allocation (Jerry Snitselaar) [1742234]
- [iommu] Add sysfs attribyte for domain type (Jerry Snitselaar) [1742234]
- [iommu] amd: Add basic debugfs infrastructure for AMD IOMMU (Jerry Snitselaar) [1742234]
- [iommu] Enable debugfs exposure of IOMMU driver internals (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Remove the obsolete per iommu pasid tables (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Apply per pci device pasid table in SVA (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Allocate and free pasid table (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Per PCI device pasid table interfaces (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Add for_each_device_domain() helper (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Move device_domain_info to header (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Apply global PASID in SVA (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Avoid using idr_for_each_entry() (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Global PASID name space (Jerry Snitselaar) [1742234]
- [iommu] vt-d: Fix dev iotlb pfsid use (Jerry Snitselaar) [1742234]
- [kernel] iommu/vt-d: Add definitions for PFSID (Jerry Snitselaar) [1742234]
- [iommu] amd: Argument page_size could be uninitialized (Jerry Snitselaar) [1742234]
- [iommu] arm-smmu-v3: Abort all transactions if SMMU is enabled in kdump kernel (Jerry Snitselaar) [1722978]
- [iommu] arm-smmu-v3: Prevent any devices access to memory without registration (Jerry Snitselaar) [1722978]
- [iommu] [] iommu/arm-smmu-v3: sync the OVACKFLG to PRIQ consumer register (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm-v7s: Abort allocation when table address overflows the PTE (Jerry Snitselaar) [1722978]
- [iommu] io-pgtable-arm: Fix pgtable allocation in selftest (Jerry Snitselaar) [1722978]
- [netdrv] iavf: initialize ITRN registers with correct values (Stefan Assmann) [1721697]
- [netdrv] iavf: fix MAC address setting for VFs when filter is rejected (Stefan Assmann) [1721697]
- [netdrv] iavf: allow permanent MAC address to change (Stefan Assmann) [1721697]
- [netdrv] iavf: remove unused debug function iavf_debug_d (Stefan Assmann) [1721697]
- [netdrv] Use skb_frag_off accessors (Stefan Assmann) [1721697]
- [netdrv] Use skb accessors in network drivers (Stefan Assmann) [1721697]
- [netdrv] iavf: fix dereference of null rx_buffer pointer (Stefan Assmann) [1721697]
- [netdrv] iavf: Fix up debug print macro (Stefan Assmann) [1721697]
- [netdrv] iavf: use struct_size() helper (Stefan Assmann) [1721697]
- [netdrv] iavf: allow null RX descriptors (Stefan Assmann) [1721697]
- [netdrv] iavf: add call to iavf_[add|del]_cloud_filter (Stefan Assmann) [1721697]
- [netdrv] iavf: Refactor init state machine (Stefan Assmann) [1721697]
- [netdrv] iavf: Refactor the watchdog state machine (Stefan Assmann) [1721697]
- [netdrv] iavf: Remove timer for work triggering, use delaying work instead (Stefan Assmann) [1721697]
- [netdrv] iavf: Move commands processing to the separate function (Stefan Assmann) [1721697]
- [netdrv] iavf: Fix the math for valid length for ADq enable (Stefan Assmann) [1721697]
- [netdrv] iavf: Change GFP_KERNEL to GFP_ATOMIC in kzalloc() (Stefan Assmann) [1721697]
- [netdrv] iavf: wait longer for close to complete (Stefan Assmann) [1721697]
- [netdrv] iavf: use signed variable (Stefan Assmann) [1721697]
- [netdrv] iavf: Create VLAN tag elements starting from the first element (Stefan Assmann) [1721697]
- [netdrv] iavf: update comments and file checks to match iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename i40e_device to iavf_device (Stefan Assmann) [1721697]
- [netdrv] iavf: change remaining i40e defines to be iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename iavf_client.h defines to match driver name (Stefan Assmann) [1721697]
- [netdrv] iavf: rename iavf_status structure flags (Stefan Assmann) [1721697]
- [netdrv] iavf: replace i40e variables with iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: rename i40e functions to be iavf (Stefan Assmann) [1721697]
- [netdrv] iavf: change iavf_status_code to iavf_status (Stefan Assmann) [1721697]
- [netdrv] iavf: Rename i40e_adminq* files to iavf_adminq* (Stefan Assmann) [1721697]
- [netdrv] iavf: iavf_client: use struct_size() helper (Stefan Assmann) [1721697]
- [netdrv] iavf: use struct_size() in kzalloc() (Stefan Assmann) [1721697]
- [netdrv] iavf: Limiting RSS queues to CPUs (Stefan Assmann) [1721697]
- [netdrv] iavf: Use printf instead of gnu_printf for iavf_debug_d (Stefan Assmann) [1721697]
- [netdrv] igb/igc: use ktime accessors for skb->tstamp (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for ethtool -m issue on X722 NIC (Stefan Assmann) [1721695]
- [netdrv] intel: Demote MTU change prints to debug (Stefan Assmann) [1721695]
- [netdrv] i40e: implement VF stats NDO (Stefan Assmann) [1721695]
- [netdrv] i40e: enable X710 support (Stefan Assmann) [1721695]
- [netdrv] i40e: Add UDP segmentation offload support (Stefan Assmann) [1721695]
- [netdrv] i40e: prevent memory leak in i40e_setup_macvlans (Stefan Assmann) [1721695]
- [netdrv] i40e: Refactoring VF MAC filters counting to make more reliable (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix LED blinking flow for X710T*L devices (Stefan Assmann) [1721695]
- [netdrv] i40e: allow ethtool to report SW and FW versions in recovery mode (Stefan Assmann) [1721695]
- [netdrv] i40e: initialize ITRN registers with correct values (Stefan Assmann) [1721695]
- [netdrv] i40e: Extend PHY access with page change flag (Stefan Assmann) [1721695]
- [netdrv] i40e: Extract detection of HW flags into a function (Stefan Assmann) [1721695]
- [netdrv] i40e: Wrong 'Advertised FEC modes' after set FEC to AUTO (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for persistent lldp support (Stefan Assmann) [1721695]
- [netdrv] i40e: clear __I40E_VIRTCHNL_OP_PENDING on invalid min Tx rate (Stefan Assmann) [1721695]
- [netdrv] i40e: use BIT macro to specify the cloud filter field flags (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix message for other card without FEC (Stefan Assmann) [1721695]
- [netdrv] i40e: fix missed "Negotiated" string in i40e_print_link_message() (Stefan Assmann) [1721695]
- [netdrv] i40e: mark additional missing bits as reserved (Stefan Assmann) [1721695]
- [netdrv] i40e: remove I40E_AQC_ADD_CLOUD_FILTER_OIP (Stefan Assmann) [1721695]
- [netdrv] i40e: use ktime_get_real_ts64 instead of ktime_to_timespec64 (Stefan Assmann) [1721695]
- [netdrv] i40e: check __I40E_VF_DISABLE bit in i40e_sync_filters_subtask (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove EMPR traces from debugfs facility (Stefan Assmann) [1721695]
- [netdrv] i40e: Implement debug macro hw_dbg using dev_dbg (Stefan Assmann) [1721695]
- [netdrv] i40e: fix hw_dbg usage in i40e_hmc_get_object_va (Stefan Assmann) [1721695]
- [netdrv] i40e: simplify Rx buffer recycle (Stefan Assmann) [1721695]
- [netdrv] i40e: fix retrying in i40e_aq_get_phy_capabilities (Stefan Assmann) [1721695]
- [netdrv] i40e: Persistent LLDP support (Stefan Assmann) [1721695]
- [netdrv] i40e: allow reset in recovery mode (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove function i40e_update_dcb_config() (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix crash caused by stress setting of VF MAC addresses (Stefan Assmann) [1721695]
- [netdrv] i40e: reset veb.tc_stats when resetting veb.stats (Stefan Assmann) [1721695]
- [netdrv] i40e: Update FW API version to 1.9 (Stefan Assmann) [1721695]
- [netdrv] i40e: check_recovery_mode had wrong if statement (Stefan Assmann) [1721695]
- [netdrv] i40e: Add drop mode parameter to set mac config (Stefan Assmann) [1721695]
- [netdrv] i40e: fix shifts of signed values (Stefan Assmann) [1721695]
- [netdrv] i40e: add check on i40e_configure_tx_ring() return value (Stefan Assmann) [1721695]
- [netdrv] i40e: Check if transceiver implements DDM before access (Stefan Assmann) [1721695]
- [netdrv] i40e: reduce stack usage in i40e_set_fc (Stefan Assmann) [1721695]
- [netdrv] i40e: no need to check return value of debugfs_create functions (Stefan Assmann) [1721695]
- [netdrv] i40e: Remove unicast log when VF is leaving multicast mode (Stefan Assmann) [1721695]
- [netdrv] i40e: verify string count matches even on early return (Stefan Assmann) [1721695]
- [netdrv] i40e: Log info when PF is entering and leaving Allmulti mode (Stefan Assmann) [1721695]
- [netdrv] i40e: Update visual effect for advertised FEC mode (Stefan Assmann) [1721695]
- [netdrv] i40e: fix code comments (Stefan Assmann) [1721695]
- [netdrv] i40e: don't report link up for a VF who hasn't enabled queues (Stefan Assmann) [1721695]
- [netdrv] i40e: Log disable-fw-lldp flag change by ethtool (Stefan Assmann) [1721695]
- [netdrv] i40e: fix incorrect ethtool statistics veb and veb.tc_ (Stefan Assmann) [1721695]
- [netdrv] Use skb_frag_off accessors (Stefan Assmann) [1721695]
- [netdrv] i40e: Use dev_get_drvdata (Stefan Assmann) [1721695]
- [netdrv] Use skb accessors in network drivers (Stefan Assmann) [1721695]
- [netdrv] i40e: Add macvlan support on i40e (Stefan Assmann) [1721695]
- [netdrv] i40e/i40e_virtchnl_pf: Use struct_size() in kzalloc() (Stefan Assmann) [1721695]
- [netdrv] i40e: update copyright string (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix descriptor count manipulation (Stefan Assmann) [1721695]
- [netdrv] i40e: missing priorities for any QoS traffic (Stefan Assmann) [1721695]
- [netdrv] i40e: Add log entry while creating or deleting TC0 (Stefan Assmann) [1721695]
- [netdrv] i40e: fix incorrect function documentation comment (Stefan Assmann) [1721695]
- [netdrv] i40e: Fix for missing "link modes" info in ethtool (Stefan Assmann) [1721695]
- [netdrv] i40e: fix 'Unknown bps' in dmesg for 2.5Gb/5Gb speeds (Stefan Assmann) [1721695]
- [netdrv] i40e: mark expected switch fall-through (Stefan Assmann) [1721695]
- [netdrv] i40e: Missing response checks in driver when starting/stopping FW LLDP (Stefan Assmann) [1721695]
- [netdrv] i40e: remove duplicate stat calculation for tx_errors (Stefan Assmann) [1721695]
- [netdrv] i40e: Check if the BAR size is large enough before writing to registers (Stefan Assmann) [1721695]
- [netdrv] i40e: Missing response checks in driver when starting/stopping FW LLDP (Stefan Assmann) [1721695]
- [netdrv] i40e: add input validation for virtchnl handlers (Stefan Assmann) [1721695]
- [netdrv] i40e: Improve AQ log granularity (Stefan Assmann) [1721695]
- [netdrv] i40e: Add bounds check for ch[] array (Stefan Assmann) [1721695]
- [netdrv] i40e: Use signed variable (Stefan Assmann) [1721695]
- [netdrv] i40e: add constraints for accessing veb array (Stefan Assmann) [1721695]
- [netdrv] i40e: let untrusted VF to create up to 16 VLANs (Stefan Assmann) [1721695]
- [netdrv] i40e: add functions stubs to support EEE (Stefan Assmann) [1721695]
- [netdrv] i40e: Use LLDP ethertype define ETH_P_LLDP (Stefan Assmann) [1721695]
- [netdrv] r8169: disable TSO on a single version of RTL8168c to fix performance (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix sporadic transmit timeout issue (Corinna Vinschen) [1730024]
- [netdrv] r8169: inline rtl8169_free_rx_databuff (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix performance issue on RTL8168evl (Corinna Vinschen) [1730024]
- [netdrv] r8169: allocate rx buffers using alloc_pages_node (Corinna Vinschen) [1730024]
- [netdrv] r8169: sync PCIe PHY init with vendor driver 8.047.01 (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helper r8168_mac_ocp_modify (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove access to legacy register MultiIntr (Corinna Vinschen) [1730024]
- [netdrv] r8169: make use of xmit_more (Corinna Vinschen) [1730024]
- [netdrv] r8169: don't use MSI before RTL8168d (Corinna Vinschen) [1730024]
- [netdrv] revert ("r8169: remove 1000/Half from supported modes") (Corinna Vinschen) [1730024]
- [netdrv] r8169: enable HW csum and TSO (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove r8169_csum_workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: implement callback ndo_features_check (Corinna Vinschen) [1730024]
- [netdrv] r8169: set GSO size and segment limits (Corinna Vinschen) [1730024]
- [netdrv] r8169: align setting PME with vendor driver (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_set_rx_mode (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix a typo in a comment (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_rx (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix RTL8168g PHY init (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix issue with confused RX unit after PHY power-down on RTL8411b (Corinna Vinschen) [1730024]
- [netdrv] r8169: sync few chip names with vendor driver (Corinna Vinschen) [1730024]
- [netdrv] r8169: add random MAC address fallback (Corinna Vinschen) [1730024]
- [netdrv] revert "r8169: improve handling VLAN tag" (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove not needed call to dma_sync_single_for_device (Corinna Vinschen) [1730024]
- [netdrv] r8169: consider that 32 Bit DMA is the default (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve handling VLAN tag (Corinna Vinschen) [1730024]
- [netdrv] r8169: don't activate ASPM in chip if OS can't control ASPM (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve handling of Abit Fatal1ty F-190HD (Corinna Vinschen) [1730024]
- [netdrv] r8169: use helper rtl_is_8168evl_up for setting register MaxTxPacketSize (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helper rtl_is_8168evl_up (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_coalesce_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: let mdio read functions return -ETIMEDOUT (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove member coalesce_info from struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove callback hw_start from struct rtl_cfg_info (Corinna Vinschen) [1730024]
- [netdrv] r8169: rename CPCMD_QUIRK_MASK and apply it on all chip versions (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve setting interrupt mask (Corinna Vinschen) [1730024]
- [netdrv] r8169: silence sparse warning in rtl8169_start_xmit (Corinna Vinschen) [1730024]
- [netdrv] r8169: factor out firmware handling (Corinna Vinschen) [1730024]
- [netdrv] r8169: rename r8169.c to r8169_main.c (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_fw_request_firmware and rtl_fw_release_firmware (Corinna Vinschen) [1730024]
- [netdrv] r8169: make rtl_fw_format_ok and rtl_fw_data_ok more independent (Corinna Vinschen) [1730024]
- [netdrv] r8169: simplify rtl_fw_write_firmware (Corinna Vinschen) [1730024]
- [netdrv] r8169: add enum rtl_fw_opcode (Corinna Vinschen) [1730024]
- [netdrv] r8169: use paged versions of phylib MDIO access functions (Corinna Vinschen) [1730024]
- [netdrv] r8169: avoid tso csum function indirection (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct jumbo_ops (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove struct mdio_ops (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve r8169_csum_workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: decouple rtl_phy_write_fw from actual driver code (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve rtl_fw_format_ok (Corinna Vinschen) [1730024]
- [netdrv] r8169: enable WoL speed down on more chip versions (Corinna Vinschen) [1730024]
- [netdrv] r8169: fix MAC address being lost in PCI D3 (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove 1000/Half from supported modes (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove support for RTL_GIGA_MAC_VER_01 (Corinna Vinschen) [1730024]
- [netdrv] r8169: improve RTL8168d PHY initialization (Corinna Vinschen) [1730024]
- [netdrv] r8169: change type of member mac_version in rtl8169_private (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove unneeded return statement in rtl_hw_init_8168g (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove rtl_hw_init_8168ep (Corinna Vinschen) [1730024]
- [netdrv] treewide: Add SPDX license identifier - Makefile/Kconfig (Corinna Vinschen) [1730024]
- [netdrv] treewide: Add SPDX license identifier for more missed files (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl8168g_set_pause_thresholds (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_set_fifo_size (Corinna Vinschen) [1730024]
- [netdrv] r8169: move EEE LED config to rtl8168_config_eee_mac (Corinna Vinschen) [1730024]
- [netdrv] r8169: simplify rtl_writephy_batch and rtl_ephy_init (Corinna Vinschen) [1730024]
- [netdrv] r8169: speed up rtl_loop_wait (Corinna Vinschen) [1730024]
- [netdrv] r8169: make use of phy_set_asym_pause (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove rtl_write_exgmac_batch (Corinna Vinschen) [1730024]
- [netdrv] r8169: remove manual autoneg restart workaround (Corinna Vinschen) [1730024]
- [netdrv] r8169: add rtl_reset_packet_filter (Corinna Vinschen) [1730024]
- [netdrv] r8169: add helpers rtl_eri_set/clear_bits (Corinna Vinschen) [1730024]
- [netdrv] r8169: make ERIAR_EXGMAC the default in eri functions (Corinna Vinschen) [1730024]
- [netdrv] r8169: use pci_dev_id() helper (Corinna Vinschen) [1730024]
- [kernel] phy: fix write to mii-ctrl1000 register (Petr Oros) [1772010]
- [netdrv] bcmgenet: don't set phydev->link from MAC (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix PTR_ERR applied after initialization to constant (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Asym Pause workaround for KSZ9021 (Petr Oros) [1772010]
- [netdrv] phy: fix race in genphy_update_link (Petr Oros) [1772010]
- [netdrv] phy: consider AN_RESTART status when reading link status (Petr Oros) [1772010]
- [kernel] fixed_phy: Add forward declaration for struct gpio_desc; (Petr Oros) [1772010]
- [netdrv] phy: fixed_phy: print gpio error only if gpio node is present (Petr Oros) [1772010]
- [netdrv] phy: mscc: initialize stats array (Petr Oros) [1772010]
- [netdrv] phy: bcm7xxx: define soft_reset for 40nm EPHY (Petr Oros) [1772010]
- [netdrv] Add genphy_c45_config_aneg() function to phy-c45.c (Petr Oros) [1772010]
- [netdrv] phy: sfp: hwmon: Fix scaling of RX power (Petr Oros) [1772010]
- [kernel] hwmon: Fix HWMON_P_MIN_ALARM mask (Petr Oros) [1772010]
- [netdrv] phy: rename Asix Electronics PHY driver (Petr Oros) [1772010]
- [netdrv] sfp: read eeprom in maximum 16 byte increments (Petr Oros) [1772010]
- [netdrv] phylink: avoid reducing support mask (Petr Oros) [1772010]
- [netdrv] phy: dp83867: Set up RGMII TX delay (Petr Oros) [1772010]
- [netdrv] phy: dp83867: do not call config_init twice (Petr Oros) [1772010]
- [netdrv] phy: dp83867: increase SGMII autoneg timer duration (Petr Oros) [1772010]
- [netdrv] phy: dp83867: fix speed 10 in sgmii mode (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: report if the PHY fails to boot firmware (Petr Oros) [1772010]
- [netdrv] phylink: ensure consistent phy interface mode (Petr Oros) [1772010]
- [netdrv] phylink: ensure inband AN works correctly (Petr Oros) [1772010]
- [netdrv] phy: aquantia: readd XGMII support for AQR107 (Petr Oros) [1772010]
- [netdrv] phy: realtek: Replace phy functions with non-locked version in rtl8211e_config_init() (Petr Oros) [1772010]
- [netdrv] meson: fixup g12a glue ephy id (Petr Oros) [1772010]
- [netdrv] phy: realtek: fix double page ops in generic Realtek driver (Petr Oros) [1772010]
- [netdrv] phy: realtek: add missing page operations (Petr Oros) [1772010]
- [netdrv] phy: realtek: Change TX-delay setting for RGMII modes only (Petr Oros) [1772010]
- [netdrv] phy: realtek: Add rtl8211e rx/tx delays config (Petr Oros) [1772010]
- [netdrv] phy: improve pause mode reporting in phy_print_status (Petr Oros) [1772010]
- [kernel] phy: improve resuming from hibernation (Petr Oros) [1772010]
- [netdrv] phy: fix phy_validate_pause (Petr Oros) [1772010]
- [netdrv] phy: micrel: make sure the factory test bit is cleared (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix buffer overrun with stats counters (Petr Oros) [1772010]
- [netdrv] phy: avoid unneeded MDIO reads in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_soft_reset (Petr Oros) [1772010]
- [netdrv] spi: micrel eth switch: declare missing of table (Petr Oros) [1772010]
- [netdrv] phy: marvell: add new default led configure for m88e151x (Petr Oros) [1772010]
- [netdrv] phy: vitesse: Remove support for VSC8514 (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8514 PHY (Petr Oros) [1772010]
- [netdrv] mdio: rename mdio_device reset to reset_gpio (Petr Oros) [1772010]
- [netdrv] phy: add support for reset-controller (Petr Oros) [1772010]
- [documentation] dt-bindings: add PHY reset controller binding (Petr Oros) [1772010]
- [netdrv] phy: remove dead code from phy_sanitize_settings (Petr Oros) [1772010]
- [netdrv] phy: don't set autoneg if it's not supported (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Asym Pause workaround (Petr Oros) [1772010]
- [netdrv] phy: warn if phylib and ethtool PHY mode definitions are out of sync (Petr Oros) [1772010]
- [netdrv] phy: add support for new modes in phylib (Petr Oros) [1772010]
- [netdrv] phy: shrink PHY settings array (Petr Oros) [1772010]
- [netdrv] phy: switch drivers to use dynamic feature detection (Petr Oros) [1772010]
- [netdrv] phy: fix setting autoneg_complete in genphy_update_link (Petr Oros) [1772010]
- [netdrv] phy: replace genphy_10g_driver with genphy_c45_driver (Petr Oros) [1772010]
- [netdrv] phy: remove unnecessary callback settings in C45 drivers (Petr Oros) [1772010]
- [netdrv] phy: improve link partner capability detection (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: clean-up gxl variant driver (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: add g12a support (Petr Oros) [1772010]
- [netdrv] phy: add amlogic g12a mdio mux support (Petr Oros) [1772010]
- [documentation] dt-bindings: phy: add g12a mdio mux documentation (Petr Oros) [1772010]
- [netdrv] phy: realtek: remove setting callback get_features and use phylib fallback (Petr Oros) [1772010]
- [netdrv] phy: fix autoneg mismatch case in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: add the suspend/resume callbacks for the 88x2210 (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: implement suspend/resume callbacks (Petr Oros) [1772010]
- [netdrv] phy: deal properly with autoneg incomplete in genphy_c45_read_lpa (Petr Oros) [1772010]
- [netdrv] phy: use c45 standard to detect link partner autoneg capability (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add SGMII statistics (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add suspend / resume callbacks for AQR107 family (Petr Oros) [1772010]
- [netdrv] phy: realtek: use genphy_read_abilities (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: remove redundant !timeout check (Petr Oros) [1772010]
- [netdrv] phy: marvell: add PHY tunable fast link down support for 88E1540 (Petr Oros) [1772010]
- [uapi] ethtool: add PHY Fast Link Down support (Petr Oros) [1772010]
- [netdrv] phy: aquantia: inform about proprietary 1000Base-T2 mode being in use (Petr Oros) [1772010]
- [netdrv] phy: aquantia: report PHY details like firmware version (Petr Oros) [1772010]
- [netdrv] phy: aquantia: print remote capabilities if link partner is Aquantia PHY (Petr Oros) [1772010]
- [kernel] phy: bcm54xx: Encode link speed and activity into LEDs (Petr Oros) [1772010]
- [netdrv] phy: aquantia: simplify aqr_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: don't clear BMCR in genphy_soft_reset (Petr Oros) [1772010]
- [netdrv] phy: Re-parent menus for MDIO bus drivers correctly (Petr Oros) [1772010]
- [netdrv] phy: Correct Cygnus/Omega PHY driver prompt (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add downshift support (Petr Oros) [1772010]
- [netdrv] phy: Move Omega PHY entry to Cygnus PHY driver (Petr Oros) [1772010]
- [netdrv] phy: Prepare for moving Omega out of bcm7xxx (Petr Oros) [1772010]
- [netdrv] phy: Add DP83825I to the DP83822 driver (Petr Oros) [1772010]
- [netdrv] phy: aquantia: check for changed interface mode in read_status (Petr Oros) [1772010]
- [netdrv] phy: aquantia: check for supported interface modes in config_init (Petr Oros) [1772010]
- [netdrv] phy: improve handling link_change_notify callback (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: fix interrupt support (Petr Oros) [1772010]
- [gpio] gpiolib: devprop: Fix syntax error (Petr Oros) [1772010]
- [kernel] gpiolib: export devprop_gpiochip_set_names() (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux: fix Kconfig dependencies (Petr Oros) [1772010]
- [netdrv] phy: use phy_modify_mmd_changed in genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_no_soft_reset (Petr Oros) [1772010]
- [netdrv] phy: don't export gen10g_read_status (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_config_init (Petr Oros) [1772010]
- [netdrv] phy: remove gen10g_suspend and gen10g_resume (Petr Oros) [1772010]
- [netdrv] phy: use genphy_c45_aneg_done in genphy_aneg_done (Petr Oros) [1772010]
- [netdrv] phy: micrel ksz8061: link failure after cable connect (Petr Oros) [1772010]
- [netdrv] phy: phylink: fix uninitialized variable in phylink_get_mac_state (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add hwmon support (Petr Oros) [1772010]
- [netdrv] phy: aquantia: rename aquantia.c to aquantia_main.c (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use the generic C45 helper to read the 2110 features (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Let genphy_c45_pma_read_abilities set Aneg bit (Petr Oros) [1772010]
- [netdrv] phy: dp83867: add soft reset delay (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux: Add support for Generic Mux controls (Petr Oros) [1772010]
- [netdrv] phy: improve auto-neg emulation in swphy (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: add support for the 88x2110 PHY (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Force reading of 2.5/5G (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use a #define for 88X3310 family id (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use 2500BASEX when using 2.5GBASET (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use linkmode_set_bit helper instead of __set_bit (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Use get_features to get the PHY abilities (Petr Oros) [1772010]
- [netdrv] phy: aquantia: use genphy_c45_read_status (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_read_status (Petr Oros) [1772010]
- [netdrv] phy: don't change modes we don't care about in genphy_c45_read_lpa (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add support for auto-negotiation configuration (Petr Oros) [1772010]
- [netdrv] phy: aquantia: remove false 5G and 10G speed ability for AQCS109 (Petr Oros) [1772010]
- [netdrv] phy: check PMAPMD link status only in genphy_c45_read_link (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix use-after-free on device_register fails (Petr Oros) [1772010]
- [netdrv] phy: at803x: disable delay only for RGMII mode (Petr Oros) [1772010]
- [netdrv] phy: at803x: don't inline helpers (Petr Oros) [1772010]
- [netdrv] phy: aquantia: Use get_features for the PHYs abilities (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: use genphy_c45_check_and_restart_aneg in mv3310_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_check_and_restart_aneg (Petr Oros) [1772010]
- [netdrv] phy: use genphy_config_eee_advert in genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: export genphy_config_eee_advert (Petr Oros) [1772010]
- [netdrv] phy: don't use 10BaseT/half as default in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: remove orphaned register read in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: improve mv3310_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: disable aneg in genphy_c45_pma_setup_forced (Petr Oros) [1772010]
- [netdrv] phy: use mii_10gbt_stat_mod_linkmode_lpa_t in genphy_c45_read_lpa (Petr Oros) [1772010]
- [kernel] phy: add helper mii_10gbt_stat_mod_linkmode_lpa_t (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: check for newly set aneg (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: use genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add genphy_c45_an_config_aneg (Petr Oros) [1772010]
- [kernel] phy: add helper linkmode_adv_to_mii_10gbt_adv_t (Petr Oros) [1772010]
- [netdrv] mdio_bus: Fix PTR_ERR() usage after initialization to constant (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Support generic PHY status read (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: Don't explicitly set Pause and Asym_Pause (Petr Oros) [1772010]
- [netdrv] phy: use phy_resolve_aneg_linkmode in genphy_read_status (Petr Oros) [1772010]
- [netdrv] phy: improve phy_resolve_aneg_linkmode (Petr Oros) [1772010]
- [netdrv] phy: fix potential race in the phylib state machine (Petr Oros) [1772010]
- [kernel] phy: don't use locking in phy_is_started (Petr Oros) [1772010]
- [netdrv] phy: fix interrupt handling in non-started states (Petr Oros) [1772010]
- [netdrv] phy: simplify genphy_config_eee_advert (Petr Oros) [1772010]
- [netdrv] phylink: avoid resolving link state too early (Petr Oros) [1772010]
- [netdrv] phylink: add phylink_init_eee() helper (Petr Oros) [1772010]
- [netdrv] phylink: only call mac_config() during resolve when link is up (Petr Oros) [1772010]
- [netdrv] phy: use phy_modify_changed in genphy_config_advert (Petr Oros) [1772010]
- [netdrv] phy: marvell10g: fix usage of new MMD modifying helpers (Petr Oros) [1772010]
- [netdrv] phy: add register modifying helpers returning 1 on change (Petr Oros) [1772010]
- [netdrv] phy: aquantia: add support for AQCS109 (Petr Oros) [1772010]
- [netdrv] phy: disregard "Clause 22 registers present" bit in get_phy_c45_devs_in_pkg (Petr Oros) [1772010]
- [netdrv] phy: let genphy_c45_read_link manage the devices to check (Petr Oros) [1772010]
- [netdrv] phy: don't double-read link status register if link is up (Petr Oros) [1772010]
- [netdrv] fixed-phy: Add fixed_phy_register_with_gpiod() API (Petr Oros) [1772010]
- [netdrv] phy: fixed_phy: Fix fixed_phy not checking GPIO (Petr Oros) [1772010]
- [netdrv] phy: consider latched link-down status in polling mode (Petr Oros) [1772010]
- [netdrv] sfp: do not probe SFP module before we're attached (Petr Oros) [1772010]
- [netdrv] phy: make use of new MMD accessors (Petr Oros) [1772010]
- [kernel] phy: provide full set of accessor functions to MMD registers (Petr Oros) [1772010]
- [netdrv] phy: improve genphy_c45_read_link (Petr Oros) [1772010]
- [netdrv] phy: fixed-phy: Drop GPIO from fixed_phy_add() (Petr Oros) [1772010]
- [netdrv] dp83640: expire old TX-skb (Petr Oros) [1772010]
- [netdrv] phy: aquantia: replace magic numbers with constants (Petr Oros) [1772010]
- [netdrv] phy: aquantia: use macro PHY_ID_MATCH_MODEL (Petr Oros) [1772010]
- [netdrv] phy: aquantia: remove unneeded includes (Petr Oros) [1772010]
- [netdrv] phy: aquantia: Shorten name space prefix to aqr_ (Petr Oros) [1772010]
- [netdrv] revert "net: phy: marvell: avoid pause mode on SGMII-to-Copper for 88e151x" (Petr Oros) [1772010]
- [netdrv] phy: at803x: Use helpers to access MMD PHY registers (Petr Oros) [1772010]
- [netdrv] phy: change phy_start_interrupts to phy_request_interrupt (Petr Oros) [1772010]
- [netdrv] phy: start interrupts in phy_start (Petr Oros) [1772010]
- [netdrv] phy: warn if phy_start is called from invalid state (Petr Oros) [1772010]
- [netdrv] phy: start state machine in phy_start only (Petr Oros) [1772010]
- [netdrv] phy: Add SDPX tag based on COPYING file (Petr Oros) [1772010]
- [netdrv] phy: Fixup GPLv2 SPDX tags based on license text (Petr Oros) [1772010]
- [netdrv] phy: Fixup GPLv2+ SPDX tags based on license text (Petr Oros) [1772010]
- [netdrv] phy: Remove redundent License text when SPDX header is present (Petr Oros) [1772010]
- [netdrv] phy: Convert some PHY and MDIO driver files to SPDX headers (Petr Oros) [1772010]
- [netdrv] phy: at803x: Disable phy delay for RGMII mode (Petr Oros) [1772010]
- [netdrv] phy: improve phy_init_hw (Petr Oros) [1772010]
- [netdrv] phy: fix issue with loading PHY driver w/o initramfs (Petr Oros) [1772010]
- [netdrv] phy: remove phy_stop_interrupts (Petr Oros) [1772010]
- [netdrv] phy: ensure phylib state machine is stopped after calling phy_stop (Petr Oros) [1772010]
- [netdrv] phy: stop PHY if needed when entering phy_disconnect (Petr Oros) [1772010]
- [netdrv] phy: micrel: use phy_read_mmd and phy_write_mmd (Petr Oros) [1772010]
- [netdrv] phy: improve get_phy_id (Petr Oros) [1772010]
- [kernel] phy: remove state PHY_CHANGELINK (Petr Oros) [1772010]
- [netdrv] phy: mdio_bus: add missing device_del() in mdiobus_register() error handling (Petr Oros) [1772010]
- [netdrv] phy: check return code when requesting PHY driver module (Petr Oros) [1772010]
- [netdrv] phy: Add helpers to determine if PHY driver is generic (Petr Oros) [1772010]
- [netdrv] phy: improve logging in phylib (Petr Oros) [1772010]
- [netdrv] phy: don't include asm/irq.h directly (Petr Oros) [1772010]
- [netdrv] phy: remove preliminary workaround for not loading PHY driver (Petr Oros) [1772010]
- [netdrv] phy: meson-gxl: Use the genphy_soft_reset callback (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix deadlock from wrong locking (Petr Oros) [1772010]
- [netdrv] phy: marvell: Errata for mv88e6390 internal PHYs (Petr Oros) [1772010]
- [netdrv] phy: micrel: set soft_reset callback to genphy_soft_reset for KSZ9031 (Petr Oros) [1772010]
- [netdrv] phy: fix too strict check in phy_start_aneg (Petr Oros) [1772010]
- [kernel] phy.h: fix obvious errors in doc and kerneldoc content (Petr Oros) [1772010]
- [netdrv] phy: mscc: Fix the VSC 8531/41 Chip Init sequence (Petr Oros) [1772010]
- [netdrv] phy: Fix the issue that netif always links up after resuming (Petr Oros) [1772010]
- [netdrv] phy: print stack trace in phy_error (Petr Oros) [1772010]
- [netdrv] phy: improve phy state checking (Petr Oros) [1772010]
- [netdrv] fixed phy: Add fixed_phy_change_carrier() (Petr Oros) [1772010]
- [netdrv] phy: mdio-gpio: Add phy_ignore_ta_mask to platform data (Petr Oros) [1772010]
- [kernel] phy: mdio-gpio: Add platform_data support for phy_mask (Petr Oros) [1772010]
- [kernel] gpio: Export gpiod_get_from_of_node() (Petr Oros) [1772010]
- [netdrv] phy: Revert toggling reset changes (Petr Oros) [1772010]
- [netdrv] phy: sfp: correct store of detected link modes (Petr Oros) [1772010]
- [netdrv] phy: micrel: add toggling phy reset if PHY is not attached (Petr Oros) [1772010]
- [netdrv] phy: Fix not to call phy_resume() if PHY is not attached (Petr Oros) [1772010]
- [netdrv] phy: improve generic EEE ethtool functions (Petr Oros) [1772010]
- [netdrv] phy: add workaround for issue where PHY driver doesn't bind to the device (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix deadlock in vsc85xx_default_config (Petr Oros) [1772010]
- [netdrv] phy: vitesse: remove duplicate support for VSC8574 (Petr Oros) [1772010]
- [netdrv] phy: icplus: allow configuring the interrupt function on IP101GR (Petr Oros) [1772010]
- [netdrv] phy: icplus: implement .did_interrupt for IP101A/G (Petr Oros) [1772010]
- [netdrv] phy: icplus: rename IP101A_G_NO_IRQ to IP101A_G_IRQ_ALL_MASK (Petr Oros) [1772010]
- [netdrv] phy: icplus: use the BIT macro where possible (Petr Oros) [1772010]
- [netdrv] phy: icplus: keep all ip101a_g functions together (Petr Oros) [1772010]
- [documentation] dt-bindings: phy: add bindings for the IC Plus Corp. IP101A/G PHYs (Petr Oros) [1772010]
- [documentation] dt-bindings: vendor-prefix: add prefix for IC Plus Corp (Petr Oros) [1772010]
- [netdrv] phy: mdio-gpio: Fix working over slow can_sleep GPIOs (Petr Oros) [1772010]
- [netdrv] phy: check for implementation of both callbacks in phy_drv_supports_irq (Petr Oros) [1772010]
- [netdrv] phy: icplus: add config_intr callback (Petr Oros) [1772010]
- [kernel] phy: remove states PHY_STARTING and PHY_PENDING (Petr Oros) [1772010]
- [netdrv] phy: leds: Don't make our own link speed names (Petr Oros) [1772010]
- [netdrv] phy: improve and inline phy_change (Petr Oros) [1772010]
- [netdrv] phy: simplify phy_mac_interrupt and related functions (Petr Oros) [1772010]
- [netdrv] phy: don't set state PHY_CHANGELINK in phy_change (Petr Oros) [1772010]
- [kernel] phy: improve struct phy_device member interrupts handling (Petr Oros) [1772010]
- [netdrv] phy: remove flag PHY_HAS_INTERRUPT from driver configs (Petr Oros) [1772010]
- [netdrv] phy: replace PHY_HAS_INTERRUPT with a check for config_intr and ack_interrupt (Petr Oros) [1772010]
- [netdrv] phy: use phy_check_link_status in more places in the state machine (Petr Oros) [1772010]
- [kernel] phy: remove state PHY_AN (Petr Oros) [1772010]
- [netdrv] phy: add phy_check_link_status (Petr Oros) [1772010]
- [netdrv] phy: remove useless check in state machine case PHY_RESUMING (Petr Oros) [1772010]
- [netdrv] phy: remove useless check in state machine case PHY_NOLINK (Petr Oros) [1772010]
- [netdrv] phy: make phy_trigger_machine static (Petr Oros) [1772010]
- [netdrv] phy: bcm7xxx: Add entry for BCM7255 (Petr Oros) [1772010]
- [netdrv] phy: Allow BCM54616S PHY to setup internal TX/RX clock delay (Petr Oros) [1772010]
- [netdrv] phy: mdio-mux-bcm-iproc: simplify getting .driver_data (Petr Oros) [1772010]
- [documentation] dt-bindings: add support for Microchip KSZ9131 (Petr Oros) [1772010]
- [netdrv] phy: micrel: add Microchip KSZ9131 initial driver (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix memory leak in vsc8574_config_pre_init (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix signedness bug in vsc85xx_downshift_get (Petr Oros) [1772010]
- [netdrv] phy: merge phy_start_aneg and phy_start_aneg_priv (Petr Oros) [1772010]
- [netdrv] phy: simplify handling of PHY_RESUMING in state machine (Petr Oros) [1772010]
- [netdrv] phy: improve handling of PHY_RUNNING in state machine (Petr Oros) [1772010]
- [netdrv] phy: trigger state machine immediately in phy_start_machine (Petr Oros) [1772010]
- [netdrv] phy: sfp: remove sfp_mutex's definition (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8574 PHY (Petr Oros) [1772010]
- [netdrv] phy: mscc: add support for VSC8584 PHY (Petr Oros) [1772010]
- [dt-bindings] vsc8531: add two additional LED modes for VSC8584 (Petr Oros) [1772010]
- [netdrv] phy: mscc: remove unneeded temporary variable (Petr Oros) [1772010]
- [netdrv] phy: mscc: shorten `x != 0` condition to `x` (Petr Oros) [1772010]
- [netdrv] phy: mscc: remove unneeded parenthesis (Petr Oros) [1772010]
- [netdrv] phy: mscc: Add EEE init sequence (Petr Oros) [1772010]
- [netdrv] phy: mscc: add ethtool statistics counters (Petr Oros) [1772010]
- [netdrv] phy: mscc: migrate to phy_select/restore_page functions (Petr Oros) [1772010]
- [netdrv] phy: phylink: fix SFP interface autodetection (Petr Oros) [1772010]
- [netdrv] phy: Convert to using pOFn instead of device_node.name (Petr Oros) [1772010]
- [netdrv] phy: improve handling delayed work (Petr Oros) [1772010]
- [netdrv] phy: mscc: fix printf format (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: mark PM functions as __maybe_unused (Petr Oros) [1772010]
- [netdrv] phy: marvell: Fix build (Petr Oros) [1772010]
- [netdrv] phy: marvell: Avoid unnecessary soft reset (Petr Oros) [1772010]
- [netdrv] phy: Stop with excessive soft reset (Petr Oros) [1772010]
- [netdrv] phy: sfp: Fix unregistering of HWMON SFP device (Petr Oros) [1772010]
- [netdrv] phy: fix WoL handling when suspending the PHY (Petr Oros) [1772010]
- [net] core: add member wol_enabled to struct net_device (Petr Oros) [1772010]
- [netdrv] phy: mdio-bcm-unimac: Allow configuring MDIO clock divider (Petr Oros) [1772010]
- [netdrv] phy: don't reschedule state machine when PHY is halted (Petr Oros) [1772010]
- [netdrv] phy: phylink: ensure the carrier is off when starting phylink (Petr Oros) [1772010]
- [netdrv] phy: call state machine synchronously in phy_stop (Petr Oros) [1772010]
- [net] linkwatch: add check for netdevice being present to linkwatch_do_dev (Petr Oros) [1772010]
- [netdrv] sfp: fix oops with ethtool -m (Petr Oros) [1772010]
- [netdrv] mdio: remove duplicated include from mdio_bus.c (Petr Oros) [1772010]
- [netdrv] phy: et011c: Remove incorrect PHY_POLL flags (Petr Oros) [1772010]
- [netdrv] phy: sfp: Handle unimplemented hwmon limits and alarms (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, led-d-mode' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, edge-slowdown' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: read 'vsc8531, vddmac' as an u32 (Petr Oros) [1772010]
- [netdrv] phy: mscc: factorize function for getting LED mode from DT (Petr Oros) [1772010]
- [netdrv] phy: mscc: factorize code for LEDs mode (Petr Oros) [1772010]
- [netdrv] dp83640: Mark expected switch fall-throughs (Petr Oros) [1772010]
- [netdrv] phylink: add helper for configuring 2500BaseX modes (Petr Oros) [1772010]
- [netdrv] phy: sftp: print debug message with text, not numbers (Petr Oros) [1772010]
- [netdrv] phy: Add support for Broadcom Omega internal Combo GPHY (Petr Oros) [1772010]
- [netdrv] phy: Add pm support to Broadcom iProc mdio mux driver (Petr Oros) [1772010]
- [netdrv] phy: Add support to configure clock in Broadcom iProc mdio mux (Petr Oros) [1772010]
- [documentation] dt-bindings: Add clock handle to Broadcom iProc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Use devm api for mdio bus allocation in bcm iproc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Disable external master access in bcm mdio mux driver (Petr Oros) [1772010]
- [arm64] dts: Fix the base address of the Broadcom iProc mdio mux (Petr Oros) [1772010]
- [netdrv] phy: Fix the register offsets in Broadcom iProc mdio mux driver (Petr Oros) [1772010]
- [documentation] dt-bindings: Fix Broadcom iProc mdio mux driver base address (Petr Oros) [1772010]
- [netdrv] phy: mscc: the extended page access register is 16 bits (Petr Oros) [1772010]
- [netdrv] phy: marvell: Replace mdelay() with msleep() in m88e1116r_config_init() (Petr Oros) [1772010]
- [kernel] phy: add helper phy_polling_mode (Petr Oros) [1772010]
- [netdrv] phy: prevent PHYs w/o Clause 22 regs from calling genphy_config_aneg (Petr Oros) [1772010]
- [netdrv] phy: add GBit master / slave error detection (Petr Oros) [1772010]
- [netdrv] phy: sfp: Do not use "imply HWMON" (Petr Oros) [1772010]
- [netdrv] phy: sfp: Add HWMON support for module sensors (Petr Oros) [1772010]
- [kernel] hwmon: Add helper to tell if a char is invalid in a name (Petr Oros) [1772010]
- [kernel] hwmon: Add support for power min, lcrit, min_alarm and lcrit_alarm (Petr Oros) [1772010]
- [kernel] hwmon: Add missing HWMON_T_LCRIT_ALARM define (Petr Oros) [1772010]
- [netdrv] phy: Drop OF dependency for MDIO_BCM_UNIMAC (Petr Oros) [1772010]
- [gpio] gpiolib: Mark gpio_suffixes array with __maybe_unused (Petr Oros) [1772010]
- [netdrv] phy: vitesse: Add support for VSC73xx (Petr Oros) [1772010]
- [netdrv] phy: dp83tc811: Fix SGMII enable/disable (Petr Oros) [1772010]
- [netdrv] phy: dp83tc811: Add INT_STAT3 (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Check read_status results (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Use correct mdio bus (Petr Oros) [1772010]
- [netdrv] phy: xgmiitorgmii: Check phy_driver ready before accessing (Petr Oros) [1772010]
- [netdrv] mdio-mux-gpio: Remove VLA usage (Petr Oros) [1772010]
- [netdrv] phy: fixed-phy: Make the error path simpler (Petr Oros) [1772010]
- [netdrv] phy: Allow compile test of GPIO consumers if !GPIOLIB (Petr Oros) [1772010]
- [watchdog] hpwdt: Reflect changes (Joseph Szczypek) [1769477]
- [documentation] watchdog/hpwdt: Update documentation (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Add module parameter kdumptimeout (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Have core ping watchdog (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Advertize max_hw_heartbeat_ms (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Stop hpwdt on unregister (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: drop warning after registering device (Joseph Szczypek) [1769477]
- [watchdog] hpwdt: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Joseph Szczypek) [1769477]
- [nvme] make fabrics command run on a separate request queue (David Milburn) [1766361]
- [nvme] Restart request timers in resetting state (David Milburn) [1766361]
- [nvme] nvme-rdma: fix possible use-after-free in connect timeout (David Milburn) [1766361]
- [block] blk-mq: remove blk_mq_complete_request_sync (David Milburn) [1766361]
- [nvme] wait until all completed request's complete fn is called (David Milburn) [1766361]
- [nvme] don't abort completed request in nvme_cancel_request (David Milburn) [1766361]
- [block] blk-mq: introduce blk_mq_tagset_wait_completed_request() (David Milburn) [1766361]
- [block] blk-mq: introduce blk_mq_request_completed() (David Milburn) [1766361]

* Wed Nov 27 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-155.rt13.12.el8]
- [hwtracing] intel_th: pci: Add Jasper Lake PCH support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Comet Lake PCH support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix possible memory leak in mode_store() (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix overflow in shift of an unsigned int (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix missing allocation failure check on a kstrndup (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix an uninitialized mutex (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Fix the window switching sequence (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Tiger Lake support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Preserve pre-existing buffer configuration (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Prevent freeing buffers while locked windows exist (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Get rid of the window size limit (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu-sink: An example msu buffer "sink" (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Introduce buffer interface (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Start read iterator from a non-empty window (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Split sgt array and pointer in multiwindow mode (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Support multipage blocks (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Ice Lake NNPI support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix single mode with disabled IOMMU (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Remove set but not used variable 'last' (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix unused variable warning on arm64 platform (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Add current window tracking (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Add a sysfs attribute to trigger window switch (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Correct the block wrap detection (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Add switch triggering support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Factor out trace start/stop (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Factor out pipeline draining (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Switch over to scatterlist (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Replace open-coded list_{first, last, next}_entry variants (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Only report useful IRQs to subdevices (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Start handling IRQs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Use MSI interrupt signalling (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Communicate IRQ via resource (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Add "rtit" source device (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Skip subdevices if their MMIO is missing (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Rework resource passing between glue layers and core (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix single mode with IOMMU (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pci: Add Comet Lake support (Jiri Olsa) [1771015]
- [hwtracing] intel_th: gth: Fix an off-by-one in output unassigning (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Don't reference unassigned outputs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: pti: Use sysfs_match_string() helper (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Only create useful device nodes (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Mark expected switch fall-throughs (Jiri Olsa) [1771015]
- [hwtracing] intel_th: msu: Fix an off-by-one in attribute store (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Fix resource handling for ACPI glue layer (Jiri Olsa) [1771015]
- [hwtracing] intel_th: Fix device removal logic (Jiri Olsa) [1771015]
- [hwtracing] hwtracing/intel_th/msu.c: change return type to vm_fault_t (Jiri Olsa) [1771015]
- [scripts] kbuild: modversions: Fix relative CRC byte order interpretation (Don Zickus) [1772940]
- [tools] tools x86 uapi asm: Sync the pt_regs.h copy with the kernel sources (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for trace sequences APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for APIs used to extract common fields from a record (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_parse_header_page() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for parse event APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event filter APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event fields APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_read_number_field() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for print field APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for get field value APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for find field APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for libtraceevent event get APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for list events APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event find APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_read_number() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for registering print function (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for function related libtraceevent APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for event handler APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for tep_strerror() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for page size APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for host endian APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for file endian APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for get/set cpus APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man page for header_page APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Man pages for tep_handler related APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add support for man pages with multiple names (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Introduce man pages (Michael Petlan) [1743208]
- [tools] perf/x86/regs: Use PERF_REG_EXTENDED_MASK (Michael Petlan) [1743208]
- [tools] perf record: Fix s390 missing module symbol and warning for non-root users (Michael Petlan) [1743208]
- [tools] perf machine: Read also the end of the kernel (Michael Petlan) [1743208]
- [tools] perf test vmlinux-kallsyms: Ignore aliases to _etext when searching on kallsyms (Michael Petlan) [1743208]
- [tools] perf session: Add missing swap ops for namespace events (Michael Petlan) [1743208]
- [tools] perf namespace: Protect reading thread's namespace (Michael Petlan) [1743208]
- [tools] perf data: Fix 'strncat may truncate' build failure with recent gcc (Michael Petlan) [1743208]
- [tools] perf stat: Support 'percore' event qualifier (Michael Petlan) [1743208]
- [tools] perf stat: Factor out aggregate counts printing (Michael Petlan) [1743208]
- [tools] perf tools: Add a 'percore' event qualifier (Michael Petlan) [1743208]
- [tools] perf docs: Add description for stderr (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix sample timestamp wrt non-taken branches (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix improved sample timestamp (Michael Petlan) [1743208]
- [tools] perf intel-pt: Fix instructions sampling rate (Michael Petlan) [1743208]
- [tools] perf regs x86: Add X86 specific arch__intr_reg_mask() (Michael Petlan) [1743208]
- [tools] perf parse-regs: Add generic support for arch__intr/user_reg_mask() (Michael Petlan) [1743208]
- [tools] perf parse-regs: Split parse_regs (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Add Cortex-A57 and Cortex-A72 events (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Map Brahma-B53 CPUID to cortex-a53 events (Michael Petlan) [1743208]
- [tools] perf vendor events arm64: Remove [[:xdigit:]] wildcard (Michael Petlan) [1743208]
- [tools] perf jevents: Remove unused variable (Michael Petlan) [1743208]
- [tools] perf test zstd: Fixup verbose mode output (Michael Petlan) [1743208]
- [tools] perf tests: Implement Zstd comp/decomp integration test (Michael Petlan) [1743208]
- [tools] perf inject: Enable COMPRESSED record decompression (Michael Petlan) [1743208]
- [tools] perf report: Implement perf.data record decompression (Michael Petlan) [1743208]
- [tools] perf record: Implement -z, --compression_level[=<n>] option (Michael Petlan) [1743208]
- [tools] perf report: Add stub processing of compressed events for -D (Michael Petlan) [1743208]
- [tools] perf record: Implement compression for AIO trace streaming (Michael Petlan) [1743208]
- [tools] perf record: Implement compression for serial trace streaming (Michael Petlan) [1743208]
- [tools] perf tools: Introduce Zstd streaming based compression API (Michael Petlan) [1743208]
- [tools] perf mmap: Implement dedicated memory buffer for data compression (Michael Petlan) [1743208]
- [tools] perf record: Implement COMPRESSED event record and its attributes (Michael Petlan) [1743208]
- [tools] perf session: Define 'bytes_transferred' and 'bytes_compressed' metrics (Michael Petlan) [1743208]
- [tools] perf build tests: Add NO_LIBZSTD=1 to make_minimal (Michael Petlan) [1743208]
- [tools] perf machine: Null-terminate version char array upon fgets(/proc/version) error (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Add uncore_upi JSON support (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add 'About' dialog box (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add context menu (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add copy to clipboard (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Add tree level (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Fix error when shrinking / enlarging font (Michael Petlan) [1743208]
- [tools] perf scripts python: exported-sql-viewer.py: Move view creation (Michael Petlan) [1743208]
- [tools] perf tools x86: Add support for recording and printing XMM registers (Michael Petlan) [1743208]
- [tools] perf parse-regs: Improve error output when faced with unknown register name (Michael Petlan) [1743208]
- [tools] perf record: Fix suggestion to get list of registers usable with --user-regs and --intr-regs (Michael Petlan) [1743208]
- [tools] perf tools: Speed up report for perf compiled with linwunwind (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove hard coded install paths from pkg-config file (Michael Petlan) [1743208]
- [tools] csky: Add support for libdw (Michael Petlan) [1743208]
- [tools] perf test: Fix spelling mistake "leadking" -> "leaking" (Michael Petlan) [1743208]
- [tools] perf annotate: Remove hist__account_cycles() from callback (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Silvermont to v14 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update GoldmontPlus to v1.01 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Goldmont to v13 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Bonnell to V4 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update KnightsLanding events to v9 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Haswell events to v28 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update IvyBridge events to v21 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update SandyBridge events to v16 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update JakeTown events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update IvyTown events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update HaswellX events to v20 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update BroadwellX events to v14 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update SkylakeX events to v1.12 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Skylake events to v42 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Broadwell-DE events to v7 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update Broadwell events to v23 (Michael Petlan) [1743208]
- [tools] perf vendor events intel: Update metrics from TMAM 3.5 (Michael Petlan) [1743208]
- [tools] perf record: Implement --mmap-flush=<number> option (Michael Petlan) [1743208]
- [tools] tools build: Implement libzstd feature check, LIBZSTD_DIR and NO_LIBZSTD defines (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Rename input arguments and local variables of libtraceevent from pevent to tep (Michael Petlan) [1743208]
- [tools] perf tools, tools lib traceevent: Rename "pevent" member of struct tep_event_filter to "tep" (Michael Petlan) [1743208]
- [tools] perf tools, tools lib traceevent: Rename "pevent" member of struct tep_event to "tep" (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Rename input arguments of libtraceevent APIs from pevent to tep (Michael Petlan) [1743208]
- [tools] tools tools, tools lib traceevent: Make traceevent APIs more consistent (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove call to exit() from tep_filter_add_filter_str() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Remove tep filter trivial APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Removed unneeded !! and return parenthesis (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Implement new traceevent APIs for accessing struct tep_handler fields (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Coding style fixes (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Change description of few APIs (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add more debugging to see various internal ring buffer entries (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Implement a new API, tep_list_events_copy() (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Add mono clocks to be parsed in seconds (Michael Petlan) [1743208]
- [tools] tools lib traceevent: Handle trace_printk() "px" (Michael Petlan) [1743208]
- [tools] perf list: Output tool events (Michael Petlan) [1743208]
- [tools] perf evsel: Support printing evsel name for 'duration_time' (Michael Petlan) [1743208]
- [tools] perf stat: Implement duration_time as a proper event (Michael Petlan) [1743208]
- [tools] perf stat: Revert checks for duration_time (Michael Petlan) [1743208]
- [tools] perf list: Fix s390 counter long description for L1D_RO_EXCL_WRITES (Michael Petlan) [1743208]
- [tools] perf tools: Add header defining used namespace struct to event.h (Michael Petlan) [1743208]
- [tools] perf trace beauty renameat: No need to include linux/fs.h (Michael Petlan) [1743208]
- [tools] perf augmented_raw_syscalls: Use a PERCPU_ARRAY map to copy more string bytes (Michael Petlan) [1743208]
- [tools] perf augmented_raw_syscalls: Copy strings from all syscalls with 1st or 2nd string arg (Michael Petlan) [1743208]
- [tools] perf trace: Add 'string' event alias to select syscalls with string args (Michael Petlan) [1743208]
- [x86] perf/x86: Always store regs->ip in perf_callchain_kernel() (Michael Petlan) [1743208]
- [x86] perf/x86: Remove pmu->pebs_no_xmm_regs (Michael Petlan) [1743208]
- [x86] perf/x86: Clean up PEBS_XMM_REGS (Michael Petlan) [1743208]
- [kernel] perf/x86: Disable extended registers for non-supported PMUs (Michael Petlan) [1743208]
- [kernel] perf/ioctl: Add check for the sample_period value (Michael Petlan) [1743208]
- [kernel] perf/core: Fix perf_sample_regs_user() mm check (Michael Petlan) [1743208]
- [kernel] perf/ring-buffer: Use regular variables for nesting (Michael Petlan) [1743208]
- [kernel] perf/ring-buffer: Always use {READ, WRITE}_ONCE() for rb->user_page data (Michael Petlan) [1743208]
- [kernel] perf/ring_buffer: Add ordering to rb->nest increment (Michael Petlan) [1743208]
- [kernel] perf/ring_buffer: Fix exposing a temporarily decreased data_head (Michael Petlan) [1743208]
- [x86] perf/x86/intel/ds: Fix EVENT vs. UEVENT PEBS constraints (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Allow PEBS multi-entry in watermark mode (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Fix INTEL_FLAGS_EVENT_CONSTRAINT* masking (Michael Petlan) [1743208]
- [x86] perf/x86/amd/iommu: Make the 'amd_iommu_attr_groups' symbol static (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Add Tremont core PMU support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/uncore: Add Intel Icelake uncore support (Michael Petlan) [1743208]
- [x86] perf/x86/msr: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/rapl: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel/cstate: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Add Icelake support (Michael Petlan) [1743208]
- [x86] perf/x86: Support constraint ranges (Michael Petlan) [1743208]
- [x86] perf/x86/lbr: Avoid reading the LBRs when adaptive PEBS handles them (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Support adaptive PEBS v4 (Michael Petlan) [1743208]
- [x86] perf/x86/intel/ds: Extract code of event update in short period (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Extract memory code PEBS parser for reuse (Michael Petlan) [1743208]
- [x86] perf/x86: Support outputting XMM registers (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Force resched when TFA sysctl is modified (Michael Petlan) [1743208]
- [kernel] perf/core: Add perf_pmu_resched() as global function (Michael Petlan) [1743208]
- [kernel] perf/headers: Fix stale comment for struct perf_addr_filter (Michael Petlan) [1743208]
- [kernel] perf/core: Make perf_swevent_init_cpu() static (Michael Petlan) [1743208]
- [x86] perf/x86: Add sanity checks to x86_schedule_events() (Michael Petlan) [1743208]
- [x86] perf/x86: Optimize x86_schedule_events() (Michael Petlan) [1743208]
- [x86] perf/x86: Clear ->event_constraint[] on put (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Optimize intel_get_excl_constraints() (Michael Petlan) [1743208]
- [x86] perf/x86: Remove PERF_X86_EVENT_COMMITTED (Michael Petlan) [1743208]
- [x86] perf/x86: Simplify x86_pmu.get_constraints() interface (Michael Petlan) [1743208]
- [x86] perf/x86/intel: Simplify intel_tfa_commit_scheduling() (Michael Petlan) [1743208]
- [tools] perf evsel: Do not rely on errno values for precise_ip fallback (Michael Petlan) [1715508]
- [kernel] redhat: perf kABI-check failure fix (Michael Petlan) [1715508]
- [tools] perf vendor events: Remove P8 HW events which are not supported (Michael Petlan) [1715508]
- [x86] cpufeature: Fix various quality problems in the <asm/cpu_device_hd.h> header (Michael Petlan) [1715508]
- [x86] cpufeature: Add facility to check for min microcode revisions (Michael Petlan) [1715508]
- [tools] perf tools: Remove needless asm/unistd.h include fixing build in some places (Michael Petlan) [1715508]
- [tools] tools build: Add -ldl to the disassembler-four-args feature test (Michael Petlan) [1715508]
- [tools] perf cs-etm: Always allocate memory for cs_etm_queue::prev_packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Don't check cs_etm_queue::prev_packet validity (Michael Petlan) [1715508]
- [tools] perf report: Report OOM in status line in the GTK UI (Michael Petlan) [1715508]
- [tools] perf bench numa: Add define for RUSAGE_THREAD if not present (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Change tag string for error (Michael Petlan) [1715508]
- [tools] perf annotate: Fix build on 32 bit for BPF annotation (Michael Petlan) [1715508]
- [tools] perf bpf: Return value with unlocking in perf_env__find_btf() (Michael Petlan) [1715508]
- [tools] perf bpf: Return NULL when RB tree lookup fails in perf_env__find_btf() (Michael Petlan) [1715508]
- [tools] perf tools: Fix map reference counting (Michael Petlan) [1715508]
- [tools] perf evlist: Fix side band thread draining (Michael Petlan) [1715508]
- [tools] perf tools: Check maps for bpf programs (Michael Petlan) [1715508]
- [tools] perf bpf: Return NULL when RB tree lookup fails in perf_env__find_bpf_prog_info() (Michael Petlan) [1715508]
- [tools] tools include uapi: Sync sound/asound.h copy (Michael Petlan) [1715508]
- [tools] perf top: Always sample time to satisfy needs of use of ordered queuing (Michael Petlan) [1715508]
- [tools] perf evsel: Use hweight64() instead of hweight_long(attr.sample_regs_user) (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Fix missing equality check for strcmp (Michael Petlan) [1715508]
- [tools] perf stat: Disable DIR_FORMAT feature for 'perf stat record' (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-sqlite.py: Fix use of parent_id in calls_view (Michael Petlan) [1715508]
- [tools] perf header: Fix lock/unlock imbalances when processing BPF/BTF info (Michael Petlan) [1715508]
- [tools] perf pmu: Fix parser error for uncore event alias (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Fix never-ending loop (Michael Petlan) [1715508]
- [tools] perf machine: Update kernel map address and re-order properly (Michael Petlan) [1715508]
- [tools] tools headers uapi: Synchronize i915_drm.h (Michael Petlan) [1715508]
- [tools] tools headers uapi: Update drm/i915_drm.h (Michael Petlan) [1715508]
- [tools] perf evsel: Fix max perf_event_attr.precise_ip detection (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix TSC slip (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add missing case value (Michael Petlan) [1715508]
- [tools] perf bpf: Show more BPF program info in print_bpf_prog_info() (Michael Petlan) [1715508]
- [tools] perf bpf: Extract logic to create program names from perf_event__synthesize_one_bpf_prog() (Michael Petlan) [1715508]
- [tools] perf tools: Save bpf_prog_info and BTF of new BPF programs (Michael Petlan) [1715508]
- [tools] perf evlist: Introduce side band thread (Michael Petlan) [1715508]
- [tools] perf annotate: Enable annotation of BPF programs (Michael Petlan) [1715508]
- [tools] perf build: Check what binutils's 'disassembler()' signature to use (Michael Petlan) [1715508]
- [tools] tools build: Add -lrt to FEATURE_CHECK_LDFLAGS-libaio (Michael Petlan) [1715508]
- [tools] tools build: Add test-reallocarray.c to test-all.c to fix the build (Michael Petlan) [1715508]
- [tools] perf bpf: Process PERF_BPF_EVENT_PROG_LOAD for annotation (Michael Petlan) [1715508]
- [tools] perf symbols: Introduce DSO_BINARY_TYPE__BPF_PROG_INFO (Michael Petlan) [1715508]
- [tools] perf feature detection: Add -lopcodes to feature-libbfd (Michael Petlan) [1715508]
- [tools] perf top: Add option --no-bpf-event (Michael Petlan) [1715508]
- [tools] perf bpf: Save BTF information as headers to perf.data (Michael Petlan) [1715508]
- [tools] perf bpf: Save BTF in a rbtree in perf_env (Michael Petlan) [1715508]
- [tools] perf bpf: Save bpf_prog_info information as headers to perf.data (Michael Petlan) [1715508]
- [tools] perf bpf: Save bpf_prog_info in a rbtree in perf_env (Michael Petlan) [1715508]
- [tools] perf bpf: Make synthesize_bpf_events() receive perf_session pointer instead of perf_tool (Michael Petlan) [1715508]
- [tools] perf bpf: Synthesize bpf events with bpf_program__get_prog_info_linear() (Michael Petlan) [1715508]
- [tools] perf record: Replace option --bpf-event with --no-bpf-event (Michael Petlan) [1715508]
- [tools] perf tests: Fix a memory leak in test__perf_evsel__tp_sched_test() (Michael Petlan) [1715508]
- [tools] perf tests: Fix memory leak by expr__find_other() in test__expr() (Michael Petlan) [1715508]
- [tools] perf tests: Fix a memory leak of cpu_map object in the openat_syscall_event_on_all_cpus test (Michael Petlan) [1715508]
- [tools] perf evsel: Free evsel->counts in perf_evsel__exit() (Michael Petlan) [1715508]
- [tools] perf top: Fix global-buffer-overflow issue (Michael Petlan) [1715508]
- [tools] perf maps: Purge all maps from the 'names' tree (Michael Petlan) [1715508]
- [tools] perf map: Remove map from 'names' tree in __maps__remove() (Michael Petlan) [1715508]
- [tools] perf hist: Add missing map__put() in error case (Michael Petlan) [1715508]
- [tools] perf top: Fix error handling in cmd_top() (Michael Petlan) [1715508]
- [tools] perf top: Delete the evlist before perf_session, fixing heap-use-after-free issue (Michael Petlan) [1715508]
- [tools] perf build-id: Fix memory leak in print_sdt_events() (Michael Petlan) [1715508]
- [tools] perf config: Fix a memory leak in collect_config() (Michael Petlan) [1715508]
- [tools] perf config: Fix an error in the config template documentation (Michael Petlan) [1715508]
- [tools] perf list: Don't forget to drop the reference to the allocated thread_map (Michael Petlan) [1715508]
- [tools] perf tools: Add doc about how to build perf with Asan and UBSan (Michael Petlan) [1715508]
- [tools] perf vendor events: Remove P8 HW events which are not supported (Michael Petlan) [1715508]
- [tools] perf stat: Improve scaling (Michael Petlan) [1715508]
- [tools] perf stat: Fix --no-scale (Michael Petlan) [1715508]
- [tools] perf script: Support relative time (Michael Petlan) [1715508]
- [tools] perf report: Indicate JITed code better in report (Michael Petlan) [1715508]
- [tools] perf report: Show all sort keys in help output (Michael Petlan) [1715508]
- [tools] perf record: Clarify help for --switch-output (Michael Petlan) [1715508]
- [tools] perf record: Allow to limit number of reported perf.data files (Michael Petlan) [1715508]
- [tools] perf list: Filter metrics too (Michael Petlan) [1715508]
- [tools] perf tools report: Add custom scripts to script menu (Michael Petlan) [1715508]
- [tools] perf ui browser: Fix ui popup argv browser for many entries (Michael Petlan) [1715508]
- [tools] perf script: Add array bound checking to list_scripts (Michael Petlan) [1715508]
- [tools] perf tools: Add some new tips describing the new options (Michael Petlan) [1715508]
- [tools] perf report: Implement browsing of individual samples (Michael Petlan) [1715508]
- [tools] perf report: Support builtin perf script in scripts menu (Michael Petlan) [1715508]
- [tools] perf report: Support running scripts for current time range (Michael Petlan) [1715508]
- [tools] perf report: Support time sort key (Michael Petlan) [1715508]
- [tools] perf script: Filter COMM/FORK/.. events by CPU (Michael Petlan) [1715508]
- [tools] perf tools: Update x86's syscall_64.tbl, no change in tools/perf behaviour (Michael Petlan) [1715508]
- [tools] perf script python: Add printdate function to SQL exporters (Michael Petlan) [1715508]
- [tools] perf report: Use less for scripts output (Michael Petlan) [1715508]
- [tools] perf session: Add process callback to reader object (Michael Petlan) [1715508]
- [tools] perf header: Add DIR_FORMAT feature to describe directory data (Michael Petlan) [1715508]
- [tools] perf data: Make perf_data__size() work over directory (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__update_dir() function (Michael Petlan) [1715508]
- [tools] perf data: Don't store auxtrace index for directory data file (Michael Petlan) [1715508]
- [tools] perf data: Support having perf.data stored as a directory (Michael Petlan) [1715508]
- [tools] perf vendor events amd: perf PMU events for AMD Family 17h (Michael Petlan) [1715508]
- [tools] perf probe: Fix getting the kernel map (Michael Petlan) [1715508]
- [tools] perf report: Parse time quantum (Michael Petlan) [1715508]
- [tools] perf time-utils: Add utility function to print time stamps in nanoseconds (Michael Petlan) [1715508]
- [tools] perf report: Support output in nanoseconds (Michael Petlan) [1715508]
- [tools] perf script: Support insn output for normal samples (Michael Petlan) [1715508]
- [tools] perf data: Force perf_data__open|close zero data->file.path (Michael Petlan) [1715508]
- [tools] perf session: Fix double free in perf_data__close (Michael Petlan) [1715508]
- [tools] perf evsel: Probe for precise_ip with simple attr (Michael Petlan) [1715508]
- [tools] perf tools: Read and store caps/max_precise in perf_pmu (Michael Petlan) [1715508]
- [tools] perf hist: Fix memory leak of srcline (Michael Petlan) [1715508]
- [tools] perf hist: Add error path into hist_entry__init (Michael Petlan) [1715508]
- [tools] perf diff: Support --pid/--tid filter options (Michael Petlan) [1715508]
- [tools] perf diff: Support --cpu filter option (Michael Petlan) [1715508]
- [tools] perf diff: Support --time filter option (Michael Petlan) [1715508]
- [tools] perf thread: Generalize function to copy from thread addr space from intel-bts code (Michael Petlan) [1715508]
- [tools] perf annotate: Calculate the max instruction name, align column to that (Michael Petlan) [1715508]
- [tools] perf clang: Remove needless extra semicolon (Michael Petlan) [1715508]
- [tools] perf bpf: Automatically add BTF ELF markers (Michael Petlan) [1715508]
- [tools] perf beauty msg_flags: Add missing s lost when adding prefix suppression logic (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Add call tree (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out CallGraphModelBase (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Improve TreeModel abstraction (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out TreeWindowBase (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-postgresql.py: Export calls parent_id (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-postgresql.py: Fix invalid input syntax for integer error (Michael Petlan) [1715508]
- [tools] perf scripts python: export-to-sqlite.py: Export calls parent_id (Michael Petlan) [1715508]
- [tools] perf db-export: Add calls parent_id to enable creation of call trees (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix divide by zero when TSC is not available (Michael Petlan) [1715508]
- [tools] perf auxtrace: Improve address filter error message when there is no DSO (Michael Petlan) [1715508]
- [tools] perf time-utils: Refactor time range parsing code (Michael Petlan) [1715508]
- [tools] tools lib traceevent: Fix buffer overflow in arg_eval (Michael Petlan) [1715508]
- [tools] perf probe: Clarify error message about not finding kernel modules debuginfo (Michael Petlan) [1715508]
- [tools] replace open encodings for NUMA_NO_NODE (Michael Petlan) [1715508]
- [tools] perf script python: Add Python3 support to stat-cpi.py (Michael Petlan) [1715508]
- [tools] perf tools: Add perf_exe() helper to find perf binary (Michael Petlan) [1715508]
- [tools] perf script: Handle missing fields with -F +. (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__open_dir_data function (Michael Petlan) [1715508]
- [tools] perf data: Add perf_data__(create_dir|close_dir) functions (Michael Petlan) [1715508]
- [tools] perf data: Fail check_backup in case of error (Michael Petlan) [1715508]
- [tools] perf data: Make check_backup work over directories (Michael Petlan) [1715508]
- [tools] perf tools: Add rm_rf_perf_data function (Michael Petlan) [1715508]
- [tools] perf tools: Add pattern name checking to rm_rf (Michael Petlan) [1715508]
- [tools] perf tools: Add depth checking to rm_rf (Michael Petlan) [1715508]
- [tools] perf data: Add global path holder (Michael Petlan) [1715508]
- [tools] perf data: Move size to struct perf_data_file (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Add top calls report (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove no selection error (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove SQLTableDialogDataItem (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Create new dialog data item classes (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Move report name into ReportVars (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out ReportVars (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Factor out ReportDialogBase (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Move column headers (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Hide Call Graph option if no calls table (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Remove leftover debugging prints (Michael Petlan) [1715508]
- [tools] perf scripts python: exported-sql-viewer.py: Fix missing shebang (Michael Petlan) [1715508]
- [tools] perf thread-stack: Hide x86 retpolines (Michael Petlan) [1715508]
- [tools] perf thread-stack: Improve thread_stack__no_call_return() (Michael Petlan) [1715508]
- [tools] perf tools: Make rm_rf() remove single file (Michael Petlan) [1715508]
- [tools] perf cpumap: Increase debug level for cpu_map__snprint verbose output (Michael Petlan) [1715508]
- [tools] perf bpf-event: Add missing new line into pr_debug call (Michael Petlan) [1715508]
- [tools] perf script: Allow +- operator for type specific fields option (Michael Petlan) [1715508]
- [tools] perf evsel: Force sample_type for slave events (Michael Petlan) [1715508]
- [tools] perf session: Don't report zero period samples for slave events (Michael Petlan) [1715508]
- [tools] perf trace: Allow dumping a BPF map after setting up BPF events (Michael Petlan) [1715508]
- [tools] perf bpf: Add bpf_map dumper (Michael Petlan) [1715508]
- [tools] perf doc: Fix documentation of the Flags section in perf.data (Michael Petlan) [1715508]
- [tools] perf doc: Fix HEADER_CMDLINE description in perf.data documentation (Michael Petlan) [1715508]
- [tools] perf report: Don't shadow inlined symbol with different addr range (Michael Petlan) [1715508]
- [tools] perf tools: Use sysfs__mountpoint() when reading cpu topology (Michael Petlan) [1715508]
- [tools] perf tools: Add numa_topology object (Michael Petlan) [1715508]
- [tools] perf tools: Add cpu_topology object (Michael Petlan) [1715508]
- [tools] perf tests shell: Skip trace+probe_vfs_getname.sh if built without trace support (Michael Petlan) [1715508]
- [tools] perf header: Remove unused 'cpu_nr' field from 'struct cpu_topo' (Michael Petlan) [1715508]
- [tools] perf header: Get rid of write_it label (Michael Petlan) [1715508]
- [tools] perf list: Display metric expressions for --details option (Michael Petlan) [1715508]
- [tools] perf tools: Fix legacy events symbol separator parsing (Michael Petlan) [1715508]
- [tools] perf tools: Rename build libperf to perf (Michael Petlan) [1715508]
- [tools] perf tools: Rename LIB_FILE to LIBPERF_A (Michael Petlan) [1715508]
- [tools] perf tools: Compile perf with libperf-in.o instead of libperf.a (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize auxtrace_buffer fetch function (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize main packet processing loop (Michael Petlan) [1715508]
- [tools] perf cs-etm: Modularize main decoder function (Michael Petlan) [1715508]
- [tools] perf cs-etm: Make cs_etm__run_decoder() queue independent (Michael Petlan) [1715508]
- [tools] perf cs-etm: Rethink kernel address initialisation (Michael Petlan) [1715508]
- [tools] perf cs-etm: Cleaning up function cs_etm__alloc_queue() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix erroneous comment (Michael Petlan) [1715508]
- [tools] perf cs-etm: Introducing function cs_etm__init_trace_params() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix memory leak in error path (Michael Petlan) [1715508]
- [tools] perf cs-etm: Introducing function cs_etm_decoder__init_dparams() (Michael Petlan) [1715508]
- [tools] perf cs-etm: Fix wrong return values in error path (Michael Petlan) [1715508]
- [tools] perf cs-etm: Remove unused structure field "time" and "timestamp" (Michael Petlan) [1715508]
- [tools] perf cs-etm: Remove unused structure field "state" (Michael Petlan) [1715508]
- [tools] perf build: Add missing FEATURE_CHECK_LDFLAGS-libcrypto (Michael Petlan) [1715508]
- [tools] perf unwind: Do not put libunwind-{x86, aarch64} in FEATURE_TESTS_BASIC (Michael Petlan) [1715508]
- [tools] perf coresight: Do not test for libopencsd by default (Michael Petlan) [1715508]
- [tools] perf trace: Filter out gnome-terminal* parent (Michael Petlan) [1715508]
- [tools] perf trace: Check if the 'fd' is negative when mapping it to pathname (Michael Petlan) [1715508]
- [tools] perf beauty ioctl cmd: The 'fd' arg is signed (Michael Petlan) [1715508]
- [tools] perf utils: Silence "Couldn't synthesize bpf events" warning for EPERM (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add proper header file for symbols (Michael Petlan) [1715508]
- [tools] perf record: Implement --affinity=node|cpu option (Michael Petlan) [1715508]
- [tools] perf auxtrace: Add timestamp to auxtrace errors (Michael Petlan) [1715508]
- [tools] perf intel-pt: Packet splitting can happen only on 32-bit (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix CYC timestamp calculation after OVF (Michael Petlan) [1715508]
- [tools] perf intel-pt: Fix overlap calculation for padding (Michael Petlan) [1715508]
- [tools] perf auxtrace: Define auxtrace record alignment (Michael Petlan) [1715508]
- [tools] perf thread-stack: Represent jmps to the start of a different symbol (Michael Petlan) [1715508]
- [tools] perf thread-stack: Tidy thread_stack__no_call_return() by adding more local variables (Michael Petlan) [1715508]
- [tools] perf thread-stack: Tidy thread_stack__push_cp() usage (Michael Petlan) [1715508]
- [tools] perf tools: Fix split_kallsyms_for_kcore() for trampoline symbols (Michael Petlan) [1715508]
- [tools] perf vendor events intel: Fix Load_Miss_Real_Latency on CLX (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for exception return packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for exception packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add traceID in packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Change tuple from traceID-CPU# to traceID-metadata (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add exception number in exception packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for trace discontinuity (Michael Petlan) [1715508]
- [tools] perf cs-etm: Set sample flags for instruction range packet (Michael Petlan) [1715508]
- [tools] perf cs-etm: Add last instruction information in packet (Michael Petlan) [1715508]
- [tools] perf tools: Add documentation for BPF event selection (Michael Petlan) [1715508]
- [tools] perf report: Move symbol annotation to the resort phase (Michael Petlan) [1715508]
- [tools] perf evsel: Add output_resort_cb method (Michael Petlan) [1715508]
- [tools] perf hists: Add argument to hists__resort_cb_t callback (Michael Petlan) [1715508]
- [tools] perf record: Apply affinity masks when reading mmap buffers (Michael Petlan) [1715508]
- [tools] perf tools: Add fallback versions for CPU_{OR, EQUAL}() (Michael Petlan) [1715508]
- [tools] perf record: Bind the AIO user space buffers to nodes (Michael Petlan) [1715508]
- [tools] perf record: Allocate affinity masks (Michael Petlan) [1715508]
- [tools] perf pmu: Remove set_drv_config API (Michael Petlan) [1715508]
- [tools] perf coresight: Remove set_drv_config() API (Michael Petlan) [1715508]
- [tools] perf arm cs-etm: Use event attributes to send sink information to kernel (Michael Petlan) [1715508]
- [tools] perf pmu: Move EVENT_SOURCE_DEVICE_PATH to PMU header file (Michael Petlan) [1715508]
- [tools] perf bpf-loader: Remove unecessary includes from bpf-loader.h (Michael Petlan) [1715508]
- [tools] perf powerpc kvm-stat: Add missing evlist.h header (Michael Petlan) [1715508]
- [tools] perf kvm stat: Replace kvm-stat.h includes with forward declarations (Michael Petlan) [1715508]
- [tools] perf pmu: Remove needless evsel.h only needs one fwd decl (Michael Petlan) [1715508]
- [tools] perf tests pmu: Add missing headers (Michael Petlan) [1715508]
- [tools] perf hist: Remove the needless callchain.h include from hist.h (Michael Petlan) [1715508]
- [tools] perf tools: Add missing include <callchain.h> in various places (Michael Petlan) [1715508]
- [tools] perf thread: Don't include symbol.h, symbol_conf.h is enough (Michael Petlan) [1715508]
- [tools] perf evsel: No need to include symbol.h in evsel.h, symbol_conf.h is enough (Michael Petlan) [1715508]
- [tools] perf tools: Add missing include for symbols.h (Michael Petlan) [1715508]
- [tools] perf hist: Remove symbol.h from hist.h, just fwd decls are needed (Michael Petlan) [1715508]
- [tools] perf tests: Add missing headers so far obtained indirectly (Michael Petlan) [1715508]
- [tools] perf map: Move structs and prototypes for map groups to a separate header (Michael Petlan) [1715508]
- [tools] pref tools: Add missing map.h includes (Michael Petlan) [1715508]
- [tools] perf symbols: Introduce map_symbol.h (Michael Petlan) [1715508]
- [tools] perf callchain: Uninline callchain_cursor_reset() to remove map.h dependency (Michael Petlan) [1715508]
- [tools] perf srccode: Move struct definition from map.h to srccode.h (Michael Petlan) [1715508]
- [tools] perf arm pmu: Add missing linux/string.h header (Michael Petlan) [1715508]
- [tools] perf powerpc: Add missing headers to skip-callchain-idx.c (Michael Petlan) [1715508]
- [tools] perf augmented_syscalls: Convert to bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf examples: Convert etcsnoop to use bpf_map() (Michael Petlan) [1715508]
- [tools] perf trace: Fixup etcsnoop example (Michael Petlan) [1715508]
- [tools] perf augmented_raw_syscalls: Use bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf: Convert pid_map() to bpf_map() (Michael Petlan) [1715508]
- [tools] perf bpf: Add bpf_map() helper (Michael Petlan) [1715508]
- [tools] perf bpf: Fix synthesized PERF_RECORD_KSYMBOL/BPF_EVENT (Michael Petlan) [1715508]
- [tools] perf sched: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf hist: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf symbols: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf util: Use cached rbtree for rblists (Michael Petlan) [1715508]
- [tools] perf callchain: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] perf machine: Use cached rbtrees (Michael Petlan) [1715508]
- [tools] Update rbtree implementation (Michael Petlan) [1715508]
- [tools] perf callchain: No need to include perf.h (Michael Petlan) [1715508]
- [tools] perf comm: Remove needless headers from comm.h (Michael Petlan) [1715508]
- [tools] perf namespaces: Remove namespaces.h from .h headers (Michael Petlan) [1715508]
- [tools] perf symbols: Remove some unnecessary includes from symbol.h (Michael Petlan) [1715508]
- [tools] perf symbols: Remove include map.h from dso.h (Michael Petlan) [1715508]
- [tools] perf block-range: Add missing headers (Michael Petlan) [1715508]
- [tools] perf tools: Move branch structs to branch.h (Michael Petlan) [1715508]
- [tools] perf annotate: Remove lots of headers from annotate.h (Michael Petlan) [1715508]
- [tools] perf symbols: Move symbol_conf to separate file (Michael Petlan) [1715508]
- [tools] perf color: Add missing stdarg.g to color.h (Michael Petlan) [1715508]
- [tools] perf utils: Move perf_config using routines from color.c to separate object (Michael Petlan) [1715508]
- [tools] perf top: Synthesize BPF events for pre-existing loaded BPF programs (Michael Petlan) [1715508]
- [tools] perf tools: Synthesize PERF_RECORD_* for loaded BPF programs (Michael Petlan) [1715508]
- [tools] perf tools: Handle PERF_RECORD_BPF_EVENT (Michael Petlan) [1715508]
- [tools] perf tools: Handle PERF_RECORD_KSYMBOL (Michael Petlan) [1715508]
- [tools] tools headers uapi: Sync tools/include/uapi/linux/perf_event.h (Michael Petlan) [1715508]
- [tools] tools headers uapi: Sync tools/include/uapi/linux/perf_event.h (Michael Petlan) [1715508]
- [tools] perf report: Display names in s390 diagnostic counter sets (Michael Petlan) [1715508]
- [tools] perf tools: Remove duplicate headers (Michael Petlan) [1715508]
- [tools] perf session: Add reader__process_events function (Michael Petlan) [1715508]
- [tools] perf session: Add 'data_offset' member to reader object (Michael Petlan) [1715508]
- [tools] perf session: Add 'data_size' member to reader object (Michael Petlan) [1715508]
- [tools] perf session: Add reader object (Michael Petlan) [1715508]
- [tools] perf session: Get rid of file_size variable (Michael Petlan) [1715508]
- [tools] perf session: Rearrange perf_session__process_events function (Michael Petlan) [1715508]
- [tools] perf tools: Replace automatic const char[] variables by statics (Michael Petlan) [1715508]
- [tools] perf/doc: Update design.txt for exclude_{host|guest} flags (Michael Petlan) [1715508]
- [x86] perf/x86/intel/pt: Remove software double buffering PMU capability (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Fix AUX software double buffering (Michael Petlan) [1715508]
- [x86] perf/x86/amd: Update generic hardware cache events for Family 17h (Michael Petlan) [1715508]
- [x86] perf/x86/amd: Add event map for AMD Family 17h (Michael Petlan) [1715508]
- [x86] perf/x86: Fix incorrect PEBS_REGS (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Fix AUX record suppression (Michael Petlan) [1715508]
- [kernel] perf/core: Fix the address filtering fix (Michael Petlan) [1715508]
- [kernel] perf/core: Fix perf_event_disable_inatomic() race (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Initialize TFA MSR (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Fix handling of wakeup_events for multi-entry PEBS (Michael Petlan) [1715508]
- [kernel] perf/core: Restore mmap record type correctly (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Make dev_attr_allow_tsx_force_abort static (Michael Petlan) [1715508]
- [kernel] uprobes: convert uprobe.ref to refcount_t (Michael Petlan) [1715508]
- [kernel] perf, bpf: Consider events with attr.bpf_event as side-band events (Michael Petlan) [1715508]
- [kernel] perf/core: Mark expected switch fall-through (Michael Petlan) [1715508]
- [x86] perf/x86/intel/uncore: Fix client IMC events return huge result (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Use high order allocations for AUX buffers optimistically (Michael Petlan) [1715508]
- [x86] events: Mark expected switch-case fall-throughs (Michael Petlan) [1715508]
- [kernel] perf, pt, coresight: Fix address filters for vmas with non-zero offset (Michael Petlan) [1715508]
- [kernel] perf: Copy parent's address filter offsets on clone (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Add counter freezing quirk for Goldmont (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Clean up counter freezing quirk (Michael Petlan) [1715508]
- [x86] perf/x86/intel: Clean up SNB PEBS quirk (Michael Petlan) [1715508]
- [x86] perf/x86/kvm: Avoid unnecessary work in guest filtering (Michael Petlan) [1715508]
- [perf] aux: Make perf_event accessible to setup_aux() (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Convert ring_buffer.aux_refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf/ring_buffer: Convert ring_buffer.refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf: Convert perf_event_context.refcount to refcount_t (Michael Petlan) [1715508]
- [kernel] perf/uprobes: Convert to SPDX license identifier (Michael Petlan) [1715508]
- [kernel] perf/hw_breakpoints: Convert to SPDX license identifier (Michael Petlan) [1715508]
- [kernel] perf/core: Convert to SPDX license identifiers (Michael Petlan) [1715508]
- [kernel] perf, bpf: Introduce PERF_RECORD_BPF_EVENT (Michael Petlan) [1715508]
- [kernel] perf, bpf: Introduce PERF_RECORD_KSYMBOL (Michael Petlan) [1715508]
- [kernel] perf: Remove duplicated workqueue.h include from perf_event.h (Michael Petlan) [1715508]
- [tools] perf/core: Remove unused perf_flags (Michael Petlan) [1715508]
- [x86] perf/core, arch/x86: Strengthen exclusion checks with PERF_PMU_CAP_NO_EXCLUDE (Michael Petlan) [1715508]
- [x86] perf/core, arch/x86: Use PERF_PMU_CAP_NO_EXCLUDE for exclusion incapable PMUs (Michael Petlan) [1715508]
- [kernel] perf/core: Add PERF_PMU_CAP_NO_EXCLUDE for exclusion incapable PMUs (Michael Petlan) [1715508]
- [kernel] perf/core: Add function to test for event exclusion flags (Michael Petlan) [1715508]

* Wed Nov 27 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-154.rt13.11.el8]
- [kernel] mm/hmm: fix ZONE_DEVICE anon page mapping reuse (Jerome Glisse) [1498655 1597758]
- [gpu] drm/nouveau/dmem: missing mutex_lock in error path (Jerome Glisse) [1498655 1597758]
- [mm] hmm: always return EBUSY for invalid ranges in hmm_range_{fault, snapshot} (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: move hmm_vma_range_done and hmm_vma_fault to nouveau (Jerome Glisse) [1498655 1597758]
- [kernel] mm: factor out a devm_request_free_mem_region helper (Jerome Glisse) [1498655 1597758]
- [mm] don't clear ->mapping in hmm_devmem_free (Jerome Glisse) [1498655 1597758]
- [mm] remove the struct hmm_device infrastructure (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Fix error flows in hmm_invalidate_range_start (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Remove confusing comment and logic from hmm_release (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Poison hmm_range during unregister (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Remove racy protection against double-unregistration (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Use lockdep instead of comments (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Hold on to the mmget for the lifetime of the range (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Do not use list*_rcu() for hmm->ranges (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Simplify hmm_get_or_create and make it reliable (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: Remove duplicate condition test before wait_event_timeout (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Hold a mmgrab from hmm to mm (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Use hmm_mirror not mm as an argument for hmm_range_register (Jerome Glisse) [1498655 1597758]
- [mm] hmm: fix use after free with struct hmm in the mmu notifiers (Jerome Glisse) [1498655 1597758]
- [mm] hmm: Only set FAULT_FLAG_ALLOW_RETRY for non-blocking (Jerome Glisse) [1498655 1597758]
- [mm] hmm: support automatic NUMA balancing (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: clean up some coding style and comments (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: suppress compilation warnings when CONFIG_HUGETLB_PAGE is not set (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: convert various hmm_pfn_* to device_entry which is a better name (Jerome Glisse) [1498655 1597758]
- [mm] hmm: add a helper function that fault pages and map them to a device (Jerome Glisse) [1498655 1597758]
- [mm] hmm: allow to mirror vma of a file on a DAX backed filesystem (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: add helpers to test if mm is still alive or not (Jerome Glisse) [1498655 1597758]
- [mm] hmm: mirror hugetlbfs (snapshoting, faulting and DMA mapping) (Jerome Glisse) [1498655 1597758]
- [documentation] [documentation] mm/hmm: add default fault flags to avoid the need to pre-fill pfns arrays (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve driver API to work and wait over a range (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve and rename hmm_vma_fault() to hmm_range_fault() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: improve and rename hmm_vma_get_pfns() to hmm_range_snapshot() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: do not erase snapshot when a range is invalidated (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use reference counting for HMM struct (Jerome Glisse) [1498655 1597758]
- [kernel] mm/hmm: convert to use vm_fault_t (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: remove set but not used variable 'devmem' (Jerome Glisse) [1498655 1597758]
- [mm] hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL (Jerome Glisse) [1498655 1597758]
- [mm] hmm: replace hmm_devmem_pages_create() with devm_memremap_pages() (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use devm semantics for hmm_devmem_{add, remove} (Jerome Glisse) [1498655 1597758]
- [mm] hmm: invalidate device page table at start of invalidation (Jerome Glisse) [1498655 1597758]
- [mm] hmm: use a structure for update callback parameters (Jerome Glisse) [1498655 1597758]
- [mm] hmm: properly handle migration pmd (Jerome Glisse) [1498655 1597758]
- [mm] hmm: fix utf8 . (Jerome Glisse) [1498655 1597758]
- [mm] hmm.c: remove unused variables align_start and align_end (Jerome Glisse) [1498655 1597758]
- [hid] hyperv: Use in-place iterator API in the channel callback (Benjamin Tissoires) [1740778 1772010]
- [hid] logitech-hidpp: do all FF cleanup in hidpp_ff_destroy() (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: rework device validation (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: split g920_get_config() (Benjamin Tissoires) [1740778]
- [hid] fix error message in hid_open_report() (Benjamin Tissoires) [1740778]
- [hid] Fix assumption that devices have inputs (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add Trekstor Primebook C11B to descriptor override (Benjamin Tissoires) [1740778]
- [hid] apple: Fix stuck function keys when using FN (Benjamin Tissoires) [1740778]
- [hid] wacom: Fix several minor compiler warnings (Benjamin Tissoires) [1740778]
- [hid] Add quirk for HP X500 PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [hid] hidraw: Fix invalid read in hidraw_ioctl (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix crash when initial logi_dj_recv_query_paired_devices fails (Benjamin Tissoires) [1740778]
- [hid] logitech: Fix general protection fault caused by Logitech driver (Benjamin Tissoires) [1740778]
- [hid] sony: Fix memory corruption issue on cleanup (Benjamin Tissoires) [1740778]
- [hid] prodikeys: Fix general protection fault during probe (Benjamin Tissoires) [1740778]
- [hid] wacom: correct misreported EKR ring values (Benjamin Tissoires) [1740778]
- [hid] cp2112: prevent sleeping function called from invalid context (Benjamin Tissoires) [1740778]
- [hid] wacom: Correct distance scale for 2nd-gen Intuos devices (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove support for the G700 over USB (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech-hidpp: add USB PID for a few more supported mice" (Benjamin Tissoires) [1740778]
- [hid] sony: Fix race condition between rumble and device remove (Benjamin Tissoires) [1740778]
- [hid] hiddev: do cleanup in failure of opening a device (Benjamin Tissoires) [1740778]
- [hid] hiddev: avoid opening a disconnected device (Benjamin Tissoires) [1740778]
- [hid] input: fix a4tech horizontal wheel custom usage (Benjamin Tissoires) [1740778]
- [hid] Add quirk for HP X1200 PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [hid] holtek: test for sanity of intfdata (Benjamin Tissoires) [1740778]
- [hid] wacom: fix bit shift for Cintiq Companion 2 (Benjamin Tissoires) [1740778]
- [hid] quirks: Set the INCREMENT_USAGE_ON_DUPLICATE quirk on Saitek X52 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Really fix return value of logi_dj_recv_query_hidpp_devices (Benjamin Tissoires) [1740778]
- [hid] Add 044f:b320 ThrustMaster, Inc. 2 in 1 DT (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add the Powerplay receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add USB PID for a few more supported mice (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: rename "gaming" receiver to "lightspeed" (Benjamin Tissoires) [1740778]
- [hid] Add another Primax PIXART OEM mouse quirk (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: add touchring adjustment for 2nd Gen Pro Small (Benjamin Tissoires) [1740778]
- [hid] quirks: Refactor ELAN 400 and 401 handling (Benjamin Tissoires) [1740778]
- [hid] video: fbdev: don't print error message on framebuffer_alloc() failure (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix forwarding of very long HID++ reports (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Huion HS64 tablet (Benjamin Tissoires) [1740778]
- [hid] wacom: add new MobileStudio Pro support (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: read the number of expected touches on a per collection basis (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: support the 'report valid' usage for touch (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: read HID_DG_CONTACTMAX from any feature report (Benjamin Tissoires) [1740778]
- [hid] wacom: Add 2nd gen Intuos Pro Small support (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee Rainbow CV720 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix return value of logi_dj_recv_query_hidpp_devices (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 372 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 335 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 333 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 307 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 297 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 282 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 267 (Benjamin Tissoires) [1740778]
- [hid] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 265 (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Fix 064d:c52f receiver support (Benjamin Tissoires) [1740778]
- [hid] revert "hid: core: Call request_module before doing device_add" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: core: Do not call request_module() in async context" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: Increase maximum report size allowed by hid_field_extract()" (Benjamin Tissoires) [1740778]
- [hid] a4tech: fix horizontal scrolling (Benjamin Tissoires) [1740778]
- [hid] hyperv: Add a module description line (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 178 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 177 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 149 (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: Add support for the S510 remote control (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: hid: make const array consumer_rdesc_start static (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: make const array template static (Benjamin Tissoires) [1740778]
- [hid] multitouch: handle faulty Elo touch device (Benjamin Tissoires) [1740778]
- [input] treewide: Add SPDX license identifier for more missed files (Benjamin Tissoires) [1740778]
- [hid] wacom: Sync INTUOSP2_BT touch state after each frame if necessary (Benjamin Tissoires) [1740778]
- [hid] wacom: Correct button numbering 2nd-gen Intuos Pro over Bluetooth (Benjamin Tissoires) [1740778]
- [hid] wacom: Send BTN_TOUCH in response to INTUOSP2_BT eraser contact (Benjamin Tissoires) [1740778]
- [hid] wacom: Don't report anything prior to the tool entering range (Benjamin Tissoires) [1740778]
- [hid] wacom: Don't set tool type until we're in range (Benjamin Tissoires) [1740778]
- [hid] wacom: correct touch resolution x/y typo (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: Correct pad syncing (Benjamin Tissoires) [1740778]
- [hid] wacom: generic: only switch the mode on devices with LEDs (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: Add usb-id for the 27MHz MX3000 receiver (Benjamin Tissoires) [1740778]
- [hid] rmi: Use SET_REPORT request on control endpoint for Acer Switch 3 and 5 (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for the MX5500 keyboard (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for the Logitech MX5500's Bluetooth Mini-Receiver (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add iBall Aer3 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix spelling in printk (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for KEY_KBD_LAYOUT_NEXT (Benjamin Tissoires) [1740778]
- [hid] input: fix assignment of .value (Benjamin Tissoires) [1740778]
- [hid] input: make sure the wheel high resolution multiplier is set (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add usbhid dependency in Kconfig (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 consumer keys reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 extra mouse buttons reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add support for HID++ 1.0 wheel reports (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: make hidpp10_set_register_bit a bit more generic (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: add input_device ptr to struct hidpp_device (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: do not hardcode very long report length (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: handle devices attached to 27MHz wireless receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: use RAP instead of FAP to get the protocol version (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove unused origin_is_hid_core function parameter (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove double assignment from __hidpp_send_report (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: do not make failure to get the name fatal (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: ignore very-short or empty names (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: make .probe usbhid capable (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: allow non HID++ devices to be handled by this module (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for Logitech Bluetooth Mini-Receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: make appending of the HID++ descriptors conditional (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove false-positive error on double queueing of delayed-work (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: pick a better name for non-unifying receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: deal with some KVMs adding an extra interface to the usbdev (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: replace dev_err calls with hid_err calls (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for 27 MHz mouse-only receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for 27 MHz receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for the gaming unifying receiver (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add support for non unifying receivers (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: add logi_dj_recv_queue_unknown_work helper (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: support sharing struct dj_receiver_dev between USB-interfaces (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: rename dj_receiver_dev.hdev to dj_receiver_dev.hidpp (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: protect the paired_dj_devices access in add_djhid_dev with the lock (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove unused querying_devices variable (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: do not schedule the dj report itself (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: remove USB dependency (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: declare and use a few HID++ 1.0 constants (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: use BIT() macro for RF Report types (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: fix variable naming in logi_dj_hidpp_event (Benjamin Tissoires) [1740778]
- [hid] logitech-dj: reshuffle logi_dj_recv_forward_* (Benjamin Tissoires) [1740778]
- [hid] logitech: Stop setting drvdata to NULL on probe failure and remove (Benjamin Tissoires) [1740778]
- [hid] quirks: do not blacklist Logitech devices (Benjamin Tissoires) [1740778]
- [hid] u2fzero: fail probe if not using USB transport (Benjamin Tissoires) [1740778]
- [hid] u2fzero: fix compiling error in u2fzero_probe() (Benjamin Tissoires) [1740778]
- [hid] revert "hid: i2c-hid: Disable runtime PM on Synaptics touchpad" (Benjamin Tissoires) [1740778]
- [hid] add driver for U2F Zero built-in LED and RNG (Benjamin Tissoires) [1740778]
- [hid] core: Do not call request_module() in async context (Benjamin Tissoires) [1740778]
- [hid] macally: Add support for Macally ikey keyboard (Benjamin Tissoires) [1740778]
- [hid] core: Call request_module before doing device_add (Benjamin Tissoires) [1740778]
- [hid] core: move Usage Page concatenation to Main item (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: change low battery level threshold from 31 to 30 percent (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: remove hidpp_is_connected() (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: simplify printing of HID++ version (Benjamin Tissoires) [1740778]
- [hid] picolcd: Convert to use sysfs_streq() (Benjamin Tissoires) [1740778]
- [hid] hid-sensor-custom: simplify getting .driver_data (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for Assistant key (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM on Synaptics touchpad (Benjamin Tissoires) [1740778]
- [hid] quirks: Fix keyboard + touchpad on Lenovo Miix 630 (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for "Toggle Display" key (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for "Full Screen" key (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for keyboard Brightness Up/Down/Toggle keys (Benjamin Tissoires) [1740778]
- [hid] input: add mapping for Expose/Overview key (Benjamin Tissoires) [1740778]
- [hid] input: fix mapping of aspect ratio key (Benjamin Tissoires) [1740778]
- [hid] logitech: Handle 0 scroll events for the m560 (Benjamin Tissoires) [1740778]
- [hid] debug: fix race condition with between rdesc_show() and device removal (Benjamin Tissoires) [1740778]
- [hid] logitech: check the return value of create_singlethread_workqueue (Benjamin Tissoires) [1740778]
- [hid] steam: fix deadlock with input devices (Benjamin Tissoires) [1740778]
- [hid] uclogic: remove redudant duplicated null check on ver_ptr (Benjamin Tissoires) [1740778]
- [hid] quirks: Drop misused kernel-doc annotation (Benjamin Tissoires) [1740778]
- [hid] quirks: use correct format chars in dbg_hid (Benjamin Tissoires) [1740778]
- [hid] Remove Waltop tablets from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] Remove KYE tablets from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] Remove hid-uclogic entries from hid_have_special_driver (Benjamin Tissoires) [1740778]
- [hid] uclogic: Do not initialize non-USB devices (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee G5 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support Gray-coded rotary encoders (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support faking Wacom pad device ID (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Deco 01 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Star G640 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for XP-Pen Star G540 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee EX07S frame controls (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee M540 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Add support for Ugee 2150 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support v2 protocol (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support fragmented high-res reports (Benjamin Tissoires) [1740778]
- [hid] uclogic: Support in-range reporting emulation (Benjamin Tissoires) [1740778]
- [hid] uclogic: Designate current protocol v1 (Benjamin Tissoires) [1740778]
- [hid] uclogic: Re-initialize tablets on resume (Benjamin Tissoires) [1740778]
- [hid] uclogic: Extract tablet parameter discovery into a module (Benjamin Tissoires) [1740778]
- [hid] uclogic: Extract report descriptors to a module (Benjamin Tissoires) [1740778]
- [hid] Clarify vendor ID reuse by Ugee tablets (Benjamin Tissoires) [1740778]
- [hid] viewsonic: Support PD1011 signature pad (Benjamin Tissoires) [1740778]
- [hid] kye: Add support for EasyPen M406XE (Benjamin Tissoires) [1740778]
- [hid] wacom: Add support for Pro Pen slim (Benjamin Tissoires) [1740778]
- [hid] roccat: Mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [hid] wacom: Mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [hid] fix Logitech WingMan Formula GP joined axes (Benjamin Tissoires) [1740778]
- [hid] multitouch: Lenovo X1 Tablet Gen3 trackpoint and buttons (Benjamin Tissoires) [1740778]
- [hid] steam: fix boot loop with bluetooth firmware (Benjamin Tissoires) [1740778]
- [hid] Add ASUS T100CHI keyboard dock battery quirks (Benjamin Tissoires) [1740778]
- [hid] Add support for Toshiba WT10A tablet bluetooth keyboard (Benjamin Tissoires) [1740778]
- [hid] wacom: Move HID fix for AES serial number into wacom_hid_usage_quirk (Benjamin Tissoires) [1740778]
- [hid] elan: Make array buf static, shrinks object size (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Ignore input report if there's no data present on Elan touchpanels (Benjamin Tissoires) [1740778]
- [hid] core: simplify active collection tracking (Benjamin Tissoires) [1740778]
- [hid] Support for Maltron L90 keyboard media keys (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM on Goodix touchpad (Benjamin Tissoires) [1740778]
- [hid] sony: Fix SHANWAN PS3 GamePad rumble and led settings support (Benjamin Tissoires) [1740778]
- [hid] sony: Transform one-time SHANWAN check into quirk (Benjamin Tissoires) [1740778]
- [hid] core: replace the collection tree pointers with indices (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add Odys Winbook 13 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] lenovo: Add checks to fix of_led_classdev_register (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: add MSI interrupt support (Benjamin Tissoires) [1740778]
- [hid] debug: Change to use DEFINE_SHOW_ATTRIBUTE macro (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: fixes incorrect error handling (Benjamin Tissoires) [1740778]
- [hid] logitech: Use LDJ_DEVICE macro for existing Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Enable high-resolution scrolling on Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Add function to enable HID++ 1.0 "scrolling acceleration" (Benjamin Tissoires) [1740778]
- [hid] logitech-hidpp: fix typo, hiddpp to hidpp (Benjamin Tissoires) [1740778]
- [hid] input: use the Resolution Multiplier for high-resolution scrolling (Benjamin Tissoires) [1740778]
- [hid] core: process the Resolution Multiplier (Benjamin Tissoires) [1740778]
- [hid] core: store the collections as a basic tree (Benjamin Tissoires) [1740778]
- [hid] cougar: Add support for Cougar 700K Gaming Keyboard (Benjamin Tissoires) [1740778]
- [hid] hidraw: enforce minors_lock locking via lockdep (Benjamin Tissoires) [1740778]
- [hid] quirks: fix RetroUSB.com devices (Benjamin Tissoires) [1740778]
- [kernel] hid: input: support Microsoft wireless radio control hotkey (Benjamin Tissoires) [1740778]
- [kernel] hid: use macros in IS_INPUT_APPLICATION (Benjamin Tissoires) [1740778]
- [hid] ite: Add USB id match for another ITE based keyboard rfkill key quirk (Benjamin Tissoires) [1740778]
- [hid] revert "hid: input: Create a utility class for counting scroll events" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Add function to enable HID++ 1.0 "scrolling acceleration"" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Enable high-resolution scrolling on Logitech mice" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: Use LDJ_DEVICE macro for existing Logitech mice" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: logitech: fix a used uninitialized GCC warning" (Benjamin Tissoires) [1740778]
- [hid] revert "hid: input: simplify/fix high-res scroll event handling" (Benjamin Tissoires) [1740778]
- [hid] Add quirk for Primax PIXART OEM mice (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Disable runtime PM for LG touchscreen (Benjamin Tissoires) [1740778]
- [hid] steam: remove input device when a hid client is running (Benjamin Tissoires) [1740778]
- [hid] revert "hid: uhid: use strlcpy() instead of strncpy()" (Benjamin Tissoires) [1740778]
- [hid] uhid: forbid UHID_CREATE under KERNEL_DS or elevated privileges (Benjamin Tissoires) [1740778]
- [hid] iio/hid-sensors: Fix IIO_CHAN_INFO_RAW returning wrong values for signed numbers (Benjamin Tissoires) [1740778]
- [hid] input: Ignore battery reported by Symbol DS4308 (Benjamin Tissoires) [1740778]
- [hid] Add quirk for Microsoft PIXART OEM mouse (Benjamin Tissoires) [1740778]
- [kernel] hid: fix up .raw_event() documentation (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: add Direkt-Tek DTLAPY133-1 to descriptor override (Benjamin Tissoires) [1740778]
- [hid] input: simplify/fix high-res scroll event handling (Benjamin Tissoires) [1740778]
- [hid] we do not randomly make new drivers 'default y' (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: properly terminate i2c_hid_dmi_desc_override_table[] array (Benjamin Tissoires) [1740778]
- [hid] alps: allow incoming reports when only the trackstick is opened (Benjamin Tissoires) [1740778]
- [hid] revert "hid: add NOGET quirk for Eaton Ellipse MAX UPS" (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add a small delay after sleep command for Raydium touchpanel (Benjamin Tissoires) [1740778]
- [hid] usbhid: Add quirk for Redragon/Dragonrise Seymur 2 (Benjamin Tissoires) [1740778]
- [hid] wacom: Work around HID descriptor bug in DTK-2451 and DTH-2452 (Benjamin Tissoires) [1740778]
- [hid] google: add dependency on Cros EC for Hammer (Benjamin Tissoires) [1740778]
- [hid] elan: fix spelling mistake "registred" -> "registered" (Benjamin Tissoires) [1740778]
- [hid] google: drop superfluous const before SIMPLE_DEV_PM_OPS() (Benjamin Tissoires) [1740778]
- [hid] google: add support tablet mode switch for Whiskers (Benjamin Tissoires) [1740778]
- [hid] magicmouse: add support for Apple Magic Trackpad 2 (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: override HID descriptors for certain devices (Benjamin Tissoires) [1740778]
- [hid] hid-bigbenff: driver for BigBen Interactive PS3OFMINIPAD gamepad (Benjamin Tissoires) [1740778]
- [hid] logitech: fix a used uninitialized GCC warning (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: using list_head for ipc write queue (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: use resource-managed api (Benjamin Tissoires) [1740778]
- [hid] intel_ish-hid: Enhance API to get ring buffer sizes (Benjamin Tissoires) [1740778]
- [hid] input: Set INPUT_PROP_-property for HID_UP_DIGITIZERS (Benjamin Tissoires) [1740778]
- [hid] microsoft: the driver now neeed MEMLESS_FF infrastructure (Benjamin Tissoires) [1740778]
- [hid] cougar: Stop processing vendor events on hid-core (Benjamin Tissoires) [1740778]
- [hid] cougar: Make parameter 'g6_is_space' dinamically settable (Benjamin Tissoires) [1740778]
- [hid] microsoft: Add rumble support for Xbox One S controller (Benjamin Tissoires) [1740778]
- [hid] microsoft: Convert private data to be a proper struct (Benjamin Tissoires) [1740778]
- [hid] logitech: Use LDJ_DEVICE macro for existing Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Enable high-resolution scrolling on Logitech mice (Benjamin Tissoires) [1740778]
- [hid] logitech: Add function to enable HID++ 1.0 "scrolling acceleration" (Benjamin Tissoires) [1740778]
- [hid] input: Create a utility class for counting scroll events (Benjamin Tissoires) [1740778]
- [hid] multitouch: simplify the application retrieval (Benjamin Tissoires) [1740778]
- [hid] input: do not append a suffix if the name already has it (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Remove RESEND_REPORT_DESCR quirk and its handling (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: disable runtime PM operations on hantick touchpad (Benjamin Tissoires) [1740778]
- [hid] sensor-hub: Restore fixup for Lenovo ThinkPad Helix 2 sensor hub report (Benjamin Tissoires) [1740778]
- [hid] core: fix NULL pointer dereference (Benjamin Tissoires) [1740778]
- [hid] hid-saitek: Add device ID for RAT 7 Contagion (Benjamin Tissoires) [1740778]
- [hid] core: fix memory leak on probe (Benjamin Tissoires) [1740778]
- [hid] add support for Apple Magic Keyboards (Benjamin Tissoires) [1740778]
- [hid] intel_ish-hid: tx_buf memory leak on probe/remove (Benjamin Tissoires) [1740778]
- [hid] intel-ish-hid: Prevent loading of driver on Mehlow (Benjamin Tissoires) [1740778]
- [hid] cougar: Add support for the Cougar 500k Gaming Keyboard (Benjamin Tissoires) [1740778]
- [hid] cougar: make compare_device_paths reusable (Benjamin Tissoires) [1740778]
- [hid] multitouch: handle palm for touchscreens (Benjamin Tissoires) [1740778]
- [hid] multitouch: touchscreens also use confidence reports (Benjamin Tissoires) [1740778]
- [hid] multitouch: report MT_TOOL_PALM for non-confident touches (Benjamin Tissoires) [1740778]
- [hid] microsoft: support the Surface Dial (Benjamin Tissoires) [1740778]
- [hid] core: do not upper bound the collection stack (Benjamin Tissoires) [1740778]
- [hid] input: enable Totem on the Dell Canvas 27 (Benjamin Tissoires) [1740778]
- [hid] multitouch: remove one copy of values (Benjamin Tissoires) [1740778]
- [hid] multitouch: ditch mt_report_id (Benjamin Tissoires) [1740778]
- [hid] multitouch: store a per application quirks value (Benjamin Tissoires) [1740778]
- [hid] multitouch: Store per collection multitouch data (Benjamin Tissoires) [1740778]
- [hid] multitouch: make sure the static list of class is not changed (Benjamin Tissoires) [1740778]
- [hid] elan: Add support for touchpad on the Toshiba Click Mini L9W (Benjamin Tissoires) [1740778]
- [hid] elan: Add USB-id for HP x2 10-n000nd touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Add a flag for selecting if the touchpad has a LED (Benjamin Tissoires) [1740778]
- [hid] elan: Query resolution from the touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Query device max_x and max_y value from touchpad (Benjamin Tissoires) [1740778]
- [hid] elan: Hardcode finger-count and usb-interface (Benjamin Tissoires) [1740778]
- [hid] elan: Correctly report MT_PRESSURE instead of TOOL_WIDTH (Benjamin Tissoires) [1740778]
- [hid] elan: Stop claiming we have TOUCH_MAJOR and then never reporting it (Benjamin Tissoires) [1740778]
- [hid] elan: Remove unused max_area_x and max_area_y vatiables (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sc->output_report_dmabuf (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_battery_probe() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_leds_init() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_register_sensors() (Benjamin Tissoires) [1740778]
- [hid] hid-sony.c: Use devm_ api to simplify sony_register_touchpad() (Benjamin Tissoires) [1740778]
- [hid] wacom: convert Wacom custom usages to standard HID usages (Benjamin Tissoires) [1740778]
- [hid] wacom: Move handling of HID quirks into a dedicated function (Benjamin Tissoires) [1740778]
- [hid] wacom: Replace touch_max fixup code with static touch_max definitions (Benjamin Tissoires) [1740778]
- [hid] wiimote: add support for Guitar-Hero devices (Benjamin Tissoires) [1740778]
- [hid] usbhid: use irqsave() in USB's complete callback (Benjamin Tissoires) [1740778]
- [hid] redragon: fix num lock and caps lock LEDs (Benjamin Tissoires) [1740778]
- [hid] hid-ntrig: add error handling for sysfs_create_group (Benjamin Tissoires) [1740778]
- [hid] i2c-hid: Add vddl regulator control (Benjamin Tissoires) [1740778]
- [uapi] input: document meanings of KEY_SCREEN and KEY_ZOOM (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - avoid processing unknown IRQs (Benjamin Tissoires) [1740778]
- [input] revert "input: elantech - enable SMBus on new (2018+) systems" (Benjamin Tissoires) [1740778]
- [input] elantech - annotate fall-through case in elantech_use_host_notify() (Benjamin Tissoires) [1740778]
- [samples] treewide: Add SPDX license identifier - Makefile/Kconfig (Benjamin Tissoires) [1740778]
- [kernel] input: elan_i2c - remove Lenovo Legion Y7000 PnpID (Benjamin Tissoires) [1740778]
- [input] synaptics - enable RMI mode for HP Spectre X360 (Benjamin Tissoires) [1740778]
- [input] elantech - enable SMBus on new (2018+) systems (Benjamin Tissoires) [1740778]
- [input] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Benjamin Tissoires) [1740778]
- [kernel] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 234 (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard: Use in-place iterator API in the channel callback (Benjamin Tissoires) [1740778]
- [input] usbtouchscreen - initialize PM mutex before using it (Benjamin Tissoires) [1740778]
- [input] alps - fix a mismatch between a condition check and its comment (Benjamin Tissoires) [1740778]
- [input] psmouse - fix build error of multiple definition (Benjamin Tissoires) [1740778]
- [input] alps - don't handle ALPS cs19 trackpoint-only device (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard - remove dependencies on PAGE_SIZE for ring buffer (Benjamin Tissoires) [1740778]
- [input] synaptics - fix misuse of strlcpy (Benjamin Tissoires) [1740778]
- [input] synaptics - whitelist Lenovo T580 SMBus intertouch (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBUS on T480 thinkpad trackpad (Benjamin Tissoires) [1740778]
- [input] joydev - extend absolute mouse detection (Benjamin Tissoires) [1740778]
- [kernel] input: elan_i2c - export the device id whitelist (Benjamin Tissoires) [1740778]
- [kernel] pm: suspend: Rename pm_suspend_via_s2idle() (Benjamin Tissoires) [1740778]
- [kernel] pm: sleep: Add kerneldoc comments to some functions (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus on ThinkPad E480 and E580 (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - remove set but not used variable 'sensor_flags' (Benjamin Tissoires) [1740778]
- [input] uinput - add compat ioctl number translation for UI_*_FF_UPLOAD (Benjamin Tissoires) [1740778]
- [input] libps2 - mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - write config register values to the right offset (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fix enum_fmt (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fill initial format (Benjamin Tissoires) [1740778]
- [uapi] input: add KEY_KBD_LAYOUT_NEXT (Benjamin Tissoires) [1740778]
- [input] synaptics-rmi4 - fix possible double free (Benjamin Tissoires) [1740778]
- [input] hyperv-keyboard - add module description (Benjamin Tissoires) [1740778]
- [input] i8042 - signal wakeup from atkbd/psmouse (Benjamin Tissoires) [1740778]
- [input] evdev - use struct_size() in kzalloc() and vzalloc() (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add hardware ID for multiple Lenovo laptops (Benjamin Tissoires) [1740778]
- [input] wacom_serial4 - add support for Wacom ArtPad II tablet (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add id for touchpad found in Lenovo s21e-20 (Benjamin Tissoires) [1740778]
- [input] i8042 - rework DT node name comparisons (Benjamin Tissoires) [1740778]
- [input] synaptics_i2c - remove redundant spinlock (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for touchpad in Lenovo V330-15ISK (Benjamin Tissoires) [1740778]
- [input] revert "input: elan_i2c - add ACPI ID for touchpad in ASUS Aspire F5-573G" (Benjamin Tissoires) [1740778]
- [input] elantech - enable 3rd button support on Fujitsu CELSIUS H780 (Benjamin Tissoires) [1740778]
- [uapi] input: input_event - fix the CONFIG_SPARC64 mixup (Benjamin Tissoires) [1740778]
- [input] uinput - fix undefined behavior in uinput_validate_absinfo() (Benjamin Tissoires) [1740778]
- [uapi] input: input_event - provide override for sparc64 (Benjamin Tissoires) [1740778]
- [input] soc_button_array - fix mapping of the 5th GPIO in a PNP0C40 device (Benjamin Tissoires) [1740778]
- [input] soc_button_array - add usage-page 0x01 usage-id 0xca mapping (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for touchpad in ASUS Aspire F5-573G (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus for HP EliteBook 840 G4 (Benjamin Tissoires) [1740778]
- [input] synaptics - enable RMI on ThinkPad T560 (Benjamin Tissoires) [1740778]
- [documentation] input: add `REL_WHEEL_HI_RES` and `REL_HWHEEL_HI_RES` (Benjamin Tissoires) [1740778]
- [uapi] input: restore EV_ABS ABS_RESERVED (Benjamin Tissoires) [1740778]
- [input] synaptics - enable SMBus for HP 15-ay000 (Benjamin Tissoires) [1740778]
- [input] synaptics - add PNP ID for ThinkPad P50 to SMBus (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15ARR (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add support for ELAN0621 touchpad (Benjamin Tissoires) [1740778]
- [documentation] revert "input: Add the `REL_WHEEL_HI_RES` event code" (Benjamin Tissoires) [1740778]
- [input] atkbd - clean up indentation issue (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ELAN0620 to the ACPI table (Benjamin Tissoires) [1740778]
- [input] synaptics - avoid using uninitialized variable when probing (Benjamin Tissoires) [1740778]
- [input] xen-kbdfront - mark expected switch fall-through (Benjamin Tissoires) [1740778]
- [input] elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15IGM (Benjamin Tissoires) [1740778]
- [input] of_touchscreen - add support for touchscreen-min-x|y (Benjamin Tissoires) [1740778]
- [input] elants_i2c - use DMA safe i2c when possible (Benjamin Tissoires) [1740778]
- [input] uinput - add a schedule point in uinput_inject_events() (Benjamin Tissoires) [1740778]
- [input] evdev - add a schedule point in evdev_write() (Benjamin Tissoires) [1740778]
- [input] mousedev - add a schedule point in mousedev_write() (Benjamin Tissoires) [1740778]
- [uapi] input: reserve 2 events code because of HID (Benjamin Tissoires) [1740778]
- [input] i8042 - enable keyboard wakeups by default when s2idle is used (Benjamin Tissoires) [1740778]
- [input] uinput - allow for max == min during input_absinfo validation (Benjamin Tissoires) [1740778]
- [input] atakbd - fix Atari CapsLock behaviour (Benjamin Tissoires) [1740778]
- [input] atakbd - fix Atari keymap (Benjamin Tissoires) [1740778]
- [documentation] input: Add the `REL_WHEEL_HI_RES` event code (Benjamin Tissoires) [1740778]
- [input] mark expected switch fall-throughs (Benjamin Tissoires) [1740778]
- [input] evdev - switch to bitmap API (Benjamin Tissoires) [1740778]
- [input] elan_i2c_smbus - cast sizeof to int for comparison (Benjamin Tissoires) [1740778]
- [uapi] input: stop telling users to snail-mail Vojtech (Benjamin Tissoires) [1740778]
- [documentation] input: add MT_TOOL_DIAL (Benjamin Tissoires) [1740778]
- [input] i8042 - increment wakeup_count for the respective port (Benjamin Tissoires) [1740778]
- [input] xen-kbdfront - allow better run-time configuration (Benjamin Tissoires) [1740778]
- [xen] Sync up with the canonical protocol definitions in Xen (Benjamin Tissoires) [1740778]
- [cpufreq] dev_pm_qos_update_request() can return 1 on success (Al Stone) [1739729 1725581]
- [cpufreq] Make cpufreq_generic_init() return void (Al Stone) [1739729 1725581]
- [cpufreq] Add QoS requests for userspace constraints (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Reuse refresh_frequency_limits() (Al Stone) [1739729 1725581]
- [cpufreq] Register notifiers with the PM QoS framework (Al Stone) [1739729 1725581]
- [base] pm / qos: Add support for MIN/MAX frequency constraints (Al Stone) [1739729 1725581]
- [base] pm / qos: Pass request type to dev_pm_qos_read_value() (Al Stone) [1739729 1725581]
- [base] pm / qos: Rename __dev_pm_qos_read_value() and dev_pm_qos_raw_read_value() (Al Stone) [1739729 1725581]
- [base] pm / qos: Pass request type to dev_pm_qos_{add|remove}_notifier() (Al Stone) [1739729 1725581]
- [cpufreq] Avoid calling cpufreq_verify_current_freq() from handle_update() (Al Stone) [1739729 1725581]
- [cpufreq] Consolidate cpufreq_update_current_freq() and __cpufreq_get() (Al Stone) [1739729 1725581]
- [cpufreq] Don't skip frequency validation for has_target() drivers (Al Stone) [1739729 1725581]
- [cpufreq] Use has_target() instead of !setpolicy (Al Stone) [1739729 1725581]
- [cpufreq] Remove redundant !setpolicy check (Al Stone) [1739729 1725581]
- [kernel] cpufreq: Move the IS_ENABLED(CPU_THERMAL) macro into a stub (Al Stone) [1739729 1725581]
- [opp] Don't use IS_ERR on invalid supplies (Al Stone) [1739729 1725581]
- [kernel] pm: sleep: Update struct wakeup_source documentation (Al Stone) [1739729 1725581]
- [base] base: power: remove wakeup_sources_stats_dentry variable (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: Fail initialization if driver cannot be registered (Al Stone) [1739729 1725581]
- [opp] Make dev_pm_opp_set_rate() handle freq = 0 to drop performance votes (Al Stone) [1739729 1725581]
- [opp] Don't overwrite rounded clk rate (Al Stone) [1739729 1725581]
- [base] pm: sleep: Show how long dpm_suspend_start() and dpm_suspend_end() take (Al Stone) [1739729 1725581]
- [base] pm / clk: Remove error message on out-of-memory condition (Al Stone) [1739729 1725581]
- [base] base: power: clock_ops: Use of_clk_get_parent_count() (Al Stone) [1739729 1725581]
- [opp] Allocate genpd_virt_devs from dev_pm_opp_attach_genpd() (Al Stone) [1739729 1725581]
- [opp] Attach genpds to devices from within OPP core (Al Stone) [1739729 1725581]
- [base] pm / domains: Add GENPD_FLAG_RPM_ALWAYS_ON flag (Al Stone) [1739729 1725581]
- [cpufreq] Don't find governor for setpolicy drivers in cpufreq_init_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Explain the kobject_put() in cpufreq_policy_alloc() (Al Stone) [1739729 1725581]
- [x86] cpufreq: Call transition notifier only once for each policy (Al Stone) [1739729 1725581]
- [cpufreq] Fix kobject memleak (Al Stone) [1739729 1725581]
- [cpufreq] centrino: Fix centrino_setpolicy() kerneldoc comment (Al Stone) [1739729 1725581]
- [base] pm / domains: Allow to attach a CPU via genpd_dev_pm_attach_by_id|name() (Al Stone) [1739729 1725581]
- [base] pm / domains: Search for the CPU device outside the genpd lock (Al Stone) [1739729 1725581]
- [base] pm / domains: Drop unused in-parameter to some genpd functions (Al Stone) [1739729 1725581]
- [base] pm / domains: Use the base device for driver_deferred_probe_check_state() (Al Stone) [1739729 1725581]
- [base] pm / domains: Enable genpd_dev_pm_attach_by_id|name() for single PM domain (Al Stone) [1739729 1725581]
- [base] pm / domains: Allow OF lookup for multi PM domain case from ->attach_dev() (Al Stone) [1739729 1725581]
- [base] pm / domains: Don't kfree() the virtual device in the error path (Al Stone) [1739729 1725581]
- [cpufreq] Move ->get callback check outside of __cpufreq_get() (Al Stone) [1739729 1725581]
- [x86] tsc: Rework time_cpufreq_notifier() (Al Stone) [1739729 1725581]
- [x86] tsc: Fix UV TSC initialization (Al Stone) [1739729 1725581]
- [x86] tsc: Prevent result truncation on 32bit (Al Stone) [1739729 1725581]
- [x86] tsc: Consolidate init code (Al Stone) [1739729 1725581]
- [x86] tsc: Make use of tsc_calibrate_cpu_early() (Al Stone) [1739729 1725581]
- [x86] tsc: Split native_calibrate_cpu() into early and late parts (Al Stone) [1739729 1725581]
- [x86] tsc: Use TSC as sched clock early (Al Stone) [1739729 1725581]
- [x86] tsc: Initialize cyc2ns when tsc frequency is determined (Al Stone) [1739729 1725581]
- [x86] tsc: Calibrate tsc only once (Al Stone) [1739729 1725581]
- [x86] tsc: Redefine notsc to behave as tsc=unstable (Al Stone) [1739729 1725581]
- [x86] platform/uv: Provide is_early_uv_system() (Al Stone) [1739729 1725581]
- [base] pm / domains: remove unnecessary unlikely() (Al Stone) [1739729 1725581]
- [cpufreq] Remove needless bios_limit check in show_bios_limit() (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq/acpi-cpufreq.c: This fixes the following checkpatch warning (Al Stone) [1739729 1725581]
- [base] pm / core: Propagate dev->power.wakeup_path when no callbacks (Al Stone) [1739729 1725581]
- [base] pm / domains: Add genpd governor for CPUs (Al Stone) [1739729 1725581]
- [cpuidle] Export the next timer expiration for CPUs (Al Stone) [1739729 1725581]
- [base] pm / core: Introduce dpm_async_fn() helper (Al Stone) [1739729 1725581]
- [cpufreq] boost: Remove CONFIG_CPU_FREQ_BOOST_SW Kconfig option (Al Stone) [1739729 1725581]
- [opp] Introduce dev_pm_opp_find_freq_ceil_by_volt() (Al Stone) [1739729 1725581]
- [base] pm / domains: Add support for CPU devices to genpd (Al Stone) [1739729 1725581]
- [base] pm / domains: Add generic data pointer to struct genpd_power_state (Al Stone) [1739729 1725581]
- [cpufreq] rhel: cpufreq: switch printk users from pf and pF to ps and pS, respectively (Al Stone) [1739729 1725581]
- [base] pm / core: fix kerneldoc comment for device_pm_wait_for_dev() (Al Stone) [1739729 1725581]
- [base] pm / core: fix kerneldoc comment for dpm_watchdog_handler() (Al Stone) [1739729 1725581]
- [cpufreq] stats: Use lock by stat to replace global spin lock (Al Stone) [1739729 1725581]
- [cpufreq] Remove cpufreq_driver check in cpufreq_boost_supported() (Al Stone) [1739729 1725581]
- [cpufreq] ppc_cbe: fix possible object reference leak (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq: Convert some slow-path static_cpu_has() callers to boot_cpu_has() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Update max frequency on global turbo changes (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Use pm_pr_dbg() instead of pr_debug() (Al Stone) [1739729 1725581]
- [cpufreq] Add cpufreq_cpu_acquire() and cpufreq_cpu_release() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Driver-specific handling of _PPC updates (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Load only on Intel hardware (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Fix use after free (Al Stone) [1739729 1725581]
- [base] pm / domains: Avoid a potential deadlock (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Fix up iowait_boost computation (Al Stone) [1739729 1725581]
- [opp] pm / opp: Update performance state when freq == old_freq (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Drop wakeup_source_drop() (Al Stone) [1739729 1725581]
- [base] pm / wakeup: Rework wakeup source timer cancellation (Al Stone) [1739729 1725581]
- [base] pm / domains: Remove one unnecessary blank line (Al Stone) [1739729 1725581]
- [base] pm / domains: Return early for all errors in _genpd_power_off() (Al Stone) [1739729 1725581]
- [base] pm / domains: Improve warn for multiple states but no governor (Al Stone) [1739729 1725581]
- [opp] Fix handling of multiple power domains (Al Stone) [1739729 1725581]
- [base] pm / qos: Fix typo in file description (Al Stone) [1739729 1725581]
- [base] pm-runtime: Call pm_runtime_active|suspended_time() from sysfs (Al Stone) [1739729 1725581]
- [base] pm-runtime: Consolidate code to get active/suspended time (Al Stone) [1739729 1725581]
- [base] pm: Add and use pr_fmt() (Al Stone) [1739729 1725581]
- [cpufreq] Improve kerneldoc comments for cpufreq_cpu_get/put() (Al Stone) [1739729 1725581]
- [cpufreq] acpi-cpufreq: Report if CPU doesn't support boost technologies (Al Stone) [1739729 1725581]
- [base] driver core: Fix PM-runtime for links added during consumer probe (Al Stone) [1739729 1725581]
- [cpufreq] Pass updated policy to driver ->setpolicy() callback (Al Stone) [1739729 1725581]
- [cpufreq] Fix two debug messages in cpufreq_set_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Reorder and simplify cpufreq_update_policy() (Al Stone) [1739729 1725581]
- [cpufreq] Add kerneldoc comments for two core functions (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Fix use-after-free in scmi_cpufreq_exit() (Al Stone) [1739729 1725581]
- [kernel] pm / core: Add support to skip power management in device/driver model (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Rework iowait boosting to be less aggressive (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Eliminate intel_pstate_get_base_pstate() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Avoid redundant initialization of local vars (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq / cppc: Work around for Hisilicon CPPC cpufreq (Al Stone) [1739729 1725581]
- [cpufreq] speedstep: convert BUG() to BUG_ON() (Al Stone) [1739729 1725581]
- [cpufreq] powernv: fix missing check of return value in init_powernv_pstates() (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: remove unneeded semicolon (Al Stone) [1739729 1725581]
- [kernel] pm / domains: Mark "name" const in dev_pm_domain_attach_by_name() (Al Stone) [1739729 1725581]
- [kernel] pm / domains: Mark "name" const in genpd_dev_pm_attach_by_name() (Al Stone) [1739729 1725581]
- [cpufreq] Replace double NOT (!!) with single NOT (!) (Al Stone) [1739729 1725581]
- [base] pm / suspend: Print debug messages for device using direct-complete (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Add reasons for failure and debug messages (Al Stone) [1739729 1725581]
- [base] driver core: Fix possible supplier PM-usage counter imbalance (Al Stone) [1739729 1725581]
- [base] pm-runtime: Fix __pm_runtime_set_status() race with runtime resume (Al Stone) [1739729 1725581]
- [cpufreq] dt: Implement online/offline() callbacks (Al Stone) [1739729 1725581]
- [cpufreq] Allow light-weight tear down and bring up of CPUs (Al Stone) [1739729 1725581]
- [base] pm-runtime: Take suppliers into account in __pm_runtime_set_status() (Al Stone) [1739729 1725581]
- [opp] no need to check return value of debugfs_create functions (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Register an Energy Model (Al Stone) [1739729 1725581]
- [opp] pm / opp: Introduce a power estimation helper (Al Stone) [1739729 1725581]
- [opp] pm / opp: Remove unused parameter of _generic_set_opp_clk_only() (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Register an Energy Model (Al Stone) [1739729 1725581]
- [cpufreq] dt: Register an Energy Model (Al Stone) [1739729 1725581]
- [cpufreq] stats: Fix concurrency issues while resetting stats (Al Stone) [1739729 1725581]
- [cpufreq] stats: Declare freq-attr right after their callbacks (Al Stone) [1739729 1725581]
- [base] driver core: Do not call rpm_put_suppliers() in pm_runtime_drop_link() (Al Stone) [1739729 1725581]
- [base] driver core: Fix handling of runtime PM flags in device_link_add() (Al Stone) [1739729 1725581]
- [base] driver core: Do not resume suppliers under device_links_write_lock() (Al Stone) [1739729 1725581]
- [base] driver core: Avoid careless re-use of existing device links (Al Stone) [1739729 1725581]
- [base] driver core: Fix DL_FLAG_AUTOREMOVE_SUPPLIER device link flag handling (Al Stone) [1739729 1725581]
- [base] driver core: Add flag to autoremove device link on supplier unbind (Al Stone) [1739729 1725581]
- [base] driver core: Rename flag AUTOREMOVE to AUTOREMOVE_CONSUMER (Al Stone) [1739729 1725581]
- [base] pm-runtime: update accounting_timestamp on enable (Al Stone) [1739729 1725581]
- [cpufreq] scpi: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq-dt: Use auto-registration of thermal cooling device (Al Stone) [1739729 1725581]
- [cpufreq] Auto-register the driver as a thermal cooling device if asked (Al Stone) [1739729 1725581]
- [cpufreq] thermal: cpu_cooling: Require thermal core to be compiled in (Al Stone) [1739729 1725581]
- [cpufreq] Use struct kobj_attribute instead of struct global_attr (Al Stone) [1739729 1725581]
- [base] pm / wakeup: fix kerneldoc comment for pm_wakeup_dev_event() (Al Stone) [1739729 1725581]
- [base] pm: domains: no need to check return value of debugfs_create functions (Al Stone) [1739729 1725581]
- [opp] Add support for parsing the 'opp-level' property (Al Stone) [1739729 1725581]
- [kernel] cpufreq: Replace open-coded << with BIT() (Al Stone) [1739729 1725581]
- [base] pm: clock_ops: fix missing clk_prepare() return value check (Al Stone) [1739729 1725581]
- [cpufreq] e_powersaver: Use struct_size() in kzalloc() (Al Stone) [1739729 1725581]
- [cpufreq] Don't update new_policy on failures (Al Stone) [1739729 1725581]
- [cpufreq] scmi: Fix frequency invariance in slow path (Al Stone) [1739729 1725581]
- [cpufreq] check if policy is inactive early in __cpufreq_get() (Al Stone) [1739729 1725581]
- [opp] cpufreq: scpi/scmi: Fix freeing of dynamic OPPs (Al Stone) [1739729 1725581]
- [base] pm: sleep: call devfreq suspend/resume (Al Stone) [1739729 1725581]
- [devfreq] pm / devfreq: add devfreq_suspend/resume() functions (Al Stone) [1739729 1725581]
- [base] pm / domains: remove define_genpd_open_function() and define_genpd_debugfs_fops() (Al Stone) [1739729 1725581]
- [base] pm / domains: Propagate performance state updates (Al Stone) [1739729 1725581]
- [base] pm / domains: Factorize dev_pm_genpd_set_performance_state() (Al Stone) [1739729 1725581]
- [base] pm / domains: Save OPP table pointer in genpd (Al Stone) [1739729 1725581]
- [opp] Don't return 0 on error from of_get_required_opp_performance_state() (Al Stone) [1739729 1725581]
- [opp] Add dev_pm_opp_xlate_performance_state() helper (Al Stone) [1739729 1725581]
- [opp] Improve _find_table_of_opp_np() (Al Stone) [1739729 1725581]
- [base] pm / domains: Make genpd performance states orthogonal to the idlestates (Al Stone) [1739729 1725581]
- [opp] Fix missing debugfs supply directory for OPPs (Al Stone) [1739729 1725581]
- [opp] Use opp_table->regulators to verify no regulator case (Al Stone) [1739729 1725581]
- [base] pm: Switch to use ptR (Al Stone) [1739729 1725581]
- [cpufreq] powernv: add of_node_put() (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Force HWP min perf before offline (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq: change CONFIG_6xx to CONFIG_PPC_BOOK3S_32 (Al Stone) [1739729 1725581]
- [opp] Fix parsing of multiple phandles in "operating-points-v2" property (Al Stone) [1739729 1725581]
- [opp] Remove of_dev_pm_opp_find_required_opp() (Al Stone) [1739729 1725581]
- [base] opp: Rename and relocate of_genpd_opp_to_performance_state() (Al Stone) [1739729 1725581]
- [opp] Configure all required OPPs (Al Stone) [1739729 1725581]
- [opp] Add dev_pm_opp_{set|put}_genpd_virt_dev() helper (Al Stone) [1739729 1725581]
- [base] pm / domains: Add genpd_opp_to_performance_state() (Al Stone) [1739729 1725581]
- [opp] Populate OPPs from "required-opps" property (Al Stone) [1739729 1725581]
- [opp] Populate required opp tables from "required-opps" property (Al Stone) [1739729 1725581]
- [opp] Separate out custom OPP handler specific code (Al Stone) [1739729 1725581]
- [opp] Identify and mark genpd OPP tables (Al Stone) [1739729 1725581]
- [base] pm / domains: Rename genpd virtual devices as virt_dev (Al Stone) [1739729 1725581]
- [cpufreq] remove unused arm_big_little_dt driver (Al Stone) [1739729 1725581]
- [cpufreq] drop ARM_BIG_LITTLE_CPUFREQ support for ARM64 (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: Fix compilation for !CONFIG_ACPI (Al Stone) [1739729 1725581]
- [base] pm / domains: Deal with multiple states but no governor in genpd (Al Stone) [1739729 1725581]
- [base] pm / domains: Don't treat zero found compatible idle states as an error (Al Stone) [1739729 1725581]
- [cpufreq] conservative: Take limits changes into account properly (Al Stone) [1739729 1725581]
- [opp] pm / opp: _of_add_opp_table_v2(): increment count only if OPP is added (Al Stone) [1739729 1725581]
- [cpufreq] dt: Try freeing static OPPs only if we have added them (Al Stone) [1739729 1725581]
- [opp] Return error on error from dev_pm_opp_get_opp_count() (Al Stone) [1739729 1725581]
- [opp] Improve error handling in dev_pm_opp_of_cpumask_add_table() (Al Stone) [1739729 1725581]
- [cpufreq] cpufreq / cppc: Mark acpi_ids as used (Al Stone) [1739729 1725581]
- [opp] Pass OPP table to _of_add_opp_table_v{1|2}() (Al Stone) [1739729 1725581]
- [opp] Prevent creating multiple OPP tables for devices sharing OPP nodes (Al Stone) [1739729 1725581]
- [opp] Use a single mechanism to free the OPP table (Al Stone) [1739729 1725581]
- [opp] Don't remove dynamic OPPs from _dev_pm_opp_remove_table() (Al Stone) [1739729 1725581]
- [opp] Create separate kref for static OPPs list (Al Stone) [1739729 1725581]
- [opp] Don't take OPP table's kref for static OPPs (Al Stone) [1739729 1725581]
- [opp] Parse OPP table's DT properties from _of_init_opp_table() (Al Stone) [1739729 1725581]
- [opp] Pass index to _of_init_opp_table() (Al Stone) [1739729 1725581]
- [opp] Protect dev_list with opp_table lock (Al Stone) [1739729 1725581]
- [opp] Don't try to remove all OPP tables on failure (Al Stone) [1739729 1725581]
- [opp] Free OPP table properly on performance state irregularities (Al Stone) [1739729 1725581]
- [cpufreq] Convert to using pOFn instead of device_node.name (Al Stone) [1739729 1725581]
- [cpufreq] remove unnecessary unlikely() (Al Stone) [1739729 1725581]
- [base] pm / clk: signedness bug in of_pm_clk_add_clks() (Al Stone) [1739729 1725581]
- [trace] cpufreq: trace frequency limits change (Al Stone) [1739729 1725581]
- [cpufreq] pcc-cpufreq: Disable dynamic scaling on many-CPU systems (Al Stone) [1739729 1725581]
- [base] pm / domains: Stop deferring probe at the end of initcall (Al Stone) [1739729 1725581]
- [base] driver: core: Allow subsystems to continue deferring probe (Al Stone) [1739729 1725581]
- [base] driver core: allow stopping deferred probe after init (Al Stone) [1739729 1725581]
- [base] driver core: add a debugfs entry to show deferred devices (Al Stone) [1739729 1725581]
- [base] pm / domains: Introduce dev_pm_domain_attach_by_name() (Al Stone) [1739729 1725581]
- [base] pm / domains: Introduce option to attach a device by name to genpd (Al Stone) [1739729 1725581]
- [cpufreq] intel_pstate: use match_string() helper (Al Stone) [1739729 1725581]
- [fs] ceph: use ceph_evict_inode to cleanup inode's resource (Jeff Layton) [1767959]
- [fs] ceph: return -EINVAL if given fsc mount option on kernel w/o support (Jeff Layton) [1767959]
- [fs] ceph: don't try to handle hashed dentries in non-O_CREAT atomic_open (Jeff Layton) [1767959]
- [fs] ceph: add missing check in d_revalidate snapdir handling (Jeff Layton) [1767959]
- [fs] ceph: fix RCU case handling in ceph_d_revalidate() (Jeff Layton) [1767959]
- [fs] ceph: fix use-after-free in __ceph_remove_cap() (Jeff Layton) [1767959]
- [block] rbd: cancel lock_dwork if the wait is interrupted (Jeff Layton) [1767959]
- [fs] ceph: just skip unrecognized info in ceph_reply_info_extra (Jeff Layton) [1767959]
- [fs] ceph: call ceph_mdsc_destroy from destroy_fs_client (Jeff Layton) [1767959]
- [net] libceph: use ceph_kvmalloc() for osdmap arrays (Jeff Layton) [1767959]
- [net] libceph: avoid a __vmalloc() deadlock in ceph_kvmalloc() (Jeff Layton) [1767959]
- [fs] ceph: include ceph_debug.h in cache.c (Jeff Layton) [1767959]
- [fs] ceph: move static keyword to the front of declarations (Jeff Layton) [1767959]
- [block] rbd: pull rbd_img_request_create() dout out into the callers (Jeff Layton) [1767959]
- [fs] ceph: reconnect connection if session hang in opening state (Jeff Layton) [1767959]
- [net] libceph: drop unused con parameter of calc_target() (Jeff Layton) [1767959]
- [fs] ceph: use release_pages() directly (Jeff Layton) [1767959]
- [block] rbd: fix response length parameter for encoded strings (Jeff Layton) [1767959]
- [fs] ceph: allow arbitrary security.* xattrs (Jeff Layton) [1767959]
- [fs] ceph: only set CEPH_I_SEC_INITED if we got a MAC label (Jeff Layton) [1767959]
- [fs] ceph: turn ceph_security_invalidate_secctx into static inline (Jeff Layton) [1767959]
- [fs] ceph: add buffered/direct exclusionary locking for reads and writes (Jeff Layton) [1767959]
- [net] libceph: handle OSD op ceph_pagelist_append() errors (Jeff Layton) [1767959]
- [fs] ceph: don't return a value from void function (Jeff Layton) [1767959]
- [fs] ceph: don't freeze during write page faults (Jeff Layton) [1767959]
- [fs] ceph: update the mtime when truncating up (Jeff Layton) [1767959]
- [fs] ceph: fix indentation in __get_snap_name() (Jeff Layton) [1767959]
- [fs] ceph: remove incorrect comment above __send_cap (Jeff Layton) [1767959]
- [fs] ceph: remove CEPH_I_NOFLUSH (Jeff Layton) [1767959]
- [fs] ceph: remove unneeded test in try_flush_caps (Jeff Layton) [1767959]
- [fs] ceph: have __mark_caps_flushing return flush_tid (Jeff Layton) [1767959]
- [fs] ceph: fix comments over ceph_add_cap (Jeff Layton) [1767959]
- [fs] ceph: eliminate session->s_trim_caps (Jeff Layton) [1767959]
- [fs] ceph: fetch cap_gen under spinlock in ceph_add_cap (Jeff Layton) [1767959]
- [fs] ceph: remove ceph_get_cap_mds and __ceph_get_cap_mds (Jeff Layton) [1767959]
- [fs] ceph: don't SetPageError on writepage errors (Jeff Layton) [1767959]
- [fs] ceph: auto reconnect after blacklisted (Jeff Layton) [1767959]
- [fs] ceph: invalidate all write mode filp after reconnect (Jeff Layton) [1767959]
- [fs] ceph: return -EIO if read/write against filp that lost file locks (Jeff Layton) [1767959]
- [fs] ceph: add helper function that forcibly reconnects to ceph cluster (Jeff Layton) [1767959]
- [fs] ceph: pass filp to ceph_get_caps() (Jeff Layton) [1767959]
- [fs] ceph: track and report error of async metadata operation (Jeff Layton) [1767959]
- [fs] ceph: allow closing session in restarting/reconnect state (Jeff Layton) [1767959]
- [net] libceph: add function that clears osd client's abort_err (Jeff Layton) [1767959]
- [net] libceph: add function that reset client's entity addr (Jeff Layton) [1767959]
- [fs] ceph: don't list vxattrs in listxattr() (Jeff Layton) [1767959]
- [fs] ceph: fix directories inode i_blkbits initialization (Jeff Layton) [1767959]
- [block] rbd: restore zeroing past the overlap when reading from parent (Jeff Layton) [1767959]
- [net] libceph: don't call crypto_free_sync_skcipher() on a NULL tfm (Jeff Layton) [1767959]
- [net] libceph: fix PG split vs OSD (re)connect race (Jeff Layton) [1767959]
- [fs] ceph: don't try fill file_lock on unsuccessful GETFILELOCK reply (Jeff Layton) [1767959]
- [fs] ceph: clear page dirty before invalidate page (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in fill_inode() (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in __ceph_build_xattrs_blob() (Jeff Layton) [1767959]
- [fs] ceph: fix buffer free while holding i_ceph_lock in __ceph_setxattr() (Jeff Layton) [1767959]
- [kernel] libceph: allow ceph_buffer_put() to receive a NULL ceph_buffer (Jeff Layton) [1767959]
- [fs] ceph: fix end offset in truncate_inode_pages_range call (Jeff Layton) [1767959]
- [fs] ceph: initialize superblock s_time_gran to 1 (Jeff Layton) [1767959]
- [block] rbd: setallochint only if object doesn't exist (Jeff Layton) [1767959]
- [block] rbd: support for object-map and fast-diff (Jeff Layton) [1767959]
- [block] rbd: call rbd_dev_mapping_set() from rbd_dev_image_probe() (Jeff Layton) [1767959]
- [net] libceph: export osd_req_op_data() macro (Jeff Layton) [1767959]
- [net] libceph: change ceph_osdc_call() to take page vector for response (Jeff Layton) [1767959]
- [kernel] libceph: bump CEPH_MSG_MAX_DATA_LEN (again) (Jeff Layton) [1767959]
- [block] rbd: new exclusive lock wait/wake code (Jeff Layton) [1767959]
- [block] rbd: quiescing lock should wait for image requests (Jeff Layton) [1767959]
- [block] rbd: lock should be quiesced on reacquire (Jeff Layton) [1767959]
- [block] rbd: introduce copyup state machine (Jeff Layton) [1767959]
- [block] rbd: rename rbd_obj_setup_*() to rbd_obj_init_*() (Jeff Layton) [1767959]
- [block] rbd: move OSD request allocation into object request state machines (Jeff Layton) [1767959]
- [block] rbd: factor out __rbd_osd_setup_discard_ops() (Jeff Layton) [1767959]
- [block] rbd: factor out rbd_osd_setup_copyup() (Jeff Layton) [1767959]
- [block] rbd: introduce obj_req->osd_reqs list (Jeff Layton) [1767959]
- [fs] libceph: rename r_unsafe_item to r_private_item (Jeff Layton) [1767959]
- [block] rbd: introduce image request state machine (Jeff Layton) [1767959]
- [block] rbd: move OSD request submission into object request state machines (Jeff Layton) [1767959]
- [block] rbd: get rid of RBD_OBJ_WRITE_{FLAT, GUARD} (Jeff Layton) [1767959]
- [block] rbd: replace obj_req->tried_parent with obj_req->read_state (Jeff Layton) [1767959]
- [block] rbd: get rid of obj_req->xferred, obj_req->result and img_req->xferred (Jeff Layton) [1767959]
- [fs] ceph: don't NULL terminate virtual xattrs (Jeff Layton) [1767959]
- [fs] ceph: return -ERANGE if virtual xattr value didn't fit in buffer (Jeff Layton) [1767959]
- [fs] ceph: make getxattr_cb return ssize_t (Jeff Layton) [1767959]
- [fs] ceph: more precise CEPH_CLIENT_CAPS_PENDING_CAPSNAP (Jeff Layton) [1767959]
- [fs] ceph: kick flushing and flush snaps before sending normal cap message (Jeff Layton) [1767959]
- [fs] ceph: clear CEPH_I_KICK_FLUSH flag inside __kick_flushing_caps() (Jeff Layton) [1767959]
- [fs] ceph: increment change_attribute on local changes (Jeff Layton) [1767959]
- [fs] ceph: handle change_attr in cap messages (Jeff Layton) [1767959]
- [fs] ceph: add change_attr field to ceph_inode_info (Jeff Layton) [1767959]
- [kernel] iversion: add a routine to update a raw value with a larger one (Jeff Layton) [1767959]
- [fs] ceph: allow querying of STATX_BTIME in ceph_getattr (Jeff Layton) [1767959]
- [kernel] libceph: turn on CEPH_FEATURE_MSG_ADDR2 (Jeff Layton) [1767959]
- [fs] ceph: handle btime in cap messages (Jeff Layton) [1767959]
- [fs] ceph: add btime field to ceph_inode_info (Jeff Layton) [1767959]
- [net] libceph: rename ceph_encode_addr to ceph_encode_banner_addr (Jeff Layton) [1767959]
- [net] libceph: use TYPE_LEGACY for entity addrs instead of TYPE_NONE (Jeff Layton) [1767959]
- [net] ceph: fix decode_locker to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [fs] ceph: have MDS map decoding use entity_addr_t decoder (Jeff Layton) [1767959]
- [net] libceph: correctly decode ADDR2 addresses in incremental OSD maps (Jeff Layton) [1767959]
- [net] libceph: fix watch_item_t decoding to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: switch osdmap decoding to use ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: ADDR2 support for monmap (Jeff Layton) [1767959]
- [net] libceph: add ceph_decode_entity_addr (Jeff Layton) [1767959]
- [net] libceph: fix sa_family just after reading address (Jeff Layton) [1767959]
- [fs] ceph: remove request from waiting list before unregister (Jeff Layton) [1767959]
- [fs] ceph: don't blindly unregister session that is in opening state (Jeff Layton) [1767959]
- [fs] ceph: fix infinite loop in get_quota_realm() (Jeff Layton) [1767959]
- [fs] ceph: add selinux support (Jeff Layton) [1767959]
- [fs] ceph: rename struct ceph_acls_info to ceph_acl_sec_ctx (Jeff Layton) [1767959]
- [fs] ceph: fix debug print format in __set_xattr() (Jeff Layton) [1767959]
- [fs] ceph: fix warning PTR_ERR_OR_ZERO can be used (Jeff Layton) [1767959]
- [fs] ceph: hold i_ceph_lock when removing caps for freeing inode (Jeff Layton) [1767959]
- [fs] ceph: ensure d_name/d_parent stability in ceph_mdsc_lease_send_msg() (Jeff Layton) [1767959]
- [fs] ceph: use READ_ONCE to access d_parent in RCU critical section (Jeff Layton) [1767959]
- [fs] ceph: fix dir_lease_is_valid() (Jeff Layton) [1767959]
- [fs] ceph: close race between d_name_cmp() and update_dentry_lease() (Jeff Layton) [1767959]
- [fs] ceph: fix improper use of smp_mb__before_atomic() (Jeff Layton) [1767959]
- [fs] ceph: fix "ceph.dir.rctime" vxattr value (Jeff Layton) [1767959]
- [fs] ceph: remove unused vxattr length helpers (Jeff Layton) [1767959]
- [fs] ceph: fix listxattr vxattr buffer length calculation (Jeff Layton) [1767959]
- [fs] ceph: add ceph.snap.btime vxattr (Jeff Layton) [1767959]
- [fs] ceph: carry snapshot creation time with inodes (Jeff Layton) [1767959]
- [fs] ceph: clean up ceph.dir.pin vxattr name sizeof() (Jeff Layton) [1767959]
- [fs] ceph: silence a checker warning in mdsc_show() (Jeff Layton) [1767959]
- [net] libceph: remove ceph_get_direct_page_vector() (Jeff Layton) [1767959]
- [fs] ceph: don't open-code the check for dead lockref (Jeff Layton) [1767959]
- [net] ceph: no need to check return value of debugfs_create functions (Jeff Layton) [1767959]
- [fs] ceph: fix ceph_mdsc_build_path to not stop on first component (Jeff Layton) [1767959]
- [fs] ceph: fix error handling in ceph_get_caps() (Jeff Layton) [1767959]
- [fs] ceph: avoid iput_final() while holding mutex or in dispatch thread (Jeff Layton) [1767959]
- [fs] ceph: single workqueue for inode related works (Jeff Layton) [1767959]
- [fs] ceph: flush dirty inodes before proceeding with remount (Jeff Layton) [1767959]
- [fs] ceph: fix unaligned access in ceph_send_cap_releases (Jeff Layton) [1767959]
- [net] libceph: make ceph_pr_addr take an struct ceph_entity_addr pointer (Jeff Layton) [1767959]
- [net] libceph: fix unaligned accesses in ceph_entity_addr handling (Jeff Layton) [1767959]
- [block] rbd: don't assert on writes to snapshots (Jeff Layton) [1767959]
- [block] rbd: client_mutex is never nested (Jeff Layton) [1767959]
- [fs] ceph: print inode number in __caps_issued_mask debugging messages (Jeff Layton) [1767959]
- [fs] ceph: just call get_session in __ceph_lookup_mds_session (Jeff Layton) [1767959]
- [fs] ceph: simplify arguments and return semantics of try_get_cap_refs (Jeff Layton) [1767959]
- [fs] ceph: fix comment over ceph_drop_caps_for_unlink (Jeff Layton) [1767959]
- [fs] ceph: move wait for mds request into helper function (Jeff Layton) [1767959]
- [fs] ceph: have ceph_mdsc_do_request call ceph_mdsc_submit_request (Jeff Layton) [1767959]
- [fs] ceph: after an MDS request, do callback and completions (Jeff Layton) [1767959]
- [fs] ceph: use pathlen values returned by set_request_path_attr (Jeff Layton) [1767959]
- [fs] ceph: use __getname/__putname in ceph_mdsc_build_path (Jeff Layton) [1767959]
- [fs] ceph: use ceph_mdsc_build_path instead of clone_dentry_name (Jeff Layton) [1767959]
- [fs] ceph: fix potential use-after-free in ceph_mdsc_build_path (Jeff Layton) [1767959]
- [fs] ceph: dump granular cap info in "caps" debugfs file (Jeff Layton) [1767959]
- [fs] ceph: make iterate_session_caps a public symbol (Jeff Layton) [1767959]
- [fs] ceph: fix NULL pointer deref when debugging is enabled (Jeff Layton) [1767959]
- [fs] ceph: properly handle granular statx requests (Jeff Layton) [1767959]
- [fs] ceph: remove superfluous inode_lock in ceph_fsync (Jeff Layton) [1767959]
- [kernel] libceph: fix clang warning for CEPH_DEFINE_OID_ONSTACK (Jeff Layton) [1767959]
- [block] rbd: convert all rbd_assert(0) to BUG() (Jeff Layton) [1767959]
- [block] rbd: avoid clang -Wuninitialized warning (Jeff Layton) [1767959]
- [fs] ceph: snapshot nfs re-export (Jeff Layton) [1767959]
- [fs] ceph: quota: fix quota subdir mounts (Jeff Layton) [1767959]
- [fs] ceph: factor out ceph_lookup_inode() (Jeff Layton) [1767959]
- [fs] ceph: remove duplicated filelock ref increase (Jeff Layton) [1767959]
- [fs] ceph: fix ci->i_head_snapc leak (Jeff Layton) [1767959]
- [fs] ceph: handle the case where a dentry has been renamed on outstanding req (Jeff Layton) [1767959]
- [fs] ceph: ensure d_name stability in ceph_dentry_hash() (Jeff Layton) [1767959]
- [fs] ceph: only use d_name directly when parent is locked (Jeff Layton) [1767959]
- [fs] mark expected switch fall-throughs (Jeff Layton) [1767959]
- [fs] ceph: fix use-after-free on symlink traversal (Jeff Layton) [1767959]
- [net] libceph: fix breakage caused by multipage bvecs (Jeff Layton) [1767959]
- [block] rbd: drop wait_for_latest_osdmap() (Jeff Layton) [1767959]
- [net] libceph: wait for latest osdmap in ceph_monc_blacklist_add() (Jeff Layton) [1767959]
- [block] rbd: set io_min, io_opt and discard_granularity to alloc_size (Jeff Layton) [1767959]
- [block] rbd: advertise support for RBD_FEATURE_DEEP_FLATTEN (Jeff Layton) [1767959]
- [block] rbd: whole-object write and zeroout should copyup when snapshots exist (Jeff Layton) [1767959]
- [block] rbd: copyup with an empty snapshot context (aka deep-copyup) (Jeff Layton) [1767959]
- [block] rbd: introduce rbd_obj_issue_copyup_ops() (Jeff Layton) [1767959]
- [block] rbd: stop copying num_osd_ops in rbd_obj_issue_copyup() (Jeff Layton) [1767959]
- [block] rbd: factor out __rbd_osd_req_create() (Jeff Layton) [1767959]
- [block] rbd: clear ->xferred on error from rbd_obj_issue_copyup() (Jeff Layton) [1767959]
- [block] rbd: remove experimental designation from kernel layering (Jeff Layton) [1767959]
- [fs] ceph: add mount option to limit caps count (Jeff Layton) [1767959]
- [fs] ceph: periodically trim stale dentries (Jeff Layton) [1767959]
- [fs] ceph: delete stale dentry when last reference is dropped (Jeff Layton) [1767959]
- [fs] ceph: remove dentry_lru file from debugfs (Jeff Layton) [1767959]
- [fs] ceph: touch existing cap when handling reply (Jeff Layton) [1767959]
- [fs] ceph: pass inclusive lend parameter to filemap_write_and_wait_range() (Jeff Layton) [1767959]
- [block] rbd: round off and ignore discards that are too small (Jeff Layton) [1767959]
- [block] rbd: handle DISCARD and WRITE_ZEROES separately (Jeff Layton) [1767959]
- [block] rbd: get rid of obj_req->obj_request_count (Jeff Layton) [1767959]
- [net] libceph: use struct_size() for kmalloc() in crush_decode() (Jeff Layton) [1767959]
- [fs] ceph: send cap releases more aggressively (Jeff Layton) [1767959]
- [fs] ceph: support getting ceph.dir.pin vxattr (Jeff Layton) [1767959]
- [fs] ceph: support versioned reply (Jeff Layton) [1767959]
- [fs] ceph: map snapid to anonymous bdev ID (Jeff Layton) [1767959]
- [fs] ceph: split large reconnect into multiple messages (Jeff Layton) [1767959]
- [fs] ceph: decode feature bits in session message (Jeff Layton) [1767959]
- [fs] ceph: set special inode's blocksize to page size (Jeff Layton) [1767959]
- [fs] ceph: avoid repeatedly adding inode to mdsc->snap_flush_list (Jeff Layton) [1767959]
- [fs] ceph: quota: cleanup license mess (Jeff Layton) [1767959]
- [net] libceph: avoid KEEPALIVE_PENDING races in ceph_con_keepalive() (Jeff Layton) [1767959]
- [fs] ceph: clear inode pointer when snap realm gets dropped by its inode (Jeff Layton) [1767959]
- [block] rbd: don't return 0 on unmap if RBD_DEV_FLAG_REMOVING is set (Jeff Layton) [1767959]
- [fs] ceph: use vmf_error() in ceph_filemap_fault() (Jeff Layton) [1767959]
- [net] libceph: allow setting abort_on_full for rbd (Jeff Layton) [1767959]
- [fs] ceph: don't encode inode pathes into reconnect message (Jeff Layton) [1767959]
- [fs] ceph: update wanted caps after resuming stale session (Jeff Layton) [1767959]
- [fs] ceph: skip updating 'wanted' caps if caps are already issued (Jeff Layton) [1767959]
- [fs] ceph: don't request excl caps when mount is readonly (Jeff Layton) [1767959]
- [fs] ceph: don't update importing cap's mseq when handing cap export (Jeff Layton) [1767959]
- [net] libceph: switch more to bool in ceph_tcp_sendmsg() (Jeff Layton) [1767959]
- [net] libceph: use MSG_SENDPAGE_NOTLAST with ceph_tcp_sendpage() (Jeff Layton) [1767959]
- [net] libceph: use sock_no_sendpage() as a fallback in ceph_tcp_sendpage() (Jeff Layton) [1767959]
- [net] libceph: drop last_piece logic from write_partial_message_data() (Jeff Layton) [1767959]
- [fs] ceph: remove redundant assignment (Jeff Layton) [1767959]
- [fs] ceph: cleanup splice_dentry() (Jeff Layton) [1767959]
- [fs] libceph: assume argonaut on the server side (Jeff Layton) [1767959]
- [fs] ceph: quota: fix null pointer dereference in quota check (Jeff Layton) [1767959]
- [fs] ceph: add non-blocking parameter to ceph_try_get_caps() (Jeff Layton) [1767959]
- [net] libceph: check reply num_data_items in setup_request_data() (Jeff Layton) [1767959]
- [net] libceph: preallocate message data items (Jeff Layton) [1767959]
- [net] libceph, rbd, ceph: move ceph_osdc_alloc_messages() calls (Jeff Layton) [1767959]
- [net] libceph: introduce alloc_watch_request() (Jeff Layton) [1767959]
- [net] libceph: assign cookies in linger_submit() (Jeff Layton) [1767959]
- [net] libceph: enable fallback to ceph_msg_new() in ceph_msgpool_get() (Jeff Layton) [1767959]
- [fs] ceph: num_ops is off by one in ceph_aio_retry_work() (Jeff Layton) [1767959]
- [net] libceph: no need to call osd_req_opcode_valid() in osd_req_encode_op() (Jeff Layton) [1767959]
- [fs] ceph: set timeout conditionally in __cap_delay_requeue (Jeff Layton) [1767959]
- [net] libceph: don't consume a ref on pagelist in ceph_msg_data_add_pagelist() (Jeff Layton) [1767959]
- [net] libceph: introduce ceph_pagelist_alloc() (Jeff Layton) [1767959]
- [net] libceph: osd_req_op_cls_init() doesn't need to take opcode (Jeff Layton) [1767959]
- [kernel] libceph: bump CEPH_MSG_MAX_DATA_LEN (Jeff Layton) [1767959]
- [fs] ceph: only allow punch hole mode in fallocate (Jeff Layton) [1767959]
- [fs] ceph: refactor ceph_sync_read() (Jeff Layton) [1767959]
- [fs] ceph: check if LOOKUPNAME request was aborted when filling trace (Jeff Layton) [1767959]
- [fs] ceph: fix dentry leak in ceph_readdir_prepopulate (Jeff Layton) [1767959]
- [fs] revert "ceph: fix dentry leak in splice_dentry()" (Jeff Layton) [1767959]
- [fs] ceph: check snap first in ceph_set_acl() (Jeff Layton) [1767959]
- [block] rbd: add __init/__exit annotations (Jeff Layton) [1767959]
- [fs] ceph: reset cap hold timeout only for requeued inode (Jeff Layton) [1767959]
- [fs] ceph: don't drop message if it contains more data than expected (Jeff Layton) [1767959]
- [fs] ceph: support cephfs' own feature bits (Jeff Layton) [1767959]
- [net] crush: fix using plain integer as NULL warning (Jeff Layton) [1767959]
- [net] libceph: remove unnecessary non NULL check for request_key (Jeff Layton) [1767959]
- [fs] ceph: refactor error handling code in ceph_reserve_caps() (Jeff Layton) [1767959]
- [fs] ceph: refactor ceph_unreserve_caps() (Jeff Layton) [1767959]
- [fs] ceph: change to void return type for __do_request() (Jeff Layton) [1767959]
- [fs] ceph: compare fsc->max_file_size and inode->i_size for max file size limit (Jeff Layton) [1767959]
- [fs] ceph: add additional size check in ceph_setattr() (Jeff Layton) [1767959]
- [fs] ceph: add additional offset check in ceph_write_iter() (Jeff Layton) [1767959]
- [fs] ceph: add additional range check in ceph_fallocate() (Jeff Layton) [1767959]
- [fs] ceph: add new field max_file_size in ceph_fs_client (Jeff Layton) [1767959]
- [net] ceph: fix whitespace (Jeff Layton) [1767959]
- [fs] ceph: adding new return type vm_fault_t (Jeff Layton) [1767959]
- [kernel] libceph: remove now unused ceph_{en, de}code_timespec() (Jeff Layton) [1767959]
- [fs] ceph: use timespec64 for r_stamp (Jeff Layton) [1767959]
- [fs] libceph: use timespec64 for r_mtime (Jeff Layton) [1767959]
- [fs] ceph: use timespec64 for inode timestamp (Jeff Layton) [1767959]
- [fs] ceph: stop using current_kernel_time() (Jeff Layton) [1767959]
- [net] libceph: use timespec64 in for keepalive2 and ticket validity (Jeff Layton) [1767959]
- [fs] ceph: add d_drop for some error cases in ceph_symlink() (Jeff Layton) [1767959]
- [fs] ceph: add d_drop for some error cases in ceph_mknod() (Jeff Layton) [1767959]
- [fs] ceph: return errors from posix_acl_equiv_mode() correctly (Jeff Layton) [1767959]
- [net] libceph: amend "bad option arg" error message (Jeff Layton) [1767959]
- [net] libceph: stop parsing when a bad int arg is detected (Jeff Layton) [1767959]
- [kernel] libceph: change ceph_pagelist_encode_string() to take u32 (Jeff Layton) [1767959]
- [net] libceph: make ceph_osdc_notify{, _ack}() payload_len u32 (Jeff Layton) [1767959]
- [fs] ceph: restore ctime as well in the case of restoring old mode (Jeff Layton) [1767959]
- [fs] ceph: add retry logic for error -ERANGE in ceph_get_acl() (Jeff Layton) [1767959]

* Tue Nov 26 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-153.rt13.10.el8]
- [tools] objtool: Support repeated uses of the same C jump table (Yauheni Kaliuta) [1747617]
- [tools] objtool: Refactor jump table code (Yauheni Kaliuta) [1747617]
- [tools] objtool: Fix sibling call detection (Yauheni Kaliuta) [1747617]
- [tools] objtool: Add --backtrace support (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Improve handling of corrupted ELF during map initialization (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix negative FD close() in xsk_setup_xdp_prog() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Change size to u64 for bpf_map_{area_alloc, charge_init}() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: Fix btf_dump padding test case (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix struct end padding in btf_dump (Yauheni Kaliuta) [1747617]
- [tools] bpf: Allow narrow loads of bpf_sysctl fields with offset > 0 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: move "__printf()" attributes to header file (Yauheni Kaliuta) [1747617]
- [media] bpf: media: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix format string for p_err() in detect_common_prefix() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix argument for p_err() in BTF do_dump() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix arguments for p_err() in do_event_pipe() (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix format strings and arguments for jsonw_printf() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking of stack slots (Yauheni Kaliuta) [1747617]
- [kernel] bpf: handle 32-bit zext during constant blinding (Yauheni Kaliuta) [1747617]
- [net] bpf: allow narrow loads of some sk_reuseport_md fields with offset > 0 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking in presence of bpf2bpf calls (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add config fragment BPF_JIT (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_btf_dump with O= (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_cgroup_storage on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: close prog FD before exit on showing a single program (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix "bind{4, 6} deny specific IP & port" on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools infrastructure (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add error message on pin failure (Yauheni Kaliuta) [1747617]
- [tools] bpftool: fix error message (prog -> object) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: tests for jmp to 1st insn (Yauheni Kaliuta) [1747617]
- [x86] bpf: fix x64 JIT code generation for jmp to 1st insn (Yauheni Kaliuta) [1747617]
- [tools] libbpf: set BTF FD for prog only when there is supported .BTF.ext data (Yauheni Kaliuta) [1747617]
- [tools] libbpf : make libbpf_num_possible_cpus function thread safe (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix missing __WORDSIZE definition (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix erroneous multi-closing of BTF FD (Yauheni Kaliuta) [1747617]
- [tools] libbpf: silence GCC8 warning about string truncation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add another gso_segs access (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix sendmsg6_prog on s390 (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Avoid designated initializers for unnamed union members (Yauheni Kaliuta) [1747617]
- [tools] libbpf: Fix endianness macro usage for some compilers (Yauheni Kaliuta) [1747617]
- [tools] libbpf: sanitize VAR to conservative 1-byte INT (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix SIGSEGV when BTF loading fails, but .BTF.ext exists (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_xdp_noinline on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix "valid read map access into a read-only array 1" on s390 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Disable GCC -fgcse optimization for ___bpf_prog_run() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix perf_buffer on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: structure test_{progs, maps, verifier} test runners uniformly (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_verifier/test_maps make dependencies (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix another GCC8 warning for strncpy (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: skip nmi test when perf hw events are disabled (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: remove logic duplication in test_verifier (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add selftests for wide loads (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: rename verifier/wide_store.c to verifier/wide_access.c (Yauheni Kaliuta) [1747617]
- [net] bpf: allow wide aligned loads for bpf_sock_addr user_ip6 and msg_src_ip6 (Yauheni Kaliuta) [1747617]
- [samples] bpf: build with -D__TARGET_ARCH_$(SRCARCH) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: put test_stub.o into $(OUTPUT) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: make directory prerequisites order-only (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix attach_probe on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: use typedef'ed arrays as map values (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add trickier size resolution tests (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix BTF verifier size resolution logic (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix compiling loop{1, 2, 3}.c on s390 (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: make PT_REGS_* work in userspace (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix s930 -> s390 typo (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: compile progs with -D__TARGET_ARCH_$(SRCARCH) (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: do not ignore clang failures (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: avoid fall-through warnings (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix bpf_target_sparc check (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix ptr to u64 conversion warning on 32-bit platforms (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision bit propagation for BPF_ST instructions (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Fix ORC unwinding in non-JIT BPF code (Yauheni Kaliuta) [1747617]
- [tools] objtool: Add support for C jump tables (Yauheni Kaliuta) [1747617]
- [tools] objtool: Don't use ignore flag for fake jumps (Yauheni Kaliuta) [1747617]
- [tools] objtool: Support per-function rodata sections (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_reuseport_array on s390 (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add completion for bpftool prog "loadall" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup: Fix build error without CONFIG_NET (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_attach_probe map definition (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add verifier tests for wide stores (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add perf_buffer_ prefix to README (Yauheni Kaliuta) [1747617]
- [tools] bpftool: switch map event_pipe to libbpf's perf_buffer (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test perf buffer API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: auto-set PERF_EVENT_ARRAY size to number of CPUs (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add perf buffer API (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add test_tcp_rtt to .gitignore (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix test_align liveliness expectations (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add "prog run" subcommand to test-run programs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert legacy BPF maps to BTF-defined ones (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert selftests using BTF-defined maps to new syntax (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add __uint and __type macro for BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] libbpf: capture value in BTF type info for BTF-defined map defs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert existing tracepoint tests to new APIs (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add kprobe/uprobe selftests (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: switch test to new attach_perf_event API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add raw tracepoint attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add tracepoint attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add kprobe/uprobe attach API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add ability to attach/detach BPF program to perf event (Yauheni Kaliuta) [1747617]
- [tools] libbpf: introduce concept of bpf_link (Yauheni Kaliuta) [1747617]
- [tools] libbpf: make libbpf_strerror_r agnostic to sign of error (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: fix inlines in test_lwt_seg6local (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: standardize to static __always_inline (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add support for fq's EDT to HBM (Yauheni Kaliuta) [1747617]
- [tools] bpf, libbpf, smatch: Fix potential NULL pointer dereference (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix GCC8 warning for strncpy (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: add tests for shifts by zero (Yauheni Kaliuta) [1747617]
- [x86] bpf, x32: Fix bug with ALU64 {LSH, RSH, ARSH} BPF_K shift by 0 (Yauheni Kaliuta) [1747617]
- [x86] bpf, x32: Fix bug with ALU64 {LSH, RSH, ARSH} BPF_X shift by 0 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix precision tracking (Yauheni Kaliuta) [1747617]
- [tools] bpf: fix uapi bpf_prog_info fields alignment (Yauheni Kaliuta) [1747617]
- [kernel] devmap: Allow map lookups from eBPF (Yauheni Kaliuta) [1747617]
- [net] bpf_xdp_redirect_map: Perform map lookup in eBPF helper (Yauheni Kaliuta) [1747617]
- [net] devmap: Rename ifindex member in bpf_redirect_info (Yauheni Kaliuta) [1747617]
- [kernel] devmap/cpumap: Use flush list instead of bitmap (Yauheni Kaliuta) [1747617]
- [kernel] xskmap: Move non-standard list manipulation to helper (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix -Wstrict-aliasing in test_sockopt_sk.c (Yauheni Kaliuta) [1747617]
- [tools] bpftool: support cgroup sockopt (Yauheni Kaliuta) [1747617]
- [documentation] bpf: add sockopt documentation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test that exercises BPF_F_ALLOW_MULTI (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test that exercises sk helpers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add sockopt test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test sockopt section name (Yauheni Kaliuta) [1747617]
- [tools] libbpf: support sockopt hooks (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1747617]
- [kernel] bpf: implement getsockopt and setsockopt hooks (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix cgroup bpf release synchronization (Yauheni Kaliuta) [1747617]
- [samples] bpf: make the use of xdp samples consistent (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix BPF_ALU32 | BPF_ARSH on BE arches (Yauheni Kaliuta) [1747617]
- [tools] bpftool: use correct argument in cgroup errors (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix compiler warning with CONFIG_MODULES=n (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: build tests with debug info (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix max() type mismatch for 32bit (Yauheni Kaliuta) [1747617]
- [trace] xdp: Add tracepoint for bulk XDP_TX (Yauheni Kaliuta) [1747617]
- [tools] selftests, bpf: Add test for veth native XDP (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix spelling mistake "conflictling" -> "conflicting" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: precise scalar_value tracking (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add realistic loop tests (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add basic verifier tests for loops (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix tests (Yauheni Kaliuta) [1747617]
- [kernel] bpf: fix callees pruning callers (Yauheni Kaliuta) [1747617]
- [kernel] bpf: introduce bounded loops (Yauheni Kaliuta) [1747617]
- [kernel] bpf: extend is_branch_taken to registers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix tests due to const spill/fill (Yauheni Kaliuta) [1747617]
- [kernel] bpf: track spill/fill of constants (Yauheni Kaliuta) [1747617]
- [tools] libbpf: constify getter APIs (Yauheni Kaliuta) [1747617]
- [samples] bpf: refactor header include path (Yauheni Kaliuta) [1747617]
- [samples] bpf: remove unnecessary include options in Makefile (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert tests w/ custom values to BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: switch BPF_ANNOTATE_KV_PAIR tests to BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add test for BTF-defined maps (Yauheni Kaliuta) [1747617]
- [tools] libbpf: allow specifying map definitions using BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: split initialization and loading of BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: identify maps by section index in addition to offset (Yauheni Kaliuta) [1747617]
- [tools] libbpf: refactor map initialization (Yauheni Kaliuta) [1747617]
- [tools] libbpf: streamline ELF parsing error-handling (Yauheni Kaliuta) [1747617]
- [tools] libbpf: extract BTF loading logic (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add common min/max macro to libbpf_internal.h (Yauheni Kaliuta) [1747617]
- [net] bpf: fix the check that forwarding is enabled in bpf_ipv6_fib_lookup (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Fix build error without CONFIG_INET (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert socket_cookie test to sk storage (Yauheni Kaliuta) [1747617]
- [tools] bpf/tools: sync bpf.h (Yauheni Kaliuta) [1747617]
- [net] bpf: export bpf_sock for BPF_PROG_TYPE_SOCK_OPS prog type (Yauheni Kaliuta) [1747617]
- [net] bpf: export bpf_sock for BPF_PROG_TYPE_CGROUP_SOCK_ADDR prog type (Yauheni Kaliuta) [1747617]
- [tools] bpf: Add test for SO_REUSEPORT_DETACH_BPF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix check for presence of associated BTF for map creation (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: signedness bug in enable_all_controllers() (Yauheni Kaliuta) [1747617]
- [samples] bpf: fix include path in Makefile (Yauheni Kaliuta) [1747617]
- [kernel] bpf: silence warning messages in core (Yauheni Kaliuta) [1747617]
- [tools] bpf: use libbpf_num_possible_cpus internally (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: remove bpf_util.h from BPF C progs (Yauheni Kaliuta) [1747617]
- [tools] bpf: add a new API libbpf_num_possible_cpus() (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf : clean up feature/ when make clean (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fix constness of source arg for bpf helpers (Yauheni Kaliuta) [1747617]
- [samples] bpf: don't run probes at the local make stage (Yauheni Kaliuta) [1747617]
- [tools] libbpf: remove qidconf and better support external bpf programs (Yauheni Kaliuta) [1747617]
- [tools] bpf: Add bpf_map_lookup_elem selftest for xskmap (Yauheni Kaliuta) [1747617]
- [tools] bpf/tools: sync bpf.h (Yauheni Kaliuta) [1747617]
- [net] bpf: Allow bpf_map_lookup_elem() on an xskmap (Yauheni Kaliuta) [1747617]
- [documentation] docs: bpf: get rid of two warnings (Yauheni Kaliuta) [1747617]
- [net] bpf: allow CGROUP_SKB programs to use bpf_skb_cgroup_id() helper (Yauheni Kaliuta) [1747617]
- [samples] bpf: print a warning about headers_install (Yauheni Kaliuta) [1747617]
- [kernel] bpf: remove redundant assignment to err (Yauheni Kaliuta) [1747617]
- [samples] bpf: hbm: fix spelling mistake "notifcations" -> "notificiations" (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: measure RTT from xdp using xdping (Yauheni Kaliuta) [1747617]
- [documentation] bpf: doc: update answer for 32-bit subregister question (Yauheni Kaliuta) [1747617]
- [kernel] bpf: move memory size checks to bpf_map_charge_init() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: rework memlock-based memory accounting for maps (Yauheni Kaliuta) [1747617]
- [kernel] bpf: group memory related fields in struct bpf_map_memory (Yauheni Kaliuta) [1747617]
- [net] bpf: add memlock precharge for socket local storage (Yauheni Kaliuta) [1747617]
- [kernel] bpf: add memlock precharge check for cgroup_local_storage (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add more stats to HBM (Yauheni Kaliuta) [1747617]
- [samples] bpf: Add cn support to hbm_out_kern.c (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Update __cgroup_bpf_run_filter_skb with cn (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup inet skb programs can return 0 to 3 (Yauheni Kaliuta) [1747617]
- [kernel] bpf: Create BPF_PROG_CGROUP_INET_EGRESS_RUN_ARRAY (Yauheni Kaliuta) [1747617]
- [tools] libbpf: reduce unnecessary line wrapping (Yauheni Kaliuta) [1747617]
- [tools] libbpf: typo and formatting fixes (Yauheni Kaliuta) [1747617]
- [tools] libbpf: simplify two pieces of logic (Yauheni Kaliuta) [1747617]
- [tools] libbpf: use negative fd to specify missing BTF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix error code returned on corrupted ELF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: check map name retrieved from ELF (Yauheni Kaliuta) [1747617]
- [tools] libbpf: simplify endianness check (Yauheni Kaliuta) [1747617]
- [tools] libbpf: preserve errno before calling into user callback (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix detection of corrupted BPF instructions section (Yauheni Kaliuta) [1747617]
- [tools] libbpf: prevent overwriting of log_level in bpf_object__load_progs() (Yauheni Kaliuta) [1747617]
- [kernel] bpf: tracing: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cgroup: properly use bpf_prog_array api (Yauheni Kaliuta) [1747617]
- [kernel] bpf: remove __rcu annotations from bpf_prog_array (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add auto-detach test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: enable all available cgroup v2 controllers (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: convert test_cgrp2_attach2 example into kselftest (Yauheni Kaliuta) [1747617]
- [samples] bpf: fix a couple of style issues in bpf_load (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: fail test_tunnel.sh if subtests fail (Yauheni Kaliuta) [1747617]
- [tools] bpftool: make -d option print debug output from verifier (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add bpf_object__load_xattr() API function to pass log_level (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add -d option to get debug output from libbpf (Yauheni Kaliuta) [1747617]
- [tools] libbpf: fix warning that PTR_ERR_OR_ZERO can be used (Yauheni Kaliuta) [1747617]
- [tools] bpf: style fix in while(!feof()) loop (Yauheni Kaliuta) [1747617]
- [kernel] bpf: check signal validity in nmi for bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpftool: auto-complete BTF IDs for btf dump (Yauheni Kaliuta) [1747617]
- [samples] bpf: add ibumad sample to .gitignore (Yauheni Kaliuta) [1747617]
- [x86] x32: bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [s390] bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [powerpc] bpf: eliminate zero extension code-gen (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: enable hi32 randomization for all tests (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: adjust several test_verifier helpers for insn insertion (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add "prog_flags" to bpf_program/bpf_prog_load_attr/bpf_load_program_attr (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: randomize high 32-bit when BPF_F_TEST_RND_HI32 is set (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync uapi header bpf.h (Yauheni Kaliuta) [1747617]
- [uapi] bpf: introduce new bpf prog load flags "BPF_F_TEST_RND_HI32" (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: insert zero extension according to analysis result (Yauheni Kaliuta) [1747617]
- [kernel] bpf: introduce new mov32 variant for doing explicit zero extension (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: mark patched-insn with sub-register zext flag (Yauheni Kaliuta) [1747617]
- [kernel] bpf: verifier: mark verified-insn with sub-register zext flag (Yauheni Kaliuta) [1747617]
- [tools] bpf: add selftest in test_progs for bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpf: sync bpf uapi header bpf.h to tools directory (Yauheni Kaliuta) [1747617]
- [kernel] bpf: implement bpf_send_signal() helper (Yauheni Kaliuta) [1747617]
- [tools] bpftool: update bash-completion w/ new c option for btf dump (Yauheni Kaliuta) [1747617]
- [tools] bpftool/docs: add description of btf dump C option (Yauheni Kaliuta) [1747617]
- [tools] bpftool: add C output format option to btf dump subcommand (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add btf_dump BTF-to-C conversion tests (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add btf_dump API for BTF-to-C conversion (Yauheni Kaliuta) [1747617]
- [tools] libbpf: switch btf_dedup() to hashmap for dedup table (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add tests for libbpf's hashmap (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add resizable non-thread safe internal hashmap (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: use btf__parse_elf to check presence of BTF/BTF.ext (Yauheni Kaliuta) [1747617]
- [tools] bpftool: use libbpf's btf__parse_elf API (Yauheni Kaliuta) [1747617]
- [tools] libbpf: add btf__parse_elf API to load .BTF and .BTF.ext (Yauheni Kaliuta) [1747617]
- [tools] libbpf: ensure libbpf.h is included along libbpf_internal.h (Yauheni Kaliuta) [1747617]
- [samples] bpf: Do not define bpf_printk macro (Yauheni Kaliuta) [1747617]
- [tools] selftests: bpf: Move bpf_printk to bpf_helpers.h (Yauheni Kaliuta) [1747617]
- [kernel] bpf: convert explored_states to hash table (Yauheni Kaliuta) [1747617]
- [kernel] bpf: split explored_states (Yauheni Kaliuta) [1747617]
- [kernel] bpf: cleanup explored_states (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: add pyperf scale test (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: adjust verifier scale test (Yauheni Kaliuta) [1747617]
- [kernel] bpf: bump jmp sequence limit (Yauheni Kaliuta) [1747617]
- [tools] libbpf: emit diff of mismatched public API, if any (Yauheni Kaliuta) [1747617]
- [tools] bpf, selftest: test global data/bss/rodata sections (Yauheni Kaliuta) [1747617]
- [tools] selftests/bpf: test_tc_tunnel: skip unsupported tests (Jiri Benc) [1749814]
- [tools] selftests/bpf: More compatible nc options in test_tc_edt (Jiri Benc) [1749814]
- [net] xdp: check device pointer before clearing (Jiri Benc) [1749814]
- [net] bpf: udp: Avoid calling reuseport's bpf_prog from udp_gro (Jiri Benc) [1749814]
- [net] bpf: sockmap, fix use after free from sleep in psock backlog workqueue (Jiri Benc) [1749814]
- [include] bpf: sockmap, restore sk_write_space when psock gets dropped (Jiri Benc) [1749814]
- [net] bpfilter: fallback to netfilter if failed to load bpfilter kernel module (Jiri Benc) [1749814]
- [net] pass net_device argument to the eth_get_headlen (Jiri Benc) [1749814]
- [net] flow_dissector: handle no-skb use case (Jiri Benc) [1749814]
- [net] plumb network namespace into __skb_flow_dissect (Jiri Benc) [1749814]
- [net] bpfilter: dont use module_init in non-modular code (Jiri Benc) [1749814]
- [net] xsk: fix XDP socket ring buffer memory ordering (Jiri Benc) [1749814]
- [tools] selftests/bpf: install files test_xdp_vlan.sh (Jiri Benc) [1749814]
- [net] fix bpf_xdp_adjust_head regression for generic-XDP (Jiri Benc) [1749814]
- [tools] selftests/bpf: reduce time to execute test_xdp_vlan.sh (Jiri Benc) [1749814]
- [tools] selftests/bpf: add wrapper scripts for test_xdp_vlan.sh (Jiri Benc) [1749814]
- [tools] bpf: fix XDP vlan selftests test_xdp_vlan.sh (Jiri Benc) [1749814]
- [net] core: support XDP generic on stacked devices. (Jiri Benc) [1749814]
- [netdrv] netvsc: unshare skb in VF rx handler (Jiri Benc) [1749814]
- [net] convert rps_needed and rfs_needed to new static branch api (Jiri Benc) [1749814]
- [net] core: Document __skb_flow_dissect() flags argument (Jiri Benc) [1749814]
- [net] gso: Fix skb_segment splat when splitting gso_size mangled skb having linear-headed frag_list (Jiri Benc) [1749814]
- [net] sock_map, fix missing ulp check in sock hash case (Jiri Benc) [1749814]
- [net] Fix missing meta data in skb with vlan packet (Jiri Benc) [1749814]
- [include] skbuff.h: fix using plain integer as NULL warning (Jiri Benc) [1749814]
- [netdrv] netdevsim: Fix error handling in nsim_fib_init and nsim_fib_exit (Jiri Benc) [1761359]
- [netdrv] netdevsim: Restore per-network namespace accounting for fib entries (Jiri Benc) [1761359]
- [netdrv] netdevsim: Make nsim_num_vf static (Jiri Benc) [1761359]
- [netdrv] netdevsim: fix fall-through annotation (Jiri Benc) [1761359]
- [netdrv] netdevsim: implement ndo_get_devlink_port (Jiri Benc) [1761359]
- [netdrv] netdevsim: move netdev creation/destruction to dev probe (Jiri Benc) [1761359]
- [netdrv] netdevsim: extend device attrs to support port addition and deletion (Jiri Benc) [1761359]
- [netdrv] netdevsim: implement dev probe/remove skeleton with port initialization (Jiri Benc) [1761359]
- [netdrv] netdevsim: change debugfs tree topology (Jiri Benc) [1761359]
- [netdrv] netdevsim: generate random switch id instead of using dev id (Jiri Benc) [1761359]
- [netdrv] netdevsim: merge sdev into dev (Jiri Benc) [1761359]
- [netdrv] netdevsim: rename dev_init/exit() functions and make them independent on ns (Jiri Benc) [1761359]
- [netdrv] netdevsim: add bus attributes to add new and delete devices (Jiri Benc) [1761359]
- [netdrv] netdevsim: use ida for bus device ids (Jiri Benc) [1761359]
- [netdrv] netdevsim: add stub netdevsim driver implementation (Jiri Benc) [1761359]
- [netdrv] netdevsim: move device registration and related code to bus.c (Jiri Benc) [1761359]
- [netdrv] netdevsim: put netdevsim bus code into separate file (Jiri Benc) [1761359]
- [netdrv] netdevsim: rename devlink.c to dev.c to contain per-dev(asic) items (Jiri Benc) [1761359]
- [netdrv] netdevsim: create devlink instance per netdevsim instance (Jiri Benc) [1761359]
- [netdrv] netdevsim: move device registration on bus to be done earlier in init (Jiri Benc) [1761359]
- [netdrv] netdevsim: move sdev-specific init/uninit code into separate functions (Jiri Benc) [1761359]
- [netdrv] netdevsim: make bpf_offload_dev_create() per-sdev instead of first ns (Jiri Benc) [1761359]
- [netdrv] netdevsim: move shared dev creation and destruction into separate file (Jiri Benc) [1761359]
- [netdrv] netdevsim: let net core to free netdevsim netdev (Jiri Benc) [1761359]
- [netdrv] netdevsim: remove nsim_dellink() implementation (Jiri Benc) [1761359]
- [include] driver core: add BUS_ATTR_WO() macro (Jiri Benc) [1761359]
- arm64: bpf: do not allocate executable memory (Yauheni Kaliuta) [1762214]
- modules: page-align module section allocations only for arches supporting strict module rwx (Yauheni Kaliuta) [1762214]
- modules: always page-align module section allocations (Yauheni Kaliuta) [1762214]
- modules: fix compile error if don't have strict module rwx (Yauheni Kaliuta) [1762214]
- modules: Use vmalloc special flag (Yauheni Kaliuta) [1762214]
- modules: fix BUG when load module with rodata=n (Yauheni Kaliuta) [1762214]
- x86/modules: Avoid breaking W^X while loading modules (Yauheni Kaliuta) [1762214]
- x86/alternatives, jumplabel: Use text_poke_early() before mm_init() (Yauheni Kaliuta) [1762214]
- x86/kprobes: Set instruction page as executable (Yauheni Kaliuta) [1762214]
- x86/ftrace: Set trampoline pages as executa (Yauheni Kaliuta) [1762214]
- [tools] bpftool: Fix json dump crash on powerpc (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix race in flow dissector tests (Yauheni Kaliuta) [1747615]
- [arm64] insn: Fix ldadd instruction encoding (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: tolerate missing pahole when generating BTF (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: handle old pahole more gracefully when generating BTF (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: add ability to generate BTF type info for vmlinux (Yauheni Kaliuta) [1747615]
- [scripts] kbuild: hardcode genksyms path and remove GENKSYMS variable (Yauheni Kaliuta) [1747615]
- [scripts] bpf: fix script for generating man page on BPF helpers (Yauheni Kaliuta) [1747615]
- [tools] add smp_* barrier variants to include infrastructure (Yauheni Kaliuta) [1747615]
- [tools] tools headers barrier: Fix arm64 tools build failure wrt smp_load_{acquire, release} (Yauheni Kaliuta) [1747615]
- [tools] bpf, x32: Fix bug for BPF_JMP | {BPF_JSGT, BPF_JSLE, BPF_JSLT, BPF_JSGE} (Yauheni Kaliuta) [1747615]
- [x86] unwind/orc: Fall back to using frame pointers for generated code (Yauheni Kaliuta) [1747615]
- [x86] unwind: Add hardcoded ORC entry for NULL (Yauheni Kaliuta) [1747615]
- [x86] unwind: Handle NULL pointer calls better in frame unwinder (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix accessing bpf_sysctl.file_pos on s390 (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix narrower loads on s390 (Yauheni Kaliuta) [1747615]
- [net] bpf: rename bpf_ctx_wide_store_ok to bpf_ctx_wide_access_ok (Yauheni Kaliuta) [1747615]
- [net] bpf: allow wide (u64) aligned stores for some fields of bpf_sock_addr (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: improve unexpected success reporting in test_syctl (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix "ctx:write sysctl:write read ok" on s390 (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix format string for p_err() in query_flow_dissector() (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add raw_tracepoint_writable prog type to header (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix NULL deref in btf_type_is_resolve_source_only (Yauheni Kaliuta) [1747615]
- [net] bpf: Set sk_bpf_storage back to NULL for cloned sk (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix nested bpf tracepoints with per-cpu data (Yauheni Kaliuta) [1747615]
- [net] bpf: Fix out of bounds memory access in bpf_sk_storage (Yauheni Kaliuta) [1747615]
- [kernel] sysctl: define proc_do_static_key() (Yauheni Kaliuta) [1747615]
- [x86] bpf, x64: fix stack layout of JITed bpf code (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Add missing RCU read lock on flush (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Add missing bulk queue free (Yauheni Kaliuta) [1747615]
- [kernel] bpf, devmap: Fix premature entry free on destroying map (Yauheni Kaliuta) [1747615]
- [powerpc] bpf: use unsigned division instruction for 64-bit operations (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix div64 overflow tests to properly detect errors (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync BPF_FIB_LOOKUP flag changes with BPF uapi (Yauheni Kaliuta) [1747615]
- [uapi] bpf: simplify definition of BPF_FIB_LOOKUP related flags (Yauheni Kaliuta) [1747615]
- [tools] bpf: lpm_trie: check left child of last leftmost node for NULL (Yauheni Kaliuta) [1747615]
- [tools] bpf: expand section tests for test_section_names (Yauheni Kaliuta) [1747615]
- [tools] bpf: more msg_name rewrite tests to test_sock_addr (Yauheni Kaliuta) [1747615]
- [tools] bpf, bpftool: enable recvmsg attach types (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: enable recvmsg attach types (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync tooling uapi header (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix unconnected udp hooks (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Fix JSON output when lookup fails (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: move test_lirc_mode2_user to TEST_GEN_PROGS_EXTENDED (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Return btf_fd for load_sk_storage_btf (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix compiler warning in flow_dissector test (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: complete sub-register zero extension checks (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: move sub-register zero extension checks into subreg.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add zero extend checks for ALU32 and/or/xor (Yauheni Kaliuta) [1747615]
- [samples] bpf: suppress compiler warning (Yauheni Kaliuta) [1747615]
- [samples] bpf: fix to change the buffer size for read() (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix BTF raw dump of FWD's fwd_kind (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix bpf_get_current_task (Yauheni Kaliuta) [1747615]
- [tools] libbpf: move logging helpers into libbpf_internal.h (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add test_sysctl and map_tests/tests.h to .gitignore (Yauheni Kaliuta) [1747615]
- [kernel] bpf: relax inode permission check for retrieving bpf program (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add prog detach to flow_dissector test (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add missing \n to flow_dissector CHECK errors (Yauheni Kaliuta) [1747615]
- [tools] libbpf: don't fail when feature probing fails (Yauheni Kaliuta) [1747615]
- [tools] bpf: test ref bit from data path and add new tests for syscall path (Yauheni Kaliuta) [1747615]
- [kernel] bpf, lru: avoid messing with eviction heuristics upon syscall lookup (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add map_lookup_elem_sys_only for lookups from syscall side (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync kernel btf.h header (Yauheni Kaliuta) [1747615]
- [uapi] bpf: btf: fix the brackets of BTF_INT_OFFSET() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: devmap: fix use-after-free Read in __dev_map_entry_free (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix undefined behavior in narrow load handling (Yauheni Kaliuta) [1747615]
- [tools] libbpf: detect supported kernel BTF features and sanitize BTF (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: Add files generated after build to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix minor issues in documentation for BPF helpers (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix recurring typo in documentation for BPF helpers (Yauheni Kaliuta) [1747615]
- [tools] bpf: add various test cases for backward jumps (Yauheni Kaliuta) [1747615]
- [documentation] docs/btf: fix the missing section marks (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: initialize bpf_object pointers where needed (Yauheni Kaliuta) [1747615]
- [tools] libbpf: add libbpf_util.h to header install (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix perf build error with uClibc (seen on ARC) (Yauheni Kaliuta) [1747615]
- [tools] bpftool: exclude bash-completion/bpftool from .gitignore pattern (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: set RLIMIT_MEMLOCK properly for test_libbpf_open.c (Yauheni Kaliuta) [1747615]
- [net] bpf: Use PTR_ERR_OR_ZERO in bpf_fd_sk_storage_update_elem() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Use vmalloc special flag (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Fail bpf_probe_write_user() while mm is switched (Yauheni Kaliuta) [1747615]
- [kernel] mm/tlb: Provide default nmi_uaccess_okay() (Yauheni Kaliuta) [1747615]
- [kernel] asm-generic/tlb: Guard with #ifdef CONFIG_MMU (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add ene-to-end test for bpf_sk_storage_* helpers (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add BPF_MAP_TYPE_SK_STORAGE test to test_maps (Yauheni Kaliuta) [1747615]
- [tools] bpf: Add verifier tests for the bpf_sk_storage (Yauheni Kaliuta) [1747615]
- [tools] bpf: Refactor BTF encoding macro to test_btf.h (Yauheni Kaliuta) [1747615]
- [tools] bpf: Support BPF_MAP_TYPE_SK_STORAGE in bpf map probing (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools (Yauheni Kaliuta) [1747615]
- [net] bpf: Introduce bpf sk local storage (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: test writable buffers in raw tps (Yauheni Kaliuta) [1747615]
- [tools] sync bpf.h (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add writable context for raw tracepoints (Yauheni Kaliuta) [1747615]
- [arm64] bpf, arm64: use more scalable stadd over ldxr / stxr loop in xadd (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix indendation in bash-completion/bpftool (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add bash completions for btf command (Yauheni Kaliuta) [1747615]
- [tools] bpftool/docs: add btf sub-command documentation (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add ability to dump BTF types (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Fix errno variable usage (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show flow_dissector attachment status (Yauheni Kaliuta) [1747615]
- [net] bpf: support BPF_PROG_QUERY for BPF_FLOW_DISSECTOR attach_type (Yauheni Kaliuta) [1747615]
- [samples] bpf: add hbm sample to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix samples/bpf build failure due to undefined UINT32_MAX (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: fix segfault in bpf_object__init_maps' pr_debug statement (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: handle old kernels more graceful wrt global data sections (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand test_tc_tunnel with SIT encap (Yauheni Kaliuta) [1747615]
- [net] bpf: update skb->protocol in bpf_skb_net_grow (Yauheni Kaliuta) [1747615]
- [tools] bpf/flow_dissector: don't adjust nhoff by ETH_HLEN in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: properly return error from bpf_flow_load (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: run flow dissector tests in skb-less mode (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add flow dissector bpf_skb_load_bytes helper test (Yauheni Kaliuta) [1747615]
- [net] bpf: when doing BPF_PROG_TEST_RUN for flow dissector use no-skb mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: drop bpf_verifier_lock (Yauheni Kaliuta) [1747615]
- [kernel] bpf: remove global variables (Yauheni Kaliuta) [1747615]
- [documentation] bpf: document the verifier limits (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix BPF_LOG_BUF_SIZE off-by-one error (Yauheni Kaliuta) [1747615]
- [documentation] bpf: move BPF_PROG_TYPE_FLOW_DISSECTOR documentation to a new common place (Yauheni Kaliuta) [1747615]
- [tools] bpf: Increase MAX_NR_MAPS to 17 in test_verifier.c (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix compile errors due to unsync linux/in6.h and netinet/in.h (Yauheni Kaliuta) [1747615]
- [documentation] bpf: Document BPF_PROG_TYPE_CGROUP_SYSCTL (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: fix a compilation error (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap memory prefetchw optimizations for struct page (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap do bulk allocation of SKBs (Yauheni Kaliuta) [1747615]
- [net] core: introduce build_skb_around (Yauheni Kaliuta) [1747615]
- [kernel] bpf: cpumap use ptr_ring_consume_batched (Yauheni Kaliuta) [1747615]
- [tools] libbpf: optimize barrier for XDP socket rings (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show btf_id in map listing (Yauheni Kaliuta) [1747615]
- [tools] bpftool: re-organize newline printing for map listing (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Support sysctl hook (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix printf formatter for ptrdiff_t argument (Yauheni Kaliuta) [1747615]
- [kernel] bpf: use BPF_CAST_CALL for casting bpf call (Yauheni Kaliuta) [1747615]
- [uapi] bpf: allow clearing all sock_ops callback flags (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add VRF test cases to lwt_ip_encap test (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: make flow dissector tests more extensible (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: two scale tests (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Improve handling of ENOSPC on reuseport_array map dumps (Yauheni Kaliuta) [1747615]
- [tools] bpftool: Use print_entry_error() in case of ENOENT when dumping (Yauheni Kaliuta) [1747615]
- [tools] bpftool: add a note on program statistics in man page (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix short option name for printing version in man pages (Yauheni Kaliuta) [1747615]
- [tools] bpftool: fix man page documentation for "pinmaps" keyword (Yauheni Kaliuta) [1747615]
- [tools] bpftool: reset errno for "bpftool cgroup tree" (Yauheni Kaliuta) [1747615]
- [tools] bpftool: remove blank line after btf_id when listing programs (Yauheni Kaliuta) [1747615]
- [net] bpf: reserve flags in bpf_skb_net_shrink (Yauheni Kaliuta) [1747615]
- [tools] bpf: fix whitespace for ENCAP_L2 defines in bpf.h (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: bring back (void *) cast to set_ipv4_csum in test_tc_tunnel (Yauheni Kaliuta) [1747615]
- [tools] selftests/btf: add VAR and DATASEC case for dedup tests (Yauheni Kaliuta) [1747615]
- [tools] btf: add support for VAR and DATASEC in btf_dedup() (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor "check_reg_arg" to eliminate code redundancy (Yauheni Kaliuta) [1747615]
- [kernel] bpf: factor out reg and stack slot propagation into "propagate_liveness_reg" (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor propagate_liveness to eliminate code redundance (Yauheni Kaliuta) [1747615]
- [kernel] bpf: refactor propagate_liveness to eliminate duplicated for loop (Yauheni Kaliuta) [1747615]
- [netdrv] netdevsim: move sdev specific bpf debugfs files to sdev dir (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Fix distinct pointer types warning for ARCH=i386 (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: C based test for sysctl and strtoX (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_strtol and bpf_strtoul helpers (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test ARG_PTR_TO_LONG arg type (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Add sysctl and strtoX helpers to bpf_helpers.h (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_strtol and bpf_strtoul helpers (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce ARG_PTR_TO_{INT,LONG} arg types (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test file_pos field in bpf_sysctl ctx (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_sysctl_{get, set}_new_value helpers (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test sysctl_get_current_value helper (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test bpf_sysctl_get_name helper (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test BPF_CGROUP_SYSCTL (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test sysctl section name (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Support sysctl hook (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add file_pos field to bpf_sysctl ctx (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_{get, set}_new_value helpers (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_get_current_value helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Introduce bpf_sysctl_get_name helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Sysctl hook (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add base proto function for cgroup-bpf programs (Yauheni Kaliuta) [1747615]
- [net] bpf: explicitly prohibit ctx_{in, out} in non-skb BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] selftests_bpf: add L2 encap to test_tc_tunnel (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync bpf.h to tools/ for BPF_F_ADJ_ROOM_ENCAP_L2 (Yauheni Kaliuta) [1747615]
- [net] bpf: add layer 2 encap support to bpf_skb_adjust_room (Yauheni Kaliuta) [1747615]
- [tools] selftests_bpf: extend test_tc_tunnel for UDP encap (Yauheni Kaliuta) [1747615]
- [kernel] bpf: fix missing bpf_check_uarg_tail_zero in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [s390] Convert IS_ENABLED uses to __is_defined (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: add selftest for __sk_buff context in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] libbpf: add support for ctx_{size, }_{in, out} in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [net] bpf: support input __sk_buff context in BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747615]
- [tools] bpftool: show btf id in program information (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Fix build with gcc-8 (Yauheni Kaliuta) [1747615]
- [tools] libbpf: fix crash in XDP socket part with new larger BPF_LOG_BUF_SIZE (Yauheni Kaliuta) [1747615]
- [tools] bpf, bpftool: fix a few ubsan warnings (Yauheni Kaliuta) [1747615]
- [tools] bpf, selftest: add test cases for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [tools] bpf, selftest: test {rd, wr}only flags and direct value access (Yauheni Kaliuta) [1747615]
- [tools] bpf: bpftool support for dumping data/bss/rodata sections (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: add support for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: support global data/bss/rodata sections (Yauheni Kaliuta) [1747615]
- [tools] bpf, libbpf: refactor relocation handling (Yauheni Kaliuta) [1747615]
- [tools] bpf: sync {btf, bpf}.h uapi header from tools infrastructure (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow for key-less BTF in array map (Yauheni Kaliuta) [1747615]
- [kernel] bpf: kernel side support for BTF Var and DataSec (Yauheni Kaliuta) [1747615]
- [documentation] bpf: add specification for BTF Var and DataSec kinds (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow . char as part of the object name (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add syscall side map freeze support (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add program side {rd, wr}only support for maps (Yauheni Kaliuta) [1747615]
- [kernel] bpf: do not retain flags that are not tied to map lifetime (Yauheni Kaliuta) [1747615]
- [kernel] bpf: implement lookup-free direct value access for maps (Yauheni Kaliuta) [1747615]
- [net] ipv6: Add neighbor helpers that use the ipv6 stub (Yauheni Kaliuta) [1747615]
- [tools] libbpf: Ignore -Wformat-nonliteral warning (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Add missed newline in verifier verbose log (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test unbounded var_off stack access (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Sanity check max value for var_off stack access (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test indirect var_off stack access in unpriv mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Reject indirect var_off stack access in unpriv mode (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test indirect var_off stack access in raw mode (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Reject indirect var_off stack access in raw mode (Yauheni Kaliuta) [1747615]
- [samples] bpf: fix build with new clang (Yauheni Kaliuta) [1747615]
- [samples] selftests/bpf: add NULL check for ksym_search (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: ksym_search won't check symbols exists (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: synthetic tests to push verifier limits (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add few verifier scale tests (Yauheni Kaliuta) [1747615]
- [tools] libbpf: teach libbpf about log_level bit 2 (Yauheni Kaliuta) [1747615]
- [kernel] bpf: increase verifier log limit (Yauheni Kaliuta) [1747615]
- [kernel] bpf: increase complexity limit and maximum program size (Yauheni Kaliuta) [1747615]
- [kernel] bpf: verbose jump offset overflow check (Yauheni Kaliuta) [1747615]
- [kernel] bpf: convert temp arrays to kvcalloc (Yauheni Kaliuta) [1747615]
- [kernel] bpf: improve verification speed by not remarking live_read (Yauheni Kaliuta) [1747615]
- [kernel] bpf: improve verification speed by droping states (Yauheni Kaliuta) [1747615]
- [kernel] bpf: add verifier stats and log_level bit 2 (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: remove duplicate .flags initialization in ctx_skb.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix -Wformat-invalid-specifier for bpf_obj_id.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: fix -Wformat-security warning for flow_dissector_load.c (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: tests.h should depend on .c files, not the output (Yauheni Kaliuta) [1747615]
- [tools] bpf: add bpffs multi-dimensional array tests in test_btf (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Test variable offset stack access (Yauheni Kaliuta) [1747615]
- [kernel] bpf: Support variable offset stack access from helpers (Yauheni Kaliuta) [1747615]
- [net] ipv6: Move ipv6 stubs to a separate header file (Yauheni Kaliuta) [1747615]
- [tools] bpf: generate pkg-config file for libbpf (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: don't depend on hardcoded perf sample_freq (Yauheni Kaliuta) [1747615]
- [tools] bpf: test_tc_tunnel.sh needs reverse path filtering disabled (Yauheni Kaliuta) [1747615]
- [tools] selftests: bpf: tc-bpf flow shaping with EDT (Yauheni Kaliuta) [1747615]
- [net] bpf: make bpf_skb_ecn_set_ce callable from BPF_PROG_TYPE_SCHED_ACT (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to encap modes (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to BPF_F_ADJ_ROOM_FIXED_GSO (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: convert bpf tunnel test to BPF_ADJ_ROOM_MAC (Yauheni Kaliuta) [1747615]
- [tools] bpf: Sync bpf.h to tools (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room encap flags (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room flag BPF_F_ADJ_ROOM_FIXED_GSO (Yauheni Kaliuta) [1747615]
- [net] bpf: add bpf_skb_adjust_room mode BPF_ADJ_ROOM_MAC (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: extend bpf tunnel test with tso (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: extend bpf tunnel test with gre (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand bpf tunnel test to ipv6 (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: expand bpf tunnel test with decap (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: bpf tunnel encap test (Yauheni Kaliuta) [1747615]
- [net] bpf: in bpf_skb_adjust_room avoid copy in tx fast path (Yauheni Kaliuta) [1747615]
- [samples] bpf: add xdp_sample_pkts to .gitignore (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: add tests for bpf_tcp_check_syncookie and bpf_skc_lookup_tcp (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: test references to sock_common (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: allow specifying helper for BPF_SK_LOOKUP (Yauheni Kaliuta) [1747615]
- [tools] update uapi/linux/bpf.h (Yauheni Kaliuta) [1747615]
- [net] bpf: add helper to check for a valid SYN cookie (Yauheni Kaliuta) [1747615]
- [net] bpf: add skc_lookup_tcp helper (Yauheni Kaliuta) [1747615]
- [kernel] bpf: allow helpers to return PTR_TO_SOCK_COMMON (Yauheni Kaliuta) [1747615]
- [kernel] bpf: track references based on is_acquire_func (Yauheni Kaliuta) [1747615]
- [tools] selftests/bpf: Add arm target register definitions (Yauheni Kaliuta) [1747615]
- [documentation] bpf, doc: add RISC-V JIT to BPF documentation (Yauheni Kaliuta) [1747615]
- [uapi] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1747615]
- [uapi] bpf: add documentation for helpers bpf_spin_lock(), bpf_spin_unlock() (Yauheni Kaliuta) [1747615]

* Tue Nov 26 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-152.rt13.9.el8]
- [perf] perf: Add CCPI2 PMU support in ThunderX2 UNCORE driver (Robert Richter) [1726054]
- [documentation] documentation: perf: Update documentation for ThunderX2 PMU uncore driver (Robert Richter) [1726054]
- [scsi] lpfc: Update lpfc version to 12.6.0.2 (Dick Kennedy) [1771674]
- [scsi] lpfc: revise nvme max queues to be hdwq count (Dick Kennedy) [1771674]
- [scsi] lpfc: Initialize cpu_map for not present cpus (Dick Kennedy) [1771674]
- [scsi] lpfc: fix inlining of lpfc_sli4_cleanup_poll_list() (Dick Kennedy) [1771674]
- [scsi] lpfc: fix: coverity: lpfc_cmpl_els_rsp(): Null pointer dereferences (Dick Kennedy) [1771674]
- [scsi] lpfc: fix: coverity: lpfc_get_scsi_buf_s3(): Null pointer dereferences (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix lpfc_cpumask_of_node_init() (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix a kernel warning triggered by lpfc_sli4_enable_intr() (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix a kernel warning triggered by lpfc_get_sgl_per_hdwq() (Dick Kennedy) [1771674]
- [scsi] lpfc: Update lpfc version to 12.6.0.1 (Dick Kennedy) [1771674]
- [scsi] lpfc: Add enablement of multiple adapter dumps (Dick Kennedy) [1771674]
- [scsi] lpfc: Change default IRQ model on AMD architectures (Dick Kennedy) [1771674]
- [scsi] lpfc: Add registration for CPU Offline/Online events (Dick Kennedy) [1771674]
- [scsi] lpfc: Clarify FAWNN error message (Dick Kennedy) [1771674]
- [scsi] lpfc: Sync with FC-NVMe-2 SLER change to require Conf with SLER (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix dynamic fw log enablement check (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix unexpected error messages during RSCN handling (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix kernel crash at lpfc_nvme_info_show during remote port bounce (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix configuration of BB credit recovery in service parameters (Dick Kennedy) [1771674]
- [scsi] lpfc: Fix duplicate unreg_rpi error in port offline flow (Dick Kennedy) [1771674]
- [infiniband] ib/srp: Add missing new line after displaying fast_io_fail_tmo param (Kamal Heib) [1678461 1720899]
- [net] sunrpc: The RDMA back channel mustn't disappear while requests are outstanding (Kamal Heib) [1720899]
- [infiniband] rdma/nldev: Skip counter if port doesn't match (Kamal Heib) [1720899]
- [rdma] uverbs: Prevent potential underflow (Kamal Heib) [1720899]
- [infiniband] ib/core: Use rdma_read_gid_l2_fields to compare GID L2 fields (Kamal Heib) [1720899]
- [infiniband] rdma/siw: free siw_base_qp in kref release routine (Kamal Heib) [1720899]
- [infiniband] rdma/iwcm: move iw_rem_ref() calls out of spinlock (Kamal Heib) [1720899]
- [infiniband] ib/core: Fix wrong iterating on ports (Kamal Heib) [1720899]
- [infiniband] rdma/nldev: Reshuffle the code to avoid need to rebind QP in error path (Kamal Heib) [1720899]
- [infiniband] rdma/cm: Fix memory leak in cm_add/remove_one (Kamal Heib) [1720899]
- [infiniband] rdma/core: Fix an error handling path in 'res_get_common_doit()' (Kamal Heib) [1720899]
- [infiniband] rdma/iwcm: Fix a lock inversion issue (Kamal Heib) [1720899]
- [infiniband] rdma/siw: Fix serialization issue in write_space() (Kamal Heib) [1720899]
- [infiniband] rdma/vmw_pvrdma: Free SRQ only once (Kamal Heib) [1757294 1720899]
- [infiniband] rdma: Fix double-free in srq creation error flow (Kamal Heib) [1720899]
- [infiniband] rdma/siw: Fix page address mapping in TX path (Kamal Heib) [1720899]
- [infiniband] rdma/cma: Fix false error message (Kamal Heib) [1720899]
- [infiniband] rdma/{cxgb3, cxgb4, i40iw}: Remove common code (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/core: Fix use after free and refcnt leak on ndev in_device in iwarp_query_port (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/core: Add common iWARP query port (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/i40iw: Associate ibdev to netdev before IB device registration (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma/cxgb3: Use ib_device_set_netdev() (Kamal Heib) [1760097 1745655 1720899]
- [infiniband] rdma: Introduce ib_port_phys_state enum (Kamal Heib) [1760097 1745655 1720899]
- [sched] topology: Improve load balancing on AMD EPYC systems (Phil Auld) [1757535]
- [netdrv] broadcom: Use dev_get_drvdata (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add a new BNXT_FW_RESET_STATE_POLL_FW_DOWN state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.100 (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Increase timeout for HWRM_DBG_COREDUMP_XX commands (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Don't proceed in .ndo_set_rx_mode() when device is not in open state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix compile error regression with CONFIG_BNXT_SRIOV not set (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add FW fatal devlink_health_reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add bnxt_fw_exception() to handle fatal firmware errors (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add RESET_FW state logic to bnxt_fw_reset_task() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Do not send firmware messages if firmware is in error state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Retain user settings on a VF after RESET_NOTIFY event (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add devlink health reset reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle firmware reset (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle RESET_NOTIFY async event from firmware (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add new FW devlink_health_reporter (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add BNXT_STATE_IN_FW_RESET state (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Enable health monitoring (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Pre-map the firmware health monitoring registers (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Discover firmware error recovery capabilities (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle firmware reset status during IF_UP (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Register buffers for VFs before reserving resources (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_sriov_enable() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Prepare bnxt_init_one() to be called multiple times (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Suppress all error messages in hwrm_do_send_msg() in silent mode (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Simplify error checking in the SR-IOV message forwarding functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Convert error code in firmware message response to standard code (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Remove the -1 error return code from bnxt_hwrm_do_send_msg() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Use a common function to print the same ethtool -f error message (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix allocation of zero statistics block size regression (Jonathan Toppins) [1724766]
- [netdrv] bnxt: no need to check return value of debugfs_create functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add PCI IDs for 57500 series NPAR devices (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Support all variants of the 5750X chip family (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_init_one() and turn on TPA support on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Support TPA counters on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Allocate the larger per-ring statistics block for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor ethtool ring statistics logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add hardware GRO setup function for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add TPA ID mapping logic for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add fast path logic for TPA on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Set TPA GRO mode flags on 57500 chips properly (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor tunneled hardware GRO logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Handle standalone RX_AGG completions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Expand bnxt_tpa_info struct to support 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor TPA logic (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add TPA structure definitions for BCM57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.89 (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Suppress HWRM errors for HWRM_NVM_GET_VARIABLE command (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix to include flow direction in L2 key (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Use correct src_fid to determine direction of the flow (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix handling FRAG_ERR when NVM_INSTALL_UPDATE cmd fails (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Improve RX doorbell sequence (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix VNIC clearing logic for 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix VNIC accounting when enabling aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add page_pool_destroy() during RX ring cleanup (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: add page_pool support (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: optimized XDP_REDIRECT support (Jonathan Toppins) [1724766 1669220]
- [netdrv] bnxt_en: Refactor __bnxt_xmit_xdp() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: rename some xdp functions (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Device serial number is supported only for PFs (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add support for aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Query firmware capability to support aRFS on 57500 chips (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Separate RDMA MR/AH context allocation (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: read the clause type from the PHY ID (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Read package version from firmware (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Check new firmware capability to display extended stats (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Add support for PCIe statistics (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Refactor bnxt_alloc_stats() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Update firmware interface to 1.10.0.69 (Jonathan Toppins) [1724766]
- [netdrv] bnxt: remove ndo_get_port_parent_id implementation for physical ports (Jonathan Toppins) [1724766]
- [netdrv] bnxt: pass switch ID through devlink_port_attrs_set() (Jonathan Toppins) [1724766]
- [netdrv] bnxt: move bp->switch_id initialization to PF probe (Jonathan Toppins) [1724766]
- [netdrv] bnxt: remove ndo_get_phys_port_name implementation (Jonathan Toppins) [1724766]
- [netdrv] bnxt: implement ndo_get_devlink_port (Jonathan Toppins) [1724766]
- [netdrv] bnxt: Implement ndo_get_port_parent_id() (Jonathan Toppins) [1724766]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Jonathan Toppins) [1724766]
- [netdrv] bnxt_en: Fix firmware signaled resource change logic in open (Jonathan Toppins) [1724766]
- [netdrv] bnx2x: Mark expected switch fall-thoughs (Jonathan Toppins) [1724766]
- [netdrv] bnx2x: Mark expected switch fall-throughs (Jonathan Toppins) [1724766]
- [tools] selftests: kvm: vmx_dirty_log_test: skip the test when VMX is not supported (Vitaly Kuznetsov) [1771575]
- [tools] selftests: kvm: consolidate VMX support checks (Vitaly Kuznetsov) [1771575]
- [tools] selftests: kvm: vmx_set_nested_state_test: don't check for VMX support twice (Vitaly Kuznetsov) [1771575]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 321 (Stefano Garzarella) [1769904]
- [net] vsock: Send reset control packet when socket is partially bound (Stefano Garzarella) [1769904]
- [net] vsock/virtio: fix sock refcnt holding during the shutdown (Stefano Garzarella) [1769855]
- [kernel] vsock/virtio: remove unused 'work' field from 'struct virtio_vsock_pkt' (Stefano Garzarella) [1769855]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 482 (Stefano Garzarella) [1769855]
- [net] vsock/virtio: set SOCK_DONE on peer shutdown (Stefano Garzarella) [1769855]
- [net] vsock/virtio: discard packets if credit is not respected (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: send a credit update when buffer size is changed (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: a better comment on credit update (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: fix locking in virtio_transport_inc_tx_pkt() (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: reduce credit update messages (Stefano Garzarella) [1769853 1769846 1769836]
- [net] vsock/virtio: change the maximum packet size allowed (Stefano Garzarella) [1679971]
- [vhost] vsock: split packets to send using multiple buffers (Stefano Garzarella) [1679971]
- [net] vsock/virtio: limit the memory used per-socket (Stefano Garzarella) [1769744]
- [net] vsock/virtio: free packets during the socket release (Stefano Garzarella) [1769744]
- [net] vsock: Fix a lockdep warning in __vsock_release() (Stefano Garzarella) [1769714]
- [net] vsock: correct removal of socket from the list (Stefano Garzarella) [1769714]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Stefano Garzarella) [1769714]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 321 (Stefano Garzarella) [1769714]
- [net] Fix ERROR:do not initialise statics to 0 in af_vsock.c (Stefano Garzarella) [1769714]
- [net] vsock: bind to random port for VMADDR_PORT_ANY (Stefano Garzarella) [1769714]
- [tools] tc-testing: added tests with cookie for conntrack TC action (Ivan Vecera) [1739606]
- [net] cls_bpf: fix NULL deref on offload filter removal (Ivan Vecera) [1739606]
- [tools] tc-testing: fixed two failing pedit tests (Ivan Vecera) [1739606]
- [tools] tc-testing: implement tests for new fast_init action flag (Ivan Vecera) [1739606]
- [net] sched: update action implementations to support flags (Ivan Vecera) [1739606]
- [net] sched: use temporary variable for actions indexes (Ivan Vecera) [1739606]
- [net] sched: extend TCA_ACT space with TCA_ACT_FLAGS (Ivan Vecera) [1739606]
- [net] sched: modify stats helper functions to support regular stats (Ivan Vecera) [1739606]
- [net] sched: don't expose action qstats to skb_tc_reinsert() (Ivan Vecera) [1739606]
- [net] sched: extract qstats update code into functions (Ivan Vecera) [1739606]
- [net] sched: extract bstats update code into function (Ivan Vecera) [1739606]
- [net] sched: extract common action counters update code into function (Ivan Vecera) [1739606]
- [tools] tc-testing: list required kernel options for act_ct action (Ivan Vecera) [1739606]
- [net] fq_codel: do not include <linux/jhash.h> (Ivan Vecera) [1739606]
- [net] sch_generic: Use pfifo_fast as fallback scheduler for CAN hardware (Ivan Vecera) [1739606]
- [net] sched: taprio: fix -Wmissing-prototypes warnings (Ivan Vecera) [1739606]
- [net] sched: act_police: re-use tcf_tm_dump() (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit TDC tests (Ivan Vecera) [1739606]
- [net] sched: Avoid using yield() in a busy waiting loop (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit test cases (Ivan Vecera) [1739606]
- [net] sched: etf: Fix ordering of packets with same txtime (Ivan Vecera) [1739606]
- [tools] tc-testing: updated pedit test cases (Ivan Vecera) [1739606]
- [net] taprio: Fix returning EINVAL when configuring without flags (Ivan Vecera) [1739606]
- [net] net_sched: fix backward compatibility for TCA_ACT_KIND (Ivan Vecera) [1739606]
- [net] net_sched: fix backward compatibility for TCA_KIND (Ivan Vecera) [1739606]
- [net] sched: Set default of CONFIG_NET_TC_SKB_EXT to N (Ivan Vecera) [1739606]
- [net] sch_netem: fix rcu splat in netem_enqueue() (Ivan Vecera) [1739606]
- [net] net_sched: remove need_resched() from qdisc_run() (Ivan Vecera) [1739606]
- [net] sched: cbs: Avoid division by zero when calculating the port rate (Ivan Vecera) [1739606]
- [net] sched: taprio: Avoid division by zero on invalid link speed (Ivan Vecera) [1739606]
- [net] sched: taprio: Fix potential integer overflow in taprio_set_picos_per_byte (Ivan Vecera) [1739606]
- [net] sched: cbs: Fix not adding cbs instance to list (Ivan Vecera) [1739606]
- [net] Fix Kconfig indentation (Ivan Vecera) [1739606]
- [net] net_sched: add policy validation for action attributes (Ivan Vecera) [1739606]
- [net] net_sched: add max len check for TCA_KIND (Ivan Vecera) [1739606]
- [net] taprio: Add support for hardware offloading (Ivan Vecera) [1739606]
- [net] sched: use get_dev() action API in flow_action infra (Ivan Vecera) [1739606]
- [net] sched: take reference to psample group in flow_action infra (Ivan Vecera) [1739606]
- [net] sched: extend flow_action_entry with destructor (Ivan Vecera) [1739606]
- [net] sch_hhf: ensure quantum and hhf_non_hh_weight are non-zero (Ivan Vecera) [1739606]
- [net] net_sched: check cops->tcf_block in tc_bind_tclass() (Ivan Vecera) [1739606]
- [net] sched: fix reordering issues (Ivan Vecera) [1739606]
- [net] net_sched: act_police: add 2 new attributes to support police 64bit rate and peakrate (Ivan Vecera) [1739606]
- [net] openvswitch: Set OvS recirc_id from tc chain index (Ivan Vecera) [1739606]
- [net] sk_buff: drop all skb extensions on free and skb scrubbing (Ivan Vecera) [1739606]
- [net] minor cleanup in skb_ext_add() (Ivan Vecera) [1739606]
- [include] net: drop the unused helper skb_ext_get() (Ivan Vecera) [1739606]
- [net] fix possible user-after-free in skb_ext_add() (Ivan Vecera) [1739606]
- [net] sk_buff: add skb extension infrastructure (Ivan Vecera) [1739606]
- [net] sched: cbs: remove redundant assignment to variable port_rate (Ivan Vecera) [1739606]
- [tools] tc-testing: don't hardcode 'ip' in nsPlugin.py (Ivan Vecera) [1739606]
- [net] sched: cbs: Set default link speed to 10 Mbps in cbs_set_port_rate (Ivan Vecera) [1739606]
- [net] taprio: Set default link speed to 10 Mbps in taprio_set_picos_per_byte (Ivan Vecera) [1739606]
- [net] taprio: Fix kernel panic in taprio_destroy (Ivan Vecera) [1739606]
- [netdrv] mlx5e: Move local var definition into ifdef block (Ivan Vecera) [1739606]
- [net] sched: cls_matchall: cleanup flow_action before deallocating (Ivan Vecera) [1739606]
- [net] sched: act_vlan: implement stats_update callback (Ivan Vecera) [1739606]
- [net] sched: act_sample: fix psample group handling on overwrite (Ivan Vecera) [1739606]
- [net] sched: flower: don't take rtnl lock for cls hw offloads API (Ivan Vecera) [1739606]
- [net] sched: copy tunnel info when setting flow_action entry->tunnel (Ivan Vecera) [1739606]
- [net] sched: take reference to action dev before calling offloads (Ivan Vecera) [1739606]
- [net] sched: take rtnl lock in tc_setup_flow_action() (Ivan Vecera) [1739606]
- [net] sched: conditionally obtain rtnl lock in cls hw offloads API (Ivan Vecera) [1739606]
- [net] sched: add API for registering unlocked offload block callbacks (Ivan Vecera) [1739606]
- [net] sched: notify classifier on successful offload add/delete (Ivan Vecera) [1739606]
- [net] sched: refactor block offloads counter usage (Ivan Vecera) [1739606]
- [net] sched: change tcf block offload counter type to atomic_t (Ivan Vecera) [1739606]
- [net] sched: protect block offload-related fields with rw_semaphore (Ivan Vecera) [1739606]
- [net] net_sched: fix a NULL pointer deref in ipt action (Ivan Vecera) [1739606]
- [tools] tc-testing: concurrency: wrap piped rule update commands (Ivan Vecera) [1739606]
- [tools] tc-testing: use dedicated DUMMY interface name for dummy dev (Ivan Vecera) [1739606]
- [net] flow_offload: convert block_ing_cb_list to regular list type (Ivan Vecera) [1739606]
- [netdrv] sched: use major priority number as hardware priority (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for matchall filter (Ivan Vecera) [1739606]
- [net] taprio: remove unused variable 'entry_list_policy' (Ivan Vecera) [1739606]
- [tools] tc-testing: updated skbedit action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update skbedit action for batched events operations (Ivan Vecera) [1739606]
- [net] fq_codel: remove set but not used variables 'prev_ecn_mark' and 'prev_drop_count' (Ivan Vecera) [1739606]
- [net] flow_offload: support get multi-subsystem block (Ivan Vecera) [1739606]
- [net] flow_offload: move tc indirect block to flow offload (Ivan Vecera) [1739606]
- [net] cls_api: add flow_indr_block_call function (Ivan Vecera) [1739606]
- [net] cls_api: remove the tcf_block cache (Ivan Vecera) [1739606]
- [net] cls_api: modify the tc_indr_block_ing_cmd parameters. (Ivan Vecera) [1739606]
- [net] sched: sch_taprio: fix memleak in error path for sched list parse (Ivan Vecera) [1739606]
- [net] fq_codel: Kill useless per-flow dropped statistic (Ivan Vecera) [1739606]
- [net] Increase fq_codel count in the bulk dropper (Ivan Vecera) [1739606]
- [include] sched: sample: allow accessing psample_group with rtnl (Ivan Vecera) [1739606]
- [tools] tc-testing: updated vlan action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update vlan action for batched events operations (Ivan Vecera) [1739606]
- [tools] tc-testing: Clarify the use of tdc's -d option (Ivan Vecera) [1739606]
- [net] sched: Fix a possible null-pointer dereference in dequeue_func() (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for [b|p]fifo qdisc (Ivan Vecera) [1739606]
- [net] ife: error out when nla attributes are empty (Ivan Vecera) [1739606]
- [net] sched: verify that q!=NULL before setting q->flags (Ivan Vecera) [1739606]
- [net] net_sched: unset TCQ_F_CAN_BYPASS when adding filters (Ivan Vecera) [1739606]
- [net] fix: taprio: Change type of txtime-delay parameter to u32 (Ivan Vecera) [1739606]
- [tools] tc-tests: updated skbedit tests (Ivan Vecera) [1739606]
- [include] pkt_sched: Include const.h (Ivan Vecera) [1739606]
- [tools] tc-testing: introduce scapyPlugin for basic traffic (Ivan Vecera) [1739606]
- [tools] tc-testing: Allow tdc plugins to see test case data (Ivan Vecera) [1739606]
- [tools] tc-testing: added tdc tests for prio qdisc (Ivan Vecera) [1739606]
- [tools] tc-testing: updated mirred action tests with batch create/delete (Ivan Vecera) [1739606]
- [net] sched: update mirred action for batched events operations (Ivan Vecera) [1739606]
- [net] sched: em_ipt: add support for addrtype matching (Ivan Vecera) [1739606]
- [net] sched: em_ipt: keep the user-specified nfproto and dump it (Ivan Vecera) [1739606]
- [net] sched: em_ipt: set the family based on the packet if it's unspecified (Ivan Vecera) [1739606]
- [net] sched: em_ipt: match only on ip/ipv6 traffic (Ivan Vecera) [1739606]
- [net] taprio: Adjust timestamps for TCP packets (Ivan Vecera) [1739606]
- [net] taprio: make clock reference conversions easier (Ivan Vecera) [1739606]
- [net] taprio: Add support for txtime-assist mode (Ivan Vecera) [1739606]
- [net] taprio: Remove inline directive (Ivan Vecera) [1739606]
- [net] taprio: calculate cycle_time when schedule is installed (Ivan Vecera) [1739606]
- [net] etf: Add skip_sock_check (Ivan Vecera) [1739606]
- [include] etf: Don't use BIT() in UAPI headers. (Ivan Vecera) [1739606]
- [tools] tc-testing: add ingress qdisc tests (Ivan Vecera) [1739606]
- [tools] tc-testing: Restore original behaviour for namespaces in tdc (Ivan Vecera) [1739606]
- [include] net: sched: act_ctinfo: tidy UAPI definition (Ivan Vecera) [1739606]
- [include] act_ctinfo: Don't use BIT() in UAPI headers. (Ivan Vecera) [1739606]
- [net] sched: cls_matchall: allow to delete filter (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: fix policy validation (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: fix action creation (Ivan Vecera) [1739606]
- [tools] tc-tests: updated skbedit tests (Ivan Vecera) [1739606]
- [tools] tc-tests: added path to ip command in tdc (Ivan Vecera) [1739606]
- [net] sched: remove NET_CLS_IND config option (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: use extack error reporting (Ivan Vecera) [1739606]
- [net] sched: ingress: set 'unlocked' flag for clsact Qdisc ops (Ivan Vecera) [1739606]
- [net] sched: ingress: set 'unlocked' flag for Qdisc ops (Ivan Vecera) [1739606]
- [tools] tc-tests: updated fw with bind actions by reference use cases (Ivan Vecera) [1739606]
- [net] sched: act_ctinfo: minor size optimisation (Ivan Vecera) [1739606]
- [net] flow_offload: use struct_size() in kzalloc() (Ivan Vecera) [1739606]
- [net] sched: don't use tc_action->order during action dump (Ivan Vecera) [1739606]
- [net] sch_htb: redefine htb qdisc overlimits (Ivan Vecera) [1739606]
- [tools] selftests: tc-testing: Add pedit tests (Ivan Vecera) [1739606]
- [net] sched: add ingress mirred action to hardware IR (Ivan Vecera) [1757520]
- [include] net: tc_act: add helpers to detect ingress mirred actions (Ivan Vecera) [1757520]
- [net] sched: add skbedit of ptype action to hardware IR (Ivan Vecera) [1757520]
- [include] net: tc_act: add skbedit_ptype helper functions (Ivan Vecera) [1757520]
- [net] openvswitch: load and reference the NAT helper. (Flavio Leitner) [1752970]
- [net] openvswitch: load NAT helper (Flavio Leitner) [1752970]
- [net] netfilter: nf_nat: register NAT helpers. (Flavio Leitner) [1752970]
- [net] netfilter: add API to manage NAT helpers. (Flavio Leitner) [1752970]
- [net] netfilter: use macros to create module aliases. (Flavio Leitner) [1752970]
- [net] xfrm: remove a duplicated assignment (Sabrina Dubroca) [1760002]
- [net] xfrm: remove empty xfrmi_init_net (Sabrina Dubroca) [1760002]
- [net] xfrm: remove unneeded export_symbols (Sabrina Dubroca) [1760002]
- [include] xfrm: clean an indentation issue, remove a space (Sabrina Dubroca) [1760002]
- [net] xfrm6: remove BUG_ON from xfrm6_dst_ifdown (Sabrina Dubroca) [1760002]
- [net] xfrm: policy: add missing indentation (Sabrina Dubroca) [1760002]
- [net] xfrm: Fix bucket count reported to userspace (Sabrina Dubroca) [1760002]
- [net] xfrm: use complete IPv6 addresses for hash (Sabrina Dubroca) [1760002]
- [net] xfrm: use correct size to initialise sp->ovec (Sabrina Dubroca) [1760002]
- [net] xfrm: allow driver to quietly refuse offload (Sabrina Dubroca) [1760002]
- [net] esp: remove redundant define esph (Sabrina Dubroca) [1760002]
- [net] ip6_vti: simplify stats handling in vti6_xmit (Sabrina Dubroca) [1760002]
- [net] xfrm: fix 'passing zero to ERR_PTR()' warning (Sabrina Dubroca) [1760002]
- [net] xfrm: remove blank lines at EOF (Sabrina Dubroca) [1760002]
- [net] xfrm: don't check offload_handle for nonzero (Sabrina Dubroca) [1760002]
- [net] ipv6: xfrm: use 64-bit timestamps (Sabrina Dubroca) [1760002]
- [net] devlink: Introduce PCI VF port flavour and port attribute (Petr Oros) [1761495]
- [net] devlink: Introduce PCI PF port flavour and port attribute (Petr Oros) [1761495]
- [net] devlink: Return physical port fields only for applicable port flavours (Petr Oros) [1761495]
- [net] devlink: Refactor physical port attributes (Petr Oros) [1761495]
- [net] ipv4: fix race condition between route lookup and invalidation (Guillaume Nault) [1765639]
- [net] add {READ|WRITE}_ONCE() annotations on ->rskq_accept_head (Guillaume Nault) [1765639]
- [net] ipv4/icmp: fix rt dst dev null pointer dereference (Guillaume Nault) [1765639]
- [net] ipip: validate header length in ipip_tunnel_xmit (Guillaume Nault) [1765639]
- [net] ipv4: Use return value of inet_iif() for __raw_v4_lookup in the while loop (Guillaume Nault) [1765639]
- [net] ipv4: Fix raw socket lookup for local traffic (Guillaume Nault) [1765639]
- [net] ipv4: Return error for RTA_VIA attribute (Guillaume Nault) [1765639]
- [net] ipmr: fix unresolved entry dumps (Guillaume Nault) [1765639]
- [net] ipvs: don't ignore errors in case refcounting ip_vs module fails (Davide Caratti) [1687094]
- [net] ipvs: fix tinfo memory leak in start_sync_thread (Davide Caratti) [1687094]
- [net] tcp: fix a possible lockdep splat in tcp_done() (Marcelo Leitner) [1764654]
- [net] tcp: add rcu protection around tp->fastopen_rsk (Marcelo Leitner) [1764654]
- [net] tcp: annotate lockless access to tcp_memory_pressure (Marcelo Leitner) [1764654]
- [net] tcp: fix tcp_ecn_withdraw_cwr() to clear TCP_ECN_QUEUE_CWR (Marcelo Leitner) [1764654]
- [net] tcp: inherit timestamp on mtu probe (Marcelo Leitner) [1764654]
- [net] tcp: remove empty skb from write queue in error cases (Marcelo Leitner) [1764654]
- [net] tcp: get rid of tcp_check_send_head() (Marcelo Leitner) [1764654]
- [net] tcp: make sure EPOLLOUT wont be missed (Marcelo Leitner) [1764654]
- [net] ipv4: set the tcp_min_rtt_wlen range from 0 to one day (Marcelo Leitner) [1764654]
- [net] net-tcp: /proc/sys/net/ipv4/tcp_probe_interval is a u32 not int (Marcelo Leitner) [1764654]
- [net] tcp: fix a race in inet_diag_dump_icsk() (Marcelo Leitner) [1764654]
- [net] netfilter: nft_meta: Add NFT_META_I/OIFKIND meta type (Florian Westphal) [1763657]
- [net] netfilter: nft_xfrm: use state family, not hook one (Florian Westphal) [1763654]
- [net] netfilter: nf_tables: add xfrm expression (Florian Westphal) [1763654]
- [net] netfilter: nf_tables: rt: allow checking if dst has xfrm attached (Florian Westphal) [1763654]
- [netdrv] mlx5e: Fix unnecessary flow_block_cb_is_busy call (Ivan Vecera) [1737890]
- [netdrv] nfp: flower: verify that block cb is not busy before binding (Ivan Vecera) [1737890]
- [netdrv] net/mlx5e: Provide cb_list pointer when setting up tc block on rep (Ivan Vecera) [1737890]
- [net] sched: Fix NULL-pointer dereference in tc_indr_block_ing_cmd() (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block structure and use it (Ivan Vecera) [1737890]
- [net] flow_offload: rename tc_setup_cb_t to flow_setup_cb_t (Ivan Vecera) [1737890]
- [include] flow_offload: include linux/kernel.h from flow_offload.h (Ivan Vecera) [1737890]
- [net] flow_offload: remove netns parameter from flow_block_cb_alloc() (Ivan Vecera) [1737890]
- [net] openvswitch: rename flow_stats to sw_flow_stats (Ivan Vecera) [1737890]
- [netdrv] mlx5e: Fix unused variable warning when CONFIG_MLX5_ESWITCH is off (Ivan Vecera) [1737890]
- [netdrv] net: flow_offload: rename tc_cls_flower_offload to flow_cls_offload (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_is_busy() and use it (Ivan Vecera) [1737890]
- [net] sched: remove tcf block API (Ivan Vecera) [1737890]
- [include] sched: use new symbol for TC kABI version (Ivan Vecera) [1737890]
- [netdrv] use flow block API (Ivan Vecera) [1737890]
- [net] sched: use flow block API (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_{priv, incref, decref}() (Ivan Vecera) [1737890]
- [net] flow_offload: add list handling functions (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_alloc() and flow_block_cb_free() (Ivan Vecera) [1737890]
- [net] flow_offload: rename TCF_BLOCK_BINDER_TYPE_* to FLOW_BLOCK_BINDER_TYPE_* (Ivan Vecera) [1737890]
- [net] flow_offload: rename TC_BLOCK_{UN}BIND to FLOW_BLOCK_{UN}BIND (Ivan Vecera) [1737890]
- [net] flow_offload: add flow_block_cb_setup_simple() (Ivan Vecera) [1737890]
- [net] openvswitch: free vport unless register_netdevice() succeeds (Stefano Brivio) [1765580]
- [net] openvswitch: Clear the L4 portion of the key for "later" fragments. (Stefano Brivio) [1765580]
- [net] openvswitch: Properly set L4 keys on "later" IP fragments (Stefano Brivio) [1765580]
- [net] openvswitch: Print error when ovs_execute_actions() fails (Stefano Brivio) [1765580]
- [net] openvswitch: do not free vport if register_netdevice() is failed. (Stefano Brivio) [1765580]
- [net] xfrm: policy: remove pcpu policy cache (Xin Long) [1743519]
- [net] netem: correct the parent's backlog when corrupted packet was dropped (Davide Caratti) [1764553]
- [net] netem: fix error path for corrupted GSO frames (Davide Caratti) [1764553]
- [net] avoid potential infinite loop in tc_ctl_action() (Davide Caratti) [1764553]
- [net] act_mirred: Fix mirred_init_module error handling (Davide Caratti) [1764553]
- [net] sch_dsmark: fix potential NULL deref in dsmark_init() (Davide Caratti) [1764553]
- [net] sch_cbq: validate TCA_CBQ_WRROPT to avoid crash (Davide Caratti) [1764553]
- [net] sched: sch_sfb: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: multiq: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: sch_htb: don't call qdisc_put() while holding tree lock (Davide Caratti) [1764553]
- [net] sched: fix possible crash in tcf_action_destroy() (Davide Caratti) [1764553]
- [net] sch_netem: fix a divide by zero in tabledist() (Davide Caratti) [1764553]
- [net] sched: act_sample: don't push mac header on ip6gre ingress (Davide Caratti) [1764553]
- [net] net_sched: let qdisc_put() accept NULL pointer (Davide Caratti) [1764553]
- [net] tcp: adjust rto_base in retransmits_timed_out() (Marcelo Leitner) [1756775]
- [net] tcp: better handle TCP_USER_TIMEOUT in SYN_SENT state (Marcelo Leitner) [1756775]
- [include] netlink: use 48 byte ctx instead of 6 signed longs for callback (Petr Oros) [1751273]
- [net] rtnetlink: skip metrics loop for dst_default_metrics (Petr Oros) [1751273]
- [include] netlink: Add field to skip in-kernel notifications (Petr Oros) [1751273]
- [include] netlink: Document all fields of 'struct nl_info' (Petr Oros) [1751273]
- [net] ipoib: show VF broadcast address (Petr Oros) [1751273]
- [net] remove empty netlink_tap_exit_net (Petr Oros) [1751273]
- [net] netlink: make netlink_walk_start() void return type (Petr Oros) [1751273]
- [include] net: nexthop uapi (Petr Oros) [1751273]
- [net] Treat sock->sk_drops as an unsigned int when printing (Petr Oros) [1751273]
- [net] fix two coding style issues (Petr Oros) [1751273]
- [net] ipset: drop ipset_nest_start() and ipset_nest_end() (Petr Oros) [1751273]
- [net] netlink: make nla_nest_start() add NLA_F_NESTED flag (Petr Oros) [1751273]
- [net] netfilter: nf_tables: fix a missing check of nla_put_failure (Petr Oros) [1751273]
- [net] ncsi: fix a missing check for nla_nest_start (Petr Oros) [1751273]
- [net] genetlink: use idr_alloc_cyclic for family->id assignment (Petr Oros) [1751273]
- [net] netlink: Check address length before reading groups field (Petr Oros) [1751273]
- [net] core: Fix rtnetlink kernel-doc headers (Petr Oros) [1751273]
- [net] rhashtable: Remove obsolete rhashtable_walk_init function (Petr Oros) [1751273]
- [net] netfilter: nf_tables: use rhashtable_walk_enter instead of rhashtable_walk_init (Petr Oros) [1751273]
- [net] netlink: reduce NLA_POLICY_NESTED{, _ARRAY} arguments (Petr Oros) [1751273]
- [net] netlink: rename NETLINK_DUMP_STRICT_CHK -> NETLINK_GET_STRICT_CHK (Petr Oros) [1751273]
- [include] netlink: replace __NLA_ENSURE implementation (Petr Oros) [1751273]
- [include] netlink: fix typo in nla_parse_nested() comment (Petr Oros) [1751273]
- [net] netlink: remove hash::nelems check in netlink_insert (Petr Oros) [1751273]
- [net] netlink: Make groups check less stupid in netlink_bind() (Petr Oros) [1751273]
- [include] genetlink: constify genl_err_attr() argument (Petr Oros) [1751273]
- [net] netlink: do not store start function in netlink_cb (Petr Oros) [1751273]
- [include] linux: Add skb_frag_t page_offset accessors (Petr Oros) [1757515]
- [include] net: add missing documentation in linux/skbuff.h (Petr Oros) [1757515]
- [net] l2tp: Fix possible NULL pointer dereference (Stefano Brivio) [1764185]
- [net] l2ip: fix possible use-after-free (Stefano Brivio) [1764185]
- [net] l2tp: use rcu_dereference_sk_user_data() in l2tp_udp_encap_recv() (Stefano Brivio) [1764185]
- [net] l2tp: fix infoleak in l2tp_ip6_recvmsg() (Stefano Brivio) [1764185]
- [net] l2tp: copy 4 more bytes to linear part if necessary (Stefano Brivio) [1764185]
- [net] l2tp: fix reading optional fields of L2TPv3 (Stefano Brivio) [1764185]
- [net] l2tp: remove ->recv_payload_hook (Stefano Brivio) [1764185]
- [net] l2tp: don't export l2tp_session_queue_purge() (Stefano Brivio) [1764185]
- [net] l2tp: remove .show from struct l2tp_tunnel (Stefano Brivio) [1764185]
- [netdrv] vxlan: do not destroy fdb if register_netdevice() is failed (Stefano Brivio) [1763793]
- [net] ip6erspan: remove the incorrect mtu limit for ip6erspan (Stefano Brivio) [1763286]
- [net] ipv6: Handle missing host route in __ipv6_ifa_notify (Stefano Brivio) [1763286]
- [net] ipv6: drop incoming packets having a v4mapped source address (Stefano Brivio) [1763286]
- [net] ip6_gre: fix a dst leak in ip6erspan_tunnel_xmit (Stefano Brivio) [1763286]
- [net] mld: fix memory leak in mld_del_delrec() (Stefano Brivio) [1763286]
- [net] ipv6: rt6_check should return NULL if 'from' is NULL (Stefano Brivio) [1763286]
- [net] ipv6_sockglue: Fix a missing-check bug in ip6_ra_control() (Stefano Brivio) [1763286]
- [net] ipv6_gre: Fix GRO to work on IPv6 over GRE tap (Stefano Brivio) [1763286]
- [net] ipv4: Return -ENETUNREACH if we can't create route but saddr is valid (Stefano Brivio) [1686686]
- [net] netfilter: nft_connlimit: disable bh on garbage collection (Florian Westphal) [1762844]
- [net] netfilter: ebtables: Fix argument order to ADD_COUNTER (Florian Westphal) [1762844]
- [net] netfilter: ebtables: CONFIG_COMPAT: reject trailing data after last rule (Florian Westphal) [1762844]
- [net] netfilter: ebtables: CONFIG_COMPAT: drop a bogus WARN_ON (Florian Westphal) [1762844]
- [net] netfilter: bridge: set skb transport_header before entering NF_INET_PRE_ROUTING (Florian Westphal) [1762844]
- [net] netfilter: ebtables: also count base chain policies (Florian Westphal) [1762844]
- [net] netfilter: ebtables: compat: un-break 32bit setsockopt when no rules are present (Florian Westphal) [1762844]
- [net] sctp: change sctp_prot .no_autobind with true (Xin Long) [1762625]
- [net] sctp: destroy bucket if failed to bind addr (Xin Long) [1762625]
- [net] sctp: remove redundant assignment when call sctp_get_port_local (Xin Long) [1762625]
- [net] sctp: change return type of sctp_get_port_local (Xin Long) [1762625]
- [net] sctp: Fix the link time qualifier of 'sctp_ctrlsock_exit()' (Xin Long) [1762625]
- [net] sctp: fix the missing put_user when dumping transport thresholds (Xin Long) [1762625]
- [net] sctp: use transport pf_retrans in sctp_do_8_2_transport_strike (Xin Long) [1762625]
- [net] sctp: allow users to set ep ecn flag by sockopt (Xin Long) [1762625]
- [net] sctp: allow users to set netns ecn flag with sysctl (Xin Long) [1762625]
- [net] sctp: make ecn flag per netns and endpoint (Xin Long) [1762625]
- [net] sctp: remove net sctp.x_enable working as a global switch (Xin Long) [1762625]
- [net] sctp: add SCTP_AUTH_SUPPORTED sockopt (Xin Long) [1762625]
- [net] sctp: add sctp_auth_init and sctp_auth_free (Xin Long) [1762625]
- [net] sctp: use ep and asoc auth_enable properly (Xin Long) [1762625]
- [net] sctp: add SCTP_ASCONF_SUPPORTED sockopt (Xin Long) [1762625]
- [net] sctp: check asoc peer.asconf_capable before processing asconf (Xin Long) [1762625]
- [net] sctp: not set peer.asconf_capable in sctp_association_init (Xin Long) [1762625]
- [net] sctp: add asconf_enable in struct sctp_endpoint (Xin Long) [1762625]
- [net] sctp: fix memleak in sctp_send_reset_streams (Xin Long) [1762625]
- [net] sctp: fix the transport error_count check (Xin Long) [1762625]
- [net] sched: fix corrupted L2 header with MPLS 'push' and 'pop' actions (Ivan Vecera) [1737820]
- [net] avoid errors when trying to pop MLPS header on non-MPLS packets (Ivan Vecera) [1737820]
- [net] netfilter: connlabels: prefer static lock initialiser (Ivan Vecera) [1737820]
- [net] sched: include mpls actions in hardware intermediate representation (Ivan Vecera) [1737820]
- [net] sched: Make NET_ACT_CT depends on NF_NAT (Ivan Vecera) [1737820]
- [tools] tc-tests: Add tc action ct tests (Ivan Vecera) [1737820]
- [net] sched: cls_flower: Add matching on conntrack info (Ivan Vecera) [1737820]
- [net] flow_dissector: add connection tracking dissection (Ivan Vecera) [1737820]
- [net] sched: Introduce action ct (Ivan Vecera) [1737820]
- [tools] tc-tests: actions: add MPLS tests (Ivan Vecera) [1737820]
- [net] sched: add mpls manipulation actions to TC (Ivan Vecera) [1737820]
- [net] core: add MPLS update core helper and use in OvS (Ivan Vecera) [1737820]
- [net] core: move pop MPLS functionality from OvS to core helper (Ivan Vecera) [1737820]
- [net] core: move push MPLS functionality from OvS to core helper (Ivan Vecera) [1737820]
- [net] sched: Introduce act_ctinfo action (Ivan Vecera) [1737820]
- [netdrv] mlx5e: Allow dissector meta key in tc flower (Ivan Vecera) [1762861]
- [tools] selftests: tc: add ingress device matching support (Ivan Vecera) [1762861]
- [net] flow_offload: implement support for meta key (Ivan Vecera) [1762861]
- [net] sched: cls_flower: use flow_dissector for ingress ifindex (Ivan Vecera) [1762861]
- [net] flow_dissector: add support for ingress ifindex dissection (Ivan Vecera) [1762861]
- [net] udp: only do GSO if # of segs > 1 (Guillaume Nault) [1762357]
- [net] udp: fix gso_segs calculations (Guillaume Nault) [1762357]
- [tools] selftests: rtnetlink: add small test case with 'promote_secondaries' enabled (Petr Oros) [1759177]
- [net] ipv4: fix infinite loop on secondary addr promotion (Petr Oros) [1759177]
- [tools] selftests: rtnetlink: add addresses with fixed life time (Petr Oros) [1759177]
- [net] ipv4: remove erroneous advancement of list pointer (Petr Oros) [1759177]
- [net] ipv4: fix rcu lockdep splat due to wrong annotation (Petr Oros) [1759177]
- [net] ipv4: provide __rcu annotation for ifa_list (Petr Oros) [1759177]
- [drivers] use in_dev_for_each_ifa_rtnl/rcu (Petr Oros) [1759177]
- [net] use new in_dev_ifa iterators (Petr Oros) [1759177]
- [net] netfilter: use in_dev_for_each_ifa_rcu (Petr Oros) [1759177]
- [net] devinet: use in_dev_for_each_ifa_rcu in more places (Petr Oros) [1759177]
- [net] inetdevice: provide replacement iterators for in_ifaddr walk (Petr Oros) [1759177]
- [fs] afs: do not send list of client addresses (Petr Oros) [1759177]
- [net] sctp: add SCTP_SEND_FAILED_EVENT event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_MADE_PRIM event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_REMOVED event (Xin Long) [1751129]
- [net] sctp: add SCTP_ADDR_ADDED event (Xin Long) [1751129]
- [netdrv] team: call RCU read lock when walking the port_list (Hangbin Liu) [1724896]
- [net] packet: fix race in tpacket_snd() (Davide Caratti) [1760276]
- [net] packet: fix memory leak in packet_set_ring() (Davide Caratti) [1760276]
- [net] packet: unconditionally free po->rollover (Davide Caratti) [1760276]
- [net] llc: fix skb leak in llc_build_and_send_ui_pkt() (Davide Caratti) [1760276]
- [net] af_key: fix leaks in key_pol_get_resp and dump_sp. (Davide Caratti) [1760276]
- [net] packet: in recvmsg msg_name return at least sizeof sockaddr_ll (Davide Caratti) [1760276]
- [net] packet: Set __GFP_NOWARN upon allocation in alloc_pg_vec (Davide Caratti) [1760276]
- [net] packet: fix 4gb buffer limit due to overflow check (Davide Caratti) [1760276]
- [net] llc: do not use sk_eat_skb() (Davide Caratti) [1760276]
- [fs] proc: fix /proc/net/* after setns(2) (Davide Caratti) [1760276]
- [net] Unpublish sk from sk_reuseport_cb before call_rcu (Paolo Abeni) [1760409]
- [net] Fix null de-reference of device refcount (Paolo Abeni) [1760409]
- [include] ipv4: Define __ipv4_neigh_lookup_noref when CONFIG_INET is disabled (Paolo Abeni) [1760409]
- [net] neighbor: Call __ipv4_neigh_lookup_noref in neigh_xmit (Paolo Abeni) [1760409]
- [net] ebpf: record usage of flow dissector (Jiri Benc) [1749812]
- [tools] selftests/bpf: More compatible nc options in test_lwt_ip_encap (Jiri Benc) [1749812]
- [tools] selftests/bpf: Set rp_filter in test_flow_dissector (Jiri Benc) [1749812]
- [net] bpf: lwtunnel: fix reroute supplying invalid dst (Jiri Benc) [1749812]
- [kernel] rh_features: convert to atomic allocation (Jiri Benc) [1749812]
- [net] xsk: lock the control mutex in sock_diag interface (Jiri Benc) [1749812]
- [documentation] networking: fix af_xdp.rst Sphinx warnings (Jiri Benc) [1749812]
- [documentation] flow_dissector: rst'ify documentation (Jiri Benc) [1749812]
- [documentation] flow_dissector: document BPF flow dissector environment (Jiri Benc) [1749812]
- [net] xsk: fix umem memory leak on cleanup (Jiri Benc) [1749812]
- [net] xsk: fix to reject invalid options in Tx descriptor (Jiri Benc) [1749812]
- [net] xsk: fix to reject invalid flags in xsk_bind (Jiri Benc) [1749812]
- [net] xsk: fix potential crash in xsk_diag_put_umem() (Jiri Benc) [1749812]
- [net] bpfilter: re-add header search paths to tools include to fix build error (Jiri Benc) [1749812]
- [documentation] xsk: add FAQ to facilitate for first time users (Jiri Benc) [1749812]
- [net] bpf/test_run: fix unkillable BPF_PROG_TEST_RUN for flow dissector (Jiri Benc) [1749812]
- [tools] sync uapi/linux/if_link.h header (Jiri Benc) [1749812]
- [net] xdp: allow generic and driver XDP on one interface (Jiri Benc) [1749812]
- [net] xdp: Provide extack messages when prog attachment failed (Jiri Benc) [1749812]
- [net] bpfilter: remove extra header search paths for bpfilter_umh (Jiri Benc) [1749812]
- [include] bpf: fix missing prototype warnings (Jiri Benc) [1749812]
- [net] xsk: add sock_diag interface for AF_XDP (Jiri Benc) [1749812]
- [net] xsk: add id to umem (Jiri Benc) [1749812]
- [net] xsk: track AF_XDP sockets on a per-netns list (Jiri Benc) [1749812]
- [include] redhat: rh_kabi: introduce RH_KABI_EXTEND_WITH_SIZE (Jiri Benc) [1749812]
- [net] tcp: Avoid TCP syncookie rejected by SO_REUSEPORT socket (Jiri Benc) [1749812]
- [net] tcp: use monotonic timestamps for PAWS (Jiri Benc) [1749812]
- [net] tcp: remove one indentation level in tcp_create_openreq_child (Jiri Benc) [1749812]
- [netdrv] ppp: Fix memory leak in ppp_write (Guillaume Nault) [1759312]
- [netdrv] ppp: deflate: Fix possible crash in deflate_init (Guillaume Nault) [1759312]
- [netdrv] pppoe: fix reception of frames with no mac header (Guillaume Nault) [1759312]
- [net] tcp_bbr: fix quantization code to not raise cwnd if not probing bandwidth (Florian Westphal) [1759208]
- [net] tcp_bbr: refactor bbr_target_cwnd() for general inflight provisioning (Florian Westphal) [1759208]
- [net] tcp_bbr: centralize code to set gains (Florian Westphal) [1759208]
- [net] tcp_bbr: apply PROBE_RTT cwnd cap even if acked==0 (Florian Westphal) [1759208]
- [net] tcp_bbr: in restart from idle, see if we should exit PROBE_RTT (Florian Westphal) [1759208]
- [net] tcp_bbr: add bbr_check_probe_rtt_done() helper (Florian Westphal) [1759208]
- [net] xfrm/xfrm_policy: fix dst dev null pointer dereference in collect_md mode (Hangbin Liu) [1734589]
- [tools] selftests: forwarding: gre_multipath: Fix flower filters (Hangbin Liu) [1756832]
- [tools] selftests: forwarding: gre_multipath: Enable IPv4 forwarding (Hangbin Liu) [1756832]
- [tools] set sysctl bc_forwarding properly in router_broadcast.sh (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: enable forwarding before ipv4 from/iif test (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: use pre-defined DEV_ADDR (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: fix local IPv4 address typo (Hangbin Liu) [1756832]
- [tools] selftests: fib_rule_tests: print the result and return 1 if any tests failed (Hangbin Liu) [1756832]
- [tools] selftests: fib_tests: Fix 'Command line is not complete' errors (Hangbin Liu) [1756832]
- [tools] selftests: Update fib_tests to handle missing ping6 (Hangbin Liu) [1756832]
- [tools] fib_tests: Add tests for metrics on routes (Hangbin Liu) [1756832]
- [tools] selftests: udpgso_bench.sh explicitly requires bash (Hangbin Liu) [1756832]
- [tools] selftests/net: add tls to .gitignore (Hangbin Liu) [1756832]
- [net] ipv4: avoid mixed n_redirects and rate_tokens usage (Paolo Abeni) [1753092]
- [lib] netlink: set bad attribute also on maxtype check (Petr Oros) [1757776]
- [lib] netlink: add validation of NLA_F_NESTED flag (Petr Oros) [1757776]
- [net] ila: Fix rhashtable walker list corruption (Petr Oros) [1757776]
- [lib] ila: make lockdep happy again (Petr Oros) [1757776]
- [net] genetlink: do not validate dump requests if there is no policy (Petr Oros) [1757776]
- [include] netlink: Fix nlmsg_parse as a wrapper for strict message parsing (Petr Oros) [1757776]
- [net] tipc: fix missing indentation in source code (Petr Oros) [1757776]
- [net] genetlink: optionally validate strictly/dumps (Petr Oros) [1757776]
- [lib] netlink: add strict parsing for future attributes (Petr Oros) [1757776]
- [include] netlink: re-add parse/validate functions in strict mode (Petr Oros) [1757776]
- [net] netlink: make validation more configurable for future strictness (Petr Oros) [1757776]
- [lib] netlink: add NLA_MIN_LEN (Petr Oros) [1757776]
- [net] genetlink: make policy common to family (Petr Oros) [1757776]
- [net] ila: Flush netlink command to clear xlat table (Petr Oros) [1757776]
- [net] ila: Create main ila source file (Petr Oros) [1757776]
- [net] ila: Call library function alloc_bucket_locks (Petr Oros) [1757776]
- [net] ila: Fix use of rhashtable walk in ila_xlat.c (Petr Oros) [1757776]
- [net] rtnetlink: fix rtnl_valid_stats_req() nlmsg_len check (Petr Oros) [1757750]
- [net] mpls: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] mpls: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: addrlabel: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv6: addr: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: ipmr: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: route: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] ipv4: netconf: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] namespace: perform strict checks also for doit handlers (Petr Oros) [1757750]
- [net] rtnetlink: ifinfo: perform strict checks also for doit handler (Petr Oros) [1757750]
- [net] rtnetlink: stats: reject requests for unknown stats (Petr Oros) [1757750]
- [net] rtnetlink: stats: validate attributes in get as well as dumps (Petr Oros) [1757750]
- [net] netlink: add helper to retrieve NETLINK_F_STRICT_CHK (Petr Oros) [1757750]
- [include] linux/netlink.h: drop unnecessary extern prefix (Petr Oros) [1757750]
- [net] rtnetlink: avoid frame size warning in rtnl_newlink() (Petr Oros) [1757750]
- [net] rtnetlink: remove a level of indentation in rtnl_newlink() (Petr Oros) [1757750]
- [net] rtnetlink: Add more extack messages to rtnl_newlink (Petr Oros) [1757750]
- [net] netfilter: nf_tables: allow lookups in dynamic sets (Florian Westphal) [1759074]
- [net] netfilter: nf_tables: check the result of dereferencing base_chain->stats (Florian Westphal) [1759074]
- [net] revert "netfilter: nft_hash: add map lookups for hashing operations" (Florian Westphal) [1759074]
- [net] netfilter: nf_tables: don't prevent event handler from device cleanup on netns exit (Florian Westphal) [1759074]
- [net] netfilter: nft_ct: enable conntrack for helpers (Florian Westphal) [1759074]
- [net] netfilter: conntrack: always store window size un-scaled (Florian Westphal) [1758668]
- [net] netfilter: synproxy: fix rst sequence number mismatch (Florian Westphal) [1758668]
- [net] netfilter: synproxy: fix erroneous tcp mss option (Florian Westphal) [1758668]
- [net] netfilter: nfnetlink: avoid deadlock due to synchronous request_module (Florian Westphal) [1758668]
- [net] netfilter: nf_queue: fix reinject verdict handling (Florian Westphal) [1758668]
- [net] netfilter: conntrack: Use consistent ct id hash calculation (Florian Westphal) [1758668]
- [net] netfilter: ctnetlink: don't use conntrack/expect object addresses as id (Florian Westphal) [1758668]
- [net] netfilter: bridge: Don't sabotage nf_hook calls for an l3mdev slave (Florian Westphal) [1758668]
- [net] netfilter: avoid using skb->nf_bridge directly (Florian Westphal) [1758668]
- [net] netfilter: nat: can't use dst_hold on noref dst (Florian Westphal) [1758668]
- [net] netfilter: bridge: Don't sabotage nf_hook calls from an l3mdev (Florian Westphal) [1758668]
- [net] netfilter: conntrack: fix removal of conntrack entries when l4tracker is removed (Florian Westphal) [1758668]
- [net] netfilter: xt_hashlimit: fix a possible memory leak in htable_create() (Florian Westphal) [1758668]
- [net] netfilter: xt_TEE: add missing code to get interface index in checkentry. (Florian Westphal) [1758668]
- [net] netfilter: xt_TEE: fix wrong interface selection (Florian Westphal) [1758668]
- [net] netfilter: xtables: avoid BUG_ON (Florian Westphal) [1758668]
- [net] netfilter: nat: limit port clash resolution attempts (Florian Westphal) [1758646]
- [net] netfilter: nat: remove l4 protocol port rovers (Florian Westphal) [1758646]
- [net] neighbour: remove stray semicolon (Ivan Vecera) [1757459]
- [net] neighbor: Initialize protocol when new pneigh_entry are created (Ivan Vecera) [1757459]
- [net] neighbour: register rtnl doit handler (Ivan Vecera) [1757459]
- [net] neighbor: Add protocol attribute (Ivan Vecera) [1757459]
- [net] neighbor: Add extack messages for add and delete commands (Ivan Vecera) [1757459]
- [net] rtnetlink: address is mandatory for rtnl_fdb_get (Ivan Vecera) [1757105]
- [netdrv] vxlan: support for ndo_fdb_get (Ivan Vecera) [1757105]
- [net] rtnetlink: support for fdb get (Ivan Vecera) [1757105]
- [net] bridge: support for ndo_fdb_get (Ivan Vecera) [1757105]
- [net] ipmr: remove hard code cache_resolve_queue_len limit (Hangbin Liu) [1631022]
- [net] ipv6/addrconf: allow adding multicast addr if IFA_F_MCAUTOJOIN is set (Hangbin Liu) [1740961]
- [net] xfrm interface: fix management of phydev (Xin Long) [1727240]
- [net] xfrm interface: fix list corruption for x-netns (Xin Long) [1727240]
- [net] xfrm interface: ifname may be wrong in logs (Xin Long) [1727240]
- [net] xfrm interface: avoid corruption on changelink (Xin Long) [1727240]
- [net] netlink: add validation function to policy (Ivan Vecera) [1753333]
- [net] netlink: add attribute range validation to policy (Ivan Vecera) [1753333]
- [net] sched: police: allow accessing police->params with rtnl (Ivan Vecera) [1731416]
- [net] sched: remove block pointer from common offload structure (Ivan Vecera) [1731416]
- [net] nfp: flower: add qos offload install and remove functionality. (Ivan Vecera) [1731416]
- [net] nfp: flower: add qos offload framework (Ivan Vecera) [1731416]
- [net] sched: add block pointer to tc_cls_common_offload structure (Ivan Vecera) [1731416]
- [net] sched: allow stats updates from offloaded police actions (Ivan Vecera) [1731416]
- [net] sched: extend matchall offload for hardware statistics (Ivan Vecera) [1731416]
- [net] sched: add police action to the hardware intermediate representation (Ivan Vecera) [1731416]
- [net] sched: move police action structures to header (Ivan Vecera) [1731416]
- [net] sched: remove unused functions for matchall offload (Ivan Vecera) [1731416]
- [net] dsa: use intermediate representation for matchall offload (Ivan Vecera) [1731416]
- [netdrv] mlxsw: use intermediate representation for matchall offload (Ivan Vecera) [1731416]
- [net] tipc: disallow enabling of loopback interface bearer (Jon Maloy) [1717305]
- [net] tipc: add NULL pointer check before calling kfree_rcu (Jon Maloy) [1747392]
- [net] xsk: Return the whole xdp_desc from xsk_umem_consume_tx (Ivan Vecera) [1748497]
- [net] devlink: add warning for ndo_get_port_parent_id set when not needed (Petr Oros) [1737133]
- [net] devlink: introduce devlink_compat_switch_id_get() helper (Petr Oros) [1737133]
- [net] devlink: extend port attrs for switch ID (Petr Oros) [1737133]
- [net] devlink: convert devlink_port_attrs bools to bits (Petr Oros) [1737133]
- [net] devlink: add warning for ndo_get_phys_port_name set when not needed (Petr Oros) [1737133]
- [netdrv] nfp: move devlink port type set after netdev registration (Petr Oros) [1737133]
- [netdrv] dsa: move devlink_port_attrs_set() call before register (Petr Oros) [1737133]
- [netdrv] mlxsw: Move devlink_port_attrs_set() call before register (Petr Oros) [1737133]
- [netdrv] bnxt: set devlink port type after registration (Petr Oros) [1737133]
- [netdrv] bnxt: call devlink_port_type_eth_set() before port register (Petr Oros) [1737133]
- [netdrv] bnxt: set devlink port attrs properly (Petr Oros) [1737133]
- [netdrv] dsa: add missing net/devlink.h include (Petr Oros) [1737133]
- [netdrv] bnxt: add missing net/devlink.h include (Petr Oros) [1737133]
- [netdrv] revert "devlink: Add a generic wake_on_lan port parameter" (Petr Oros) [1737133]
- [netdrv] bnxt_en: Add bnxt_en initial port params table and register it (Petr Oros) [1737133]
- [netdrv] mlxsw: spectrum: Assume CONFIG_NET_DEVLINK is always enabled (Petr Oros) [1737527]
- [netdrv] netdevsim: assume CONFIG_NET_DEVLINK is always enabled (Petr Oros) [1737527]
- [net] devlink: introduce devlink_compat_phys_port_name_get() (Petr Oros) [1737527]
- [net] replace ndo_get_devlink with ndo_get_devlink_port (Petr Oros) [1737527]
- [net] devlink: select NET_DEVLINK from drivers (Petr Oros) [1737527]
- [net] devlink: add port type spinlock (Petr Oros) [1737527]
- [net] devlink: warn on setting type on unregistered port (Petr Oros) [1737527]
- [net] devlink: disallow port_attrs_set() to be called before register (Petr Oros) [1737527]
- [net] devlink: don't pass return value of __devlink_port_type_set() (Petr Oros) [1737527]
- [net] devlink: don't take devlink_mutex for devlink_compat_* (Petr Oros) [1737527]
- [net] devlink: add couple of missing mutex_destroy() calls (Petr Oros) [1737527]
- [net] devlink: fix kdoc (Petr Oros) [1737527]
- [net] devlink: require non-NULL ops for devlink instances (Petr Oros) [1737527]
- [net] devlink: hold a reference to the netdevice around ethtool compat (Petr Oros) [1737527]
- [net] devlink: create a special NDO for getting the devlink instance (Petr Oros) [1737527]
- [net] devlink: Add WARN_ON to catch errors of not cleaning devlink objects (Petr Oros) [1737527]
- [netdrv] s390/qeth: fix xmit_more support (Ivan Vecera) [1734516]
- [netdrv] revert "[netdrv] gve: account for lack of netdev_xmit_more() definition (RHEL-only)" (Ivan Vecera) [1734516]
- [netdrv] net/mlx5e: Fix wrong xmit_more application (Ivan Vecera) [1734516]
- [include] net: use correct this_cpu primitive in dev_recursion_level (Ivan Vecera) [1734516]
- [netdrv] drivers: net: aurora: use netdev_xmit_more helper (Ivan Vecera) [1734516]
- [netdrv] drivers: net: sfc: use netdev_xmit_more helper (Ivan Vecera) [1734516]
- [netdrv] drivers: mellanox: use netdev_xmit_more() helper (Ivan Vecera) [1734516]
- [netdrv] net: move skb->xmit_more hint to softnet data (Ivan Vecera) [1734516]
- [net] place xmit recursion in softnet data (Ivan Vecera) [1734516]

* Mon Nov 18 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-151.rt13.8.el8]
- [netdrv] net: ena: clean up indentation issue (John Linville) [1770979]
- [netdrv] net: ena: Select DIMLIB for ENA_ETHERNET (John Linville) [1770979]
- [netdrv] net: ena: fix incorrect update of intr_delay_resolution (John Linville) [1770979]
- [netdrv] net: ena: fix retrieval of nonadaptive interrupt moderation intervals (John Linville) [1770979]
- [netdrv] net: ena: fix update of interrupt moderation register (John Linville) [1770979]
- [netdrv] net: ena: remove all old adaptive rx interrupt moderation code from ena_com (John Linville) [1770979]
- [netdrv] net: ena: remove ena_restore_ethtool_params() and relevant fields (John Linville) [1770979]
- [netdrv] net: ena: remove old adaptive interrupt moderation code from ena_netdev (John Linville) [1770979]
- [netdrv] net: ena: remove code duplication in ena_com_update_nonadaptive_moderation_interval _*() (John Linville) [1770979]
- [netdrv] net: ena: enable the interrupt_moderation in driver_supported_features (John Linville) [1770979]
- [netdrv] net: ena: reimplement set/get_coalesce() (John Linville) [1770979]
- [netdrv] net: ena: switch to dim algorithm for rx adaptive interrupt moderation (John Linville) [1770979]
- [netdrv] net: ena: add intr_moder_rx_interval to struct ena_com_dev and use it (John Linville) [1770979]

* Fri Nov 15 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-150.rt13.7.el8]
- [fs] autofs: add ignore mount option (Ian Kent) [1743441]
- [fs] autofs: improve ioctl sbi checks (Ian Kent) [1672133]
- [crypto] crypto: ccp - Retry SEV INIT command in case of integrity check failure. (Gary Hook) [1767627]
- [crypto] crypto: ccp - Verify access to device registers before initializing (Gary Hook) [1756867]
- [crypto] crypto: ccp - Change a message to reflect status instead of failure (Gary Hook) [1756867]
- [netdrv] ixgbevf: Bump version for RHEL 8.2.0 (Ken Cox) [1721701]
- [netdrv] ixgbevf: Fix secpath usage for IPsec Tx offload (Ken Cox) [1721701]
- [netdrv] ixgbevf: make array api static const, makes object smaller (Ken Cox) [1721701]
- [netdrv] ixgbevf: Link lost in VM on ixgbevf when restoring from freeze or suspend (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix a compilation error of skb_frag_t (Ken Cox) [1721701]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721701]
- [netdrv] ixgbevf: Use cached link state instead of re-reading the value for ethtool (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix possible divide by zero in ixgbevf_update_itr (Ken Cox) [1721701]
- [netdrv] ixgbevf: fix a missing check of ixgbevf_write_msg_read_ack (Ken Cox) [1721701]
- [infiniband] IB/hfi1: Use a common pad buffer for 9B and 16B packets (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Avoid excessive retry for TID RDMA READ request (Honggang Li) [1719676]
- [infiniband] RDMA/hfi1: Prevent memory leak in sdma_init (Honggang Li) [1719676]
- [infiniband] IB/hfi1: remove unlikely() from IS_ERR*() condition (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Define variables as unsigned long to fix KASAN warning (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Add a counter for credit waits (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add traces for TID RDMA READ (Honggang Li) [1719676]
- [infiniband] infiniband: hfi1: fix memory leaks (Honggang Li) [1719676]
- [infiniband] infiniband: hfi1: fix a memory leak bug (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop stale TID RDMA packets that cause TIDErr (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add additional checks when handling TID RDMA WRITE DATA packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add additional checks when handling TID RDMA READ RESP packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Unsafe PSN checking for TID RDMA READ Resp packet (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop stale TID RDMA packets (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Fix Spectre v1 vulnerability (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove unused define (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Do not update hcrc for a KDETH packet during fault injection (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Drop all TID RDMA READ RESP packets after r_next_psn (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Field not zero-ed when allocating TID flow memory (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Unreserve a flushed OPFN request (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Check for error on call to alloc_rsm_map_table (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix variable shadowing issue in rvt_create_cq (Honggang Li) [1719676]
- [infiniband] RDMA/rvt: Do not use a kernel header in the ABI (Honggang Li) [1719676]
- [infiniband] IB/hfi1: No need to use try_module_get for debugfs (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Add trace for map_mr_sg (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Enhance trace information for FRWR debug (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add missing INVALIDATE opcodes for trace (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Reduce excessive aspm inlines (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Add helpers to hide SWQE WR details (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1, qib}: Remove AH refcount for UD QPs (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Set QP allowed opcodes after QP allocation (Honggang Li) [1719676]
- [infiniband] IB/{hfi1, qib, rdmavt}: Put qp in error state when cq is full (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fracture single lock used for posting and processing RWQEs (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Move receive work queue struct into uapi directory (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Move rvt_cq_wc struct into uapi directory (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Add new completion inline (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, qib, hfi1}: Convert to new completion API (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Spelling s/statisfied/satisfied/ (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Handle port down properly in pio (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Handle wakeup of orphaned QPs for pio (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Wakeup QPs orphaned on wait list after flush (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Use aborts to trigger RC throttling (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Create inline to get extended headers (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Silence txreq allocation warnings (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Avoid hardlockup with flushlist_lock (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Correct tid qp rcd to match verbs context (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Close PSM sdma_progress sleep window (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Validate fault injection opcode user input (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Use struct_size() helper (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Use struct_size() helper (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Validate page aligned for a given virtual address (Honggang Li) [1719676]
- [infiniband] IB/{qib, hfi1, rdmavt}: Correct ibv_devinfo max_mr value (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Insure freeze_work work_struct is canceled on shutdown (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix alloc_qpn() WARN_ON() (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove set but not used variables 'offset' and 'fspsn' (Honggang Li) [1719676]
- [infiniband] RDMA/rdmavt: Catch use-after-free access of AH structures (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Remove reference to RHF.VCRCErr (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add selected Rcv counters (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, qib, hfi1}: Use new routine to release reference counts (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Use more efficient allowed_ops (Honggang Li) [1719676]
- [infiniband] IB/rdmavt: Fix ab/ba include issues (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Make opfn.h self sufficient (Honggang Li) [1719676]
- [infiniband] IB/{rdmavt, hfi1): Miscellaneous comment fixes (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add debugfs to control expansion ROM write protect (Honggang Li) [1719676]
- [infiniband] hfi1: Convert hfi1_unit_table to XArray (Honggang Li) [1719676]
- [infiniband] hfi1: Convert vesw_idr to XArray (Honggang Li) [1719676]
- [infiniband] RDMA/rdmavt: Use correct sizing on buffers holding page DMA addresses (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Fix two format strings (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Add running average for adaptive pio (Honggang Li) [1719676]
- [infiniband] mm: replace all open encodings for NUMA_NO_NODE (Honggang Li) [1719676]
- [infiniband] drivers/IB,hfi1: do not se mmap_sem (Honggang Li) [1719676]
- [infiniband] IB/hfi1: Suppress a compiler warning (Honggang Li) [1719676]
- [scsi] qla2xxx: Update driver version (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: don't use zero for FC4_PRIORITY_NVME (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: initialize fc4_type_priority (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: fix NPIV tear down process (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Remove an include directive (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix device connect issues in P2P configuration (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Improve logging for scan thread (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Capture FW dump on MPI heartbeat stop event (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Check for MB timeout while capturing ISP27/28xx FW dump (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Set remove flag for all VP (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Add error handling for PLOGI ELS passthrough (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Dual FCP-NVMe target port support (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix a dma_pool_free() call (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix memory leak when sending I/O fails (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix driver unload hang (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix SRB leak on switch command timeout (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix double scsi_done for abort path (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Do command completion on abort timeout (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Reduce the number of forward declarations (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: fixup incorrect usage of host_byte (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Fix partial flash write of MBI (Himanshu Madhani) [1763248]
- [scsi] scsi: qla2xxx: Remove WARN_ON_ONCE in qla2x00_status_cont_entry() (Himanshu Madhani) [1763248]
- [scsi] qla2xxx: Fix conflict_port check for NULL (Himanshu Madhani) [1763248]
- [netdrv] Bump version for RHEL 8.2.0 (Ken Cox) [1721700]
- [netdrv] ixgbe: Fix secpath usage for IPsec TX offload. (Ken Cox) [1721700]
- [netdrv] ixgbe: fix double clean of Tx descriptors with xdp (Ken Cox) [1721700]
- [netdrv] ixgbe: Prevent u8 wrapping of ITR value to something less than 10us (Ken Cox) [1721700]
- [netdrv] ixgbe: use skb_get_queue_mapping in tx path (Ken Cox) [1721700]
- [netdrv] ixgbe: fix memory leaks (Ken Cox) [1721700]
- [netdrv] ixgbe: sync the first fragment unconditionally (Ken Cox) [1721700]
- [netdrv] ixgbe: Use kzfree() rather than its implementation. (Ken Cox) [1721700]
- [netdrv] ixgbe: simplify Rx buffer recycle (Ken Cox) [1721700]
- [netdrv] ixgbe: no need to check return value of debugfs_create functions (Ken Cox) [1721700]
- [netdrv] ixgbe: fix possible deadlock in ixgbe_service_task() (Ken Cox) [1721700]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721700]
- [netdrv] ixgbe: fix potential u32 overflow on shift (Ken Cox) [1721700]
- [netdrv] ixgbe: Avoid NULL pointer dereference with VF on non-IPsec hw (Ken Cox) [1721700]
- [netdrv] ixgbe: Check DDM existence in transceiver before access (Ken Cox) [1721700]
- [netdrv] ixgbe: implement support for SDP/PPS output on X550 hardware (Ken Cox) [1721700]
- [netdrv] ixgbe: Use LLDP ethertype define ETH_P_LLDP (Ken Cox) [1721700]
- [netdrv] ixgbe: add a kernel documentation comment for ixgbe_ptp_get_ts_config (Ken Cox) [1721700]
- [netdrv] ixgbe: use 'cc' instead of 'hw_cc' for local variable (Ken Cox) [1721700]
- [netdrv] ixgbe: fix PTP SDP pin setup on X540 hardware (Ken Cox) [1721700]
- [netdrv] ixgbe: reduce PTP Tx timestamp timeout to 1 second (Ken Cox) [1721700]
- [netdrv] ixgbe: fix AF_XDP tx packet count (Ken Cox) [1721700]
- [netdrv] ixgbe: fix AF_XDP tx byte count (Ken Cox) [1721700]
- [netdrv] ixgbe: remove umem from adapter (Ken Cox) [1721700]
- [netdrv] ixgbe: add tracking of AF_XDP zero-copy state for each queue pair (Ken Cox) [1721700]
- [netdrv] ixgbe: fix mdio bus registration (Ken Cox) [1721700]
- [netdrv] nfp: bpf: implement jitting of JMP32 (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: support removing dead code (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: support optimizing dead branches (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: save original program length (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: split up the skip flag (Pablo Cascon) [1729067]
- [netdrv] nfp: bpf: don't use instruction number for jump target (Pablo Cascon) [1729067]
- [scsi] scsi: target: iscsi: rename some variables to avoid confusion. (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: iscsi: tie the challenge length to the hash digest size (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: iscsi: CHAP: add support for SHA1, SHA256 and SHA3-256 (Maurizio Lombardi) [1769801]
- [scsi] scsi: target: compare full CHAP_A Algorithm strings (Maurizio Lombardi) [1769801]
- [arm64] arm64: topology: Use PPTT to determine if PE is a thread (Jeremy Linton) [1721297]
- [acpi] ACPI/PPTT: Add support for ACPI 6.3 thread flag (Jeremy Linton) [1721297]
- [acpi] ACPI / LPSS: Save/restore LPSS private registers also on Lynxpoint (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [documentation] docs: fix numaperf.rst and add it to the doc tree (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Rename arm_smmu_v3_set_proximity() 'node' local variable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [misc] h8300: pci: Remove local declaration of pcibios_penalize_isa_irq (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [mm] mmc: sdhci-acpi: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [ata] ata: pata_acpi: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [gpu] vga-switcheroo: make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: intel_ips: make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: intel_pmc: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: apple-gmux: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/intel/lpss: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/Kconfig: Select PCI_LOCKLESS_CONFIG if PCI is enabled (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [mfd] mfd: Fix unmet dependency warning for MFD_TPS68470 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] drivers/acpi/scan.c: document why we don't need the device_hotplug_lock (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Fix regression in acpi_device_set_power() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix off-by-one check in iort_dev_find_its_id() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: video: Add new hw_changes_brightness quirk, set it on PB Easynote MZ35 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: blacklist: fix clang warning for unused DMI table (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPICA: Update table load object initialization" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Make acpi_sleep_state_supported() non-static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove needless __ghes_check_estatus() calls (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Unexport acpi_device_get_power() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI / ACPI: Use cached ACPI device state to get PCI device power state (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190703 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update table load object initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for object initialization sequence (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: remove legacy module-level code due to deprecation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: simplify creation of the initial/default namespace (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: intel: Drop double removal of address space handler (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APD: remove redundant assignment to pointer clk (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Introduce "poweroff" callbacks for ACPI PM domain and LPSS (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Simplify and fix PM domain hibernation callbacks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PM: ACPI/PCI: Resume all devices during hibernation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI: PM/ACPI: Refresh all stale power state data in pci_pm_complete() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Add function to return ACPI 6.3 Identical tokens (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Modify node flag detection to find last IDENTICAL (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Introduce concept of a _PR0 dependent device (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Allow transitions to D0 to occur in special cases (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Avoid evaluating _PS3 on transitions from D3hot to D3cold (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: utils: Cleanup acpi_dev_match_cb (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Make AC and battery drivers available on !X86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] coresight: acpi: Support for AMBA components (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of GPEs on first direct enable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: configfs: Resolve objects on host-directed table loads (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: tables: Allow BGRT to be overridden (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / sleep: Switch to use acpi_dev_get_first_match_dev() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] gpio: merrifield: Fix build err without CONFIG_ACPI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: OSL: Make a W=1 kernel-doc warning go away (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: Don't limit named child node matching to data nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPIT: Correct LPIT end address for lpit_process() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/irq: Implement helper to create hierachical domains (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Add memory-side caching attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Add heterogenous memory access attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] node: Link memory nodes to their compute nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [documentation] doc/mm: New documentation for memory performance (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Call pm_set_suspend_via_firmware() during hibernation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PCI: PM: Add missing wakeup.flags.valid checks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix build error when IOMMU_SUPPORT is disabled (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Set enable_for_wake for wakeup GPEs during suspend-to-idle (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190509 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Linux: move ACPI_DEBUG_DEFAULT flag out of ifndef (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: bus: change _ADR representation to 64 bits (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: fix handling of data_nodes in acpi_get_next_subnode() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: fix an uninitialized memory_target (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Update acpi_hmat_type enum with ACPI_HMAT_TYPE_PROXIMITY (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: fix memory leaks in hmat_init() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Check ATS capability in root complex nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / DPTF: Use dev_get_drvdata() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: event: replace strcpy() by strscpy() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Use acpi_lpss_* instead of acpi_subsys_* functions for hibernate (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Reject platform device creation on NUMA node mapping failure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: button: reinitialize button state upon resume (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190405 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: add check to avoid null pointer dereference (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190329 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: utilities: fix spelling of PCC to platform_comm_channel (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg length macro/define for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg compare macro for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename nameseg copy macro for clarity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Print debug messages when enabling GPEs for wakeup (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register memory side cache attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register performance attributes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Register processor domain to its memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi/hmat: Parse and report heterogeneous memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: Add HMAT to generic parsing tables (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi: Create subtable parsing infrastructure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [arm64] arm64: numa: rework ACPI NUMA initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Add support for PMCG (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: video: Use vendor backlight on Sony VPCEH3U1E (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / utils: Remove deprecated function since no user left (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: Clean up whitespace (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Add labels for PNP button devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Simplify acpi_bus_extract_wakeup_device_power_package() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Fix comment typos (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPICA: Clear status of GPEs before enabling them" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Namespace: remove address node from global list after method termination (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of GPEs before enabling them (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: use different default debug value than ACPICA (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / utils: Drop reference in test for device presence (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: sysfs: Prevent get_status() from returning acpi_status (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / device_sysfs: Avoid OF modalias creation for removed device (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / configfs: Mark local data structures static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / configfs: Mark local functions static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: tables: Simplify PPTT leaf node detection (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / bus: Respect PRP0001 when retrieving device match data (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190215 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/ACPICA: Trivial: fix spelling mistakes and fix whitespace formatting (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add GTDT Revision 3 support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: HMAT updates (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: PPTT add additional fields in Processor Structure Flags (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add Error Disconnect Recover Notification value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: MADT: add support for statistical profiling in GICC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: add PCC operation region support for AML interpreter (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [clk] clk: x86: Move clk-lpss.h to platform_data/x86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APEI: Fix possible out-of-bounds access to BERT region (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / processor: Set P_LVL{2, 3sc] } idle state descriptions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / CPPC: Add a helper to get desired performance (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: SRAT: add Generic Affinity Structure subtable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: Add Trigger order to PCC Identifier structure in PDTT (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: ACPI 6.3: Adding predefined methods _NBS, _NCH, _NIC, _NIH, and _NIG (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update/clarify messages for control method failures (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: Fix possible fault with the "test objects" command (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Interpreter: Emit warning for creation of a zero-length op region (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove legacy module-level code support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: Make PWM2 device always present at Lenovo Yoga Book (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / video: Extend chassis-type detection with a "Lunch Box" check (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / video: Refactor and fix dmi_is_desktop() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Add support for the SDEI GHES Notification type (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [firmware] firmware: arm_sdei: Add ACPI GHES registration helper (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/PPTT: Add acpi_pptt_warn_missing() to consolidate logs (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Use separate fixmap pages for arm64 NMI-like notifications (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Only use queued estatus entry during in_nmi_queue_one_entry() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Split ghes_read_estatus() to allow a peek at the CPER length (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make GHES estatus header validation more user friendly (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Pass ghes and estatus separately to avoid a later copy (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Let the notification helper specify the fixmap slot (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Move locking to the notification helper (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Switch NOTIFY_SEA to use the estatus queue (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Move NOTIFY_SEA between the estatus-queue and NOTIFY_NMI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't allow ghes_ack_error() to mask earlier errors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Generalise the estatus queue's notify code (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't update struct ghes' flags in read/clear estatus (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove spurious GHES_TO_CLEAR check (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't store CPER records physical address in struct ghes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make estatus pool allocation a static size (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Make hest.c manage the estatus memory pool (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Switch estatus pool to use vmalloc memory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Remove silent flag from ghes_read_estatus() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Don't wait to serialise with oops messages when panic()ing (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Set debug output flags independent of ACPICA (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Get rid of acpi_sleep_dispatch() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for BSG2150 ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPI / EC: Remove old CLEAR_ON_RESUME quirk" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Simplify boot EC checks in acpi_ec_add() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Eliminate acpi_config_boot_ec() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Make acpi_ec_dsdt_probe() more straightforward (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Make acpi_ec_ecdt_probe() more straightforward (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Declare boot_ec as static (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / DPTF: remove header search path to the parent directory (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Clean up probing for early EC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: debug: Clean up acpi_aml_init() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: no need to check return value of debugfs_create functions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC: Look for ECDT EC after calling acpi_load_tables() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make PCI dependency explicit (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20190108 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: All acpica: Update copyrights to 2019 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpiexec: Add option to dump extra info for memory leaks (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Convert more ACPI errors to firmware errors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: APEI: EINJ: Use DEFINE_DEBUGFS_ATTRIBUTE for debugfs files (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / APEI: Fix parsing HEST that includes Deferred Machine Check subtable (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: table override from built-in initrd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] APEI / ERST: Switch to use new generic UUID API (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Add generic intel_soc_pmic_exec_mipi_pmic_seq_element handling (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Implement exec_mipi_pmic_seq_element for CHT Whiskey Cove PMIC (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix build when CONFIG_IOMMU_API=n (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Fix TS-pin current-source handling (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: NUMA: Use correct type for printing addresses on i386-PAE (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: power: Skip duplicate power resource references in _PRx (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Fix build failure when CONFIG_NLS is set to 'n' (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: Add an ifdef around amlcode and dsdt_amlcode (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Make PCI slot detection driver depend on PCI (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Stub out ACS functions when CONFIG_PCI is not set (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] PCI/ACPI: Allow ACPI to be built without CONFIG_PCI set (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSI: Add OEM _OSI string to enable dGPU direct output (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: PM: Loop in full LPS0 mode only (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: EC / PM: Disable non-wakeup GPEs for suspend-to-idle (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Don't call iommu_ops->add_device directly (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Use device_iommu_mapped() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Use helper functions to access dev->iommu_fwspec (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] driver core: Introduce device_iommu_mapped() function (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu/sysfs: Rename iommu_release_device() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu: Consolitate ->add/remove_device() calls (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [iommu] iommu: Introduce wrappers around dev->iommu_fwspec (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / tables: add DSDT AmlCode new declaration name support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181213 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: change coding style to match ACPICA, no functional change (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debug output: Add option to display method/object evaluation (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: disassembler: disassemble OEMx tables as AML (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Add "Windows 2018.2" string in the _OSI support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Expressions in package elements are not supported (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update buffer-to-string conversions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: add comments, no functional change (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove defines that use deprecated flag (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Add "Windows 2018" string in the _OSI support (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [pci] PCI: Remove unused attr variable in pci_dma_configure (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Refactor _CCA enforcement (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Ignore acpi_device_fix_up_power() return value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI, APEI, EINJ: Change to use DEFINE_SHOW_ATTRIBUTE macro (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for INT3515 ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI/IORT: Fix iort_get_platform_device_domain() uninitialized pointer value (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: SPCR: Consider baud rate 0 as preconfigured state (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / glue: Add acpi_platform_notify() function (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [drivers] drivers core: Prepare support for multiple platform notifications (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / platform: Add SMB0001 HID to forbidden_id_list (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Fix handling of buffer-size in acpi_ex_write_data_to_field() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181031 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: iASL: Enhance error detection (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: iASL: adding definition and disassembly for TPM2 revision 3 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: refactor to fix unused variable warning (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: fix IOSF_MBI dependency (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Add depends on IOSF_MBI to Kconfig entry (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: xpower: Block P-Unit I2C access during read-modify-write (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [include] PM / Domains: Document flags for genpd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for INT33FE ACPI nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSL: Use 'jiffies' as the time bassis for acpi_os_get_timer() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: probe ECDT before loading AML tables regardless of module-level code flag (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Remove acpi_gbl_group_module_level_code and only use acpi_gbl_execute_tables_as_methods instead (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: AML Parser: fix parse loop to correctly skip erroneous extended opcodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: AML interpreter: add region addresses in global list during initialization (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: TAD: Add low-level support for real time capability (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Export acpi_device_get_power() for use by modular build drivers (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: remove redundant 'default n' from Kconfig (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / SBS: Fix rare oops when removing modules (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / SBS: Fix GPE storm on recent MacBookPro's (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20181003 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Never run _REG on system_memory and system_IO (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Split large interpreter file (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for field unit access (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Rename some of the Field Attribute defines (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update for generic_serial_bus and attrib_raw_process_bytes protocol (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / processor: Fix the return value of acpi_processor_ids_walk() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Resume BYT/CHT I2C controllers from resume_noirq (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add a device link from the GPU to the BYT I2C5 controller (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add a device link from the GPU to the CHT I2C7 controller (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make acpi_lpss_find_device() also find PCI devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make hid_uid_match helper accept a NULL uid argument (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Make hid_uid_match helper take an acpi_device as first argument (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] acpi:ipmi: Convert ipmi_user_t to struct ipmi_user 0001-x86-smp-fix-non-SMP-broken-build-due-to-redefinition.patch brew_job bzlist bzlist-v2 run.sh testing_desc v4-notes v5-notes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Exclude I2C busses shared with PUNIT from pmc_atom_d3_mask (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Convert drivers to use SPDX identifier (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: Sort headers alphabetically (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / property: Switch to bitmap_zalloc() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Add alternative ACPI HIDs for Cherry Trail DMA controllers (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: custom_method: remove meaningless null check before debugfs_remove() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / LPSS: Force LPSS quirks on boot (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / bus: Only call dmi_check_system() on X86 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: fix menuconfig presentation of ACPI submenu (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] xen/ACPI: don't upload Px/Cx data for disabled processors (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [x86] x86/smp: fix non-SMP broken build due to redefinition of apic_id_is_primary_thread (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PMIC: CrystalCove: Extend PMOP support to support all possible fields (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Clear status of all events when entering sleep states (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20180810 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpiexec: fix a small memory leak regression (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Reference count: add additional debugging details (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: acpi_exec: fixing -fi option (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Debugger: Cleanup interface to the AML disassembler (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Utilities: split hex detection into smaller functions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update an error message for a duplicate table (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [platform] platform/x86: Add ACPI i2c-multi-instantiate pseudo driver (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [kernel] PM / reboot: Eliminate race between reboot and suspend (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: utils: Remove status workaround from acpi_device_always_present() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Create platform device for fwnodes with multiple i2c devices (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Initialize status to ACPI_STA_DEFAULT (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / EC: Add another entry for Thinkpad X1 Carbon 6th (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: bus: Fix a pointer coding style issue (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] arm64 / ACPI: clean the additional checks before calling ghes_notify_sea() (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / scan: Add static attribute to indirect_io_hosts[] (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: Do not export energy_full[_design] on devices without full_charge_capacity (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / EC: Use ec_no_wakeup on ThinkPad X1 Yoga 3rd (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: get rid of negations in conditions (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: use specialized print macros (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: reorder headers alphabetically (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / battery: drop inclusion of init.h (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: battery: remove redundant old_present check on insertion (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Use data node name and reg property for graphs (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Allow direct graph endpoint references (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Make the ACPI graph API private (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: property: Allow making references to non-device nodes (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI: Convert ACPI reference args to generic fwnode reference args (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / OSI: Add OEM _OSI string to enable NVidia HDMI audio (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] Revert "ACPI / bus: Parse tables as term_list for Dell XPS 9570 and Precision M5530" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: save NVS memory for ASUS 1025C laptop (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / button: fix defined but not used warning (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Update version to 20180629 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Revert "iASL compiler: allow compilation of externals with paths that refer to existing names" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPICA: Revert "iASL: change processing of external op namespace nodes for correctness" (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / x86: enable touchscreen on Dell Venue Pro 7139 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / PM: Default to s2idle in all machines supporting LP S0 (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [acpi] ACPI / button: increment wakeup count only when notified (Al Stone) [1754787 1739728 1730098 1721297 1664185]
- [powerpc] powerpc/papr_scm: Fix an off-by-one check in papr_scm_meta_{get, set} (Gustavo Duarte) [1731035]
- [nvdimm] libnvdimm/altmap: Track namespace boundaries in altmap (Gustavo Duarte) [1731035]
- [powerpc] powerpc/nvdimm: Pick nearby online node if the device node is not online (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Force a scm-unbind if initial scm-bind fails (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Update drc_pmem_unbind() to use H_SCM_UNBIND_ALL (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: Update SCM hcall op-codes in hvcall.h (Gustavo Duarte) [1731035]
- [mm] mm/nvdimm: add is_ioremap_addr and use that to check ioremap address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries/scm: Use a specific endian format for storing uuid from the device tree (Gustavo Duarte) [1731035]
- [powerpc] powerpc/nvdimm: Add support for multibyte read/write for metadata (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries/scm: Mark the region volatile if cache flush not required (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/nvdimm: Add an informative message if we fail to allocate altmap block (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Consolidate numa_enable check and min_common_depth check (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Fix node look up with numa=off boot (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/drconf: Use NUMA_NO_NODE on failures instead of node 0 (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/radix: Use the right page size for vmemmap mapping (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm/hash/4k: Don't use 64K page size for vmemmap with 4K pagesize (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use the correct bind address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/mm: Fallback to RAM if the altmap is unusable (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use ibm, unit-guid as the iset cookie (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Fix DIMM device registration race (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Remove endian conversions (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Update DT properties (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Fix resource end address (Gustavo Duarte) [1731035]
- [powerpc] powerpc/papr_scm: Use depend instead of select (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: Add driver for PAPR SCM regions (Gustavo Duarte) [1731035]
- [powerpc] powerpc/pseries: PAPR persistent memory support (Gustavo Duarte) [1731035]
- [mm] mm, vmstat: reduce zone->lock holding time by /proc/pagetypeinfo (Waiman Long) [1770314]
- [mm] mm, vmstat: hide /proc/pagetypeinfo from normal users (Waiman Long) [1770314]
- [crypto] crypto: chtls - remove cdev_list_lock (Neil Horman) [1737078]
- [crypto] crypto/chelsio/chtls: listen fails with multiadapt (Neil Horman) [1737078]
- [tools] cpupower : Handle set and info subcommands correctly (Steve Best) [1769973]
- [s390] s390/qeth: use IQD Multi-Write (Philipp Rudo) [1731028]
- [s390] s390/qdio: implement IQD Multi-Write (Philipp Rudo) [1731028]
- [s390] s390/qeth: add xmit_more support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: add BQL support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: when in TX NAPI mode, use napi_consume_skb() (Philipp Rudo) [1731028]
- [s390] s390/qeth: add TX NAPI support for IQD devices (Philipp Rudo) [1731028]
- [s390] s390/qeth: collect accurate TX statistics (Philipp Rudo) [1731028]
- [s390] s390/qdio: let drivers opt-out from Output Queue scanning (Philipp Rudo) [1731028]
- [s390] s390/qdio: enable drivers to poll for Output completions (Philipp Rudo) [1731028]
- [usb] xhci-pci: allow host runtime PM as default for Intel Alpine and Titan Ridge (Myron Stowe) [1769877]
- [x86] x86/atomic: Fix smp_mb__{before,after}_atomic() (Prarit Bhargava) [1769789]
- [kernel] stacktrace: Don't skip first entry on noncurrent tasks (Waiman Long) [1766681]
- [kernel] tracing: Fix user stack trace "??" output (Waiman Long) [1766681]
- [kernel] tracing: Fix out-of-range read in trace_stack_print() (Waiman Long) [1766681]
- [kernel] stacktrace: Constify 'entries' arguments (Waiman Long) [1766681]
- [kernel] stacktrace: Force USER_DS for stack_trace_save_user() (Waiman Long) [1766681]
- [x86] x86/stacktrace: Prevent infinite loop in arch_stack_walk_user() (Waiman Long) [1766681]
- [kernel] stacktrace: Use PF_KTHREAD to check for kernel threads (Waiman Long) [1766681]
- [kernel] stacktrace: Unbreak stack_trace_save_tsk_reliable() (Waiman Long) [1766681]
- [x86] x86/stacktrace: Use common infrastructure (Waiman Long) [1766681]
- [kernel] stacktrace: Keep stack_trace structure and remove snprint_stack_trace() (Waiman Long) [1766681]
- [kernel] stacktrace: Provide common infrastructure (Waiman Long) [1766681]
- [kernel] livepatch: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] tracing: Remove the last struct stack_trace usage (Waiman Long) [1766681]
- [kernel] tracing: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] tracing: Make ftrace_trace_userstack() static and conditional (Waiman Long) [1766681]
- [kernel] tracing: Use percpu stack trace buffer more intelligently (Waiman Long) [1766681]
- [kernel] tracing: Simplify stacktrace retrieval in histograms (Waiman Long) [1766681]
- [kernel] lockdep: Remove save argument from check_prev_add() (Waiman Long) [1766681]
- [kernel] lockdep: Remove unused trace argument from print_circular_bug() (Waiman Long) [1766681]
- [drm] drm: Simplify stacktrace handling (Waiman Long) [1766681]
- [md] dm persistent data: Simplify stack trace handling (Waiman Long) [1766681]
- [md] dm bufio: Simplify stack trace retrieval (Waiman Long) [1766681]
- [fs] btrfs: ref-verify: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] dma/debug: Simplify stracktrace retrieval (Waiman Long) [1766681]
- [lib] fault-inject: Simplify stacktrace retrieval (Waiman Long) [1766681]
- [mm] mm/page_owner: Simplify stack trace handling (Waiman Long) [1766681]
- [mm] mm/kmemleak: Simplify stacktrace handling (Waiman Long) [1766681]
- [mm] mm/slub: Simplify stack trace retrieval (Waiman Long) [1766681]
- [kernel] latency_top: Simplify stack trace handling (Waiman Long) [1766681]
- [fs] proc: Simplify task stack retrieval (Waiman Long) [1766681]
- [kernel] backtrace-test: Simplify stack trace handling (Waiman Long) [1766681]
- [lib] lib/stackdepot: Provide functions which operate on plain storage arrays (Waiman Long) [1766681]
- [kernel] stacktrace: Provide helpers for common stack trace operations (Waiman Long) [1766681]
- [kernel] tracing: Cleanup stack trace code (Waiman Long) [1766681]
- [kernel] tracing: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [drm] drm: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] latency_top: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/kasan: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/page_owner: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [mm] mm/slub: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] lockdep: Remove the ULONG_MAX stack trace hackery (Waiman Long) [1766681]
- [kernel] s390/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] parisc/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] arm64/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] riscv/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] unicore32/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] sh/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] arm/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] [x86] x86/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [kernel] um/stacktrace: Remove the pointless ULONG_MAX marker (Waiman Long) [1766681]
- [mm] mm/page_owner: clamp read count to PAGE_SIZE (Waiman Long) [1766681]
- [kernel] tracing: Export trace_dump_stack to modules (Waiman Long) [1766681]
- [kernel] tracing: Have stack tracer trace full stack (Waiman Long) [1766681]
- [kernel] trace: Use rcu_dereference_raw for hooks from trace-event subsystem (Waiman Long) [1766681]
- [kernel] tracing: Have trace_stack nr_entries compare not be so subtle (Waiman Long) [1766681]
- [cpuidle] cpuidle: governor: Add new governors to cpuidle_governors again (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: do not set an owner to allow modunload (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: set haltpoll as preferred governor (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: allow governor switch on cpuidle_register_driver() (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: Add cpuidle.governor= command line parameter (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: vcpu hotplug support (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: disable host side polling when kvm virtualized (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: add haltpoll governor (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: header file stubs must be "static inline" (Marcelo Tosatti) [1759282]
- [cpuidle] governors: unify last_state_idx (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: add poll_limit_ns to cpuidle_device structure (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Fix default time limit (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Disregard disable idle states (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: poll_state: Revise loop termination condition (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle: menu: Fix wakeup statistics updates for polling state (Marcelo Tosatti) [1759282]
- [cpuidle] cpuidle-haltpoll: return -ENODEV on modinit failure (Marcelo Tosatti) [1759282]
- [cpuidle] add cpuidle-haltpoll driver (Marcelo Tosatti) [1759282]
- [mm] mem-hotplug: fix node spanned pages when we have a node with only ZONE_MOVABLE (Baoquan He) [1756210]
- [x86] x86, efi: never relocate kernel below lowest acceptable address (Kairui Song) [1747367]
- [fs] CIFS: Force reval dentry if LOOKUP_REVAL flag is set (Dave Wysochanski) [1767664]
- [fs] CIFS: Force revalidate inode when dentry is stale (Dave Wysochanski) [1767664]
- [fs] CIFS: Gracefully handle QueryInfo errors during open (Dave Wysochanski) [1767664]
- [block] blk-mq: make sure that line break can be printed (Ming Lei) [1741462]
- [block] blk-mq: avoid sysfs buffer overflow with too many CPU cores (Ming Lei) [1741462]
- [netdrv] bnx2x: Fix VF's VLAN reconfiguration in reload. (Manish Chopra) [1720393]
- [netdrv] bnx2x: Prevent ptp_task to be rescheduled indefinitely (Manish Chopra) [1720393]
- [netdrv] bnx2x: Check if transceiver implements DDM before access (Manish Chopra) [1720393]
- [fs] xfs: allocate xattr buffer on demand (Eric Sandeen) [1684599]
- [fs] xfs: consolidate attribute value copying (Eric Sandeen) [1684599]
- [fs] xfs: move remote attr retrieval into xfs_attr3_leaf_getvalue (Eric Sandeen) [1684599]
- [fs] xfs: remove unnecessary indenting from xfs_attr3_leaf_getvalue (Eric Sandeen) [1684599]
- [fs] xfs: make attr lookup returns consistent (Eric Sandeen) [1684599]
- [i2c] i2c: i801: Add support for Intel Comet Lake (David Arcari) [1761547]
- [powerpc] powerpc/xmon: Improve output of XIVE interrupts (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Fix output of XIVE IPI (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Add a dump of all XIVE interrupts (Diego Domingos) [1731130]
- [powerpc] powerpc/xive: Fix dump of XIVE interrupt under pseries (Diego Domingos) [1731130]
- [powerpc] powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL (Diego Domingos) [1731130]
- [fs] xfs: convert inode to extent format after extent merge due to shift (Brian Foster) [1745253]
- [mmc] mmc: sdhci-pci: Add support for Intel CML (Alexander Beregalov) [1761593]
- [powerpc] powerpc/mm/mce: Keep irqs disabled during lockless page table walk (Gustavo Duarte) [1524649]
- [tools] seltests/powerpc: Add a selftest for memcpy_mcsafe (Gustavo Duarte) [1524649]
- [powerpc] powerpc/memcpy: Fix stack corruption for smaller sizes (Gustavo Duarte) [1524649]
- [powerpc] powerpc: add machine check safe copy_to_user (Gustavo Duarte) [1524649]
- [powerpc] powerpc/memcpy: Add memcpy_mcsafe for pmem (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Handle UE event for memcpy_mcsafe (Gustavo Duarte) [1524649]
- [kernel] extable: Add function to search only kernel exception table (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Make machine_check_ue_event() static (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Fix MCE handling for huge pages (Gustavo Duarte) [1524649]
- [powerpc] powerpc/mce: Schedule work from irq_work (Gustavo Duarte) [1524649]
- [x86] x86/boot/64: Round memory hole size up to next PMD page (Frank Ramsay) [1755602]
- [x86] x86/boot/64: Make level2_kernel_pgt pages invalid outside kernel area (Frank Ramsay) [1755602]
- [idle] intel_idle: add support for Jacobsville (Steve Best) [1481744]
- [powercap] powercap/intel_rapl: add support for ICX (Steve Best) [1724421]
- [block] blk-mq: apply normal plugging for HDD (Ming Lei) [1759380]
- [block] blk-mq: honor IO scheduler for multiqueue devices (Ming Lei) [1759380]
- [block] blk-mq: simplify blk_mq_make_request() (Ming Lei) [1759380]
- [block] blk-mq: remove blk_mq_put_ctx() (Ming Lei) [1759380]
- [nvdimm] libnvdimm: Enable unit test infrastructure compile checks (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm: Use PAGE_SIZE instead of SZ_4K for align check (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/label: Remove the dpa align check (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn_dev: Add page size and struct page size to pfn superblock (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn_dev: Add a build check to make sure we notice when struct page size change (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pmem: Advance namespace seed for specific probe errors (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/region: Rewrite _probe_success() to _advance_seeds() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Consolidate 'security' operations (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Tighten scope of nvdimm->busy vs security operations (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/security: Introduce a 'frozen' attribute (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm, region: Use struct_size() in kzalloc() (Jeff Moyer) [1724965]
- [tools] tools/testing/nvdimm: Fix fallthrough warning (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/of_pmem: Provide a unique name for bus provider (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Fix wait_nvdimm_bus_probe_idle() ABBA deadlock (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Stop holding nvdimm_bus_list_mutex over __nd_ioctl() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Prepare the nd_ioctl() path to be re-entrant (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/region: Register badblocks before namespaces (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/bus: Prevent duplicate device_unregister() calls (Jeff Moyer) [1724965]
- [drivers] drivers/base: Introduce kill_device() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm, namespace: Drop uuid_t implementation detail (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'resource' attribute (Jeff Moyer) [1724965]
- [dax] device-dax: Drop register_filesystem() (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/pmem: Bypass CONFIG_HARDENED_USERCOPY overhead (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm: Fix compilation warnings with W=1 (Jeff Moyer) [1724965]
- [nvdimm] libnvdimm/namespace: Fix label tracking error (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'modalias' attribute to DAX 'bus' devices (Jeff Moyer) [1724965]
- [dax] device-dax: Add a 'target_node' attribute (Jeff Moyer) [1724965]
- [dax] device-dax: Auto-bind device after successful new_id (Jeff Moyer) [1724965]
- [dax] acpi/nfit, device-dax: Identify differentiated memory with a unique numa-node (Jeff Moyer) [1724965]
- [dax] device-dax: Add /sys/class/dax backwards compatibility (Jeff Moyer) [1724965]
- [dax] device-dax: Add support for a dax override driver (Jeff Moyer) [1724965]
- [dax] device-dax: Move resource pinning+mapping into the common driver (Jeff Moyer) [1724965]
- [dax] device-dax: Introduce bus + driver model (Jeff Moyer) [1724965]
- [dax] device-dax: Start defining a dax bus model (Jeff Moyer) [1724965]
- [dax] device-dax: Remove multi-resource infrastructure (Jeff Moyer) [1724965]
- [dax] device-dax: Kill dax_region base (Jeff Moyer) [1724965]
- [dax] device-dax: Kill dax_region ida (Jeff Moyer) [1724965]
- [kernel] memremap: Convert to XArray (Jeff Moyer) [1724965]
- [drivers] drivers/dax/device.c: convert variable to vm_fault_t type (Jeff Moyer) [1724965]
- [drivers] driver core: Rewrite test_async_driver_probe to cover serialization and NUMA affinity (Jeff Moyer) [1724965]
- [drivers] libnvdimm: Schedule device registration on node local to the device (Jeff Moyer) [1724965]
- [drivers] PM core: Use new async_schedule_dev command (Jeff Moyer) [1724965]
- [drivers] driver core: Attach devices on CPU local to device node (Jeff Moyer) [1724965]
- [kernel] async: Add support for queueing on specific NUMA node (Jeff Moyer) [1724965]
- [kernel] workqueue: Provide queue_work_node to queue work near a given NUMA node (Jeff Moyer) [1724965]
- [drivers] driver core: Probe devices asynchronously instead of the driver (Jeff Moyer) [1724965]
- [drivers] device core: Consolidate locking and unlocking of parent and device (Jeff Moyer) [1724965]
- [drivers] driver core: Establish order of operations for device_add and device_del via bitflag (Jeff Moyer) [1724965]
- [drivers] driver core: Add missing dev->bus->need_parent_lock checks (Jeff Moyer) [1724965]
- [drivers] driver core: Move async_synchronize_full call (Jeff Moyer) [1724965]

* Thu Nov 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-149.rt13.6.el8]
- [scsi] scsi: qedi: update driver version to 8.37.0.20 (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: Check targetname while finding boot target information (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: remove set but not used variables 'cdev' and 'udev' (Nilesh Javali) [1724588]
- [scsi] scsi: qedi: remove memset/memcpy to nfunc and use func instead (Nilesh Javali) [1724588]
- [scsi] qedi: Use hwfns and affin_hwfn_idx to get MSI-X vector index (Nilesh Javali) [1724588]
- [scsi] scsi: qedf: Update the version to 8.42.3.0 (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Fix race betwen fipvlan request and response path (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Use discovery list to traverse rports (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Decrease the LL2 MTU size to 2500 (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Check for module unloading bit before processing link update AEN (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Initiator fails to re-login to switch after link down (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add debug information for unsolicited processing (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add support for 20 Gbps speed (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Interpret supported caps value correctly (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Add shutdown callback handler (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Update module description string (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Fix crash during sg_reset (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Stop sending fipvlan request on unload (Nilesh Javali) [1724589]
- [scsi] scsi: qedf: Print message during bailout conditions (Nilesh Javali) [1724589]
- [scsi] qedf: Use hwfns and affin_hwfn_idx to get MSI-X vector index to use (Nilesh Javali) [1724589]
- [scsi] scsi: bnx2fc: Handle scope bits when array returns BUSY or TSF (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variables 'task', 'port', 'orig_task' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variables 'lport', 'host' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: remove set but not used variable 'fh' (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix bnx2fc_cmd refcount imbalance in send_srr (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix bnx2fc_cmd refcount imbalance in send_rec (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Update the driver version to 2.12.10 (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Limit the IO size according to the FW capability (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Do not allow both a cleanup completion and abort completion for the same request (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Separate out completion flags and variables for abort and cleanup (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Only put reference to io_req in bnx2fc_abts_cleanup if cleanup times out (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: Redo setting source FCoE MAC (Nilesh Javali) [1724598]
- [scsi] scsi: bnx2fc: fix incorrect cast to u64 on shift operation (Nilesh Javali) [1724598]
- [netdrv] qed: Fix build error without CONFIG_DEVLINK (Manish Chopra) [1720392]
- [netdrv] RDMA/qedr: Fix the hca_type and hca_rev returned in device attributes (Manish Chopra) [1720392]
- [netdrv] qede: qede_fp: simplify a bit 'qede_rx_build_skb()' (Manish Chopra) [1720392]
- [netdrv] qede: Make two functions static (Manish Chopra) [1720392]
- [netdrv] qede: Handle infinite driver spinning for Tx timestamp. (Manish Chopra) [1720392]
- [netdrv] qed: fix spelling mistake "fullill" -> "fulfill" (Manish Chopra) [1720392]
- [netdrv] qed: Fix Config attribute frame format. (Manish Chopra) [1720392]
- [netdrv] qed*: Fix size of config attribute dump. (Manish Chopra) [1720392]
- [netdrv] net: qed: Move static keyword to the front of declaration (Manish Chopra) [1720392]
- [netdrv] qede: Add support for dumping the grc data. (Manish Chopra) [1720392]
- [netdrv] qed: Add APIs for configuring grc dump config flags. (Manish Chopra) [1720392]
- [netdrv] qede: Add support for reading the config id attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add APIs for reading config id attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add cleanup in qed_slowpath_start() (Manish Chopra) [1720392]
- [netdrv] qed: Add driver API for flashing the config attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add API for configuring NVM attributes. (Manish Chopra) [1720392]
- [netdrv] qed: Add new ethtool supported port types based on media. (Manish Chopra) [1720392]
- [netdrv] net/ethernet/qlogic/qed: force the string buffer NULL-terminated (Manish Chopra) [1720392]
- [netdrv] qed: RDMA - Fix the hw_ver returned in device attributes (Manish Chopra) [1720392]
- [netdrv] qed*: Change dpi_addr to be denoted with __iomem (Manish Chopra) [1720392]
- [netdrv] qed: reduce maximum stack frame size (Manish Chopra) [1720392]
- [netdrv] qed: Prefer pcie_capability_read_word() (Manish Chopra) [1720392]
- [netdrv] qed: Add support for Timestamping the unicast PTP packets. (Manish Chopra) [1720392]
- [netdrv] qed: Fix -Wmaybe-uninitialized false positive (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Fix default window size to be based on chip (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Fix tc for MPA ll2 connection (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - fix uninitialized callback (Manish Chopra) [1720392]
- [netdrv] qed: iWARP - Use READ_ONCE and smp_store_release to access ep->state (Manish Chopra) [1720392]
- [netdrv] qed: remove redundant assignment to rc (Manish Chopra) [1720392]
- [netdrv] qed: Fix static checker warning (Manish Chopra) [1720392]
- [netdrv] qed: fix spelling mistake "inculde" -> "include" (Manish Chopra) [1720392]
- [netdrv] qed: Reduce the severity of ptp debug message. (Manish Chopra) [1720392]
- [netdrv] qed*: Add iWARP 100g support (Manish Chopra) [1720392]
- [netdrv] qed: Add qed devlink parameters table (Manish Chopra) [1720392]
- [netdrv] qed: Set the doorbell address correctly (Manish Chopra) [1720392]
- [netdrv] qedr: Change the MSI-X vectors selection to be based on affined engine (Manish Chopra) [1720392]
- [netdrv] qed: Modify offload protocols to use the affined engine (Manish Chopra) [1720392]
- [netdrv] qed*: Change hwfn used for sb initialization (Manish Chopra) [1720392]
- [netdrv] qed: Add llh ppfid interface and 100g support for offload protocols (Manish Chopra) [1720392]
- [netdrv] qed: Modify api for performing a dmae to another PF (Manish Chopra) [1720392]
- [virt] kvm: arm/arm64: vgic: Use the appropriate TRACE_INCLUDE_PATH (Auger Eric) [1749501]
- [arm64] kvm: Kill hyp_alternate_select() (Auger Eric) [1749501]
- [arm64] kvm: Replace hyp_alternate_select with has_vhe() (Auger Eric) [1749501]
- [arm64] kvm: Drop hyp_alternate_select for checking for ARM64_WORKAROUND_834220 (Auger Eric) [1749501]
- [documentation] kvm: arm/arm64: vgic: Allow more than 256 vcpus for KVM_IRQ_LINE (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Use a single IO device per redistributor (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Remove spurious semicolons (Auger Eric) [1749501]
- [arm64] perf_event: Add missing header needed for smp_processor_id() (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Make function comments match function declarations (Auger Eric) [1749501]
- [arm64] kvm: Remove VMID rollover I-cache maintenance (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-irqfd: Implement kvm_arch_set_irq_inatomic (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Check the LPI translation cache on MSI injection (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Cache successful MSI->LPI translation (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on vgic teardown (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on ITS disable (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on disabling LPIs (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Invalidate MSI-LPI translation cache on specific commands (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-its: Add MSI-LPI translation cache invalidation (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Add __vgic_put_lpi_locked primitive (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Add LPI translation cache definition (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic-v2: Handle SGI bits in GICD_I{S, C}PENDR0 as WI (Auger Eric) [1749501]
- [arm64] kvm: Replace hardcoded '1' with SYS_PAR_EL1_F (Auger Eric) [1749501]
- [arm64] sysreg: Add some field definitions for PAR_EL1 (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Fix potential deadlock when ap_list is long (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Properly initialise private IRQ affinity (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Reevaluate level sensitive interrupts on enable (Auger Eric) [1749501]
- [arm64] kvm: arm64: Don't write junk to sysregs on reset (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Sync ICH_VMCR_EL2 back when about to block (Auger Eric) [1749501]
- [arm64] kvm: hyp: debug-sr: Mark expected switch fall-through (Auger Eric) [1749501]
- [arm64] kvm: arm64: Update kvm_arm_exception_class and esr_class_str for new EC (Auger Eric) [1749501]
- [virt] kvm: arm: vgic-v3: Mark expected switch fall-through (Auger Eric) [1749501]
- [arm64] kvm: regmap: Fix unexpected switch fall-through (Auger Eric) [1749501]
- [arm64] sve: Fix a couple of magic numbers for the Z-reg count (Auger Eric) [1749501]
- [arm64] sve: Factor out FPSIMD to SVE state conversion (Auger Eric) [1749501]
- [arm64] kvm: arm/arm64: Initialise host's MPIDRs by reading the actual register (Auger Eric) [1749501]
- [arm64] kvm: arm64: Migrate _elx sysreg accessors to msr_s/mrs_s (Auger Eric) [1749501]
- [arm64] sysreg: Make mrs_s and msr_s macros work with Clang and LTO (Auger Eric) [1749501]
- [documentation] kvm: doc: Add API documentation on the KVM_REG_ARM_WORKAROUNDS register (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Add save/restore support for firmware workaround state (Auger Eric) [1749501]
- [arm64] kvm: Propagate full Spectre v2 workaround state to KVM guests (Auger Eric) [1749501]
- [arm64] sve: Fix missing SVE/FPSIMD endianness conversions (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: vgic: Fix kvm_device leak in vgic_its_destroy (Auger Eric) [1749501]
- [arm64] kvm: arm64: Filter out invalid core register IDs in KVM_GET_REG_LIST (Auger Eric) [1749501]
- [arm64] kvm: arm64: Skip more of the SError vaxorcism (Auger Eric) [1749501]
- [arm64] kvm: arm64: Re-mask SError after the one instruction window (Auger Eric) [1749501]
- [arm64] Update silicon-errata.txt for Neoverse-N1 #1349291 (Auger Eric) [1749501]
- [arm64] kvm: arm64: Defer guest entry when an asynchronous exception is pending (Auger Eric) [1749501]
- [arm64] kvm: arm64: Consume pending SError as early as possible (Auger Eric) [1749501]
- [arm64] kvm: arm64: Make indirect vectors preamble behaviour symmetric (Auger Eric) [1749501]
- [arm64] kvm: arm64: Abstract the size of the HYP vectors pre-amble (Auger Eric) [1749501]
- [arm64] assembler: Switch ESB-instruction with a vanilla nop if !ARM64_HAS_RAS (Auger Eric) [1749501]
- [arm64] kvm: arm64/sve: Fix vq_present() macro to yield a bool (Auger Eric) [1749501]
- [arm64] kvm: arm64: Implement vq_present() as a macro (Auger Eric) [1749501]
- [arm64] fpsimd: Don't disable softirq when touching FPSIMD/SVE state (Auger Eric) [1749501]
- [arm64] fpsimd: Introduce fpsimd_save_and_flush_cpu_state() and use it (Auger Eric) [1749501]
- [arm64] fpsimd: Remove the prototype for sve_flush_cpu_state() (Auger Eric) [1749501]
- [scripts] genksyms: Teach parser about 128-bit built-in types (Auger Eric) [1749501]
- [tools] kvm: selftests: introduce aarch64_vcpu_add_default (Auger Eric) [1749501]
- [tools] kvm: selftests: introduce aarch64_vcpu_setup (Auger Eric) [1749501]
- [virt] kvm: arm/arm64: Move cc/it checks under hyp's Makefile to avoid instrumentation (Auger Eric) [1749501]
- [arm64] kvm: arm64: Move pmu hyp code under hyp's Makefile to avoid instrumentation (Auger Eric) [1749501]
- [documentation] arm64: docs: Document perf event attributes (Auger Eric) [1749501]
- [arm64] kvm: Fix perf cycle counter support for VHE (Auger Eric) [1749501]
- [arm64] kvm: Avoid isb's by using direct pmxevtyper sysreg (Auger Eric) [1749501]
- [arm64] kvm: Enable VHE support for :G/:H perf event modifiers (Auger Eric) [1749501]
- [arm64] kvm: Enable !VHE support for :G/:H perf event modifiers (Auger Eric) [1749501]
- [arm64] arm_pmu: Add !VHE support for exclude_host/exclude_guest attributes (Auger Eric) [1749501]
- [arm64] kvm: Add accessors to track guest/host only counters (Auger Eric) [1749501]
- [arm64] arm_pmu: Remove unnecessary isb instruction (Auger Eric) [1749501]
- [arm64] perf: Add support for chaining event counters (Auger Eric) [1749501]
- [arm64] perf: Disable PMU while processing counter overflows (Auger Eric) [1749501]
- [arm64] perf: Clean up armv8pmu_select_counter (Auger Eric) [1749501]
- [arm64] kvm: arm: Remove pgtable page standard functions from stage-2 page tables (Auger Eric) [1749501]
- [netdrv] e1000e: Add support for Tiger Lake (Ken Cox) [1767480]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (Corinna Vinschen) [1721705]
- [netdrv] igb: Use dev_get_drvdata where possible (Corinna Vinschen) [1721705]
- [netdrv] net: Use skb accessors in network drivers (Corinna Vinschen) [1721705]
- [netdrv] igb: add RR2DCDELAY to ethtool registers dump (Corinna Vinschen) [1721705]
- [netdrv] igb: minor ethool regdump amendment (Corinna Vinschen) [1721705]
- [netdrv] igb: clear out skb->tstamp after reading the txtime (Corinna Vinschen) [1721705]
- [netdrv] igb: mark expected switch fall-through (Corinna Vinschen) [1721705]
- [netdrv] igb: mark expected switch fall-through (Corinna Vinschen) [1721705]
- [netdrv] igb/igc: warn when fatal read failure happens (Corinna Vinschen) [1721705]
- [netdrv] igb: fix various indentation issues (Corinna Vinschen) [1721705]
- [netdrv] igb: Exclude device from suspend direct complete optimization (Corinna Vinschen) [1721705]
- [netdrv] intel: correct return from set features callback (Corinna Vinschen) [1721705]
- [netdrv] net: Use skb accessors in network drivers (Corinna Vinschen) [1721708]
- [s390] s390/kaslr: reserve memory for kasan usage (Philipp Rudo) [1725888]
- [s390] s390/mem_detect: provide single get_mem_detect_end (Philipp Rudo) [1725888]
- [s390] s390/setup: adjust start_code of init_mm to _text (Philipp Rudo) [1725888]
- [s390] s390/boot: add missing declarations and includes (Philipp Rudo) [1725888]
- [s390] locking/lockdep: check for freed initmem in static_obj() (Philipp Rudo) [1725888]
- [s390] s390/kernel: add support for kernel address space layout randomization (KASLR) (Philipp Rudo) [1725888]
- [s390] s390/kernel: introduce .dma sections (Philipp Rudo) [1725888]
- [s390] s390/sclp: do not use static sccbs (Philipp Rudo) [1725888]
- [s390] s390/kprobes: use static buffer for insn_page (Philipp Rudo) [1725888]
- [s390] s390/kernel: convert SYSCALL and PGM_CHECK handlers to .quad (Philipp Rudo) [1725888]
- [s390] s390/kernel: build a relocatable kernel (Philipp Rudo) [1725888]
- [s390] s390/extmem: remove code for 31 bit addressing mode (Philipp Rudo) [1725888]
- [s390] s390/setup: remove obsolete #ifdef (Philipp Rudo) [1725888]
- [net] net/core: work around section mismatch warning for ptp_classifier (Philipp Rudo) [1725888]
- [sound] ALSA: bebob: fix to detect configured source of sampling clock for Focusrite Saffire Pro i/o series (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: link the order of establishing connections and Syt-match clock mode (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: expand delay of start for IR context just for version 3 firmware (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: expand sleep just after breaking connections for protocol version 1 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC/SOF - enable SND_SOC_SOF_HDA_COMMON_HDMI_CODEC (Jaroslav Kysela) [1710702]
- [sound] ALSA: timer: Fix mutex deadlock at releasing card (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Add quirk for boards using pmc_plt_clk_0 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: eve: Enable mclk and ssp sclk early (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: dt-bindings: rt5682: add button delay device property (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: rt5682: improve the sensitivity of push button (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: bxt_rt298: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: common hdmi codec support (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: add support for snd-hda-codec-hdmi (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: fix include guard name (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: use snd-hda-codec-hdmi (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: hdac_hda: add support for HDMI/DP as a HDA codec (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/hdmi - implement mst_no_extra_pcms flag (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF - remove the dead code (skylake/kabylake) (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel - fix the card names (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pci: Add prepare/complete PM callbacks (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: Add support for DSP D0i3 state when entering S0ix (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: return -ENOTSUPP if D0I3 is not supported (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: implement suspend/resume for S0ix<->S0 transition (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ignore suspend/resume for D0ix compatible streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: implement prepare/complete callbacks (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a flag suspend_ignored for sof stream (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a flag to indicate the system suspend target (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add support for sending compact IPC (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: add helpers for setting D0 substate for ADSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: configure D0ix IPC flags in set_power_state (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: HDA: add cAVS specific compact IPC header file (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: Don't read mailbox for PM_GATE reply (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: introduce message for DSP power gating (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: PM: rename sof_send_pm_ipc to sof_send_pm_ctx_ipc (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: HDA: use macro for register polling retry count (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: align the comments for D0I3C update (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: parse and store d0i3_compatible flag (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: token: add tokens for PCM compatible with D0i3 substate (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add flag to snd_sof_pcm_stream for D0i3 compatible stream (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: APL: add set_power_state() ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add set_power_state() ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-dsp: Add helper for setting DSP D0ix substate (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add set_power_state() to dsp_ops for power state update (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: reset default d0_substate at probe() and resume() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: add a field to store the current D0 substate of DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: eve: implement set_bias_level function for rt5514 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: only support INFO_BATCH for legacy platforms (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: define INFO_ flags in dsp_ops (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: initial support to JasperLake. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for JSL (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: add dev_err() traces for snd_sof_dsp_read_poll_timeout() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda-loader: improve error handling (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: sof: include types.h at header.h (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Fix randbuild error (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: check errors when parsing LED tokens (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: remove always-true redundant test (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: bdw: fix operator precedence warnings (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: byt: fix operator precedence warnings (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: imx: Read ESAI parameters and send them to DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: acpi led support for switch controls (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: imx: Describe ESAI parameters to be sent to DSP (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pci: add debug module param (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: acpi: add debug module param (Jaroslav Kysela) [1710702]
- [sound] ALSA: Revert "ASoC: SOF: Force polling mode on CFL and CNL" (Jaroslav Kysela) [1710702]
- [sound] ALSA: AsoC: SOF: refactor control load code (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: enable dual control for pga (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: enable sync_write in hdac_bus (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: simple_card_utils.h: Add missing include (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: Add context data to any IPC timeout. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix reset of host_period_bytes (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: introduce no_stream_position in sof_ipc_stream_params struct (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: core: check for mandatory fw_ready op during SOF probe (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: ipc: retain DSP context after FW exception. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: trace: move to opt-in with Kconfig and module parameter (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Fix 2 front mics of codec 0x623 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Add support for ALC623 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Fix mutex deadlock in HDMI codec driver (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Fix pending unsol events at shutdown (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: Correct a typo in the clock proc string (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: add support for MOTU UltraLite (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: code refactoring to handle model specific switch for protocol v2 (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: minor code refactoring for protocol version 2 (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: detect SPH source of sampling clock (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: print for unknown source of sampling clock (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: fix wrong spelling for macro (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: Fix prototype of helper function to return negative value (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: sound: usb: usb true/false for bool return type (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB Interface (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Allow non-Intel device probe gracefully (Jaroslav Kysela) [1710702]
- [sound] ALSA: Revert "ALSA: hda: Flush interrupts on disabling" (Jaroslav Kysela) [1710702]
- [sound] ALSA: PCI: Fix missing inline for pci_pr3_present() (Jaroslav Kysela) [1710702]
- [sound] ALSA: PCI: Add a helper to check Power Resource Requirements _PR3 existence (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Fix copy&paste error in the validator (Jaroslav Kysela) [1710702]
- [sound] ALSA: usb-audio: Add DSD support for EVGA NU Audio (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: postpone to start IR context (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: handle several AMDTP streams in callback handler of IRQ target (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: cancel flushing isoc context in the laste step to process context callback (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: replace ack callback to flush isoc contexts in AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: replace pointer callback to flush isoc contexts in AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: add irq_target member into amdtp_domain struct (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: tune the minimum available size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: tune the maximum available size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: schedule hardware IRQ according to the size of PCM period (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: share PCM buffer size for both direction (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: use variable size of queue for isoc packets instead of fixed size (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: use the same size of period for PCM substreams in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: use the same size of period for PCM substream in AMDTP streams (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireface: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-motu: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-tascam: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-digi00x: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: dice: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: oxfw: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: fireworks: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: bebob: register the size of PCM period to AMDTP domain (Jaroslav Kysela) [1710702]
- [sound] ALSA: firewire-lib: add a member into AMDTP domain for events per period (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Enable headset mic on Asus MJ401TA (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek: Reduce the Headphone static noise on XPS 9350/9360 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda/realtek - Add support for ALC711 (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Force runtime PM on Nvidia HDMI codecs (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda - Add laptop imic fixup for ASUS M9V laptop (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Add Tigerlake/Jasperlake PCI ID (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: Allow HDA to be runtime suspended when dGPU is not bound to a driver (Jaroslav Kysela) [1710702]
- [sound] ALSA: hdac: clear link output stream mapping (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: dapm: fix a memory leak bug (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: debug: fix possible memory leak in sof_dfsentry_write() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add a check for devm_clk_get (Jaroslav Kysela) [1710702]
- [sound] ALSA: Fix Kconfig indentation (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: control: return true when kcontrol values change (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: fix intel DSP config (Jaroslav Kysela) [1710702]
- [sound] ALSA: hda: add Intel DSP configuration / probe code (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: core: Fix pcm code debugfs error (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoc: rockchip: i2s: Fix RPM imbalance (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm_adsp: Don't generate kcontrols without READ flags (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: bytcr_rt5651: add null check to support_button_press (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: add remove function to disable jack (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: rt5682: add NULL handler to set_jack function (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: intel: sof_rt5682: use separate route map for dmic (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: initialise and verify FW crash dump data. (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix warnings during FW load (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pcm: harden PCM STOP sequence (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: pcm: fix resource leak in hw_free (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: topology: fix parse fail issue for byte/bool tuple types (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: SOF: loader: fix kernel oops on firmware boot failure (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm_adsp: Fix theoretical NULL pointer for alg_region (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: max98373: check for device node before parsing (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: topology: Fix a signedness bug in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: soc-component: fix a couple missing error assignments (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: wm8994: Do not register inapplicable controls for WM1811 (Jaroslav Kysela) [1710702]
- [sound] ALSA: ASoC: samsung: arndale: Add missing OF node dereferencing (Jaroslav Kysela) [1710702]
- [infiniband] RDMA/bnxt_re: Fix spelling mistake "missin_resp" -> "missing_resp" (Kamal Heib) [1724772]
- [infiniband] RDMA: Fix goto target to release the allocated memory (Kamal Heib) [1724772]
- [infiniband] IB/bnxt_re: Do not notifify GID change event (Kamal Heib) [1724772]
- [infiniband] RDMA/bnxt_re: Honor vlan_id in GID entry comparison (Kamal Heib) [1724772]
- [infiniband] ib/bnxt: Remove mention of idr_alloc from comment (Kamal Heib) [1724772]
- [infiniband] RDMA/bnxt_re: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1724772]
- [infiniband] bnxt_re: Clean cq for kernel consumers only (Kamal Heib) [1724772]
- [infiniband] bnxt_re: fix the regression due to changes in alloc_pbl (Kamal Heib) [1724772]
- [scsi] scsi: lpfc: Make lpfc_debugfs_ras_log_data static (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix NULL check before mempool_destroy is not needed (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix spelling error in MAGIC_NUMER_xxx (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix build error of lpfc_debugfs.c for vfree/vmalloc (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: lpfc_nvmet: Fix Use plain integer as NULL pointer (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: lpfc_attr: Fix Use plain integer as NULL pointer (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Update lpfc version to 12.6.0.0 (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add additional discovery log messages (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add FC-AL support to lpe32000 models (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add FA-WWN Async Event reporting (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Add log macros to allow print by serverity or verbosity setting (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Make FW logging dynamically configurable (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Revise interrupt coalescing for missing scenarios (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Remove lock contention target write path (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Slight fast-path performance optimizations (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix coverity error of dereference after null check (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix hardlockup in lpfc_abort_handler (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix bad ndlp ptr in xri aborted handling (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix SLI3 hba in loop mode not discovering devices (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix lockdep errors in sli_ringtx_put (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Fix reporting of read-only fw error errors (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: fix lpfc_nvmet_mrq to be bound by hdw queue count (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: Make function lpfc_defer_pt2pt_acc static (Dick Kennedy) [1768102]
- [scsi] scsi: lpfc: add support for posting FC events on FPIN reception (Dick Kennedy) [1768102]
- [infiniband] RDMA/siw: Mark Software iWARP Driver as tech-preview (Kamal Heib) [1767292]
- [crypto] crypto: ccp - Replace dma_pool_alloc + memset with dma_pool_zalloc (Gary Hook) [1724859]
- [crypto] crypto: ccp/gcm - use const time tag comparison. (Gary Hook) [1724859]
- [crypto] crypto: ccp - Switch to SPDX license identifiers (Gary Hook) [1724859]
- [crypto] crypto: ccp - Validate the the error value used to index error messages (Gary Hook) [1724859]
- [crypto] crypto: ccp - Make ccp_register_rsa_alg static (Gary Hook) [1724859]
- [crypto] crypto: ccp - Update copyright notices and dates (Gary Hook) [1724859]
- [crypto] cross-tree: phase out dma_zalloc_coherent() (Gary Hook) [1724859]
- [x86] x86/umwait: Fix error handling in umwait_init() (Steve Best) [1724525]
- [documentation] Documentation/ABI: Document umwait control sysfs interfaces (Steve Best) [1724525]
- [x86] x86/umwait: Add sysfs interface to control umwait maximum time (Steve Best) [1724525]
- [x86] x86/umwait: Add sysfs interface to control umwait C0.2 state (Steve Best) [1724525]
- [x86] x86/umwait: Initialize umwait control values (Steve Best) [1724525]
- [x86] x86/cpufeatures: Enumerate user wait instructions (Steve Best) [1724525]
- [fs] virtiofs: Remove set but not used variable 'fc' (Vivek Goyal) [1694161]
- [fs] virtiofs: Retry request submission from worker context (Vivek Goyal) [1694161]
- [fs] virtiofs: Count pending forgets as in_flight forgets (Vivek Goyal) [1694161]
- [fs] virtiofs: Set FR_SENT flag only after request has been sent (Vivek Goyal) [1694161]
- [fs] virtiofs: No need to check fpq->connected state (Vivek Goyal) [1694161]
- [fs] virtiofs: Do not end request in submission context (Vivek Goyal) [1694161]
- [fs] fuse: don't advise readdirplus for negative lookup (Vivek Goyal) [1694161]
- [fs] fuse: don't dereference req->args on finished request (Vivek Goyal) [1694161]
- [fs] virtio-fs: don't show mount options (Vivek Goyal) [1694161]
- [fs] virtio-fs: Change module name to virtiofs.ko (Vivek Goyal) [1694161]
- [include] bitops: protect variables in bit_clear_unless() macro (Vivek Goyal) [1694161]
- [include] bitops: protect variables in set_mask_bits() macro (Vivek Goyal) [1694161]
- [fs] fuse: Make fuse_args_to_req static (Vivek Goyal) [1694161]
- [fs] fuse: fix memleak in cuse_channel_open (Vivek Goyal) [1694161]
- [fs] fuse: fix beyond-end-of-page access in fuse_parse_cache() (Vivek Goyal) [1694161]
- [fs] fuse: unexport fuse_put_request (Vivek Goyal) [1694161]
- [fs] fuse: kmemcg account fs data (Vivek Goyal) [1694161]
- [fs] fuse: on 64-bit store time in d_fsdata directly (Vivek Goyal) [1694161]
- [fs] fuse: fix missing unlock_page in fuse_writepage() (Vivek Goyal) [1694161]
- [fs] virtio-fs: add virtiofs filesystem (Vivek Goyal) [1694161]
- [fs] fuse: allow skipping control interface and forced unmount (Vivek Goyal) [1694161]
- [fs] fuse: dissociate DESTROY from fuseblk (Vivek Goyal) [1694161]
- [fs] fuse: delete dentry if timeout is zero (Vivek Goyal) [1694161]
- [fs] fuse: separate fuse device allocation and installation in fuse_conn (Vivek Goyal) [1694161]
- [fs] fuse: add fuse_iqueue_ops callbacks (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_fill_super_common() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_dequeue_forget() function (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_get_unique() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_send_init_request() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_len_args() (Vivek Goyal) [1694161]
- [fs] fuse: export fuse_end_request() (Vivek Goyal) [1694161]
- [fs] fuse: fix request limit (Vivek Goyal) [1694161]
- [fs] fuse: stop copying pages to fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: stop copying args to fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_req (Vivek Goyal) [1694161]
- [fs] fuse: simplify request allocation (Vivek Goyal) [1694161]
- [fs] fuse: unexport request ops (Vivek Goyal) [1694161]
- [fs] fuse: convert retrieve to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert release to simple api (Vivek Goyal) [1694161]
- [fs] cuse: convert init to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert init to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert writepages to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert readdir to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert readpages to simple api (Vivek Goyal) [1694161]
- [fs] fuse: convert direct_io to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add simple background helper (Vivek Goyal) [1694161]
- [fs] fuse: convert sync write to simple api (Vivek Goyal) [1694161]
- [fs] fuse: covert readpage to simple api (Vivek Goyal) [1694161]
- [fs] fuse: fuse_short_read(): don't take fuse_req as argument (Vivek Goyal) [1694161]
- [fs] fuse: convert ioctl to simple api (Vivek Goyal) [1694161]
- [fs] fuse: move page alloc (Vivek Goyal) [1694161]
- [fs] fuse: convert readlink to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add pages to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert destroy to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add nocreds to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert fuse_force_forget() to simple api (Vivek Goyal) [1694161]
- [fs] fuse: add noreply to fuse_args (Vivek Goyal) [1694161]
- [fs] fuse: convert flush to simple api (Vivek Goyal) [1694161]
- [fs] fuse: simplify 'nofail' request (Vivek Goyal) [1694161]
- [fs] fuse: rearrange and resize fuse_args fields (Vivek Goyal) [1694161]
- [fs] fuse: flatten 'struct fuse_args' (Vivek Goyal) [1694161]
- [fs] fuse: fix deadlock with aio poll and fuse_iqueue::waitq.lock (Vivek Goyal) [1694161]
- [fs] cuse: fix broken release (Vivek Goyal) [1694161]
- [fs] fuse: cleanup fuse_wait_on_page_writeback (Vivek Goyal) [1694161]
- [fs] fuse: require /dev/fuse reads to have enough buffer capacity (take 2) (Vivek Goyal) [1694161]
- [fs] Revert "fuse: require /dev/fuse reads to have enough buffer capacity" (Vivek Goyal) [1694161]
- [fs] fuse: extract helper for range writeback (Vivek Goyal) [1694161]
- [fs] fuse: add FUSE_WRITE_KILL_PRIV (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_alloc_inode (Vivek Goyal) [1694161]
- [fs] fuse: Add ioctl flag for x32 compat ioctl (Vivek Goyal) [1694161]
- [fs] fuse: document fuse_fsync_in.fsync_flags (Vivek Goyal) [1694161]
- [fs] fuse: require /dev/fuse reads to have enough buffer capacity (Vivek Goyal) [1694161]
- [fs] fuse: retrieve: cap requested size to negotiated max_write (Vivek Goyal) [1694161]
- [fs] fuse: allow filesystems to have precise control over data cache (Vivek Goyal) [1694161]
- [fs] fuse: convert printk -> pr_* (Vivek Goyal) [1694161]
- [fs] fuse: fix writepages on 32bit (Vivek Goyal) [1694161]
- [fs] fuse: cache readdir calls if filesystem opts out of opendir (Vivek Goyal) [1694161]
- [fs] fuse: support clients that don't implement 'opendir' (Vivek Goyal) [1694161]
- [fs] fuse: lift bad inode checks into callers (Vivek Goyal) [1694161]
- [fs] fuse: multiplex cached/direct_io file operations (Vivek Goyal) [1694161]
- [fs] fuse add copy_file_range to direct io fops (Vivek Goyal) [1694161]
- [fs] fuse: use iov_iter based generic splice helpers (Vivek Goyal) [1694161]
- [fs] fuse: Switch to using async direct IO for FOPEN_DIRECT_IO (Vivek Goyal) [1694161]
- [fs] fuse: use atomic64_t for khctr (Vivek Goyal) [1694161]
- [fs] fuse: clean up aborted (Vivek Goyal) [1694161]
- [fs] fuse: Protect ff->reserved_req via corresponding fi->lock (Vivek Goyal) [1694161]
- [fs] fuse: Protect fi->nlookup with fi->lock (Vivek Goyal) [1694161]
- [fs] fuse: Introduce fi->lock to protect write related fields (Vivek Goyal) [1694161]
- [fs] fuse: Convert fc->attr_version into atomic64_t (Vivek Goyal) [1694161]
- [fs] fuse: Add fuse_inode argument to fuse_prepare_release() (Vivek Goyal) [1694161]
- [fs] fuse: Verify userspace asks to requeue interrupt that we really sent (Vivek Goyal) [1694161]
- [fs] fuse: Do some refactoring in fuse_dev_do_write() (Vivek Goyal) [1694161]
- [fs] fuse: Wake up req->waitq of only if not background (Vivek Goyal) [1694161]
- [fs] fuse: Optimize request_end() by not taking fiq->waitq.lock (Vivek Goyal) [1694161]
- [fs] fuse: Kill fasync only if interrupt is queued in queue_interrupt() (Vivek Goyal) [1694161]
- [fs] fuse: Remove stale comment in end_requests() (Vivek Goyal) [1694161]
- [fs] fuse: Replace page without copying in fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: fix leaked aux requests (Vivek Goyal) [1694161]
- [fs] fuse: only reuse auxiliary request in fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: clean up fuse_writepage_in_flight() (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_find_writeback() helper (Vivek Goyal) [1694161]
- [fs] cuse: fix ioctl (Vivek Goyal) [1694161]
- [fs] fuse: Fix memory leak in fuse_dev_free() (Vivek Goyal) [1694161]
- [fs] fuse: fix revalidation of attributes for permission check (Vivek Goyal) [1694161]
- [fs] fuse: fix fsync on directory (Vivek Goyal) [1694161]
- [fs] fuse: Add bad inode check in fuse_destroy_inode() (Vivek Goyal) [1694161]
- [fs] fuse: enable caching of symlinks (Vivek Goyal) [1694161]
- [fs] fuse: only invalidate atime in direct read (Vivek Goyal) [1694161]
- [fs] fuse: realloc page array (Vivek Goyal) [1694161]
- [fs] fuse: add max_pages to init_out (Vivek Goyal) [1694161]
- [fs] fuse: allocate page array more efficiently (Vivek Goyal) [1694161]
- [fs] fuse: reduce size of struct fuse_inode (Vivek Goyal) [1694161]
- [fs] fuse: use iversion for readdir cache verification (Vivek Goyal) [1694161]
- [fs] fuse: use mtime for readdir cache verification (Vivek Goyal) [1694161]
- [fs] fuse: add readdir cache version (Vivek Goyal) [1694161]
- [fs] fuse: allow using readdir cache (Vivek Goyal) [1694161]
- [fs] fuse: allow caching readdir (Vivek Goyal) [1694161]
- [fs] fuse: extract fuse_emit() helper (Vivek Goyal) [1694161]
- [fs] fuse: add FOPEN_CACHE_DIR (Vivek Goyal) [1694161]
- [fs] fuse: split out readdir.c (Vivek Goyal) [1694161]
- [fs] fuse: Use hash table to link processing request (Vivek Goyal) [1694161]
- [fs] fuse: kill req->intr_unique (Vivek Goyal) [1694161]
- [fs] fuse: change interrupt requests allocation algorithm (Vivek Goyal) [1694161]
- [fs] fuse: do not take fc->lock in fuse_request_send_background() (Vivek Goyal) [1694161]
- [fs] fuse: introduce fc->bg_lock (Vivek Goyal) [1694161]
- [fs] fuse: add locking to max_background and congestion_threshold changes (Vivek Goyal) [1694161]
- [fs] fuse: use READ_ONCE on congestion_threshold and max_background (Vivek Goyal) [1694161]
- [fs] fuse: use list_first_entry() in flush_bg_queue() (Vivek Goyal) [1694161]
- [fs] fuse: reduce allocation size for splice_write (Vivek Goyal) [1694161]
- [fs] fuse: use kvmalloc to allocate array of pipe_buffer structs. (Vivek Goyal) [1694161]
- [fs] fuse: convert last timespec use to timespec64 (Vivek Goyal) [1694161]
- [fs] fs: fuse: Adding new return type vm_fault_t (Vivek Goyal) [1694161]
- [fs] fuse: simplify fuse_abort_conn() (Vivek Goyal) [1694161]
- [infiniband] RDMA/siw: Fix IPv6 addr_list locking (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix 64/32bit pointer inconsistency (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix SGL mapping issues (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix potential NULL de-ref (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Change CQ flags from 64->32 bits (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix a memory leak in siw_init_cpulist() (Kamal Heib) [1725830 1720892]
- [infiniband] Do not dereference 'siw_crypto_shash' before checking (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Remove set but not used variables 'rv' (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix error return code in siw_init_module() (Kamal Heib) [1725830 1720892]
- [infiniband] RMDA/siw: Require a 64 bit arch (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Mark expected switch fall-throughs (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Remove set but not used variable 's' (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Add missing dependencies on LIBCRC32C and DMA_VIRT_OPS (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Add missing rtnl_lock around access to ifa (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: Use proper enumerated type in map_cqe_status (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Remove unnecessary kthread create/destroy printouts (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/siw: Fix DEFINE_PER_CPU compilation when ARCH_NEEDS_WEAK_PER_CPU (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: addition to kernel build environment (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: completion queue methods (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: receive path (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: transmit path (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: queue pair methods (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: application buffer management (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: application interface (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: connection management (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: network and RDMA core interface (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: main include file (Kamal Heib) [1725830 1720892]
- [infiniband] rdma/siw: iWarp wire packet format (Kamal Heib) [1725830 1720892]
- [infiniband] RDMA/cma: fix null-ptr-deref Read in cma_cleanup (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Rewrite PID namespace check to be reliable (Kamal Heib) [1720892]
- [infiniband] RDMA/counters: Properly implement PID checks (Kamal Heib) [1720892]
- [infiniband] IB/core: Fix NULL pointer dereference when bind QP to counter (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Fix MR npages calculation for IB_ACCESS_HUGETLB (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix error code in stat_get_doit_qp() (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Prevent QP counter binding if counters unsupported (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix -Wunused-const-variable warnings (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Added configuration of RDMA dynamic interrupt moderation to netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Provide RDMA DIM support for ULPs (Kamal Heib) [1720892]
- [infiniband] linux/dim: Implement RDMA adaptive moderation (DIM) (Kamal Heib) [1720892]
- [infiniband] IB/mad: Fix use-after-free in ib mad completion handling (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Track driver QP types in resource tracker (Kamal Heib) [1720892]
- [infiniband] RDMA/devices: Remove the lock around remove_client_context (Kamal Heib) [1720892]
- [infiniband] RDMA/devices: Do not deadlock during client removal (Kamal Heib) [1720892]
- [infiniband] IB/core: Add mitigation for Spectre V1 (Kamal Heib) [1720892]
- [infiniband] IB/counters: Always initialize the port counter object (Kamal Heib) [1720892]
- [infiniband] IB/core: Fix querying total rdma stats (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix race when resolving IP address (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Modernize ops->connect (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove rpcrdma_req::rl_buffer (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Refactor chunk encoding (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Streamline rpcrdma_post_recvs (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Simplify rpcrdma_rep_create (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Wake RPCs directly in rpcrdma_wc_send path (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Reduce context switching due to Local Invalidation (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Add mechanism to place MRs back on the free list (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove fr_state (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Remove the RPCRDMA_REQ_F_PENDING flag (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Fix occasional transport deadlock (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Replace use of xdr_stream_pos in rpcrdma_marshal_req (Kamal Heib) [1720892]
- [infiniband] xprtrdma: Fix use-after-free in rpcrdma_post_recvs (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Make rdma_counter.h compile stand alone (Kamal Heib) [1720892]
- [infiniband] IB/core: Work on the caller socket net namespace in nldev_newlink() (Kamal Heib) [1663224 1720892]
- [infiniband] RDMA/rxe: Fill in wc byte_len with IB_WC_RECV_RDMA_WITH_IMM (Kamal Heib) [1720892]
- [infiniband] ibverbs/rxe: Remove variable self-initialization (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow get default counter statistics through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow get counter mode through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow counter manual mode configration through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Allow manual mode configuration support (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Get sum value of all counters when perform a sysfs stat read (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Implement counter dumpit calback (Kamal Heib) [1720892]
- [infiniband] RDMA/nldev: Allow counter auto mode configration through RDMA netlink (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Add "auto" configuration mode support (Kamal Heib) [1720892]
- [infiniband] RDMA/counter: Add set/clear per-port auto mode support (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Make is_visible_in_pid_ns() as an API (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Add an API to attach a task to a resource (Kamal Heib) [1720892]
- [infiniband] RDMA/restrack: Introduce statistic counter (Kamal Heib) [1720892]
- [infiniband] IB/ipoib: Add child to parent list only if device initialized (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: remove redundant assignment to variable ret (Kamal Heib) [1720892]
- [infiniband] IB/ipoib: Remove memset after vzalloc in ipoib_cm.c (Kamal Heib) [1720892]
- [infiniband] IB: Remove unneeded memset (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Audit policy settings for netlink attributes (Kamal Heib) [1720892]
- [infiniband] docs: infiniband: convert docs to ReST and rename to *.rst (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Use IB_WR_REG_MR_INTEGRITY for PI handover (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Introduce rdma_rw_inv_key helper (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Validate integrity handover device cap (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Rename signature qp create flag and signature device capability (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Add an integrity MR pool support (Kamal Heib) [1720892]
- [infiniband] IB/iser: Unwind WR union at iser_tx_desc (Kamal Heib) [1720892]
- [infiniband] IB/iser: Use IB_WR_REG_MR_INTEGRITY for PI handover (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Introduce and implement new IB_WR_REG_MR_INTEGRITY work request (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Update set_sig_data_segment attribute for new signature API (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Pass UMR segment flags instead of boolean (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Add attr for max number page list length for PI operation (Kamal Heib) [1720892]
- [infiniband] RDMA/mlx5: Implement mlx5_ib_map_mr_sg_pi and mlx5_ib_alloc_mr_integrity (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Add signature attrs element for ib_mr structure (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce ib_map_mr_sg_pi to map data/protection sgl's (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce IB_MR_TYPE_INTEGRITY and ib_alloc_mr_integrity API (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Save the MR type in the ib_mr structure (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Introduce new header file for signature operations (Kamal Heib) [1720892]
- [infiniband] RDMA/odp: Do not leak dma maps when working with huge pages (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: Use offsetofend instead of opencoding (Kamal Heib) [1720892]
- [infiniband] [scsi] scsi: RDMA/srp: Fix a sleep-in-invalid-context bug (Kamal Heib) [1720892]
- [infiniband] RDMA: Check umem pointer validity prior to release (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Remove asynchronic QP destroy (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert destroy_wq to be void (Kamal Heib) [1720892]
- [infiniband] RDMA/netlink: Resort policy array (Kamal Heib) [1720892]
- [infiniband] RDMA: Report available cdevs through RDMA_NLDEV_CMD_GET_CHARDEV (Kamal Heib) [1720892]
- [infiniband] RDMA: Add NLDEV_GET_CHARDEV to allow char dev discovery and autoload (Kamal Heib) [1720892]
- [infiniband] ipoib: correcly show a VF hardware address (Kamal Heib) [1720892]
- [infiniband] RDMA: Move rdma_node_type to uapi/ (Kamal Heib) [1720892]
- [infiniband] rdma: Remove nes (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: Remove check for ETH_SS_TEST (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert CQ allocations to be under core responsibility (Kamal Heib) [1720892]
- [infiniband] RDMA/hns: Return correct error code from hns_roce_v1_rsv_lp_qp() (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Don't expose DMA addresses (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb4: Don't expose DMA addresses (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Use sizeof() notation instead of plain sizeof (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA: Clear CQ objects during their allocation (Kamal Heib) [1720892]
- [infiniband] RDMA: Clean destroy CQ in drivers do not return errors (Kamal Heib) [1720892]
- [infiniband] RDMA/i40iw: Remove useless NULL checks (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb3: Delete and properly mark unimplemented resize CQ function (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Avoid memory allocation during CQ destroy (Kamal Heib) [1720892]
- [infiniband] RDMA: Move owner into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] RDMA: Move uverbs_abi_ver into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] RDMA: Move driver_id into struct ib_device_ops (Kamal Heib) [1720892]
- [infiniband] rdma: Delete the ib_ucm module (Kamal Heib) [1720892]
- [infiniband] ucma: Convert ctx_idr to XArray (Kamal Heib) [1720892]
- [infiniband] ucma: Convert multicast_idr to XArray (Kamal Heib) [1720892]
- [infiniband] RDMA/ucma: Use struct_size() helper (Kamal Heib) [1720892]
- [infiniband] RDMA/srp: Accept again source addresses that do not have a port number (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: implement ethtool .get_link() callback (Kamal Heib) [1720892]
- [infiniband] RDMA/uverbs: check for allocation failure in uapi_add_elm() (Kamal Heib) [1720892]
- [infiniband] RDMA: Convert put_page() to put_user_page*() (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Remove second wait queue initialization call (Kamal Heib) [1720892]
- [infiniband] RDMA/nes: Remove useless NULL checks (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Make ib_destroy_cq() void (Kamal Heib) [1720892]
- [infiniband] RDMA/ipoib: Remove check of destroy CQ (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Return void from ib_device_check_mandatory() (Kamal Heib) [1720892]
- [infiniband] RDMA/umem: Move page_shift from ib_umem to ib_odp_umem (Kamal Heib) [1720892]
- [infiniband] RDMA/qedr: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/cxgb4: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720892]
- [infiniband] RDMA/core: Fix doc typo (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Add info regarding SG count failure (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Print the correct number of sig MRs (Kamal Heib) [1720892]
- [infiniband] RDMA/rw: Fix doc typo (Kamal Heib) [1720892]
- [infiniband] IB/isert: Remove unused sig_attrs argument (Kamal Heib) [1720892]
- [infiniband] IB/iser: Remove unused sig_attrs argument (Kamal Heib) [1720892]
- [infiniband] IB/iser: Refactor iscsi_iser_check_protection function (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Entropy in admin commands id (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Print address on AH creation failure (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Be consistent with success flow return value (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use API to get contiguous memory blocks aligned to device supported page size (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove unused includes (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use rdma block iterator in chunk list creation (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove unneeded admin commands abort flow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Use kvzalloc instead of kzalloc with fallback (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove check that prevents destroy of resources in error flows (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Handle mmap insertions overflow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Fix success return value in case of error (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Remove MAYEXEC flag check from mmap flow (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add driver to Kconfig/Makefile (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa module (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add EFA verbs implementation (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add common command handlers (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Implement functions that submit and complete admin commands (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the ABI definitions (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the com service API definitions (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa_com.h file (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add the efa.h header file (Kamal Heib) [1720892]
- [infiniband] RDMA/efa: Add EFA device definitions (Kamal Heib) [1720892]
- [infiniband] RDMA: Add EFA related definitions (Kamal Heib) [1720892]
- [fs] CIFS: Fix use after free of file info structures (Dave Wysochanski) [1757865]
- [mm] mm, memory_hotplug: fix scan_movable_pages() for gigantic hugepages (Rafael Aquini) [1730172]
- [char] ipmi: Don't allow device module unload when in use (Tony Camuso) [1759916]
- [netdrv] net: phy: Also request modules for C45 IDs (Gary Hook) [1764274]
- [s390] s390/dasd: Fix error handling during online processing (Philipp Rudo) [1764492]
- [s390] s390/cpumsf: Check for CPU Measurement sampling (Philipp Rudo) [1764490]
- [edac] EDAC/amd64: Support asymmetric dual-rank DIMMs (Gary Hook) [1753384]
- [edac] EDAC/amd64: Cache secondary Chip Select registers (Gary Hook) [1753384]
- [edac] EDAC/amd64: Decode syndrome before translating address (Gary Hook) [1753384]
- [edac] EDAC/amd64: Find Chip Select memory size using Address Mask (Gary Hook) [1753384]
- [edac] EDAC/amd64: Initialize DIMM info for systems with more than two channels (Gary Hook) [1753384]
- [edac] EDAC/amd64: Recognize DRAM device type ECC capability (Gary Hook) [1753384]
- [edac] EDAC/amd64: Support more than two controllers for chip selects handling (Gary Hook) [1753384]
- [scsi] scsi: fnic: fix msix interrupt allocation (Govindarajulu Varadarajan) [1745083]
- [scsi] scsi: fnic: print port speed only at driver init or speed change (Govindarajulu Varadarajan) [1745083]
- [netdrv] qmi_wwan: apply SET_DTR quirk to Sierra WP7607 (Lubomir Rintel) [1729083]

* Mon Nov 11 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-148.rt13.5.el8]
- [rt] timers: condense pending bitmap information (Marcelo Tosatti) [1757165]
- [rt] timers: do not raise softirq unconditionally (spinlockless version) (Marcelo Tosatti) [1757165]
- [rt] timers: raise timer softirq on __mod_timer/add_timer_on (Marcelo Tosatti) [1757165]
- [rt] redhat: Add linux-kernel-test patch support for kernel-rt (Juri Lelli)
- [rt] padata: Make padata_do_serial() use get_cpu_light() (Daniel Bristot de Oliveira)
- [tools] libbpf: remove compile time warning from libbpf_util.h (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove dependency on barrier.h in xsk.h (Yauheni Kaliuta) [1747341]
- [kernel] seccomp, bpf: disable preemption before calling into bpf prog (Yauheni Kaliuta) [1747341]
- [lib] bpf: test_bpf: turn off preemption in function __run_once (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove unnecessary cast-to-void (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix sysctl.c warning (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix using uninitialized ioctl results (Yauheni Kaliuta) [1747341]
- [tools] libbpf: proper XSKMAP cleanup (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix invalid munmap call (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix XDP socket ring buffer memory ordering (Yauheni Kaliuta) [1747341]
- [tools] libbpf: remove likely/unlikely in xsk.h (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: xdp_redirect, correctly get dummy program id (Yauheni Kaliuta) [1747341]
- [net] bpf: fix access to skb_shared_info->gso_segs (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix out of bounds backwards jmps due to dead code removal (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix use after free in prog symbol exposure (Yauheni Kaliuta) [1747341]
- [include] bpf: Fix preempt_enable_no_resched() abuse (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test cases for pkt/null checks in subprogs (Yauheni Kaliuta) [1747341]
- [kernel] bpf: mark registers in all frames after pkt/null checks (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add binary to gitignore (Yauheni Kaliuta) [1747341]
- [net] bpf: Check address length before reading address family (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: disable preemption around BPF calls (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: switch kernel context to struct bpf_flow_dissector (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: fix clamping of BPF flow_keys for non-zero nhoff (Yauheni Kaliuta) [1747341]
- [net] flow_dissector: allow access only to a subset of __sk_buff fields (Yauheni Kaliuta) [1747341]
- [net] net/flow_dissector: pass flow_keys->n_proto to BPF programs (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix vlan handling in flow dissector program (Yauheni Kaliuta) [1747341]
- [tools] bpf, libbpf: fix quiet install_headers (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add libelf dependency to shared library build (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add xsk.h to install_headers target (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add btf_dedup test for VOID equivalence check (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix btf_dedup equivalence check handling of different kinds (Yauheni Kaliuta) [1747341]
- [documentation] bpf, doc: fix BTF docs reflow of bullet list (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test case for invalid call stack in dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: remove incorrect 'verifier bug' warning (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Only print ref_obj_id for refcounted reg (Yauheni Kaliuta) [1747341]
- [tools] tool: use bpf_program__get_prog_info_linear() in prog.c:do_dump() (Yauheni Kaliuta) [1747341]
- [tools] tools lib bpf: Introduce bpf_program__get_prog_info_linear() (Yauheni Kaliuta) [1747341]
- [tools] perf tools: Fix errors under optimization level '-Og' (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Try harder when allocating memory for large maps (Yauheni Kaliuta) [1747341]
- [tools] tools: bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add fwd enum resolution test for btf_dedup (Yauheni Kaliuta) [1747341]
- [tools] btf: resolve enum fwds in btf_dedup (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add an example for bpf_get_listener_sock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Test ref release issue in bpf_tcp_sock and bpf_sk_fullsock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747341]
- [net] bpf: Add bpf_get_listener_sock(struct bpf_sock *sk) helper (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Fix bpf_tcp_sock and bpf_sk_fullsock issue related to bpf_sk_release (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix to reject unknown flags in xsk_socket__create() (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix segfault of test_progs when prog loading failed (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix replace_map_fd_with_map_ptr's ldimm64 second imm field (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: test_progs: initialize duration in singal_pending test (Yauheni Kaliuta) [1747341]
- [tools] libbpf: force fixdep compilation at the start of the build (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: fix compilation with out-of-tree $(OUTPUT) (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test that GSO works in lwt_ip_encap (Yauheni Kaliuta) [1747341]
- [bpf] bpf: hbm: fix spelling mistake "deault" -> "default" (Yauheni Kaliuta) [1747341]
- [tools] bpf: add test cases for non-pointer sanitiation logic (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - misc (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - spinlock (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - tracepoint (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - stackmap (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - xdp (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - pkt access (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_progs - preparations (Yauheni Kaliuta) [1747341]
- [bpf] bpf: HBM test script (Yauheni Kaliuta) [1747341]
- [bpf] bpf: User program for testing HBM (Yauheni Kaliuta) [1747341]
- [bpf] bpf: Sample HBM BPF program to limit egress bw (Yauheni Kaliuta) [1747341]
- [include] bpf: sync bpf.h to tools and update bpf_helpers.h (Yauheni Kaliuta) [1747341]
- [net] bpf: add bpf helper bpf_skb_ecn_set_ce (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: silence compiler warning for xdpsock_user.c (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: set unlimited RLIMIT_MEMLOCK for test_sock_fields (Yauheni Kaliuta) [1747341]
- [documentation] docs/bpf: minor casing/punctuation fixes (Yauheni Kaliuta) [1747341]
- [documentation] docs/btf: reflow text to fill up to 78 characters (Yauheni Kaliuta) [1747341]
- [documentation] docs/btf: fix typos, improve wording (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix u64_stats_init() usage in bpf_prog_alloc() (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add btf_dedup test of FWD/STRUCT resolution (Yauheni Kaliuta) [1747341]
- [tools] btf: allow to customize dedup hash table size (Yauheni Kaliuta) [1747341]
- [tools] libbpf: fix formatting for btf_ext__get_raw_data (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix btf_dedup testing code (Yauheni Kaliuta) [1747341]
- [tools] tools: libbpf: make sure readelf shows full names in build checks (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: use libbpf where easy (Yauheni Kaliuta) [1747341]
- [tools] tools: libbpf: add a correctly named define for map iteration (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: remove load_sock_ops in favour of bpftool (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: force IPv4 in ping (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: use __bpf_constant_htons in test_prog.c for flow dissector (Yauheni Kaliuta) [1747341]
- [tools] bpf: add missing entries to bpf_helpers.h (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: selftests: add map lookup to test_map_in_map bpf prog (Yauheni Kaliuta) [1747341]
- [kernel] bpf: set inner_map_meta->spin_lock_off correctly (Yauheni Kaliuta) [1747341]
- [bpf] samples: bpf: fix: broken sample regarding removed function (Yauheni Kaliuta) [1747341]
- [tools] tools/bpftool: recognize bpf_prog_info run_time_ns and run_cnt (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync bpf.h into tools (Yauheni Kaliuta) [1747341]
- [kernel] bpf: expose program stats via bpf_prog_info (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix build without bpf_syscall (Yauheni Kaliuta) [1747341]
- [kernel] bpf: enable program stats (Yauheni Kaliuta) [1747341]
- [kernel] bpf: check that BPF programs run with preemption disabled (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: convert xdpsock to use libbpf for AF_XDP access (Yauheni Kaliuta) [1747341]
- [tools] libbpf: add support for using AF_XDP sockets (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: make sure signal interrupts BPF_PROG_TEST_RUN (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Fix dummy program unloading for xdp_redirect samples (Yauheni Kaliuta) [1747341]
- [s390] s390/net: convert pnetids to ascii (Yauheni Kaliuta) [1747341]
- [net] bpf: add skb->queue_mapping write access from tc clsact (Yauheni Kaliuta) [1747341]
- [tools] tools/libbpf: support bigger BTF data sizes (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: test_lwt_ip_encap: add negative tests. (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Introduce bpf_object__btf (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Introduce bpf_map__resize (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: replace bzero with memset (Yauheni Kaliuta) [1747341]
- [net] net: fix GSO in bpf_lwt_push_ip_encap (Yauheni Kaliuta) [1747341]
- [net] net: fix double-free in bpf_lwt_xmit_reroute (Yauheni Kaliuta) [1747341]
- [net] bpf: fix memory leak in bpf_lwt_xmit_reroute (Yauheni Kaliuta) [1747341]
- [net] bpf: make LWTUNNEL_BPF dependent on INET (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add test_lwt_ip_encap selftest (Yauheni Kaliuta) [1747341]
- [include] bpf: sync <kdir>/include/.../bpf.h with tools/include/.../bpf.h (Yauheni Kaliuta) [1747341]
- [net] bpf: add handling of BPF_LWT_REROUTE to lwt_bpf.c (Yauheni Kaliuta) [1747341]
- [net] ipv6_stub: add ipv6_route_input stub/proxy. (Yauheni Kaliuta) [1747341]
- [net] bpf: handle GSO in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: implement BPF_LWT_ENCAP_IP mode in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: add plumbing for BPF_LWT_ENCAP_IP in bpf_lwt_push_encap (Yauheni Kaliuta) [1747341]
- [net] bpf: offload: add priv field for drivers (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: doc, add text about feature-subcommand (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: relax sub-register mode compilation criteria (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: centre kernel bpf objects under new subdir "progs" (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: extend sub-register mode compilation to all bpf object files (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add "alu32" to .gitignore (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add test_sock_fields for skb->sk and bpf_tcp_sock (Yauheni Kaliuta) [1747341]
- [tools] bpf: Add skb->sk, bpf_sk_fullsock and bpf_tcp_sock tests to test_verifer (Yauheni Kaliuta) [1747341]
- [nclude] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Add struct bpf_tcp_sock and BPF_FUNC_tcp_sock (Yauheni Kaliuta) [1747341]
- [net] bpf: Refactor sock_ops_convert_ctx_access (Yauheni Kaliuta) [1747341]
- [net] bpf: Add state, dst_ip4, dst_ip6 and dst_port to bpf_sock (Yauheni Kaliuta) [1747341]
- [kernel] bpf: Add a bpf_sock pointer to __sk_buff and a bpf_sk_fullsock helper (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: remove btf__get_strings() superseded by raw data API (Yauheni Kaliuta) [1747341]
- [tools] btf: expose API to work with raw btf_ext data (Yauheni Kaliuta) [1747341]
- [tools] btf: expose API to work with raw btf data (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add log_level to bpf_load_program_attr (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add missing strings.h include (Yauheni Kaliuta) [1747341]
- [s390] s390/net: move pnet constants (Yauheni Kaliuta) [1747341]
- [tools] bpf: test_maps: fix possible out of bound access warning (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: doc, fix incorrect text (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test reading the offloaded program (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add test for mixing generic and offload XDP (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: print traceback when test fails (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: fix the expected messages (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add const qualifier to btf__get_map_kv_tids() map_name parameter (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add "any alignment" annotation for some tests (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: use localhost in tcp_{server, client}.py (Yauheni Kaliuta) [1747341]
- [s390] s390: bpf: fix JMP32 code-gen (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: remove generated verifier/tests.h on 'make clean' (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Check the prog id before exiting (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Add a "force" flag to XDP samples (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Extend RLIMIT_MEMLOCK for xdp_{sample_pkts, router_ipv4} (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: Convert XDP samples to libbpf usage (Yauheni Kaliuta) [1747341]
- [bpf] samples/bpf: xdp_redirect_cpu have not need for read_trace_pipe (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: test for BPF_F_LOCK (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync uapi/bpf.h (Yauheni Kaliuta) [1747341]
- [kernel] bpf: introduce BPF_F_LOCK flag (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add bpf_spin_lock C test (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add simple BPF_PROG_TEST_RUN examples for flow dissector (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: add bpf_spin_lock verifier tests (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: sync include/uapi/linux/bpf.h (Yauheni Kaliuta) [1747341]
- [kernel] bpf: add support for bpf_spin_lock to cgroup local storage (Yauheni Kaliuta) [1747341]
- [kernel] bpf: introduce bpf_spin_lock (Yauheni Kaliuta) [1747341]
- [net] bpf: Correctly annotate implicit fall through in bpf_base_func_proto (Yauheni Kaliuta) [1747341]
- [kernel] bpf, cgroups: clean up kerneldoc warnings (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix bitrotted kerneldoc (Yauheni Kaliuta) [1747341]
- [include] bpf: BPF_PROG_TYPE_CGROUP_{SKB, SOCK, SOCK_ADDR} require cgroups enabled (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: mark verifier test that uses bpf_trace_printk as BPF_PROG_TYPE_TRACEPOINT (Yauheni Kaliuta) [1747341]
- [net] bpf: add BPF_PROG_TEST_RUN support for flow dissector (Yauheni Kaliuta) [1747341]
- [net] net/flow_dissector: move bpf case into __skb_flow_bpf_dissect (Yauheni Kaliuta) [1747341]
- [net] Revert "[net] flow_dissector: disable preemption around BPF calls" (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: warn about risky prog array updates (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: remove duplicated include (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up the rest of test_verifier (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: break up test_verifier (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: prepare for break up of verifier tests (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: makefile support sub-register code-gen test mode (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: functional and min/max reasoning unit tests for JMP32 (Yauheni Kaliuta) [1747341]
- [s390] s390: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [powerpc] ppc: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [arm64] arm64: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [x86] x86_64: bpf: implement jitting of JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: JIT blinds support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: interpreter support for JMP32 (Yauheni Kaliuta) [1747341]
- [tools] tools: bpftool: teach cfg code about JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: disassembler support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier support JMP32 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: refactor verifier min/max code for condition jump (Yauheni Kaliuta) [1747341]
- [include] bpf: allocate 0x06 to new eBPF instruction class JMP32 (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: suppress readelf stderr when probing for BTF support (Yauheni Kaliuta) [1747341]
- [net] bpf: allow BPF programs access skb_shared_info->gso_segs field (Yauheni Kaliuta) [1747341]
- [tools] tool: feature probing, change default action (Yauheni Kaliuta) [1747341]
- [kernel] bpf: notify offload JITs about optimizations (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: record original instruction index (Yauheni Kaliuta) [1747341]
- [tools] selftests: bpf: add tests for dead code removal (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: remove unconditional branches by 0 (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: remove dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: verifier: hard wire branches to dead code (Yauheni Kaliuta) [1747341]
- [kernel] bpf: change parameters of call/branch offset adjustment (Yauheni Kaliuta) [1747341]
- [tools] selftests/bpf: don't hardcode iptables/nc path in test_tcpnotify_user (Yauheni Kaliuta) [1747341]
- [tools] libbpf: Show supported ELF section names when failing to guess prog/attach type (Yauheni Kaliuta) [1747341]
- [documentation] bpf: btf: add btf documentation (Yauheni Kaliuta) [1747341]
- [kernel] perf: Make perf_event_output() propagate the output() return (Yauheni Kaliuta) [1747341]
- [kernel] bpf: fix a (false) compiler warning (Yauheni Kaliuta) [1747341]
- [tools] tool: add bash completion for peek/push/enqueue/pop/dequeue (Yauheni Kaliuta) [1747341]
- [tools] tool: add pop and dequeue commands (Yauheni Kaliuta) [1747341]
- [tools] tool: add push and enqueue commands (Yauheni Kaliuta) [1747341]
- [tools] tool: add peek command (Yauheni Kaliuta) [1747341]
- [tools] tool: don't print empty key/value for maps (Yauheni Kaliuta) [1747341]
- [tools] tool: make key optional in lookup command (Yauheni Kaliuta) [1747341]
- [tools] tool: make key and value optional in update command (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: support __int128 in bpftool map pretty dumper (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add bpffs pretty print test for int128 (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: refactor test_btf pretty printing for multiple map value formats (Yauheni Kaliuta) [1747341]
- [tools] tools/bpf: add int128 raw test in test_btf (Yauheni Kaliuta) [1747341]
- [kernel] bpf: btf: support 128 bit integer type (Yauheni Kaliuta) [1747341]
- [tools] libbpf: don't define CC and AR (Yauheni Kaliuta) [1747341]
- [include] bpf: remove leftovers after v5.0 update (Yauheni Kaliuta) [1715770]
- [target] scsi: target: cxgbit: add support for IEEE_8021QAZ_APP_SEL_STREAM selector (Vishal Kulkarni) [1725820]
- [netdrv] cxgb4i: add support for IEEE_8021QAZ_APP_SEL_STREAM selector (Vishal Kulkarni) [1725818]
- [net] SUNRPC: Fix possible autodisconnect during connect due to old last_used (Dave Wysochanski) [1724692]
- [fs] NFSv4: Add lease_time and lease_expired to 'nfs4:' line of mountstats (Dave Wysochanski) [1727369]
- [scsi] scsi: zfcp: fix reaction on bit error threshold notification (Philipp Rudo) [1764494]
- [iommu] iommu/arm-smmu: Error out only if not enough context interrupts (Mark Langsdorf) [1658736]
- [netdrv] cxgb4:Fix out-of-bounds MSI-X info array access (Vishal Kulkarni) [1763194]
- [fs] vfs: Fix EOVERFLOW testing in put_compat_statfs64 (Eric Sandeen) [1757902]
- [security] selinux: fix context string corruption in convert_context() (Ondrej Mosnacek) [1758086]
- [fs] cifs: use cifsInodeInfo->open_file_lock while iterating to avoid a panic (Dave Wysochanski) [1757865]
- [kernel] alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (Vladis Dronov) [1760638]
- [netdrv] cxgb4: RHEL-only disable device dump (Jonathan Toppins) [1708456]
- [fs] xfs: Fix deadlock between AGI and AGF with RENAME_WHITEOUT (Brian Foster) [1759564]
- [x86] x86/stacktrace: Prevent access_ok() warnings in arch_stack_walk_user() (Jerome Marchand) [1757758]
- [s390] s390/sclp: Fix bit checked for has_sipl (Philipp Rudo) [1748347]
- [fs] dax: dax_layout_busy_page() should not unmap cow pages (Jeff Moyer) [1752109]
- [fs] dax: Fix missed wakeup in put_unlocked_entry() (Jeff Moyer) [1752109]
- [fs] dax: Fix missed wakeup with PMD faults (Jeff Moyer) [1752109]
- [fs] dax: Fix xarray entry association for mixed mappings (Jeff Moyer) [1752109]
- [mm] mm: page_mkclean vs MADV_DONTNEED race (Jeff Moyer) [1752109]
- [fs] dax: Flush partial PMDs correctly (Jeff Moyer) [1752109 1724979]
- [fs] dax: Use non-exclusive wait in wait_entry_unlocked() (Jeff Moyer) [1752109]
- [x86] x86/mm: Fix decoy address handling vs 32-bit builds (Jeff Moyer) [1752109 1585079]
- [fs] dax: Fix unlock mismatch with updated API (Jeff Moyer) [1752109 1724956]
- [fs] dax: Don't access a freed inode (Jeff Moyer) [1752109 1724956]
- [fs] dax: Check page->mapping isn't NULL (Jeff Moyer) [1752109 1585079 1724956]
- [fs] dax: Avoid losing wakeup in dax_lock_mapping_entry (Jeff Moyer) [1752109]
- [fs] dax: Fix huge page faults (Jeff Moyer) [1752109]
- [fs] dax: Fix dax_unlock_mapping_entry for PMD pages (Jeff Moyer) [1752109]
- [fs] dax: Reinstate RCU protection of inode (Jeff Moyer) [1752109]
- [fs] dax: Make sure the unlocking entry isn't locked (Jeff Moyer) [1752109]
- [fs] dax: Remove optimisation from dax_lock_mapping_entry (Jeff Moyer) [1752109]
- [fs] dax: Convert page fault handlers to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_lock_mapping_entry to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax writeback to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert __dax_invalidate_entry to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_layout_busy_page to XArray (Jeff Moyer) [1752109]
- [fs] dax: Convert dax_insert_pfn_mkwrite to XArray (Jeff Moyer) [1752109]
- [fs] dax: Hash on XArray instead of mapping (Jeff Moyer) [1752109]
- [fs] dax: Rename some functions (Jeff Moyer) [1752109]
- [fs] dax: Fix deadlock in dax_lock_mapping_entry() (Jeff Moyer) [1752109 1585079 1641544]
- [drivers] device-dax: Add missing address_space_operations (Jeff Moyer) [1752109 1585079]
- [x86] x86/mm/pat: Prepare {reserve, free}_memtype() for "decoy" addresses (Jeff Moyer) [1752109 1585079]
- [mm] mm, memory_failure: Teach memory_failure() about dev_pagemap pages (Jeff Moyer) [1703560 1752109 1585079]
- [fs] filesystem-dax: Introduce dax_lock_mapping_entry() (Jeff Moyer) [1752109 1585079]
- [mm] mm, memory_failure: Collect mapping size in collect_procs() (Jeff Moyer) [1752109 1585079]
- [mm] mm, madvise_inject_error: Let memory_failure() optionally take a page reference (Jeff Moyer) [1752109 1585079]
- [mm] mm, madvise_inject_error: Disable MADV_SOFT_OFFLINE for ZONE_DEVICE pages (Jeff Moyer) [1752109 1585079]
- [fs] filesystem-dax: Set page->index (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Set page->index (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Enable page_mapping() (Jeff Moyer) [1752109 1585079]
- [drivers] device-dax: Convert to vmf_insert_mixed and vm_fault_t (Jeff Moyer) [1752109 1585079]
- [pci] PCI: Add quirk to disable MSI-X support for Amazon's Annapurna Labs Root Port (Myron Stowe) [1732357]
- [pci] PCI/VPD: Prevent VPD access for Amazon's Annapurna Labs Root Port (Myron Stowe) [1732357]
- [pci] PCI: Add ACS quirk for Amazon Annapurna Labs root ports (Myron Stowe) [1732357]
- [pci] PCI: Add Amazon's Annapurna Labs vendor ID (Myron Stowe) [1732357]
- [arm64] arm64: PCI: Preserve firmware configuration when desired (Myron Stowe) [1732372]
- [arm64] arm64: PCI: Allow resource reallocation if necessary (Myron Stowe) [1732372]
- [pci] PCI: Don't auto-realloc if we're preserving firmware config (Myron Stowe) [1732372]
- [pci] PCI/ACPI: Evaluate PCI Boot Configuration _DSM (Myron Stowe) [1732372]
- [irqchip] irqchip/gic-v2m: Add support for Amazon Graviton variant of GICv3+GICv2m (Myron Stowe) [1732382]
- [pci] PCI: al: Add Amazon Annapurna Labs PCIe host controller driver (Myron Stowe) [1732357]
- [netdrv] mlx4: fix spelling mistake "veify" -> "verify" (Alaa Hleihel) [1724340]
- [netdrv] IB/mlx4: Fix memory leaks (Alaa Hleihel) [1724340]
- [netdrv] net/mlx4_en: fix a memory leak bug (Alaa Hleihel) [1724340]
- [netdrv] IB/mlx4: Delete unused func arg (Alaa Hleihel) [1724340]
- [netdrv] net/mlx4_en: ethtool, Remove unsupported SFP EEPROM high pages query (Alaa Hleihel) [1724340 1724339]
- [netdrv] net/mlx4_core: Change the error print to info print (Alaa Hleihel) [1724340 1724339]
- [netdrv] mlx4: Convert pv_id_table to XArray (Alaa Hleihel) [1724340 1724339]
- [netdrv] IB/mlx4: Fix race condition between catas error reset and aliasguid flows (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix qp mtt size calculation (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix locking in SRIOV mode when switching between events and polling (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: Fix reset flow when in command polling mode (Alaa Hleihel) [1724340 1724338]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Alaa Hleihel) [1724340 1724338]
- [netdrv] IB/mlx4: Increase the timeout for CM cache (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4_core: A write memory barrier is sufficient in EQ ci update (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4: Mark expected switch fall-through (Alaa Hleihel) [1724340 1724338]
- [netdrv] net/mlx4: remove unneeded semicolon (Alaa Hleihel) [1724340 1724338]
- [parport] parport: parport_serial: Add support for Sunix Multi I/O boards (John Linville) [1663781]
- [tty] serial: 8250_pci: Add support for Sunix serial boards (John Linville) [1663781]
- [scsi] hpsa: update driver version (Joseph Szczypek) [1761968]
- [scsi] scsi: hpsa: add missing hunks in reset-patch (Joseph Szczypek) [1761968]
- [netdrv] igc: Clean up unused shadow_vfta pointer (David Arcari) [1721713]
- [netdrv] igc: Add Rx checksum support (David Arcari) [1721713]
- [netdrv] igc: Add set_rx_mode support (David Arcari) [1721713]
- [netdrv] igc: Add SCTP CRC checksumming functionality (David Arcari) [1721713]
- [netdrv] igc: Add tx_csum offload functionality (David Arcari) [1721713]
- [netdrv] igc: Remove unneeded PCI bus defines (David Arcari) [1721713]
- [netdrv] igc: Add NVM checksum validation (David Arcari) [1721713]
- [netdrv] igc: Remove useless forward declaration (David Arcari) [1721713]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (David Arcari) [1721713]
- [netdrv] igc: Add more SKUs for i225 device (David Arcari) [1721713]
- [netdrv] igc: Update the MAC reset flow (David Arcari) [1721713]
- [netdrv] igc: Remove the unused field from a device specification structure (David Arcari) [1721713]
- [netdrv] igc: Remove the polarity field from a PHY information structure (David Arcari) [1721713]
- [netdrv] net: Use skb accessors in network drivers (David Arcari) [1721713]
- [netdrv] igc: Prefer pcie_capability_read_word() (David Arcari) [1721713]
- [netdrv] igc: Cleanup the redundant code (David Arcari) [1721713]
- [netdrv] igc: Add flow control support (David Arcari) [1721713]
- [netdrv] igc: Remove the obsolete workaround (David Arcari) [1721713]
- [netdrv] igc: Clean up unused pointers (David Arcari) [1721713]
- [netdrv] igc: Fix double definitions (David Arcari) [1721713]
- [netdrv] igb/igc: warn when fatal read failure happens (David Arcari) [1721713]
- [scsi] scsi: qla2xxx: Fix different size DMA Alloc/Unmap (Himanshu Madhani) [1753031]
- [scsi] qla2xxx: call dma_free_coherent with correct size in all cases in qla24xx_sp_unmap (Himanshu Madhani) [1753031]
- [arm64] crypto: arm64/crc32 - remove PMULL based CRC32 driver (Mark Salter) [1742821]
- [arm64] arm64/lib: improve CRC32 performance for deep pipelines (Mark Salter) [1742821]
- [arm64] arm64/lib: add accelerated crc32 routines (Mark Salter) [1742821]
- [arm64] arm64: cpufeature: add feature for CRC32 instructions (Mark Salter) [1742821]
- [lib] lib/crc32: make core crc32() routines weak so they can be overridden (Mark Salter) [1742821]
- [arm64] arm64: cpu: Move errata and feature enable callbacks closer to callers (Mark Salter) [1742821]
- [arm64] arm64: kill config_sctlr_el1() (Mark Salter) [1742821]
- [include] ethtool: Add SFF-8436 and SFF-8636 max EEPROM length definitions (Petr Oros) [1757522]
- [net] bridge/mdb: remove wrong use of NLM_F_MULTI (Hangbin Liu) [1756799]
- [net] bridge: mcast: don't delete permanent entries when fast leave is enabled (Hangbin Liu) [1756799]
- [net] bridge: multicast: use rcu to access port list from br_multicast_start_querier (Hangbin Liu) [1756799]
- [net] bridge: Fix ethernet header pointer before check skb forwardable (Hangbin Liu) [1756799]
- [net] clear skb->tstamp in bridge forwarding path (Hangbin Liu) [1756799]
- [net] bridge: br_arp_nd_proxy: set icmp6_router if neigh has NTF_ROUTER (Hangbin Liu) [1756799]
- [net] vlan: Inherit MPLS features from parent device (Hangbin Liu) [1724306]
- [netdrv] linux/dim: Fix overflow in dim calculation (Ivan Vecera) [1737807]
- [lib] dim: Fix -Wunused-const-variable warnings (Ivan Vecera) [1737807]
- [lib] linux/dim: Add completions count to dim_sample (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Move implementation to .c files (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename externally used net_dim members (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename net_dim_sample() to net_dim_update_sample() (Ivan Vecera) [1737807]
- [netdrv] linux/dim: Rename externally exposed macros (Ivan Vecera) [1737807]
- [include] linux/dim: Remove "net" prefix from internal DIM members (Ivan Vecera) [1737807]
- [include] linux/dim: Move logic to dim.h (Ivan Vecera) [1737807]
- [tools] selftests: add a test case for cls_lower handle overflow (Ivan Vecera) [1761512]
- [net] idr: introduce idr_for_each_entry_continue_ul() (Ivan Vecera) [1761512]
- [net] idr: fix overflow case for idr_for_each_entry_ul() (Ivan Vecera) [1761512]
- [net] sctp: add chunks to sk_backlog when the newsk sk_socket is not set (Xin Long) [1734271]
- [net] netns: enable to dump full nsid translation table (Petr Oros) [1757748]
- [net] netns: enable to specify a nsid for a get request (Petr Oros) [1757748]
- [net] netns: add support of NETNSA_TARGET_NSID (Petr Oros) [1757748]
- [net] netns: introduce 'struct net_fill_args' (Petr Oros) [1757748]
- [net] netns: remove net arg from rtnl_net_fill() (Petr Oros) [1757748]
- [net] mpls: fix warning with multi-label encap (Hangbin Liu) [1756788]
- [net] mpls: Return error for RTA_GATEWAY attribute (Hangbin Liu) [1756788]
- [net] macsec: drop skb sk before calling gro_cells_receive (Xin Long) [1745819]
- [net] team: add ethtool get_link_ksettings (Hangbin Liu) [1724896]
- [net] sched: flower: don't call synchronize_rcu() on mask creation (Ivan Vecera) [1751856]
- [net] sched: flower: refactor reoffload for concurrent access (Ivan Vecera) [1751856]
- [net] sched: flower: fix filter net reference counting (Ivan Vecera) [1751856]
- [net] sched: flower: use correct ht function to prevent duplicates (Ivan Vecera) [1751856]
- [net] sched: flower: insert filter to ht before offloading it to hw (Ivan Vecera) [1751856]
- [net] sched: ensure tc flower reoffload takes filter ref (Ivan Vecera) [1751856]
- [net] sched: flower: set unlocked flag for flower proto ops (Ivan Vecera) [1751856]
- [net] sched: flower: track rtnl lock state (Ivan Vecera) [1751856]
- [net] sched: flower: protect flower classifier state with spinlock (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent tcf proto deletion (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent filter insertion in fl_change (Ivan Vecera) [1751856]
- [net] sched: flower: protect masks list with spinlock (Ivan Vecera) [1751856]
- [net] sched: flower: handle concurrent mask insertion (Ivan Vecera) [1751856]
- [net] sched: flower: add reference counter to flower mask (Ivan Vecera) [1751856]
- [net] sched: flower: track filter deletion with flag (Ivan Vecera) [1751856]
- [net] sched: flower: introduce reference counting for filters (Ivan Vecera) [1751856]
- [net] sched: flower: refactor fl_change (Ivan Vecera) [1751856]
- [net] sched: flower: don't check for rtnl on head dereference (Ivan Vecera) [1751856]
- [kernel] exit from RHEL 8.2 early ystream mode (Phillip Lougher)

* Tue Nov 05 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-147.13.rt13.4.el8]
- [x86] kvm: svm: Remove unneeded WBINVD and DF_FLUSH when starting SEV guests (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Reduce WBINVD/DF_FLUSH invocations (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Guard against DEACTIVATE when performing WBINVD/DF_FLUSH (Janakarajan Natarajan) [1762517]
- [x86] kvm: svm: Serialize access to the SEV ASID bitmap (Janakarajan Natarajan) [1762517]
- [xen] remove pre-xen3 fallback handlers (Vitaly Kuznetsov) [1759997]
- [net] SUNRPC: Count ops completing with tk_status < 0 (Dave Wysochanski) [1636572]
- [net] SUNRPC: Use proper printk specifiers for unsigned long long (Dave Wysochanski) [1636572]
- [net] SUNRPC: Move call to rpc_count_iostats before rpc_call_done (Dave Wysochanski) [1636572]
- [net] SUNRPC: Add tracking of RPC level errors (Dave Wysochanski) [1636572]
- [net] SUNRPC: Refactor rpc_restart_call/rpc_restart_call_prepare (Dave Wysochanski) [1636572]
- [net] SUNRPC: Fix up task signalling (Dave Wysochanski) [1636572]
- [net] SUNRPC: Track writers of the 'channel' file to improve cache_listeners_exist (Dave Wysochanski) [1741333]
- [net] sunrpc/cache: handle missing listeners better. (Dave Wysochanski) [1741333]
- [pci] PCI/ACPI: Advertise _HPX Type 3 support via _OSC (Myron Stowe) [1712756]
- [pci] PCI/ACPI: Implement _HPX Type 3 Setting Record (Myron Stowe) [1712756]
- [netdrv] e1000e: Add support for Comet Lake (David Arcari) [1764549]
- [netdrv] e1000e: Add support for S0ix (Ken Cox) [1721709]
- [netdrv] e1000e: Make speed detection on hotplugging cable more reliable (Ken Cox) [1721709]
- [netdrv] ethernet: Delete unnecessary checks before the macro call dev_kfree_skb (Ken Cox) [1721709]
- [netdrv] e1000e: add workaround for possible stalled packet (Ken Cox) [1721709]
- [netdrv] e1000e: Use dev_get_drvdata where possible (Ken Cox) [1721709]
- [netdrv] net: Use skb accessors in network drivers (Ken Cox) [1721709]
- [netdrv] e1000e: PCIm function state support (Ken Cox) [1721709]
- [netdrv] e1000e: Make watchdog use delayed work (Ken Cox) [1721709]
- [netdrv] e1000e: Reduce boot time by tightening sleep ranges (Ken Cox) [1721709]
- [netdrv] e1000e: Increase pause and refresh time (Ken Cox) [1721709]
- [scsi] scsi: megaraid_sas: Introduce module parameter for default queue depth (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix a compilation warning (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make a bunch of functions static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make some functions static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fix panic on loading firmware crashdump (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fix spelling mistake "megarid_sas" -> "megaraid_sas" (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.710.50.00 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add module parameter for FW Async event logging (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enable msix_load_balance for Invader and later controllers (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix calculation of target ID (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Make some symbols static (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.710.06.00-rc1 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Introduce various Aero performance modes (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Use high IOPS queues based on IO workload (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Set affinity for high IOPS reply queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enable coalescing for high IOPS queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for High IOPS queues (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for MPI toolbox commands (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Offload Aero RAID5/6 division calculations to driver (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: RAID1 PCI bandwidth limit algorithm is applicable for only Ventura (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: megaraid_sas: Add check for count returned by HOST_DEVICE_LIST DCMD (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Handle sequence JBOD map failure at driver level (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Don't send FPIO to RL Bypass queue (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: In probe context, retry IOC INIT once if firmware is in fault (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Release Mutex lock before OCR in case of DCMD timeout (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Call disable_irq from process IRQ poll (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove few debug counters from IO path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add support for Non-secure Aero PCI IDs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add 32 bit atomic descriptor support to AERO adapters (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Use struct_size() helper (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove unused including <linux/version.h> (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: use DEVICE_ATTR_{RO, RW} (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: use octal permissions instead of constants (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: make max_sectors visible in sys (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variables 'buff_addr' and 'ci_h' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variable 'sge_sz' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variables 'host' and 'wait_time' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: remove set but not used variable 'cur_state' (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Update driver version to 07.708.03.00 (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Export RAID map through debugfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Fix MSI-X vector print (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add debug prints for device list (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add prints in suspend and resume path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print firmware interrupt status (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print FW fault information (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Export RAID map id through sysfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Print BAR information from driver (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Dump system registers for debugging (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Dump system interface regs from sysfs (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Add formatting option for megasas_dump (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enhance internal DCMD timeout prints (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Enhance prints in OCR and TM path (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Load balance completions across all MSI-X (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: IRQ poll to avoid CPU hard lockups (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Block PCI config space access from userspace during OCR (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Rework code around controller reset (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: fw_reset_no_pci_access required for MFI adapters only (Tomas Henzl) [1726251]
- [scsi] scsi: megaraid_sas: Remove unused variable target_index (Tomas Henzl) [1726251]
- [x86] perf/x86/msr: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/intel: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/cstate: Add Comet Lake CPU support (Michael Petlan) [1763290]
- [x86] perf/x86/intel: Update KBL Package C-state events to also include PC8/PC9/PC10 counters (Michael Petlan) [1763290]
- [x86] x86/cpu: Add Comet Lake to the Intel CPU models header (Michael Petlan) [1763290]
- [s390] s390/qeth: reject oversized SNMP requests (Philipp Rudo) [1726414]
- [s390] s390/qeth: serialize cmd reply with concurrent timeout (Philipp Rudo) [1726414]
- [s390] s390/qeth: move cast type selection into fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: extract helper for route validation (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate skb RX processing in L3 driver (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate pm code (Philipp Rudo) [1726414]
- [s390] s390/qeth: streamline SNMP cmd code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove static cmd buffer infrastructure (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate MPC cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate vnicc cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate diag cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate various cmds with sub-types (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify parameter for simple assist cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: dynamically allocate simple IPA cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: allocate a single cmd on read channel (Philipp Rudo) [1726414]
- [s390] s390/qeth: command-chain the IDX sequence (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert RCD code to common IO infrastructure (Philipp Rudo) [1726414]
- [s390] s390/qeth: add support for dynamically allocated cmds (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove 'channel' parameter from callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert device-specific trace entries (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove OSN-specific IO code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove qeth_wait_for_buffer() (Philipp Rudo) [1726414]
- [s390] s390/qeth: clean up setting of BLKT defaults (Philipp Rudo) [1726414]
- [s390] s390/qeth: restart pending READ cmd from callback (Philipp Rudo) [1726414]
- [s390] s390/qeth: simplify DOWN state handling (Philipp Rudo) [1726414]
- [s390] s390/qeth: use mm helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't mask TX errors on IQD devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle error when updating TX queue count (Philipp Rudo) [1726414]
- [s390] s390/qeth: fix VLAN attribute in bridge_hostnotify udev event (Philipp Rudo) [1726414]
- [s390] s390/qeth: check dst entry before use (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle limited IPv4 broadcast in L3 TX path (Philipp Rudo) [1726414]
- [s390] s390/qeth: trust non-IP cast type in qeth_l3_fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: extract helper to determine L2 cast type (Philipp Rudo) [1726414]
- [s390] s390/qeth: cache max number of available buffer elements (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't clear Output buffers on every queue init (Philipp Rudo) [1726414]
- [s390] s390/qeth: use IS_* helpers for checking device type (Philipp Rudo) [1726414]
- [s390] s390/qeth: clean up stale buffer state documentation (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove RX seqno in skb->cb (Philipp Rudo) [1726414]
- [s390] s390: qeth: address type mismatch warning (Philipp Rudo) [1726414]
- [s390] s390/qeth: stop/wake TX queues based on their fill level (Philipp Rudo) [1726414]
- [s390] s390/qeth: simplify QoS code (Philipp Rudo) [1726414]
- [s390] s390/qeth: add TX multiqueue support for OSA devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: add TX multiqueue support for IQD devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't keep statistics for tx timeout (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't bother updating the last-tx time (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle error from qeth_update_from_chp_desc() (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify naming for some QDIO helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: send IDX cmds via qeth_send_control_data() (Philipp Rudo) [1726414]
- [s390] s390/qeth: use callback to finalize cmd (Philipp Rudo) [1726414]
- [s390] s390/qeth: let qeth_notify_reply() set the notify reason (Philipp Rudo) [1726414]
- [s390] s390/qeth: clarify default cmd callback (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't poll for cmd IO completion (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert IP table spinlock to mutex (Philipp Rudo) [1726414]
- [s390] s390/qeth: defer IPv6 address notifier events (Philipp Rudo) [1726414]
- [s390] s390/qeth: add wrapper for IP table access (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove locking for RX modeset cache (Philipp Rudo) [1726414]
- [s390] s390/qeth: defer RX modesetting (Philipp Rudo) [1726414]
- [s390] s390/qeth: fix race when initializing the IP address table (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't erase configuration while probing (Philipp Rudo) [1726414]
- [s390] s390/qeth: drop redundant state checking (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't special-case HW trap during suspend (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove driver-wide workqueue (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't defer close_dev work during recovery (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove a redundant check for card->dev (Philipp Rudo) [1726414]
- [s390] s390/qeth: call dev_close() during recovery (Philipp Rudo) [1726414]
- [s390] s390/qeth: unconditionally clear MAC_REGISTERED flag (Philipp Rudo) [1726414]
- [s390] s390/qeth: enable/disable the HW trap a little earlier (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove RECOVER state (Philipp Rudo) [1726414]
- [s390] s390/qeth: split out OSN netdev ops (Philipp Rudo) [1726414]
- [s390] s390/qeth: add support for ETHTOOL_GRINGPARAM (Philipp Rudo) [1726414]
- [s390] s390/qeth: overhaul ethtool statistics (Philipp Rudo) [1726414]
- [s390] s390/qeth: move ethtool code into its own file (Philipp Rudo) [1726414]
- [s390] s390/qeth: reduce ethtool statistics (Philipp Rudo) [1726414]
- [s390] s390/qeth: use a static Output Queue array (Philipp Rudo) [1726414]
- [s390] s390/qeth: allow manual recovery when device is SOFTSETUP (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert remaining legacy cmd callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: convert bridgeport callbacks (Philipp Rudo) [1726414]
- [s390] s390/qeth: allow cmd callbacks to return errnos (Philipp Rudo) [1726414]
- [s390] s390/qeth: limit trace to valid data of command request (Philipp Rudo) [1726414]
- [s390] s390/qeth: align csum offload with TSO control logic (Philipp Rudo) [1726414]
- [s390] s390/qeth: enable only required csum offload features (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate filling of low-level cmd length fields (Philipp Rudo) [1726414]
- [s390] s390/qeth: reduce data length for ARP cache query (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove VLAN tracking for L2 devices (Philipp Rudo) [1726414]
- [s390] s390/qeth: detach netdevice while card is offline (Philipp Rudo) [1726414]
- [s390] s390/qeth: delay netdevice registration (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove TX disable from online path (Philipp Rudo) [1726414]
- [s390] s390/qeth: register MAC address earlier (Philipp Rudo) [1726414]
- [s390] s390/qeth: consolidate open/stop netdev ops (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove bogus netif_wake_queue() (Philipp Rudo) [1726414]
- [s390] s390/qeth: streamline TX buffer management (Philipp Rudo) [1726414]
- [s390] s390/qeth: don't process hsuid in qeth_l3_setup_netdev() (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove unused fallback in Layer3's MAC code (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove two IPA command helpers (Philipp Rudo) [1726414]
- [s390] s390/qeth: replace open-coded cmd setup (Philipp Rudo) [1726414]
- [s390] s390/qeth: remove card list (Philipp Rudo) [1726414]
- [s390] s390/qeth: unify transmit code (Philipp Rudo) [1726414]
- [s390] s390/qeth: handle af_iucv skbs in qeth_l3_fill_header() (Philipp Rudo) [1726414]
- [s390] s390/qeth: sanitize ARP requests (Philipp Rudo) [1726414]
- [s390] s390/qdio: restrict QAOB usage to IQD unicast queues (Philipp Rudo) [1726414]
- [s390] s390/qdio: add sanity checks to the fast-requeue path (Philipp Rudo) [1726414]
- [s390] s390/qdio: don't touch the dsci in tiqdio_add_input_queues() (Philipp Rudo) [1726414]
- [s390] s390/qdio: (re-)initialize tiqdio list entries (Philipp Rudo) [1726414]
- [s390] s390/qdio: optimize state inspection of HW-owned SBALs (Philipp Rudo) [1726414]
- [s390] s390/qdio: use get_buf_state() in debug_get_buf_state() (Philipp Rudo) [1726414]
- [s390] s390/qdio: allow to scan all Output SBALs in one go (Philipp Rudo) [1726414]
- [s390] s390/qdio: consolidate index tracking for queue scan (Philipp Rudo) [1726414]
- [s390] s390/qdio: limit direct access to first_to_check cursor (Philipp Rudo) [1726414]
- [s390] s390/qdio: eliminate queue's last_move cursor (Philipp Rudo) [1726414]
- [s390] s390/qdio: simplify SBAL range calculation (Philipp Rudo) [1726414]
- [s390] s390/qdio: pass up count of ready-to-process SBALs (Philipp Rudo) [1726414]
- [s390] s390/qdio: fix output of DSCI value in debug file (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up qdio_check_outbound_after_thinint() (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up pci_out_supported() (Philipp Rudo) [1726414]
- [s390] s390/qdio: make SBAL address array type-safe (Philipp Rudo) [1726414]
- [s390] s390/qdio: clean up AOB handling (Philipp Rudo) [1726414]
- [s390] s390/ccwgroup: add get_ccwgroupdev_by_busid() (Philipp Rudo) [1726414]

* Mon Nov 04 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-147.12.rt13.3.el8]
- [net] xprtrdma: Remove stale comment (Kamal Heib) [1720891]
- [net] xprtrdma: Update comments that reference ib_drain_qp (Kamal Heib) [1720891]
- [net] xprtrdma: Remove pr_err() call sites from completion handlers (Kamal Heib) [1720891]
- [net] xprtrdma: Eliminate struct rpcrdma_create_data_internal (Kamal Heib) [1720891]
- [net] xprtrdma: Aggregate the inline settings in struct rpcrdma_ep (Kamal Heib) [1720891]
- [net] xprtrdma: Remove rpcrdma_create_data_internal::rsize and wsize (Kamal Heib) [1720891]
- [net] xprtrdma: Eliminate rpcrdma_ia::ri_device (Kamal Heib) [1720891]
- [net] xprtrdma: More Send completion batching (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up sendctx functions (Kamal Heib) [1720891]
- [net] xprtrdma: Trace marshaling failures (Kamal Heib) [1720891]
- [net] xprtrdma: Increase maximum number of backchannel requests (Kamal Heib) [1720891]
- [net] xprtrdma: Backchannel can use GFP_KERNEL allocations (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up regbuf helpers (Kamal Heib) [1720891]
- [net] xprtrdma: De-duplicate "allocate new, free old regbuf" (Kamal Heib) [1720891]
- [net] xprtrdma: Allocate req's regbufs at xprt create time (Kamal Heib) [1720891]
- [net] xprtrdma: rpcrdma_regbuf alignment (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up rpcrdma_create_rep() and rpcrdma_destroy_rep() (Kamal Heib) [1720891]
- [net] xprtrdma: Clean up rpcrdma_create_req() (Kamal Heib) [1720891]
- [scsi] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 502 (Kamal Heib) [1720891]
- [infiniband] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Kamal Heib) [1720891]
- [net] xprtrdma: Use struct_size() in kzalloc() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Fix panic when port_data isn't initialized (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Pass udata on uverbs error unwind (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Clear out the udata before error unwind (Kamal Heib) [1720891]
- [infiniband] RDMA/srp: Rename SRP sysfs name after IB device rename trigger (Kamal Heib) [1720891]
- [infiniband] treewide: Add SPDX license identifier - Makefile/Kconfig (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Change system parameters callback from dumpit to doit (Kamal Heib) [1720891]
- [infiniband] RDMA: Directly cast the sockaddr union to sockaddr (Kamal Heib) [1720891]
- [infiniband] RDMA/ipoib: Allow user space differentiate between valid dev_port (Kamal Heib) [1720891]
- [infiniband] RDMA/device: Don't fire uevent before device is fully initialized (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Remove hugetlb flag (Kamal Heib) [1720891]
- [infiniband] RDMA/bnxt_re: Use core helpers to get aligned DMA address (Kamal Heib) [1720891]
- [infiniband] RDMA/bnxt_re: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720891]
- [infiniband] RDMA/i40iw: Use core helpers to get aligned DMA address within a supported page size (Kamal Heib) [1720891]
- [infiniband] RDMA/i40iw: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720891]
- [infiniband] RDMA/verbs: Add a DMA iterator to return aligned contiguous memory blocks (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Add API to find best driver supported page size in an MR (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Allow detaching gid attribute netdevice for RoCE (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Use rdma_read_gid_attr_ndev_rcu to access netdev (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Use rdma_read_gid_attr_ndev_rcu to access netdev (Kamal Heib) [1720891]
- [infiniband] RDMA: Introduce and use GID attr helper to read RoCE L2 fields (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Add vlan enable bit for hip08 (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Update some fields of qp context (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Delete unused variable in hns_roce_v2_modify_qp function (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Add enable judgement for UD vlan (Kamal Heib) [1720891]
- [infiniband] IB/mlx5: Consider vlan of lower netdev for macvlan GID entries (Kamal Heib) [1720891]
- [infiniband] IB/cm: Reduce dependency on gid attribute ndev check (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Consider skb reserve space based on netdev of GID (Kamal Heib) [1720891]
- [infiniband] RDMA: Get rid of iw_cm_verbs (Kamal Heib) [1720891]
- [infiniband] RDMA/cxgb4: Use ib_device_set_netdev() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Do not invoke init_port on compat devices (Kamal Heib) [1720891]
- [infiniband] IB/core: Set qp->real_qp before it may be accessed (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Initialize uverbs_attr_bundle ucontext in ib_uverbs_get_context (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Initialize udata struct on destroy flows (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Handle page combining avoidance correctly in ib_umem_add_sg_table() (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce RDMA subsystem ibdev_* print functions (Kamal Heib) [1720891]
- [infiniband] uverbs: Convert idr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Remove rdma_user_mmap_page (Kamal Heib) [1720891]
- [infiniband] RDMA/mlx5: Use get_zeroed_page() for clock_info (Kamal Heib) [1720891]
- [infiniband] RDMA/mlx5: Do not allow the user to write to the clock page (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Consider scope_id while binding to ipv6 ll address (Kamal Heib) [1720891]
- [infiniband] IB/core: Allow vlan link local address based RoCE GIDs (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add a netlink command to change net namespace of rdma device (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce a helper function to change net namespace of rdma device (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Avoid freeing netdevs in disable_device() (Kamal Heib) [1720891]
- [infiniband] RDMA/ocrdma: Remove use of idr use pci bdf instead (Kamal Heib) [1720891]
- [infiniband] RDMA/drivers: Convert easy drivers to use ib_device_set_netdev() (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Use correct value for SG entries in sg_copy_to_buffer() (Kamal Heib) [1720891]
- [infiniband] RDMA: Handle SRQ allocations by IB/core (Kamal Heib) [1720891]
- [infiniband] qedr: Convert srqidr to XArray (Kamal Heib) [1720891]
- [infiniband] qedr: Convert qpidr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Handle AH allocations by IB/core (Kamal Heib) [1720891]
- [infiniband] RDMA/hns: Fix bad endianess of port_pd variable (Kamal Heib) [1720891]
- [infiniband] RDMA/mad: Reduce MAD scope to mlx5_ib only (Kamal Heib) [1720891]
- [infiniband] RDMA/ocrdma: Remove a set-but-not-used variable (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Support object allocation in atomic context (Kamal Heib) [1720891]
- [infiniband] IB: When attrs.udata/ufile is available use that instead of uobject (Kamal Heib) [1720891]
- [infiniband] RDMA/nldev: Return device protocol (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Move debug counters to be under relevant IB device (Kamal Heib) [1720891]
- [infiniband] RDMA/umem: Combine contiguous PAGE_SIZE regions in SGEs (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Remove useless zeroing of static global variable (Kamal Heib) [1720891]
- [infiniband] RDMA/cma: Set proper port number as index (Kamal Heib) [1720891]
- [infiniband] IB: Pass only ib_udata in function prototypes (Kamal Heib) [1720891]
- [infiniband] IB: Remove 'uobject->context' dependency in object destroy APIs (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert mmidr to XArray (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert qpidr to XArray (Kamal Heib) [1720891]
- [infiniband] cxgb4: Convert cqidr to XArray (Kamal Heib) [1720891]
- [infiniband] IB: Pass uverbs_attr_bundle down ib_x destroy path (Kamal Heib) [1720891]
- [infiniband] IB: Pass uverbs_attr_bundle down uobject destroy path (Kamal Heib) [1720891]
- [infiniband] IB: ucontext should be set properly for all cmd & ioctl paths (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Don't compare specific bit after boolean AND (Kamal Heib) [1720891]
- [infiniband] RDMA/netlink: Remove unused data structure (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add command to set ib_core device net namspace sharing mode (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add interface to read device namespace sharing mode (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Extend ib_device_get_by_index for net namespace (Kamal Heib) [1720891]
- [infiniband] RDMA: Check net namespace access for uverbs, umad, cma and nldev (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Add module param to disable device sharing among net ns (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Support core port attributes in non init_net (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Implement compat device/sysfs tree in net namespace (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Restrict sysfs entries view to init_net (Kamal Heib) [1720891]
- [infiniband] RDMA/core: Introduce ib_core_device to hold device (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1720891]
- [infiniband] RDMA/mthca: Use correct sizing on buffers holding page DMA addresses (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Allow the compiler to verify declaration and definition consistency (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Annotate uverbs_request_next_ptr() return value as a __user pointer (Kamal Heib) [1720891]
- [infiniband] RDMA/uverbs: Add a __user annotation to a pointer (Kamal Heib) [1720891]
- [infiniband] IB/rxe: Replace av->network_type with skb->protocol (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add SMP details to MAD tracing (Kamal Heib) [1720891]
- [infiniband] IB/UMAD: Add umad trace points (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add agent trace points (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add recv path trace point (Kamal Heib) [1720891]
- [infiniband] IB/MAD: Add send path trace points (Kamal Heib) [1720891]
- [infiniband] RDMA/vmw_pvrdma: Skip zeroing device attrs (Kamal Heib) [1720891]
- [infiniband] IB/iser: remove uninitialized variable len (Kamal Heib) [1720891]
- [infiniband] IB/core: Ensure an invalidate_range callback on ODP MR (Kamal Heib) [1720891]
- [infiniband] RDMA/rxe: Fix slab-out-bounds access which lead to kernel crash later (Kamal Heib) [1720891]
- [infiniband] drivers: infiniband: Fix whitespace in kconfig (Kamal Heib) [1720891]
- [infiniband] RDMA/nes: remove redundant check on udata (Kamal Heib) [1720891]
- [infiniband] cma: Convert portspace IDRs to XArray (Kamal Heib) [1720891]
- [infiniband] ucm: Convert ctx_id_table to XArray (Kamal Heib) [1720891]
- [infiniband] ib core: Convert query_idr to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA/cm: Convert local_id_table to XArray (Kamal Heib) [1720891]
- [infiniband] IB/mad: Convert ib_mad_clients to XArray (Kamal Heib) [1720891]
- [infiniband] RDMA: Use __packed annotation instead of __attribute__ ((packed)) (Kamal Heib) [1720891]
- [char] tpm: Remove a deprecated comments about implicit sysfs locking (Jerry Snitselaar) [1725580 1742257]
- [char] tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for interrupts (Jerry Snitselaar) [1725580 1742257]
- [char] tpm_tis_core: Turn on the TPM before probing IRQ's (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Fix null pointer dereference on chip register error path (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM operations (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Actually fail on TPM errors during "get random" (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 505 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 399 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Add SPDX license identifier - Makefile/Kconfig (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests/tpm2: Open tpm dev in unbuffered mode (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests/tpm2: Extend tests to cover partial reads (Jerry Snitselaar) [1725580 1742257]
- [tools] selftests: add TPM 2.0 tests (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: fix -Wvarags warning (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: Move trusted.h to include/keys [ver #2] (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: Expose common functionality [ver #2] (Jerry Snitselaar) [1725580 1742257]
- [char] tpm: Wrap the buffer from the caller to tpm_buf in tpm_send() (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: correctly initialize digests and fix locking issue (Jerry Snitselaar) [1725580 1742257]
- [security] KEYS: trusted: allow module init if TPM is inactive or deactivated (Jerry Snitselaar) [1725580 1742257]
- [net] net/smc: make sure EPOLLOUT is raised (Philipp Rudo) [1726415]
- [net] net/smc: avoid fallback in case of non-blocking connect (Philipp Rudo) [1726415]
- [net] net/smc: do not schedule tx_work in SMC_CLOSED state (Philipp Rudo) [1726415]
- [net] net/smc: common release code for non-accepted sockets (Philipp Rudo) [1726415]
- [net] net/smc: Fix error path in smc_init (Philipp Rudo) [1726415]
- [net] net/smc: hold conns_lock before calling smc_lgr_register_conn() (Philipp Rudo) [1726415]
- [dma] dmaengine: ioatdma: support latency tolerance report (LTR) for v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: add descriptor pre-fetch support for v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: disable DCA enabling on IOATDMA v3.4 (Jerry Snitselaar) [1661996]
- [dma] dmaengine: ioatdma: Add Snow Ridge ioatdma device id (Jerry Snitselaar) [1661996]
- [kernel] mutex: Fix up mutex_waiter usage (Waiman Long) [1736609]
- [kernel] locking/mutex: Use mutex flags macro instead of hard code (Waiman Long) [1736609]
- [kernel] locking/mutex: Make __mutex_owner static to mutex.c (Waiman Long) [1736609]
- [kernel] locking/mutex: Test for initialized mutex (Waiman Long) [1736609]
- [kernel] kernel/locking/mutex.c: remove caller signal_pending branch predictions (Waiman Long) [1736609]
- [kernel] Revert "locking/pvqspinlock: Don't wait if vCPU is preempted" (Waiman Long) [1736609]
- [kernel] locking/rwsem: Check for operations on an uninitialized rwsem (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make handoff writer optimistically spin on owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add ACQUIRE comments (Waiman Long) [1736609]
- [tty] tty/ldsem, locking/rwsem: Add missing ACQUIRE to read_failed sleep loop (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath sleep loop (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath exit when queue is empty (Waiman Long) [1736609]
- [kernel] locking/rwsem: Don't call owner_on_cpu() on read-owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Guard against making count negative (Waiman Long) [1736609]
- [kernel] locking/rwsem: Adaptive disabling of reader optimistic spinning (Waiman Long) [1736609]
- [kernel] locking/rwsem: Enable time-based spinning on reader-owned rwsem (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make rwsem->owner an atomic_long_t (Waiman Long) [1736609]
- [kernel] locking/rwsem: Enable readers spinning on writer (Waiman Long) [1736609]
- [kernel] locking/rwsem: Clarify usage of owner's nonspinaable bit (Waiman Long) [1736609]
- [kernel] locking/rwsem: Wake up almost all readers in wait queue (Waiman Long) [1736609]
- [kernel] locking/rwsem: More optimal RT task handling of null owner (Waiman Long) [1736609]
- [kernel] locking/rwsem: Always release wait_lock before waking up tasks (Waiman Long) [1736609]
- [kernel] locking/rwsem: Implement lock handoff to prevent lock starvation (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make rwsem_spin_on_owner() return owner state (Waiman Long) [1736609]
- [kernel] locking/rwsem: Code cleanup after files merging (Waiman Long) [1736609]
- [kernel] locking/rwsem: Add rwsem_init.c to keep __init_rwsem() kABI (Waiman Long) [1736609]
- [kernel] locking/rwsem: Merge rwsem.h and rwsem-xadd.c into rwsem.c (Waiman Long) [1736609]
- [kernel] locking/rwsem: Implement a new locking scheme (Waiman Long) [1736609]
- [kernel] locking/rwsem: Remove rwsem_wake() wakeup optimization (Waiman Long) [1736609]
- [kernel] locking/rwsem: Make owner available even if !CONFIG_RWSEM_SPIN_ON_OWNER (Waiman Long) [1736609]
- [kernel] locking/lock_events: Use raw_cpu_{add, inc}() for stats (Waiman Long) [1736609]
- [kernel] locking/lock_events: Use this_cpu_add() when necessary (Waiman Long) [1736609]
- [kernel] locking/rwsem: Revert "[kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath ..." (Waiman Long) [1736609]
- [block] block: don't release queue's sysfs lock during switching elevator (Ming Lei) [1760151]
- [block] blk-mq: move lockdep_assert_held() into elevator_exit (Ming Lei) [1760151]
- [block] block: fix race between switching elevator and removing queues (Ming Lei) [1760151]
- [md] raid5: use bio_end_sector in r5_next_bio (Nigel Croxon) [1754949]
- [md] raid5: remove STRIPE_OPS_REQ_PENDING (Nigel Croxon) [1754949]
- [md] md: add feature flag MD_FEATURE_RAID0_LAYOUT (Nigel Croxon) [1754949]
- [md] md/raid0: avoid RAID0 data corruption due to layout confusion. (Nigel Croxon) [1754949]
- [md] raid5: don't set STRIPE_HANDLE to stripe which is in batch list (Nigel Croxon) [1754949]
- [md] raid5: don't increment read_errors on EILSEQ return (Nigel Croxon) [1754949]
- [md] md/raid5: use bio_end_sector to calculate last_sector (Nigel Croxon) [1730670]
- [md] md/raid1: fail run raid1 array when active disk less than one (Nigel Croxon) [1730670]
- [md] md raid0/linear: Mark array as 'broken' and fail BIOs if a member is gone (Nigel Croxon) [1730670]
- [md] raid5 improve too many read errors msg by adding limits (Nigel Croxon) [1730670]
- [md] md: don't report active array_state until after revalidate_disk() completes. (Nigel Croxon) [1730670]
- [md] md: only call set_in_sync() when it is expected to succeed. (Nigel Croxon) [1730670]
- [md] raid1: factor out a common routine to handle the completion of sync write (Nigel Croxon) [1730670]
- [md] md: don't call spare_active in md_reap_sync_thread if all member devices can't work (Nigel Croxon) [1730670]
- [md] md: don't set In_sync if array is frozen (Nigel Croxon) [1730670]
- [md] md: allow last device to be forcibly removed from RAID1/RAID10. (Nigel Croxon) [1730670]
- [md] md/raid10: end bio when the device faulty (Nigel Croxon) [1730670]
- [md] md/raid1: end bio when the device faulty (Nigel Croxon) [1730670]
- [md] md/raid6: Set R5_ReadError when there is read failure on parity disk (Nigel Croxon) [1730670]
- [md] raid1: use an int as the return value of raise_barrier() (Nigel Croxon) [1730670]
- [md] md/raid1: Fix a warning message in remove_wb() (Nigel Croxon) [1730670]
- [crypto] crypto: ccp - Fix SEV_VERSION_GREATER_OR_EQUAL (Gary Hook) [1754634]
- [crypto] crypto: ccp - Do not free psp_master when PLATFORM_INIT fails (Gary Hook) [1754634]
- [crypto] crypto: ccp - Use kmemdup in ccp_copy_and_save_keypart() (Gary Hook) [1754634]
- [crypto] crypto: ccp - introduce SEV_GET_ID2 command (Gary Hook) [1754634]
- [netdrv] e1000e: start network tx queue only when link is up (Oleksandr Natalenko) [1747869]
- [netdrv] Revert "e1000e: fix cyclic resets at link up with active tx" (Oleksandr Natalenko) [1747869]
- [mm] mm/zsmalloc.c: fix build when CONFIG_COMPACTION=n (Rafael Aquini) [1735181]
- [mm] mm/zsmalloc.c: fix race condition in zs_destroy_pool (Rafael Aquini) [1735181]
- [mm] mm/zsmalloc.c: migration can leave pages in ZS_EMPTY indefinitely (Rafael Aquini) [1735181]
- [mm] mm, page_owner: handle THP splits correctly (Rafael Aquini) [1735181]
- [mm] hugetlbfs: fix hugetlb page migration/fault race causing SIGBUS (Rafael Aquini) [1735181]
- [mm] mm/usercopy: use memory range to be accessed for wraparound check (Rafael Aquini) [1735181]
- [mm] mm/memcontrol.c: fix use after free in mem_cgroup_iter() (Rafael Aquini) [1735181]
- [mm] mm/hmm: fix bad subpage pointer in try_to_unmap_one (Rafael Aquini) [1735181]
- [mm] mm: vmscan: check if mem cgroup is disabled or not before calling memcg slab shrinker (Rafael Aquini) [1735181]
- [mm] mm: revert "kmemleak: allow to coexist with fault injection" (Rafael Aquini) [1735181]
- [mm] mm/vmalloc: sync unmappings in __purge_vmap_area_lazy() (Rafael Aquini) [1735181]
- [mm] mm/vmalloc.c: add priority threshold to __purge_vmap_area_lazy() (Rafael Aquini) [1735181]
- [mm] mm/cma.c: fail if fixed declaration can't be honored (Rafael Aquini) [1735181]
- [mm] mm/mmu_notifier: use hlist_add_head_rcu() (Rafael Aquini) [1735181]
- [mm] mm/mincore.c: fix race between swapoff and mincore (Rafael Aquini) [1735181]
- [mm] mm, swap: fix race between swapoff and some swap operations (Rafael Aquini) [1735181]
- [mm] mm/failslab.c: by default, do not fail allocations with direct reclaim only (Rafael Aquini) [1735181]
- [mm] mm: vmscan: scan anonymous pages on file refaults (Rafael Aquini) [1735181]
- [mm] mm/vmscan.c: prevent useless kswapd loops (Rafael Aquini) [1735181]
- [mm] mm/page_idle.c: fix oops because end_pfn is larger than max_pfn (Rafael Aquini) [1760459 1735181]
- [mm] mm/mempolicy.c: fix an incorrect rebind node in mpol_rebind_nodemask (Rafael Aquini) [1735181]
- [mm] mm/vmscan.c: fix trying to reclaim unevictable LRU page (Rafael Aquini) [1735181]
- [mm] mm/mlock.c: change count_mm_mlocked_page_nr return type (Rafael Aquini) [1735181]
- [mm] mm/mlock.c: mlockall error for flag MCL_ONFAULT (Rafael Aquini) [1735181]
- [mm] mm/list_lru.c: fix memory leak in __memcg_init_list_lru_node (Rafael Aquini) [1735181]
- [mm] memcg: make it work on sparse non-0-node systems (Rafael Aquini) [1735181]
- [mm] prctl_set_mm: downgrade mmap_sem to read lock (Rafael Aquini) [1735181]
- [mm] mm/debug.c: fix __dump_page when mapping->host is not set (Rafael Aquini) [1735181]
- [mm] mm/debug.c: fix __dump_page() for poisoned pages (Rafael Aquini) [1735181]
- [mm] mm: update references to page _refcount (Rafael Aquini) [1735181]
- [mm] mm: lower the printk loglevel for __dump_page messages (Rafael Aquini) [1735181]
- [mm] mm: print more information about mapping in __dump_page (Rafael Aquini) [1735181]
- [mm] hugetlb: use same fault hash key for shared and private mappings (Rafael Aquini) [1735181]
- [mm] mm/hugetlb.c: don't put_page in lock of hugetlb_lock (Rafael Aquini) [1735181]
- [mm] mm: fix inactive list balancing between NUMA nodes and cgroups (Rafael Aquini) [1735181]
- [mm] mm/migrate.c: add missing flush_dcache_page for non-mapped page migrate (Rafael Aquini) [1735181]
- [mm] mm: mempolicy: make mbind() return -EIO when MPOL_MF_STRICT is specified (Rafael Aquini) [1734286 1735181]
- [mm] mm/hotplug: fix offline undo_isolate_page_range() (Rafael Aquini) [1735181]
- [mm] mm/sparse: fix a bad comparison (Rafael Aquini) [1735181]
- [mm] mm, swap: bounds check swap_info array accesses to avoid NULL derefs (Rafael Aquini) [1735181]
- [mm] mm/vmalloc.c: don't dereference possible NULL pointer in __vunmap() (Rafael Aquini) [1735181]
- [mm] mm: hwpoison: fix thp split handing in soft_offline_in_use_page() (Rafael Aquini) [1735181]
- [mm] hugetlbfs: fix races and page leaks during migration (Rafael Aquini) [1735181]
- [mm] tmpfs: fix uninitialized return value in shmem_link (Rafael Aquini) [1735181]
- [mm] tmpfs: fix link accounting when a tmpfile is linked in (Rafael Aquini) [1735181]
- [mm] mm: migrate: don't rely on __PageMovable() of newpage after unlocking it (Rafael Aquini) [1735181]
- [mm] oom, oom_reaper: do not enqueue same task twice (Rafael Aquini) [1735181]
- [mm] mm: page_mapped: don't assume compound page is huge or THP (Rafael Aquini) [1735181]
- [mm] mm, memcg: fix reclaim deadlock with writeback (Rafael Aquini) [1735181]
- [mm] mm, swap: fix swapoff with KSM pages (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: fix lockdep complaint on 32-bit i_size_read() (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: splitting set mapping+index before unfreeze (Rafael Aquini) [1735181]
- [mm] mm/huge_memory: rename freeze_page() to unmap_page() (Rafael Aquini) [1735181]
- [mm] mm/page_alloc.c: fix calculation of pgdat->nr_zones (Rafael Aquini) [1735181]
- [mm] mm: use swp_offset as key in shmem_replace_page() (Rafael Aquini) [1735181]
- [mm] mm: cleancache: fix corruption on missed inode invalidation (Rafael Aquini) [1735181]
- [mm] mm/vmstat.c: fix NUMA statistics updates (Rafael Aquini) [1735181]
- [mm] mm, swap: make CONFIG_THP_SWAP depend on CONFIG_SWAP (Rafael Aquini) [1735181]
- [mm] ARM: 8820/1: mm: Stop printing the virtual memory layout (Rafael Aquini) [1655192]
- [netdrv] net: dsa: bcm_sf2: Remove print of base address (Rafael Aquini) [1655192]
- [netdrv] net: systemport: Remove print of base address (Rafael Aquini) [1655192]
- [netdrv] net: phy: mdio-bcm-unimac: Remove print of base address (Rafael Aquini) [1655192]
- [x86] x86/mm: Don't leak kernel addresses (Rafael Aquini) [1655192]
- [x86] x86/realmode: Make set_real_mode_mem() static inline (Rafael Aquini) [1655192]
- [x86] x86/realmode: Don't leak the trampoline kernel address (Rafael Aquini) [1655192]
- [arm64] arm64/vdso: don't leak kernel addresses (Rafael Aquini) [1655192]
- [powerpc] powerpc/traps: Fix the message printed when stack overflows (Rafael Aquini) [1655192]
- [kernel] kdb: print real address of pointers instead of hashed addresses (Rafael Aquini) [1655192]
- [kernel] kdb: use correct pointer when 'btc' calls 'btt' (Rafael Aquini) [1655192]

* Wed Oct 30 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-147.11.rt13.2.el8]
- [fs] signal: Allow cifs and drbd to receive their terminating signals (Leif Sahlberg) [1757670]
- [fs] smb3: fix unmount hang in open_shroot (Leif Sahlberg) [1757670]
- [fs] cifs: update internal module number (Leif Sahlberg) [1757670]
- [fs] cifs: replace various strncpy with strscpy and similar (Leif Sahlberg) [1757670]
- [fs] cifs: Use kzfree() to zero out the password (Leif Sahlberg) [1757670]
- [fs] cifs: set domainName when a domain-key is used in multiuser (Leif Sahlberg) [1757670]
- [fs] SMB3: Kernel oops mounting a encryptData share with CONFIG_DEBUG_VIRTUAL (Leif Sahlberg) [1757670]
- [fs] smb3: send CAP_DFS capability during session setup (Leif Sahlberg) [1757670]
- [fs] SMB3: Fix potential memory leak when processing compound chain (Leif Sahlberg) [1757670]
- [fs] SMB3: Fix deadlock in validate negotiate hits reconnect (Leif Sahlberg) [1757670]
- [fs] cifs: fix rmmod regression in cifs.ko caused by force_sig changes (Leif Sahlberg) [1757670]
- [fs] cifs: update internal module number (Leif Sahlberg) [1757670]
- [fs] cifs: flush before set-info if we have writeable handles (Leif Sahlberg) [1757670]
- [fs] smb3: optimize open to not send query file internal info (Leif Sahlberg) [1757670]
- [fs] CIFS: fix deadlock in cached root handling (Leif Sahlberg) [1757670]
- [fs] cifs: fix crash in cifs_dfs_do_automount (Leif Sahlberg) [1757670]
- [fs] cifs: fix parsing of symbolic link error response (Leif Sahlberg) [1757670]
- [fs] cifs: refactor and clean up arguments in the reparse point parsing (Leif Sahlberg) [1757670]
- [fs] SMB3: query inode number on open via create context (Leif Sahlberg) [1757670]
- [fs] smb3: Send netname context during negotiate protocol (Leif Sahlberg) [1757670]
- [fs] smb3: do not send compression info by default (Leif Sahlberg) [1757670]
- [fs] smb3: add new mount option to retrieve mode from special ACE (Leif Sahlberg) [1757670]
- [fs] smb3: Allow query of symlinks stored as reparse points (Leif Sahlberg) [1757670]
- [fs] cifs: Fix a race condition with cifs_echo_request (Leif Sahlberg) [1757670]
- [fs] cifs: always add credits back for unsolicited PDUs (Leif Sahlberg) [1757670]
- [fs] fs: cifs: cifsssmb: Change return type of convert_ace_to_cifs_ace (Leif Sahlberg) [1757670]
- [fs] add some missing definitions (Leif Sahlberg) [1757670]
- [fs] cifs: fix typo in debug message with struct field ia_valid (Leif Sahlberg) [1757670]
- [fs] smb3: minor cleanup of compound_send_recv (Leif Sahlberg) [1757670]
- [fs] CIFS: Fix module dependency (Leif Sahlberg) [1757670]
- [fs] cifs: simplify code by removing CONFIG_CIFS_ACL ifdef (Leif Sahlberg) [1757670]
- [fs] cifs: Fix check for matching with existing mount (Leif Sahlberg) [1757670]
- [fs] cifs: Properly handle auto disabling of serverino option (Leif Sahlberg) [1757670]
- [fs] smb3: if max_credits is specified then display it in /proc/mounts (Leif Sahlberg) [1757670]
- [fs] Fix match_server check to allow for auto dialect negotiate (Leif Sahlberg) [1757670]
- [fs] cifs: add missing GCM module dependency (Leif Sahlberg) [1757670]
- [fs] SMB3.1.1: Add GCM crypto to the encrypt and decrypt functions (Leif Sahlberg) [1757670]
- [fs] SMB3: Add SMB3.1.1 GCM to negotiated crypto algorigthms (Leif Sahlberg) [1757670]
- [fs] fs: cifs: Drop unlikely before IS_ERR(_OR_NULL) (Leif Sahlberg) [1757670]
- [fs] cifs: Use kmemdup in SMB2_ioctl_init() (Leif Sahlberg) [1757670]
- [fs] SMB3: retry on STATUS_INSUFFICIENT_RESOURCES instead of failing write (Leif Sahlberg) [1757670]
- [fs] cifs: fix panic in smb2_reconnect (Leif Sahlberg) [1757670]
- [fs] CIFS: cifs_read_allocate_pages: don't iterate through whole page array on ENOMEM (Leif Sahlberg) [1757670]
- [fs] dfs_cache: fix a wrong use of kfree in flush_cache_ent() (Leif Sahlberg) [1757670]
- [fs] fs/cifs/smb2pdu.c: fix buffer free in SMB2_ioctl_free (Leif Sahlberg) [1757670]
- [fs] cifs: fix memory leak of pneg_inbuf on -EOPNOTSUPP ioctl case (Leif Sahlberg) [1757670]
- [fs] cifs: add support for SEEK_DATA and SEEK_HOLE (Leif Sahlberg) [1757670]
- [fs] cifs: Allocate memory for all iovs in smb2_ioctl (Leif Sahlberg) [1757670]
- [fs] cifs: Don't match port on SMBDirect transport (Leif Sahlberg) [1757670]
- [fs] cifs:smbd Use the correct DMA direction when sending data (Leif Sahlberg) [1757670]
- [fs] cifs:smbd When reconnecting to server, call smbd_destroy() after all MIDs have been called (Leif Sahlberg) [1757670]
- [fs] smb3: trivial cleanup to smb2ops.c (Leif Sahlberg) [1757670]
- [fs] cifs: cleanup smb2ops.c and normalize strings (Leif Sahlberg) [1757670]
- [fs] smb3: display session id in debug data (Leif Sahlberg) [1757670]
- [fs] cifs: update module internal version number (Leif Sahlberg) [1757670]
- [fs] cifs: fix crash querying symlinks stored as reparse-points (Leif Sahlberg) [1757670]
- [fs] SMB3: Clean up query symlink when reparse point (Leif Sahlberg) [1757670]
- [fs] cifs: fix strcat buffer overflow and reduce raciness in smb21_set_oplock_level() (Leif Sahlberg) [1757670]
- [fs] Negotiate and save preferred compression algorithms (Leif Sahlberg) [1757670]
- [fs] cifs: rename and clarify CIFS_ASYNC_OP and CIFS_NO_RESP (Leif Sahlberg) [1757670]
- [fs] smb3: Add protocol structs for change notify support (Leif Sahlberg) [1757670]
- [fs] cifs: fix smb3_zero_range for Azure (Leif Sahlberg) [1757670]
- [fs] cifs: zero-range does not require the file is sparse (Leif Sahlberg) [1757670]
- [fs] Add new flag on SMB3.1.1 read (Leif Sahlberg) [1757670]
- [fs] cifs: add fiemap support (Leif Sahlberg) [1757670]
- [fs] SMB3: Add defines for new negotiate contexts (Leif Sahlberg) [1757670]
- [fs] cifs: fix bi-directional fsctl passthrough calls (Leif Sahlberg) [1757670]
- [fs] cifs: smbd: take an array of reqeusts when sending upper layer data (Leif Sahlberg) [1757670]
- [fs] SMB3: Add handling for different FSCTL access flags (Leif Sahlberg) [1757670]
- [fs] cifs: Add support for FSCTL passthrough that write data to the server (Leif Sahlberg) [1757670]
- [fs] cifs: remove superfluous inode_lock in cifs_{strict_}fsync (Leif Sahlberg) [1757670]
- [fs] cifs: Call MID callback before destroying transport (Leif Sahlberg) [1757670]
- [fs] smbd: Make upper layer decide when to destroy the transport (Leif Sahlberg) [1757670]
- [fs] SMB3: update comment to clarify enumerating snapshots (Leif Sahlberg) [1757670]
- [fs] CIFS: check CIFS_MOUNT_NO_DFS when trying to reuse existing sb (Leif Sahlberg) [1757670]
- [fs] CIFS: Show locallease in /proc/mounts for cifs shares mounted with locallease feature. (Leif Sahlberg) [1757670]
- [fs] cifs: Fix DFS cache refresher for DFS links (Leif Sahlberg) [1757670]
- [fs] cifs: don't use __constant_cpu_to_le32() (Leif Sahlberg) [1757670]
- [fs] SMB3: Track total time spent on roundtrips for each SMB3 command (Leif Sahlberg) [1757670]
- [fs] cifs: use the right include for signal_pending() (Leif Sahlberg) [1757670]
- [fs] CIFS: Mask off signals when sending SMB packets (Leif Sahlberg) [1757670]
- [infiniband] RDMA/umem: Revert broken 'off by one' fix (Kamal Heib) [1720888]
- [infiniband] RDMA/umem: minor bug fix in error handling path (Kamal Heib) [1720888]
- [infiniband] RDMA/uverbs: Don't do double free of allocated PD (Kamal Heib) [1720888]
- [infiniband] RDMA: Handle ucontext allocations by IB/core (Kamal Heib) [1720888]
- [infiniband] cross-tree: phase out dma_zalloc_coherent() (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Fix a WARN() message (Kamal Heib) [1720888]
- [infiniband] RDMA/uverbs: Store PR pointer before it is overwritten (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Cosmetic change - move member initialization to correct block (Kamal Heib) [1720888]
- [infiniband] rdma_rxe: Use netlink messages to add/delete links (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Add RDMA_NLDEV_CMD_NEWLINK/DELLINK support (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Close a race after ib_register_device (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Add ib_device_get_by_name() and use it in rxe (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Use driver_unregister and new unregistration API (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Provide APIs from the core code to help unregistration (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Use ib_device_get_by_netdev() instead of open coding (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Add ib_device_get_by_netdev() (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Add ib_device_set_netdev() as an alternative to get_netdev (Kamal Heib) [1720888]
- [infiniband] RDMA/cache: Move the cache per-port data into the main ib_port_data (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Consolidate ib_device per_port data into one place (Kamal Heib) [1720888]
- [infiniband] RDMA: Add and use rdma_for_each_port (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Don't expose number of not-visible entries (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Connect QP number to .doit callback (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Provide parent IDs for PD, MR and QP objects (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Share with user-space object IDs (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Prepare restrack_root to addition of extra fields per-type (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Hide restrack DB from IB/core (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Reduce scope of synchronization lock while updating DB (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Add resource tracker doit callback (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Translate from ID to restrack object (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Convert internal DB from hash to XArray (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Move device addition deletion to device.c (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Introduce and use ib_setup_port_attrs() (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Use simpler device_del() instead of device_unregister() (Kamal Heib) [1720888]
- [infiniband] RDMA/nes: Remove useless usecnt variable and redundant memset (Kamal Heib) [1720888]
- [infiniband] IB/{hw, sw}: Remove 'uobject->context' dependency in object creation APIs (Kamal Heib) [1720888]
- [infiniband] RDMA/qedr: remove set but not used variable 'ib_ctx' (Kamal Heib) [1720888]
- [infiniband] RDMA/mthca: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Kamal Heib) [1720888]
- [infiniband] RDMA/mthca: Clear QP objects during their allocation (Kamal Heib) [1720888]
- [include] IB/verbs: Add helper function rdma_udata_to_drv_context (Kamal Heib) [1720888]
- [infiniband] IB/uverbs: Add ib_ucontext to uverbs_attr_bundle sent from ioctl and cmd flows (Kamal Heib) [1720888]
- [infiniband] IB/ipoib: Use __func__ instead of function's name (Kamal Heib) [1720888]
- [infiniband] RDMA/iwpm: Remove set but not used variable 'msg_seq' (Kamal Heib) [1720888]
- [infiniband] RDMA/nes: Use for_each_sg_dma_page iterator for umem SGL (Kamal Heib) [1720888]
- [net] xprtrdma: Check inline size before providing a Write chunk (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA/vmw_pvrdma: Use for_each_sg_dma_page iterator on umem SGL (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Re-organize device.c locking (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Use xarray to store the client_data (Kamal Heib) [1720888]
- [infiniband] RDMA/devices: Use xarray to store the clients (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Use an ida instead of a free page in alloc_name (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Get rid of reg_state (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Check that the rename is nop under the lock (Kamal Heib) [1720888]
- [infiniband] RDMA: Handle PD allocations by IB/core (Kamal Heib) [1720888]
- [infiniband] RDMA/hns: fix spelling mistake "reseved" -> "reserved" (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Share driver structure size with core (Kamal Heib) [1720888]
- [infiniband] IB/cma: Define option to set ack timeout and pack tos_set (Kamal Heib) [1720888]
- [infiniband] drivers/IB,core: reduce scope of mmap_sem (Kamal Heib) [1720888]
- [infiniband] drivers/IB,usnic: reduce scope of mmap_sem (Kamal Heib) [1720888]
- [net] svcrdma: Remove syslog warnings in work completion handlers (Kamal Heib) [1720888]
- [net] svcrdma: Squelch compiler warning when SUNRPC_DEBUG is disabled (Kamal Heib) [1720888]
- [net] svcrdma: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [infiniband] RDMA/iwpm: move kdoc comments to functions (Kamal Heib) [1720888]
- [infiniband] RDMA/cma: Remove CM_ID statistics provided by rdma-cm module (Kamal Heib) [1720888]
- [infiniband] scsi: RDMA/srpt: Rework I/O context allocation (Kamal Heib) [1720888]
- [infiniband] scsi: RDMA/srpt: Fix handling of command / TMF submission failure (Kamal Heib) [1720888]
- [infiniband] RDMA/IWPM: Support no port mapping requirements (Kamal Heib) [1720888]
- [infiniband] RDMA/IWPM: refactor the IWPM message attribute names (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Improve loopback marking (Kamal Heib) [1720888]
- [infiniband] RDMA/rxe: Move rxe_init_av() to rxe_av.c (Kamal Heib) [1720888]
- [infiniband] IB/core: Remove ib_sg_dma_address() and ib_sg_dma_len() (Kamal Heib) [1720888]
- [infiniband] IB/uverbs: Expose XRC ODP device capabilities (Kamal Heib) [1720888]
- [include] IB/core: Allocate a bit for SRQ ODP support (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Use the ops infrastructure to keep all callbacks in one place (Kamal Heib) [1720888]
- [infiniband] RDMA/cxgb4: Sort SRQ ops alphabetically (Kamal Heib) [1720888]
- [infiniband] RDMA/restrack: Refactor user/kernel restrack additions (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Simplify restrack interface (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Prepare CAP_NET_ADMIN checks for .doit callbacks (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Factor out the PID namespace check (Kamal Heib) [1720888]
- [infiniband] RDMA/nldev: Dynamically generate restrack dumpit callbacks (Kamal Heib) [1720888]
- [infiniband] IB/usnic: Remove stub functions (Kamal Heib) [1720888]
- [infiniband] RDMA: Add indication for in kernel API support to IB device (Kamal Heib) [1720888]
- [infiniband] IB/mlx5: Introduce async DEVX obj query API (Kamal Heib) [1720888]
- [infiniband] IB/mlx5: Introduce MLX5_IB_OBJECT_DEVX_ASYNC_CMD_FD (Kamal Heib) [1720888]
- [infiniband] infiniband: prefix header search paths with $(srctree)/ (Kamal Heib) [1720888]
- [infiniband] infiniband: remove unneeded header search paths (Kamal Heib) [1720888]
- [infiniband] infiniband: ipoib: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] infiniband: usnic: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] infiniband: ocrdma: no need to check return value of debugfs_create functions (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Use PCI-ID as an identification in debugfs (Kamal Heib) [1720888]
- [infiniband] IB/umad: Do not check status of nonseekable_open() (Kamal Heib) [1720888]
- [infiniband] IB/umad: Avoid additional device reference during open()/close() (Kamal Heib) [1720888]
- [infiniband] IB/rxe: Remove unnecessary rxe variable (Kamal Heib) [1720888]
- [infiniband] IB/core: Simplify rdma cgroup registration (Kamal Heib) [1720888]
- [infiniband] RDMA/device: Use __ib_device_get_by_name() in ib_device_rename() (Kamal Heib) [1720888]
- [infiniband] RDMA: Rename port_callback to init_port (Kamal Heib) [1720888]
- [infiniband] RDMA: Clear CTX objects during their allocation (Kamal Heib) [1720888]
- [infiniband] RDMA: Clear PD objects during their allocation (Kamal Heib) [1720888]
- [infiniband] RDMA/ocrdma: Fix out of bounds index check in query pkey (Kamal Heib) [1720888]
- [infiniband] IB/{core, hw}: Have ib_umem_get extract the ib_ucontext from ib_udata (Kamal Heib) [1720888]
- [infiniband] IB/{core, uverbs}: Move ib_umem_xxx functions from ib_core to ib_uverbs (Kamal Heib) [1720888]
- [infiniband] RDMA/core: Don't depend device ODP capabilities on kconfig option (Kamal Heib) [1720888]
- [infiniband] IB/srp: Use struct_size() in kzalloc() (Kamal Heib) [1720888]
- [infiniband] IB/core: Use struct_size() in kzalloc() (Kamal Heib) [1720888]
- [infiniband] IB/usnic: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [infiniband] IB/cm: Use struct_size() in kmalloc() (Kamal Heib) [1720888]
- [mm] mm: introduce put_user_page*(), placeholder versions (Rafael Aquini) [1746371]
- [mm] mm/gup: add FOLL_LONGTERM capability to GUP fast (Rafael Aquini) [1746371]
- [mm] mm/gup: change GUP fast to use flags rather than a write 'bool' (Rafael Aquini) [1746371]
- [mm] mm/gup: change write parameter to flags in fast walk (Rafael Aquini) [1746371]
- [mm] mm/gup: replace get_user_pages_longterm() with FOLL_LONGTERM (Rafael Aquini) [1746371]
- [s390] s390/mm: fix pxd_bad with folded page tables (Rafael Aquini) [1746371]
- [s390] s390/mm: fix dump_pagetables top level page table walking (Rafael Aquini) [1746371]
- [s390] s390/mm: convert to the generic get_user_pages_fast code (Rafael Aquini) [1746371]
- [s390] s390/mm: make the pxd_offset functions more robust (Rafael Aquini) [1746371]
- [mm] mm/gup: fix gup_pmd_range() for dax (Rafael Aquini) [1746371]
- [mm] mm/gup: remove the 'write' parameter from gup_fast_permitted() (Rafael Aquini) [1746371]
- [mm] mm/gup: fix follow_page_mask() kerneldoc comment (Rafael Aquini) [1746371]
- [mm] mm/gup: fix __get_user_pages_fast() comment (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: prevent integer overflow in ioctl (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: add additional pinning methods (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: time put_page() (Rafael Aquini) [1746371]
- [mm] mm/gup_benchmark: fix unsigned comparison to zero in __gup_benchmark_ioctl (Rafael Aquini) [1746371]
- [mm] mm: remove caller signal_pending branch predictions (Rafael Aquini) [1746371]
- [mm] mm: remove unnecessary local variable addr in __get_user_pages_fast() (Rafael Aquini) [1746371]
- [mm] mm: change return type int to vm_fault_t for fault handlers (Rafael Aquini) [1746371]
- [mm] mm: make mm->pinned_vm an atomic64 counter (Rafael Aquini) [1746371]

* Tue Oct 29 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-147.10.rt13.1.el8]
- [rt] mm/slab: Convert memcg_kmem_wq_lock to raw_spinlock (Juri Lelli)
- [rt] sysrq: Use panic() to force a crash (Matthias Kaehlcke)
- [rt] drivers/crypto/qat: Use raw_smp_processor_id to retrive a device from a node (Juri Lelli)
- [rt] redhat/Makefile: Restructure rh-release (Juri Lelli)
- [rt] redhat: Update RTBZ for 8.2 (Juri Lelli)
- [rt] redhat/genspec: Fix lasttag (Juri Lelli)
- [rt] Use rhel-8.2.0 changelog as starting point for rhel-rt-8.2.0 (Juri Lelli)
- [rt] rpmspec: update kernel-rt.spec.template (Juri Lelli)
- [rt] redhat: create kernel-module-internal subpackage (Juri Lelli)
- [rt] redhat: Adapt to latest changes in kernel.spec.template (Juri Lelli)
- [rt] move sctp_association structure rcu member on RT (Clark Williams)
- [rt] redhat: Make kernel-rt require rt-setup (Juri Lelli)
- [rt] script to handle manual gating command (Clark Williams)
- [rt] Enable gdb_index (Juri Lelli)
- [rt] allow for test and candidate build targets (Clark Williams)
- [rt] added brew target parameter for rhpkg build (Clark Williams)
- [rt] Use localversion-rt to initialize RTTAG (Juri Lelli)
- [rt] Update rt-mab.sh to 8.2.0 (Juri Lelli)
- [rt] Add RT merge-and-build script (Clark Williams)
- [rt] exclude uploading kabi whitelist tarball on RT (Clark Williams)
- [rt] RT build changes to handle new changelog mechanism (Juri Lelli)
- [rt] Reset RTBUILD for first release (Juri Lelli)
- [rt] Add RTBUILD number (Juri Lelli)
- [rt] process_configs.sh complains that CONFIG_PREEMPT is not defined ("Luis Claudio R. Goncalves")
- [rt] add CONFIG_COMPACTION back to RT build (Clark Williams)
- [rt] add CONFIG_FRAME_WARN override and set to 8192 for RT (Clark Williams)
- [rt] checkin of RT configuration overrides (Clark Williams)
- [rt] create kernel-rt.spec.template for RT on RHEL8.1 (Juri Lelli)
- [rt] scripting changes for RT builds in RHEL8.1 (Juri Lelli)
- [rt] Makefile and data file modifications for RT builds in RHEL8.1 (Juri Lelli)
- [rt] printk: Drop the logbuf_lock more often (Sebastian Andrzej Siewior)
- [rt] kernel/printk: Don't try to print from IRQ/NMI region (Sebastian Andrzej Siewior)
- [rt] printk: Make rt aware (Thomas Gleixner)
- [rt] printk: Add "force_early_printk" boot param to help with debugging (Peter Zijlstra)
- [rt] printk: Add a printk kill switch (Ingo Molnar)
- [rt] Add localversion for -RT release (Thomas Gleixner)
- [rt] signals: Allow rt tasks to cache one sigqueue struct (Thomas Gleixner)
- [rt] apparmor: use a locallock instead preempt_disable() (Sebastian Andrzej Siewior)
- [rt] cpuset: Convert callback_lock to raw_spinlock_t (Mike Galbraith)
- [rt] drm/i915: Don't disable interrupts for intel_engine_breadcrumbs_irq() (Sebastian Andrzej Siewior)
- [rt] drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE (Sebastian Andrzej Siewior)
- [rt] drm/i915: disable tracing on -RT (Sebastian Andrzej Siewior)
- [rt] drm,i915: Use local_lock/unlock_irq() in intel_pipe_update_start/end() (Mike Galbraith)
- [rt] drm,radeon,i915: Use preempt_disable/enable_rt() where recommended (Mike Galbraith)
- [rt] watchdog: prevent deferral of watchdogd wakeup on RT (Julia Cartwright)
- [rt] tpm_tis: fix stall after iowrite*()s (Haris Okanovic)
- [rt] drivers/zram: Don't disable preemption in zcomp_stream_get/put() (Mike Galbraith)
- [rt] drivers/block/zram: Replace bit spinlocks with rtmutex for -rt (Mike Galbraith)
- [rt] connector/cn_proc: Protect send_msg() with a local lock on RT (Mike Galbraith)
- [rt] sched: migrate_enable: Use stop_one_cpu_nowait() (Scott Wood)
- [rt] sched: Lazy migrate_disable processing (Scott Wood)
- [rt] sched: migrate_enable: Use select_fallback_rq() (Scott Wood)
- [rt] x86: preempt: Check preemption level before looking at lazy-preempt (Sebastian Andrzej Siewior)
- [rt] x86: Support for lazy preemption (Thomas Gleixner)
- [rt] ftrace: Fix trace header alignment (Mike Galbraith)
- [rt] sched: Add support for lazy preemption (Thomas Gleixner)
- [rt] lockdep: selftest: fix warnings due to missing PREEMPT_RT conditionals (Josh Cartwright)
- [rt] lockdep: selftest: Only do hardirq context test for raw spinlock (Yong Zhang)
- [rt] net: Add a mutex around devnet_rename_seq (Sebastian Andrzej Siewior)
- [rt] net: netfilter: Serialize xt_write_recseq sections on RT (Thomas Gleixner)
- [rt] net/core: protect users of napi_alloc_cache against reentrance (Sebastian Andrzej Siewior)
- [rt] net: Another local_irq_disable/kmalloc headache (Thomas Gleixner)
- [rt] net: Remove preemption disabling in netif_rx() (Priyanka Jain)
- [rt] sched: migrate_dis/enable: Use sleeping_lock() to annotate sleeping points (Scott Wood)
- [rt] hotplug: duct-tape RT-rwlock usage for non-RT (Sebastian Andrzej Siewior)
- [rt] sched: Allow pinned user tasks to be awakened to the CPU they pinned (Mike Galbraith)
- [rt] cpu/hotplug: Implement CPU pinning (Thomas Gleixner)
- [rt] random: Make it work on rt (Thomas Gleixner)
- [rt] x86: stackprotector: Avoid random pool on rt (Thomas Gleixner)
- [rt] panic: skip get_random_bytes for RT_FULL in init_oops_id (Thomas Gleixner)
- [rt] crypto: cryptd - add a lock instead preempt_disable/local_bh_disable (Sebastian Andrzej Siewior)
- [rt] crypto: limit more FPU-enabled sections (Sebastian Andrzej Siewior)
- [rt] crypto: Reduce preempt disabled regions, more algos (Sebastian Andrzej Siewior)
- [rt] x86: crypto: Reduce preempt disabled regions (Peter Zijlstra)
- [rt] scsi/fcoe: Make RT aware. (Thomas Gleixner)
- [rt] arm: Enable highmem for rt (Thomas Gleixner)
- [rt] arm/highmem: Flush tlb on unmap (Sebastian Andrzej Siewior)
- [rt] x86/highmem: Add a "already used pte" check (Sebastian Andrzej Siewior)
- [rt] mm, rt: kmap_atomic scheduling (Peter Zijlstra)
- [rt] sysfs: Add /sys/kernel/realtime entry (Clark Williams)
- [rt] arm64: fpsimd: use preemp_disable in addition to local_bh_disable() (Sebastian Andrzej Siewior)
- [rt] KVM: arm/arm64: downgrade preempt_disable()d region to migrate_disable() (Josh Cartwright)
- [rt] genirq: update irq_set_irqchip_state documentation (Josh Cartwright)
- [rt] ARM: enable irq in translation/section permission fault handlers ("Yadi.hu")
- [rt] irqwork: push most work into softirq context (Sebastian Andrzej Siewior)
- [rt] net: Have __napi_schedule_irqoff() disable interrupts on RT (Steven Rostedt)
- [rt] net/Qdisc: use a seqlock instead seqcount (Sebastian Andrzej Siewior)
- [rt] net: dev: always take qdisc's busylock in __dev_xmit_skb() (Sebastian Andrzej Siewior)
- [rt] net: Use skbufhead with raw lock (Thomas Gleixner)
- [rt] sunrpc: Make svc_xprt_do_enqueue() use get_cpu_light() (Mike Galbraith)
- [rt] seqlock: Prevent rt starvation (Thomas Gleixner)
- [rt] debugobjects: Make RT aware (Thomas Gleixner)
- [rt] fs/dcache: use swait_queue instead of waitqueue (Sebastian Andrzej Siewior)
- [rt] net: Use cpu_chill() instead of cpu_relax() (Thomas Gleixner)
- [rt] fs: dcache: Use cpu_chill() in trylock loops (Thomas Gleixner)
- [rt] block: Use cpu_chill() for retry loops (Thomas Gleixner)
- [rt] rt: Introduce cpu_chill() (Thomas Gleixner)
- [rt] md: raid5: Make raid5_percpu handling RT aware (Thomas Gleixner)
- [rt] block/mq: don't complete requests via IPI (Sebastian Andrzej Siewior)
- [rt] block/mq: do not invoke preempt_disable() (Sebastian Andrzej Siewior)
- [rt] block: mq: use cpu_light() (Sebastian Andrzej Siewior)
- [rt] mm/vmalloc: Another problematic preempt disable region (Thomas Gleixner)
- [rt] fs/epoll: Do not disable preemption on RT (Thomas Gleixner)
- [rt] powerpc/pseries/iommu: Use a locallock instead local_irq_save() (Sebastian Andrzej Siewior)
- [rt] squashfs: make use of local lock in multi_cpu decompressor (Julia Cartwright)
- [rt] fs/dcache: disable preemption on i_dir_seq's write side (Sebastian Andrzej Siewior)
- [rt] fs/dcache: bring back explicit INIT_HLIST_BL_HEAD init (Sebastian Andrzej Siewior)
- [rt] mm: Protect activate_mm() by preempt_[disable&enable]_rt() (Yong Zhang)
- [rt] rt: Improve the serial console PASS_LIMIT (Ingo Molnar)
- [rt] tty: serial: pl011: explicitly initialize the flags variable (Kurt Kanzenbach)
- [rt] tty/serial/pl011: Make the locking work on RT (Thomas Gleixner)
- [rt] tty/serial/omap: Make the locking RT aware (Thomas Gleixner)
- [rt] rcutorture: Avoid problematic critical section nesting on RT (Scott Wood)
- [rt] rcu: enable rcu_normal_after_boot by default for RT (Julia Cartwright)
- [rt] srcu: replace local_irqsave() with a locallock (Sebastian Andrzej Siewior)
- [rt] rcu: Use rcuc threads on PREEMPT_RT as we did (Scott Wood)
- [rt] rcu: Enable elimination of Tree-RCU softirq processing (Sebastian Andrzej Siewior)
- [rt] locking: don't check for __LINUX_SPINLOCK_TYPES_H on -RT archs (Sebastian Andrzej Siewior)
- [rt] sched/migrate_disable: fallback to preempt_disable() instead barrier() (Sebastian Andrzej Siewior)
- [rt] rtmutex: annotate sleeping lock context (Sebastian Andrzej Siewior)
- [rt] ptrace: fix ptrace vs tasklist_lock race (Sebastian Andrzej Siewior)
- [rt] locking/rtmutex: re-init the wait_lock in rt_mutex_init_proxy_locked() (Sebastian Andrzej Siewior)
- [rt] locking/rt-mutex: Flush block plug on __down_read() (Scott Wood)
- [rt] locking/rt-mutex: fix deadlock in device mapper / block-IO (Mikulas Patocka)
- [rt] kconfig: Add PREEMPT_RT_FULL (Thomas Gleixner)
- [rt] rtmutex: add ww_mutex addon for mutex-rt (Sebastian Andrzej Siewior)
- [rt] rtmutex: wire up RT's locking (Thomas Gleixner)
- [rt] rtmutex: add rwlock implementation based on rtmutex (Thomas Gleixner)
- [rt] rtmutex: add rwsem implementation based on rtmutex (Thomas Gleixner)
- [rt] rtmutex: add mutex implementation based on rtmutex (Thomas Gleixner)
- [rt] locking/rtmutex: Clean ->pi_blocked_on in the error case (Peter Zijlstra)
- [rt] rtmutex: add sleeping lock implementation (Thomas Gleixner)
- [rt] rtmutex: export lockdep-less version of rt_mutex's lock, trylock and unlock (Thomas Gleixner)
- [rt] rtmutex: Provide rt_mutex_slowlock_locked() (Thomas Gleixner)
- [rt] rbtree: don't include the rcu header (Sebastian Andrzej Siewior)
- [rt] rtmutex: Avoid include hell (Thomas Gleixner)
- [rt] spinlock: Split the lock types header (Thomas Gleixner)
- [rt] rtmutex: Make lock_killable work (Thomas Gleixner)
- [rt] rtmutex: Add rtmutex_lock_killable() (Thomas Gleixner)
- [rt] locking: locktorture: Do NOT include rwlock.h directly ("Wolfgang M. Reimer")
- [rt] arm: include definition for cpumask_t (Sebastian Andrzej Siewior)
- [rt] pid.h: include atomic.h (Grygorii Strashko)
- [rt] futex: Ensure lock/unlock symetry versus pi_lock and hash bucket lock (Thomas Gleixner)
- [rt] futex: Fix bug on when a requeued RT task times out (Steven Rostedt)
- [rt] rtmutex: Handle the various new futex race conditions (Thomas Gleixner)
- [rt] futex: workaround migrate_disable/enable in different context (Thomas Gleixner)
- [rt] fs/nfs: turn rmdir_sem into a semaphore (Sebastian Andrzej Siewior)
- [rt] rtmutex: trylock is okay on -RT (Sebastian Andrzej Siewior)
- [rt] net/core: use local_bh_disable() in netif_rx_ni() (Sebastian Andrzej Siewior)
- [rt] softirq: Disable softirq stacks for RT (Thomas Gleixner)
- [rt] softirq: Check preemption after reenabling interrupts (Thomas Gleixner)
- [rt] softirq: Avoid a cancel dead-lock in tasklet handling due to preemptible-softirq (Sebastian Andrzej Siewior)
- [rt] lockdep: Make it RT aware (Thomas Gleixner)
- [rt] trace: Add migrate-disabled counter to tracing output (Thomas Gleixner)
- [rt] hotplug: Lightweight get online cpus (Thomas Gleixner)
- [rt] sched: migrate disable: Protect cpus_ptr with lock (Scott Wood)
- [rt] rt: Increase/decrease the nr of migratory tasks when enabling/disabling migration (Daniel Bristot de Oliveira)
- [rt] sched: Disable TTWU_QUEUE on RT (Thomas Gleixner)
- [rt] sched: Use the proper LOCK_OFFSET for cond_resched() (Thomas Gleixner)
- [rt] sched: Do not account rcu_preempt_depth on RT in might_sleep() (Thomas Gleixner)
- [rt] sched: Add saved_state for tasks blocked on sleeping locks (Thomas Gleixner)
- [rt] kernel/sched: move stack + kprobe clean up to __put_task_struct() (Sebastian Andrzej Siewior)
- [rt] sched: Move mmdrop to RCU on RT (Thomas Gleixner)
- [rt] sched: Limit the number of task migrations per batch (Thomas Gleixner)
- [rt] sched: Move task_struct cleanup to RCU (Thomas Gleixner)
- [rt] posix-timers: Thread posix-cpu-timers on -rt (John Stultz)
- [rt] sched/deadline: Ensure inactive_timer runs in hardirq context (Juri Lelli)
- [rt] KVM: arm/arm64: Let the timer expire in hardirq context on RT (Thomas Gleixner)
- [rt] hrtimer: Add a missing bracket and hide `migration_base' on !SMP (Sebastian Andrzej Siewior)
- [rt] hrtimer: Prevent using hrtimer_grab_expiry_lock() on migration_base (Julien Grall)
- [rt] hrtimer: Don't grab the expiry lock for non-soft hrtimer (Julien Grall)
- [rt] hrtimer: Use READ_ONCE to access timer->base in hrimer_grab_expiry_lock() (Julien Grall)
- [rt] hrtimer: move state change before hrtimer_cancel in do_nanosleep() (Sebastian Andrzej Siewior)
- [rt] sched/fair: Make the hrtimers non-hard again (Sebastian Andrzej Siewior)
- [rt] hrtimer: by timers by default into the softirq context (Sebastian Andrzej Siewior)
- [rt] hrtimer: consolidate hrtimer_init() + hrtimer_init_sleeper() calls (Sebastian Andrzej Siewior)
- [rt] sched/completion: Fix a lockup in wait_for_completion() (Corey Minyard)
- [rt] completion: Use simple wait queues (Thomas Gleixner)
- [rt] wait.h: include atomic.h (Sebastian Andrzej Siewior)
- [rt] pci/switchtec: Don't use completion's wait queue (Sebastian Andrzej Siewior)
- [rt] x86: kvm Require const tsc for RT (Thomas Gleixner)
- [rt] timers: Prepare for full preemption (Ingo Molnar)
- [rt] radix-tree: use local locks (Sebastian Andrzej Siewior)
- [rt] mm/zswap: Do not disable preemption in zswap_frontswap_store() ("Luis Claudio R. Goncalves")
- [rt] mm/zsmalloc: copy with get_cpu_var() and locking (Mike Galbraith)
- [rt] mm/memcontrol: Replace local_irq_disable with local locks (Sebastian Andrzej Siewior)
- [rt] mm/memcontrol: Don't call schedule_work_on in preemption disabled context (Yang Shi)
- [rt] slub: Disable SLUB_CPU_PARTIAL (Sebastian Andrzej Siewior)
- [rt] slub: Enable irqs for __GFP_WAIT (Thomas Gleixner)
- [rt] mm: Enable SLUB for RT (Thomas Gleixner)
- [rt] mm/vmstat: Protect per cpu variables with preempt disable on RT (Ingo Molnar)
- [rt] mm: perform lru_add_drain_all() remotely (Luiz Capitulino)
- [rt] mm/swap: Convert to percpu locked (Ingo Molnar)
- [rt] mm: page_alloc: rt-friendly per-cpu pages (Ingo Molnar)
- [rt] mm/SLUB: delay giving back empty slubs to IRQ enabled regions (Thomas Gleixner)
- [rt] mm/SLxB: change list_lock to raw_spinlock_t (Thomas Gleixner)
- [rt] Split IRQ-off and zone->lock while freeing pages from PCP list #2 (Peter Zijlstra)
- [rt] Split IRQ-off and zone->lock while freeing pages from PCP list #1 (Peter Zijlstra)
- [rt] genirq: Force interrupt thread on RT (Thomas Gleixner)
- [rt] genirq: Disable irqpoll on -rt (Ingo Molnar)
- [rt] list_bl: fixup bogus lockdep warning (Josh Cartwright)
- [rt] list_bl: Make list head locking RT safe (Paul Gortmaker)
- [rt] fs: jbd/jbd2: Make state lock and journal head lock rt safe (Thomas Gleixner)
- [rt] buffer_head: Replace bh_uptodate_lock for -rt (Thomas Gleixner)
- [rt] x86/signal: delay calling signals on 32bit (Yang Shi)
- [rt] signal/x86: Delay calling signals in atomic (Oleg Nesterov)
- [rt] mm/scatterlist: Do not disable irqs on RT (Thomas Gleixner)
- [rt] locallock: provide {get,put}_locked_ptr() variants (Julia Cartwright)
- [rt] rt: Add local irq locks (Thomas Gleixner)
- [rt] preempt: Provide preempt_*_(no)rt variants (Thomas Gleixner)
- [rt] x86: Disable HAVE_ARCH_JUMP_LABEL (Sebastian Andrzej Siewior)
- [rt] efi: Disable runtime services on RT (Sebastian Andrzej Siewior)
- [rt] md: disable bcache (Sebastian Andrzej Siewior)
- [rt] leds: trigger: disable CPU trigger on -RT (Sebastian Andrzej Siewior)
- [rt] mips: Disable highmem on RT (Thomas Gleixner)
- [rt] powerpc: Disable highmem on RT (Thomas Gleixner)
- [rt] powerpc/kvm: Disable in-kernel MPIC emulation for PREEMPT_RT_FULL (Bogdan Purcareata)
- [rt] arm*: disable NEON in kernel mode (Sebastian Andrzej Siewior)
- [rt] net/core: disable NET_RX_BUSY_POLL (Sebastian Andrzej Siewior)
- [rt] sched: Disable CONFIG_RT_GROUP_SCHED on RT (Thomas Gleixner)
- [rt] rcu: make RCU_BOOST default on RT (Sebastian Andrzej Siewior)
- [rt] locking: Disable spin on owner for RT (Thomas Gleixner)
- [rt] mm: Allow only slub on RT (Ingo Molnar)
- [rt] lockdep: disable self-test (Sebastian Andrzej Siewior)
- [rt] kconfig: Disable config options which are not RT compatible (Thomas Gleixner)
- [rt] jump-label: disable if stop_machine() is used (Thomas Gleixner)
- [rt] cpumask: Disable CONFIG_CPUMASK_OFFSTACK for RT (Thomas Gleixner)
- [rt] rt: Provide PREEMPT_RT_BASE config switch (Thomas Gleixner)
- [rt] net: sched: Use msleep() instead of yield() (Marc Kleine-Budde)
- [rt] signal: Revert ptrace preempt magic (Thomas Gleixner)
- [rt] timekeeping: Split jiffies seqlock (Thomas Gleixner)
- [rt] sched: Remove dead __migrate_disabled() check (Scott Wood)
- [rt] sched/migrate_disable: Add export_symbol_gpl for __migrate_disabled (Sebastian Andrzej Siewior)
- [rt] kernel/sched/core: add migrate_disable() (Sebastian Andrzej Siewior)
- [rt] sched: __set_cpus_allowed_ptr: Check cpus_mask, not cpus_ptr (Scott Wood)
- [rt] kernel: sched: Provide a pointer to the valid CPU mask (Sebastian Andrzej Siewior)
- [rt] NFSv4: replace seqcount_t with a seqlock_t (Sebastian Andrzej Siewior)
- [rt] posix-timers: Unlock expiry lock in the early return (Sebastian Andrzej Siewior)
- [rt] posix-timers: Add expiry lock (Anna-Maria Gleixner)
- [rt] posix-timers: move rcu out of union (Sebastian Andrzej Siewior)
- [rt] hrtimer: Introduce expiry spin lock (Anna-Maria Gleixner)
- [rt] timers: Drop expiry lock after each timer invocation (Anna-Maria Gleixner)
- [rt] timers: Introduce expiry spin lock (Anna-Maria Gleixner)
- [rt] kmemleak: Change the lock of kmemleak_object to raw_spinlock_t (Liu Haitao)
- [rt] kmemleak: Turn kmemleak_lock to raw spinlock on RT (He Zhe)
- [rt] of: allocate / free phandle cache outside of the devtree_lock (Sebastian Andrzej Siewior)
- [rt] arm64: KVM: compute_layout before altenates are applied (Sebastian Andrzej Siewior)
- [rt] block: blk-mq: move blk_queue_usage_counter_release() into process context (Sebastian Andrzej Siewior)
- [rt] fs/aio: simple simple work (Sebastian Andrzej Siewior)
- [rt] workqueue: Convert the locks to raw type (Sebastian Andrzej Siewior)
- [rt] workqueue: Remove GPF argument from alloc_workqueue_attrs() (Thomas Gleixner)
- [rt] workqueue: Make alloc/apply/free_workqueue_attrs() static (Thomas Gleixner)
- [rt] sched/swait: Add swait_event_lock_irq() (Sebastian Andrzej Siewior)
- [rt] rcu: Acquire RCU lock when disabling BHs (Scott Wood)
- [rt] softirq: Add preemptible softirq (Sebastian Andrzej Siewior)
- [rt] dma-buf: Use seqlock_t instread disabling preemption (Sebastian Andrzej Siewior)
- [rt] efi: Allow efi=runtime (Sebastian Andrzej Siewior)
- [rt] thermal/x86_pkg_temp: make pkg_temp_lock a raw spinlock (Clark Williams)
- [rt] i2c: hix5hd2: Remove IRQF_ONESHOT (Sebastian Andrzej Siewior)
- [rt] i2c: exynos5: Remove IRQF_ONESHOT (Sebastian Andrzej Siewior)
- [rt] x86/ldt: Initialize the context lock for init_mm (Sebastian Andrzej Siewior)
- [rt] locking/lockdep: Don't complain about incorrect name for no validate class (Sebastian Andrzej Siewior)
- [rt] drm/i915: Don't disable interrupts independently of the lock (Sebastian Andrzej Siewior)
- [rt] tpm: remove tpm_dev_wq_lock (Sebastian Andrzej Siewior)
- [rt] mm: workingset: replace IRQ-off check with a lockdep assert. (Sebastian Andrzej Siewior)
- [rt] percpu: include irqflags.h for raw_local_irq_save() (Sebastian Andrzej Siewior)
- [rt] Drivers: hv: vmbus: include header for get_irq_regs() (Sebastian Andrzej Siewior)
- [rt] fscache: initialize cookie hash table raw spinlocks (Clark Williams)
- [rt] cgroup: use irqsave in cgroup_rstat_flush_locked() (Sebastian Andrzej Siewior)
- [rt] x86/ioapic: Don't let setaffinity unmask threaded EOI interrupt too early (Thomas Gleixner)
- [rt] lib/ubsan: Don't seralize UBSAN report (Julien Grall)
- [rt] lib/smp_processor_id: Don't use cpumask_equal() (Waiman Long)

* Fri Oct 25 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.10.el8]
- [kernel] sched/core: Schedule new worker even if PI-blocked (Waiman Long) [1758629]
- [char] random: add a spinlock_t to struct batched_entropy (Waiman Long) [1758629]
- [crypto] crypto: chacha20 - Fix chacha20_block() keystream alignment (again) (Waiman Long) [1758629]
- [fs] locking/percpu-rwsem: Remove preempt_disable variants (Waiman Long) [1758629]
- [x86] x86/tsc: Add option to disable tsc clocksource watchdog (Waiman Long) [1758629]
- [x86] x86/irq: Handle spurious interrupt after shutdown gracefully (Waiman Long) [1758629]
- [x86] x86/ioapic: Implement irq_get_irqchip_state() callback (Waiman Long) [1758629]
- [kernel] genirq: Add optional hardware synchronization for shutdown (Waiman Long) [1758629]
- [kernel] genirq: Fix misleading synchronize_irq() documentation (Waiman Long) [1758629]
- [kernel] genirq: Delay deactivation in free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Remove redundant NULL pointer check in __free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Synchronize only with single thread on free_irq() (Waiman Long) [1758629]
- [kernel] genirq: Update code comments wrt recycled thread_mask (Waiman Long) [1758629]
- [usb] usb: core: remove flags variable in __usb_hcd_giveback_urb() (Waiman Long) [1758629]
- [usb] usb: core: remove local_irq_save() around ->complete() handler (Waiman Long) [1758629]
- [media] media: tm6000: use irqsave() in USB's complete callback (Waiman Long) [1758629]
- [media] media: em28xx-audio: use irqsave() in USB's complete callback (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Optimize __cpa_flush_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Factor common code between cpa_flush_*() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move CLFLUSH test into cpa_flush_array() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move CLFLUSH test into cpa_flush_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Use flush_tlb_kernel_range() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Unconditionally avoid WBINDV when we can (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Move flush_tlb_all() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Use flush_tlb_all() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Avoid the 4k pages check completely (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Do the range check early (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Optimize same protection check (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add sanity check for existing mappings (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Avoid static protection checks on unmap (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add large page preservation statistics (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Add debug mechanism (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Allow range check for static protections (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Rework static_protections() (Waiman Long) [1758629]
- [x86] x86/mm/cpa: Split, rename and clean up try_preserve_large_page() (Waiman Long) [1758629]
- [x86] x86/mm/init32: Mark text and rodata RO in one go (Waiman Long) [1758629]
- [mm] mm/kasan/quarantine.c: make quarantine_lock a raw_spinlock_t (Waiman Long) [1758629]
- [mm] mm/list_lru.c: fold __list_lru_count_one() into its caller (Waiman Long) [1758629]
- [mm] mm: workingset: make shadow_lru_isolate() use locking suffix (Waiman Long) [1758629]
- [mm] mm: workingset: remove local_irq_disable() from count_shadow_nodes() (Waiman Long) [1758629]
- [iommu] iommu/amd: Remove redundant WARN_ON() (Waiman Long) [1758629]
- [mm] mm/list_lru: introduce list_lru_shrink_walk_irq() (Waiman Long) [1758629]
- [mm] mm/list_lru.c: pass struct list_lru_node* as an argument to __list_lru_walk_one() (Waiman Long) [1758629]
- [mm] mm/list_lru.c: move locking from __list_lru_walk_one() to its caller (Waiman Long) [1758629]
- [mm] mm/list_lru.c: use list_lru_walk_one() in list_lru_walk_node() (Waiman Long) [1758629]
- [kernel] userns: use irqsave variant of refcount_dec_and_lock() (Waiman Long) [1758629]
- [kernel] userns: use refcount_t for reference counting instead atomic_t (Waiman Long) [1758629]
- [kernel] bdi: use irqsave variant of refcount_dec_and_lock() (Waiman Long) [1758629]
- [mm] bdi: use refcount_t for reference counting instead atomic_t (Waiman Long) [1758629]
- [char] random: remove preempt disabled region (Waiman Long) [1758629]
- [misc] ocxl: Update for AFU descriptor template version 1.1 (Steve Best) [1751207]
- [misc] ocxl: Make ocxl_remove() static (Steve Best) [1751207]
- [misc] ocxl: do not use C++ style comments in uapi header (Steve Best) [1751207]
- [misc] ocxl: Allow contexts to be attached with a NULL mm (Steve Best) [1751207]
- [misc] ocxl: Fix return value check in afu_ioctl() (Steve Best) [1751207]
- [misc] ocxl: Provide global MMIO accessors for external drivers (Steve Best) [1751207]
- [misc] ocxl: move event_fd handling to frontend (Steve Best) [1751207]
- [misc] ocxl: afu_irq only deals with IRQ IDs, not offsets (Steve Best) [1751207]
- [misc] ocxl: Allow external drivers to use OpenCAPI contexts (Steve Best) [1751207]
- [misc] ocxl: Create a clear delineation between ocxl backend & frontend (Steve Best) [1751207]
- [misc] ocxl: Don't pass pci_dev around (Steve Best) [1751207]
- [misc] ocxl: Split pci.c (Steve Best) [1751207]
- [misc] ocxl: Remove some unused exported symbols (Steve Best) [1751207]
- [misc] ocxl: Remove superfluous 'extern' from headers (Steve Best) [1751207]
- [misc] ocxl: read_pasid never returns an error, so make it void (Steve Best) [1751207]
- [misc] ocxl: Rename struct link to ocxl_link (Steve Best) [1751207]
- [misc] ocxl: remove set but not used variables 'tid' and 'lpid' (Steve Best) [1751207]
- [misc] ocxl: Fix endiannes bug in read_afu_name() (Steve Best) [1751207]
- [misc] ocxl/afu_irq: Don't include <asm/pnv-ocxl.h> (Steve Best) [1751207]
- [misc] ocxl: Clarify error path in setup_xsl_irq() (Steve Best) [1751207]
- [misc] ocxl: Fix endiannes bug in ocxl_link_update_pe() (Steve Best) [1751207]
- [misc] ocxl: Fix access to the AFU Descriptor Data (Steve Best) [1751207]
- [netdrv] gve: account for lack of netdev_xmit_more() definition (RHEL-only) (John Linville) [1728864]
- [netdrv] gve: Copy and paste bug in gve_get_stats() (John Linville) [1728864]
- [netdrv] gve: Fix case where desc_cnt and data_cnt can get out of sync (John Linville) [1728864]
- [netdrv] gve: replace kfree with kvfree (John Linville) [1728864]
- [netdrv] gve: Remove the exporting of gve_probe (John Linville) [1728864]
- [netdrv] gve: fix unused variable/label warnings (John Linville) [1728864]
- [netdrv] gve: Fix error return code in gve_alloc_qpls() (John Linville) [1728864]
- [netdrv] gve: fix -ENOMEM null check on a page allocation (John Linville) [1728864]
- [netdrv] gve: Fix u64_stats_sync to initialize start (John Linville) [1728864]
- [netdrv] gve: Add ethtool support (John Linville) [1728864]
- [netdrv] gve: Add workqueue and reset support (John Linville) [1728864]
- [netdrv] gve: Add transmit and receive support (John Linville) [1728864]
- [netdrv] gve: Add basic driver framework for Compute Engine Virtual NIC (John Linville) [1728864]
- [mfd] mfd: intel-lpss: Add Intel Comet Lake PCI IDs (David Arcari) [1761586]
- [scsi] scsi: core: save/restore command resid for error handling (Ewan Milne) [1760503]
- [scsi] scsi: sd: Ignore a failure to sync cache due to lack of authorization (Ewan Milne) [1760503]
- [scsi] scsi: core: Add sysfs attributes for VPD pages 0h and 89h (Ewan Milne) [1760503]
- [scsi] scsi: core: Log SCSI command age with errors (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_rdac: zero cdb in send_mode_select() (Ewan Milne) [1760503]
- [scsi] scsi: sd: Improve unaligned completion resid message (Ewan Milne) [1760503]
- [scsi] scsi: core: Reduce memory required for SCSI logging (Ewan Milne) [1760503]
- [scsi] scsi: core: Complain if scsi_target_block() fails (Ewan Milne) [1760503]
- [scsi] scsi: core: Make scsi_internal_device_unblock_nowait() reject invalid new_state (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debugfs: Use for_each_set_bit to simplify code (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_alua: always use a 2 second delay before retrying RTPG (Ewan Milne) [1760503]
- [scsi] scsi: sd_zbc: Fix compilation warning (Ewan Milne) [1760503]
- [scsi] scsi: devinfo: BLIST_TRY_VPD_PAGES for SanDisk Cruzer Blade (Ewan Milne) [1760503]
- [scsi] scsi: core: use scmd_printk() to print which command timed out (Ewan Milne) [1760503]
- [scsi] scsi: Avoid that .queuecommand() gets called for a blocked SCSI device (Ewan Milne) [1760503]
- [scsi] scsi: core: don't preallocate small SGL in case of NO_SG_CHAIN (Ewan Milne) [1760503]
- [scsi] scsi: scsi_dh_alua: Fix possible null-ptr-deref (Ewan Milne) [1760503]
- [scsi] scsi: st: add a SPDX tag to st.c (Ewan Milne) [1760503]
- [scsi] scsi: sr: add a SPDX tag to sr.c (Ewan Milne) [1760503]
- [scsi] scsi: sg: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: sd: switch remaining files to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: sd: add a SPDX tag to sd.c (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_srp: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_spi: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_sas: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_iscsi: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: scsi_transport_fc: switch to SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: core: switch the remaining scsi midlayer files to use SPDX tags (Ewan Milne) [1760503]
- [scsi] scsi: core: add SPDX tags to scsi midlayer files missing licensing information (Ewan Milne) [1760503]
- [scsi] Revert "scsi: sd: Keep disk read-only when re-reading partition" (Ewan Milne) [1760503]
- [scsi] scsi: core: set result when the command cannot be dispatched (Ewan Milne) [1760503]
- [scsi] scsi: core: map PQ=1, PDT=other values to SCSI_SCAN_TARGET_PRESENT (Ewan Milne) [1760503]
- [scsi] scsi: core: don't hold device refcount in IO path (Ewan Milne) [1760503]
- [scsi] scsi: sd: Quiesce warning if device does not report optimal I/O size (Ewan Milne) [1760503]
- [scsi] scsi: core: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Ewan Milne) [1760503]
- [scsi] scsi: core: Avoid that a kernel warning appears during system resume (Ewan Milne) [1760503]
- [scsi] scsi: core: Also call destroy_rcu_head() for passthrough requests (Ewan Milne) [1760503]
- [scsi] scsi: core: replace GFP_ATOMIC with GFP_KERNEL in scsi_scan.c (Ewan Milne) [1760503]
- [scsi] scsi: sd: Optimal I/O size should be a multiple of physical block size (Ewan Milne) [1760503]
- [scsi] scsi: sd: Fix typo in sd_first_printk() (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: Implement support for write protect (Ewan Milne) [1760503]
- [scsi] scsi: sd_zbc: Fix zone information messages (Ewan Milne) [1760503]
- [scsi] scsi: sd: Improve sd_print_capacity() (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: fix write_same with virtual_gb problem (Ewan Milne) [1760503]
- [scsi] scsi: sd: Protect against READ(6) or WRITE(6) with zero block transfer length (Ewan Milne) [1760503]
- [scsi] scsi: core: Remove an atomic instruction from the hot path (Ewan Milne) [1760503]
- [scsi] scsi: sd: Rename 'SCpnt' into 'cmd' (Ewan Milne) [1760503]
- [scsi] scsi: sd: Clean up sd_setup_read_write_cmnd() (Ewan Milne) [1760503]
- [scsi] scsi: sd: Create helper functions for read/write commands (Ewan Milne) [1760503]
- [scsi] scsi: sd: Simplify misaligned I/O check (Ewan Milne) [1760503]
- [scsi] scsi: sd: Be consistent about blocks vs. sectors (Ewan Milne) [1760503]
- [scsi] scsi: sd: Remove a local variable (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: add cmd abort option to every_nth (Ewan Milne) [1760503]
- [scsi] scsi: scsi_debug: skip long delays when ndelay small (Ewan Milne) [1760503]
- [x86] efi/x86: Do not clean dummy variable in kexec path (Bhupesh Sharma) [1724436]
- [scsi] scsi: csiostor: create per port irq affinity mask set (Jonathan Toppins) [1725816]
- [pci] PCI: let pci_disable_link_state propagate errors (Myron Stowe) [1735834]
- [scsi] scsi: scsi_transport_fc: Add FPIN fc event codes (Ewan Milne) [1755587]
- [scsi] scsi: scsi_transport_fc: refactor event posting routines (Ewan Milne) [1755587]
- [scsi] scsi: fc: add FPIN ELS definition (Ewan Milne) [1755587]
- [scsi] scsi: lib/sg_pool.c: clear 'first_chunk' in case of no preallocation (Ewan Milne) [1747162]
- [scsi] scsi: core: Run queue when state is set to running after being blocked (Ewan Milne) [1691599]
- [scsi] scsi: sd: Fix a race between closing an sd device and sd I/O (Ewan Milne) [1689118]
- [net] net/ibmvnic: Fix EOI when running in XIVE mode. (Steve Best) [1761378]
- [powerpc] powerpc/mce: Fix SLB rebolting during MCE recovery path. (Desnes Augusto Nunes do Rosario) [1725842]
- [powerpc] powerpc/pseries: hwpoison the pages upon hitting UE (Desnes Augusto Nunes do Rosario) [1725842]
- [x86] perf/x86/amd: Change/fix NMI latency mitigation to use a timestamp (David Arcari) [1730134]
- [arm64] arm64: entry: Remove unneeded need_resched() loop (Mark Langsdorf) [1737075]
- [arm64] arm64: preempt: Fix big-endian when checking preempt count in assembly (Mark Langsdorf) [1737075]
- [arm64] arm64: preempt: Provide our own implementation of asm/preempt.h (Mark Langsdorf) [1737075]
- [include] preempt: Move PREEMPT_NEED_RESCHED definition into arch code (Mark Langsdorf) [1737075]
- [x86] x86/intel_rdt: Ensure a CPU remains online for the region's pseudo-locking sequence (Alexander Beregalov) [1724902]
- [kernel] perf/core: Add sanity check to deal with pinned event failure (Alexander Beregalov) [1724902]
- [arm64] arm64/sve: Fix wrong free for task->thread.sve_state (Andrew Jones) [1756450]
- [scsi] scsi: lpfc: Update lpfc version to 12.4.0.1 (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: cleanup: remove unused fcp_txcmlpq_cnt (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Complete removal of FCoE T10 PI support on SLI-4 adapters (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Update async event logging (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix list corruption detected in lpfc_put_sgl_per_hdwq (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix hdwq sgl locks and irq handling (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix spinlock_irq issues in lpfc_els_flush_cmd() (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix list corruption in lpfc_sli_get_iocbq (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix host hang at boot or slow boot (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix coverity errors on NULL pointer checks (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix NVMe ABTS in response to receiving an ABTS (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix discovery failures when target device connectivity bounces (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix GPF on scsi command completion (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix locking on mailbox command completion (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix device recovery errors after PLOGI failures (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix rpi release when deleting vport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix NVME io abort failures causing hangs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix miss of register read failure check (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix premature re-enabling of interrupts in lpfc_sli_host_down (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix pt2pt discovery on SLI3 HBAs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix reset recovery paths that are not recovering (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Convert existing pf users to ps (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: fix 12.4.0.0 GPF at boot (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove bg debugfs buffers (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Resolve checker warning for lpfc_new_io_buf() (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Update lpfc version to 12.4.0.0 (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Merge per-protocol WQ/CQ pairs into single per-cpu pair (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add NVMe sequence level error recovery support (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Support dynamic unbounded SGL lists on G7 hardware. (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add MDS driver loopback diagnostics support (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add first and second level hardware revisions to sysfs reporting (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Migrate to px and pf in kernel print calls (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Add simple unlikely optimizations to reduce NVME latency (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix coverity warnings (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme first burst module parameter description (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix BlockGuard enablement on FCoE adapters (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix reported physical link speed on a disabled trunked link (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix Max Frame Size value shown in fdmishow output (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix upcall to bsg done in non-success cases (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix sli4 adapter initialization with MSI (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme sg_seg_cnt display if HBA does not support NVME (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix nvme target mode ABTSing a received ABTS (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix hang when downloading fw on port enabled for nvme (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix too many sg segments spamming in kernel log (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix crash due to port reset racing vs adapter error handling (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix deadlock on host_lock during cable pulls (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix error in remote port address change (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix driver nvme rescan logging (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix sg_seg_cnt for HBAs that don't support NVME (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix propagation of devloss_tmo setting to nvme transport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix loss of remote port after devloss due to lack of RPIs (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix devices that don't return after devloss followed by rediscovery (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix null ptr oops updating lpfc_devloss_tmo via sysfs attribute (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix FLOGI handling across multiple link up/down conditions (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix irq raising in lpfc_sli_hba_down (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix Oops in nvme_register with target logout/login (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix issuing init_vpi mbox on SLI-3 card (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix ADISC reception terminating login state if a NVME target (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix discovery when target has no GID_FT information (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix leak of ELS completions on adapter reset (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix failure to clear non-zero eq_delay after io rate reduction (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix crash on driver unload in wq free (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix ELS field alignments (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Fix PLOGI failure with high remoteport count (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: remove NULL check before some freeing functions (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: use spin_lock_irqsave in IRQ context (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: remove redundant code (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove unnecessary null check before kfree (Dick Kennedy) [1757574]
- [scripts] scripts/spelling.txt: drop "sepc" from the misspelling list (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: reduce stack size with CONFIG_GCC_PLUGIN_STRUCTLEAK_VERBOSE (Dick Kennedy) [1757574]
- [scsi] lpfc: add sysfs interface to post NVME RSCN (Dick Kennedy) [1757574]
- [scsi] lpfc: add support for translating an RSCN rcv into a discovery rescan (Dick Kennedy) [1757574]
- [scsi] lpfc: add support to generate RSCN events for nport (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: use sg helper to iterate over scatterlist (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Avoid unused function warnings (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Make some symbols static (Dick Kennedy) [1757574]
- [scsi] scsi: lpfc: Remove set but not used variables 'qp' (Dick Kennedy) [1757574]
- [lib] lib/vsprintf: Reinstate printing of legacy clock IDs (Prarit Bhargava) [1751075]
- [lib] vsprintf: fix data type of variable in string_nocheck() (Prarit Bhargava) [1751075]
- [scripts] kconfig: tests: fix recursive inclusion unit test (Prarit Bhargava) [1751075]
- [kernel] printk: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Prarit Bhargava) [1751075]
- [kernel] printk: Add SPDX license identifier for missed files (Prarit Bhargava) [1751075]
- [kernel] printk: Add SPDX license identifier for more missed files (Prarit Bhargava) [1751075]
- [kernel] panic: add an option to replay all the printk message in buffer (Prarit Bhargava) [1751075]
- [kernel] panic: avoid the extra noise dmesg (Prarit Bhargava) [1751075]
- [lib] vsprintf: Do not break early boot with probing addresses (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Make function pointer_string static (Prarit Bhargava) [1751075]
- [lib] vsprintf: Limit the length of inlined error messages (Prarit Bhargava) [1751075]
- [lib] vsprintf: Avoid confusion between invalid address and value (Prarit Bhargava) [1751075]
- [lib] vsprintf: Prevent crash when dereferencing invalid pointers (Prarit Bhargava) [1751075]
- [lib] vsprintf: Consolidate handling of unknown pointer specifiers (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out pO handler as kobject_string() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out pV handler as va_format() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Factor out p[iI] handler as ip_addr_string() (Prarit Bhargava) [1751075]
- [lib] vsprintf: Do not check address of well-known strings (Prarit Bhargava) [1751075]
- [lib] vsprintf: Consistent pK handling for kptr_restrict == 0 (Prarit Bhargava) [1751075]
- [lib] vsprintf: Shuffle restricted_pointer() (Prarit Bhargava) [1751075]
- [kernel] printk: Tie printk_once / printk_deferred_once into .data.once for reset (Prarit Bhargava) [1751075]
- [lib] lib: Use new kselftest header (Prarit Bhargava) [1751075]
- [lib] lib/test_printf: Add empty module_exit function (Prarit Bhargava) [1751075]
- [scripts] checkpatch: add pt as a valid vsprintf extension (Prarit Bhargava) [1751075]
- [lib] lib/test_printf: Switch to bitmap_zalloc() (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf.c: move sizeof(struct printf_spec) next to its definition (Prarit Bhargava) [1751075]
- [kernel] printk/docs: Add extra integer types to printk-formats (Prarit Bhargava) [1751075]
- [kernel] printk: Remove no longer used LOG_PREFIX. (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Remove pCr remnant in comment (Prarit Bhargava) [1751075]
- [kernel] printk: Pass caller information to log_store(). (Prarit Bhargava) [1751075]
- [kernel] kernel/sysctl: add panic_print into sysctl (Prarit Bhargava) [1751075]
- [kernel] panic: add options to print system info when panic happens (Prarit Bhargava) [1751075]
- [include] include/linux/printk.h: drop silly "static inline asmlinkage" from dump_stack() (Prarit Bhargava) [1751075]
- [kernel] printk: Add caller information to printk() output. (Prarit Bhargava) [1751075]
- [kernel] printk: Remove print_prefix() calls with NULL buffer. (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Print time and date in human readable format via pt (Prarit Bhargava) [1751075]
- [kernel] printk: fix printk_time race. (Prarit Bhargava) [1751075]
- [kernel] printk: Make printk_emit() local function. (Prarit Bhargava) [1751075]
- [documentation] doc: printk-formats: Remove bogus kobject references for device nodes (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Hash printed address for netdev bits fallback (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Hash legacy clock addresses (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Prepare for more general use of ptr_to_id() (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Make ptr argument conts in ptr_to_id() (Prarit Bhargava) [1751075]
- [kernel] printk: fix integer overflow in setup_log_buf() (Prarit Bhargava) [1751075]
- [kernel] printk: do not preliminary split up cont buffer (Prarit Bhargava) [1751075]
- [kernel] printk: lock/unlock console only for new logbuf entries (Prarit Bhargava) [1751075]
- [kernel] printk: keep kernel cont support always enabled (Prarit Bhargava) [1751075]
- [kernel] printk: Give error on attempt to set log buffer length to over 2G (Prarit Bhargava) [1751075]
- [kernel] printk: Add KBUILD_MODNAME and remove a redundant print prefix (Prarit Bhargava) [1751075]
- [kernel] printk: Correct wrong casting (Prarit Bhargava) [1751075]
- [kernel] printk: CON_PRINTBUFFER console registration is a bit racy (Prarit Bhargava) [1751075]
- [kernel] printk: Do not miss new messages when replaying the log (Prarit Bhargava) [1751075]
- [kernel] Revert "printk: make sure to print log on console." (Prarit Bhargava) [1751075]
- [lib] vsprintf: print OF node name using full_name (Prarit Bhargava) [1751075]
- [kernel] printk/tracing: Do not trace printk_nmi_enter() (Prarit Bhargava) [1751075]
- [misc] notifier: Remove notifier header file wherever not used (Prarit Bhargava) [1751075]
- [init] init: allow initcall tables to be emitted using relative references (Prarit Bhargava) [1751075]
- [lib] lib/vsprintf: Do not handle pO[^F] as px (Prarit Bhargava) [1751075]
- [kernel] console: Replace #if 0 with atomic var 'ignore_console_lock_warning' (Prarit Bhargava) [1751075]
- [lib] vsprintf: Use hw RNG for ptr_key (Prarit Bhargava) [1751075]
- [kernel] printk: Fix warning about unused suppress_message_printing (Prarit Bhargava) [1751075]
- [char] random: Return nbytes filled from hw RNG (Prarit Bhargava) [1751075]
- [char] random: Fix whitespace pre random-bytes work (Prarit Bhargava) [1751075]
- [kernel] printk/nmi: Prevent deadlock when accessing the main log buffer in NMI (Prarit Bhargava) [1751075]
- [kernel] printk: Create helper function to queue deferred console handling (Prarit Bhargava) [1751075]
- [kernel] printk: Split the code for storing a message into the log buffer (Prarit Bhargava) [1751075]
- [kernel] printk: Clean up syslog_print_all() (Prarit Bhargava) [1751075]
- [kernel] printk: Export is_console_locked (Prarit Bhargava) [1751075]
- [kernel] printk: Remove unnecessary kmalloc() from syslog during clear (Prarit Bhargava) [1751075]
- [kernel] printk: Make CONSOLE_LOGLEVEL_QUIET configurable (Prarit Bhargava) [1751075]
- [kernel] printk: make sure to print log on console. (Prarit Bhargava) [1751075]
- [lib] lib/test_printf.c: accept "ptrval" as valid result for plain 'p' tests (Prarit Bhargava) [1751075]
- [kernel] softirq: Remove tasklet_hrtimer (Prarit Bhargava) [1737073]
- [include] list: add function list_rotate_to_front() (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Rename the file for consistency (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Move Kconfig option (Prarit Bhargava) [1737073]
- [clocksource] clocksource/drivers/tcb_clksrc: Use tcb as sched_clock (Prarit Bhargava) [1737073]
- [kernel] irq_work: Do not raise an IPI when queueing work on the local CPU (Prarit Bhargava) [1737073]
- [tty] tty/sysrq: Convert show_lock to raw_spinlock_t (Prarit Bhargava) [1737073]
- [net] xfrm: Replace hrtimer tasklet with softirq hrtimer (Prarit Bhargava) [1737073]
- [netdrv] mac80211_hwsim: Replace hrtimer tasklet with softirq hrtimer (Prarit Bhargava) [1737073]
- [kernel] kthread: Do not use TIMER_IRQSAFE (Prarit Bhargava) [1737073]
- [kernel] kthread: Convert worker lock to raw spinlock (Prarit Bhargava) [1737073]
- [netdrv] mac80211_hwsim: Timer should be initialized before device registered (Prarit Bhargava) [1737073]
- [net] xfrm: use time64_t for in-kernel timestamps (Prarit Bhargava) [1737073]
- [x86] x86/intel: Aggregate microserver naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core graphics naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core mobile naming (Prarit Bhargava) [1725644]
- [x86] x86/intel: Aggregate big core client naming (Prarit Bhargava) [1725644]
- [tools] turbostat: Replace GPLv2 boilerplate/reference with SPDX - rule 335 (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: update version number (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: rename has_hsw_msrs() (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix Haswell Core systems (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Add support for Hygon Fam 18h (Dhyana) RAPL (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix caller parameter of get_tdp_amd() (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Fix CPUC1 display value (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: do not enforce 1ms (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: read from pipes too (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Add Ice Lake NNPI support (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: add Jacobsville support (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: remove duplicate pc10 column (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix file descriptor leaks (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix leak of file descriptor on error return path (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: fix buffer overrun (Prarit Bhargava) [1725644]
- [tools] tools/power turbostat: Make interval calculation per thread to reduce jitter (Prarit Bhargava) [1725644]
- [tools] tools/power/x86: Enable compiler optimisations and Fortify by default (Prarit Bhargava) [1725644]
- [x86] x86/cpu: Add Ice Lake NNPI to Intel family (Prarit Bhargava) [1725644]

* Tue Oct 22 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.9.el8]
- [tools] perf tools: Fix segfault in cpu_cache_level__read() (Michael Petlan) [1761995]
- [scsi] qla2xxx: Update driver version to 10.01.00.19.08.2-k (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix Nport ID display value (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix N2N link up fail (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix N2N link reset (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Optimize NPIV tear down process (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stale mem access on driver unload (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix unbound sleep in fcport delete path. (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Silence fwdump template message (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stale session (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix stuck login session (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix driver reload for ISP82xx (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix flash read for Qlogic ISPs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix message indicating vectors used by driver (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: fix spelling mistake "initializatin" -> "initialization" (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a recently introduced kernel warning (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a NULL pointer dereference (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qla24xx_async_abort_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous if-tests (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce qla2x00_els_dcmd2_free() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Inline the qla2x00_fcport_event_handler() function (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Report invalid mailbox status codes (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove superfluous sts_entry_* casts (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Let the compiler check the type of the SCSI command context pointer (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if sp->done() is not called from the completion path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make sure that aborted commands are freed (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce qla2xxx_get_next_handle() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Modify NVMe include directives (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qlt_handle_abts_completion() more robust (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a race condition between aborting and completing a SCSI command (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the function qla2xxx_init_sp() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Enable type checking for the SRB free and done callback functions (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Rework key encoding in qlt_find_host_by_d_id() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Set the responder mode if appropriate for ELS pass-through IOCBs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make it explicit that ELS pass-through IOCBs use little endian (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check secondary image if reading the primary image fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change the return type of qla24xx_read_flash_data() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the be_id_t and le_id_t data types for FC src/dst IDs (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a soft reset fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use memcpy() and strlcpy() instead of strcpy() and strncpy() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check the PCI info string output buffer size (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if waiting for pending commands times out (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare fourth qla2x00_set_model_info() argument const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Always check the qla2x00_wait_for_hba_online() return value (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Suppress multiple Coverity complaint about out-of-bounds accesses (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Suppress a Coveritiy complaint about integer overflow (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unreachable code from qla83xx_idc_lock() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix qla24xx_process_bidir_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify a debug statement (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove dead code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if parsing the version string fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a mailbox command times out (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use strlcpy() instead of strncpy() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Do not corrupt vha->plogi_ack_list (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Report the firmware status code if a mailbox command fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix session lookup in qlt_abort_work() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qla24xx_abort_sp_done() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous tests (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a superfluous pointer check (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qlt_lport_dump() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reduce the number of casts in GID list code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Verify locking assumptions at runtime (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change data_dsd into an array (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla_tgt_cmd.cdb const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reduce the scope of three local variables in qla2xxx_queuecommand() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Change the return type of qla2x00_update_ms_fdmi_iocb() into void (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare the fourth ql_dump_buffer() argument const (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a superfluous forward declaration (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove an include directive from qla_mr.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Include the <asm/unaligned.h> header file from qla_dsd.h (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use tabs instead of spaces for indentation (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Improve Linux kernel coding style conformance (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Really fix qla2xxx_eh_abort() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_abort_srb() again decrease the sp reference count (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Allow NVMe IO to resume with short cable pull (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix hang in fcport delete path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use common update-firmware-options routine for ISP27xx+ (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix NVMe port discovery after a short device port loss (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Correct error handling during initialization failures (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Retry fabric Scan on IOCB queue full (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix premature timer expiration (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix Relogin to prevent modifying scan_state flag (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reject EH_{abort|device_reset|target_request} (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Skip FW dump on LOOP initialization error (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use Correct index for Q-Pair array (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix abort timeout race condition. (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix DMA unmap leak (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Replace vmalloc + memset with vzalloc (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unnecessary null check (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: remove double assignment in qla2x00_update_fcport (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Add cleanup for PCI EEH recovery (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that lockdep complains about unsafe locking in tcm_qla2xxx_close_session() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that qlt_send_resp_ctio() corrupts memory (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use __le64 instead of uint32_t[2] for sending DMA addresses to firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Introduce the dsd32 and dsd64 data structures (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Check the size of firmware data structures at compile time (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Pass little-endian values to the firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla24xx_async_abort_cmd() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove unnecessary locking from the target code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove qla_tgt_cmd.released (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Complain if a command is released that is owned by the firmware (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: target: Fix offline port handling and host reset handling (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix abort handling in tcm_qla2xxx_write_pending() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix error handling in qlt_alloc_qfull_cmd() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Simplify qlt_send_term_imm_notif() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix use-after-free issues in qla2xxx_qpair_sp_free_dma() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a qla24xx_enable_msix() error path (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that qla2x00_mem_free() crashes if called twice (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_mem_free() easier to verify (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Increase the size of the mailbox arrays from 4 to 8 (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Log the status code if a firmware command fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Avoid that Coverity complains about dereferencing a NULL rport pointer (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Uninline qla2x00_init_timer() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_is_reserved_id() from qla_inline.h into qla_init.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_clear_loop_id() from qla_inline.h into qla_init.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a set-but-not-used variable (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla2x00_find_new_loop_id() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_set_reserved_loop_ids() definition (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a format specifier (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Update two source code comments (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Silence Successful ELS IOCB message (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix device staying in blocked state (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move qla2x00_set_fcport_state() from a .h into a .c file (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove two superfluous casts (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove qla_tgt_cmd.data_work and qla_tgt_cmd.data_work_free (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move the <linux/io-64-nonatomic-lo-hi.h> include directive (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare qla24xx_build_scsi_crc_2_iocbs() static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Move the port_state_str[] definition from a .h to a .c file (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Insert spaces where required (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix formatting of pointer types (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Leave a blank line after declarations (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use tabs to indent code (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix FC-AL connection target discovery (Himanshu Madhani) [1728845]
- [scsi] scsi: tcm_qla2xxx: Minimize #include directives (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Unregister resources in the opposite order of the registration order (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Unregister chrdev if module initialization fails (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use get/put_unaligned where appropriate (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Make qla2x00_process_response_queue() easier to read (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Declare local symbols static (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use ARRAY_SIZE() in the definition of QLA_LAST_SPEED (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove a comment that refers to the SCSI host lock (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Remove useless set memory to zero use memset() (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Cleanup fcport memory to prevent leak (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Further limit FLASH region write access from SysFS (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix incorrect region-size setting in optrom SYSFS routines (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe during probe (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Increase the max_sgl_segments to 1024 (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Reset the FCF_ASYNC_{SENT|ACTIVE} flags (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Set the qpair in SRB to NULL when SRB is released (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix a small typo in qla_bsg.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Fix comment alignment in qla_bsg.c (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: deadlock by configfs_depend_item (Himanshu Madhani) [1728845]
- [scsi] scsi: qla2xxx: use lower_32_bits and upper_32_bits instead of reinventing them (Himanshu Madhani) [1728845]
- [md] dm snapshot: rework COW throttling to fix deadlock (Mike Snitzer) [1758605]
- [md] dm snapshot: introduce account_start_copy() and account_end_copy() (Mike Snitzer) [1758605]
- [netdrv] ice: Bump version (Jonathan Toppins) [1721711]
- [netdrv] ice: Enable DDP package download (Jonathan Toppins) [1721711]
- [netdrv] ice: Initialize DDP package structures (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement Dynamic Device Personalization (DDP) download (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix FW version formatting in dmesg (Jonathan Toppins) [1721711]
- [netdrv] ice: send driver version to firmware (Jonathan Toppins) [1721711]
- [netdrv] ice: Rework around device/function capabilities (Jonathan Toppins) [1721711]
- [netdrv] ice: change default number of receive descriptors (Jonathan Toppins) [1721711]
- [netdrv] ice: Minor refactor in queue management (Jonathan Toppins) [1721711]
- [netdrv] ice: Allow for delayed LLDP MIB change registration (Jonathan Toppins) [1721711]
- [netdrv] ice: update Tx context struct (Jonathan Toppins) [1721711]
- [netdrv] ice: Report VF link status with opcode to get resources (Jonathan Toppins) [1721711]
- [netdrv] ice: Check for DCB capability before initializing DCB (Jonathan Toppins) [1721711]
- [netdrv] ice: report link down for VF when PF's queues are not enabled (Jonathan Toppins) [1721711]
- [netdrv] ice: Reliably reset VFs (Jonathan Toppins) [1721711]
- [netdrv] ice: change work limit to a constant (Jonathan Toppins) [1721711]
- [netdrv] ice: small efficiency fixes (Jonathan Toppins) [1721711]
- [netdrv] ice: move code closer together (Jonathan Toppins) [1721711]
- [netdrv] ice: clean up arguments (Jonathan Toppins) [1721711]
- [netdrv] ice: Check root pointer for validity (Jonathan Toppins) [1721711]
- [netdrv] ice: Add ice_get_main_vsi to get PF/main VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: Update fields in ice_vsi_set_num_qs when reconfiguring (Jonathan Toppins) [1721711]
- [netdrv] ice: Only disable VLAN pruning for the VF when all VLANs are removed (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove enable DCB when SW LLDP is activated (Jonathan Toppins) [1721711]
- [netdrv] ice: Report stats when VSI is down (Jonathan Toppins) [1721711]
- [netdrv] ice: Always notify FW of VF reset (Jonathan Toppins) [1721711]
- [netdrv] ice: Correctly handle return values for init DCB (Jonathan Toppins) [1721711]
- [netdrv] ice: Limit Max TCs on devices with more than 4 ports (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup defines in ice_type.h (Jonathan Toppins) [1721711]
- [netdrv] ice: print extra message if topology issue (Jonathan Toppins) [1721711]
- [netdrv] ice: add print of autoneg state to link message (Jonathan Toppins) [1721711]
- [netdrv] ice: update driver unloading field for Queue Shutdown AQ command (Jonathan Toppins) [1721711]
- [netdrv] ice: add needed PFR during driver unload (Jonathan Toppins) [1721711]
- [netdrv] ice: Deduce TSA value from the priority value in the CEE mode (Jonathan Toppins) [1721711]
- [netdrv] ice: Report what the user set for coalesce [tx|rx]-usecs (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix resource leak in ice_remove_rule_internal() (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix EMP reset handling (Jonathan Toppins) [1721711]
- [netdrv] ice: fix adminq calls during remove (Jonathan Toppins) [1721711]
- [netdrv] ice: Rework ice_ena_msix_range (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix VF configuration issues due to reset (Jonathan Toppins) [1721711]
- [netdrv] ice: Alloc queue management bitmaps and arrays dynamically (Jonathan Toppins) [1721711]
- [netdrv] ice: add support for virtchnl_queue_select.[tx|rx]_queues bitmap (Jonathan Toppins) [1721711]
- [netdrv] ice: add support for enabling/disabling single queues (Jonathan Toppins) [1721711]
- [netdrv] ice: fix potential infinite loop (Jonathan Toppins) [1721711]
- [netdrv] ice: fix ice_is_tc_ena (Jonathan Toppins) [1721711]
- [netdrv] ice: add validation in OP_CONFIG_VSI_QUEUES VF message (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't clog kernel debug log with VF MDD events errors (Jonathan Toppins) [1721711]
- [netdrv] ice: Introduce a local variable for a VSI in the rebuild path (Jonathan Toppins) [1721711]
- [netdrv] ice: shorten local and add debug prints (Jonathan Toppins) [1721711]
- [netdrv] ice: Sanitize ice_ena_vsi and ice_dis_vsi (Jonathan Toppins) [1721711]
- [netdrv] ice: added sibling head to parse nodes (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix ethtool port and PFC stats for 4x25G cards (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't allow VSI to remove unassociated ucast filter (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix issues updating VSI MAC filters (Jonathan Toppins) [1721711]
- [netdrv] ice: update ethtool stats on-demand (Jonathan Toppins) [1721711]
- [netdrv] ice: Add input handlers for virtual channel handlers (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't clear auto_fec bit in ice_cfg_phy_fec() (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix flag used for module query (Jonathan Toppins) [1721711]
- [netdrv] ice: silence some bogus error messages (Jonathan Toppins) [1721711]
- [netdrv] ice: Rename ethtool private flag for lldp (Jonathan Toppins) [1721711]
- [netdrv] ice: reject VF attempts to enable head writeback (Jonathan Toppins) [1721711]
- [netdrv] ice: Copy dcbx configuration only if mode is correct (Jonathan Toppins) [1721711]
- [netdrv] ice: Treat DCBx state NOT_STARTED as valid (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't call synchronize_irq() for VF's from the host (Jonathan Toppins) [1721711]
- [netdrv] ice: Account for all states of FW DCBx and LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Allow egress control packets from PF_VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: improve print for VF's when adding/deleting MAC filters (Jonathan Toppins) [1721711]
- [netdrv] ice: Change type for queue counts (Jonathan Toppins) [1721711]
- [netdrv] ice: Move VF resources definition to SR-IOV specific file (Jonathan Toppins) [1721711]
- [netdrv] ice: Increase size of Mailbox receive queue for many VFs (Jonathan Toppins) [1721711]
- [netdrv] ice: Reduce wait times during VF bringup/reset (Jonathan Toppins) [1721711]
- [netdrv] ice: update GLINT_DYN_CTL and GLINT_VECT2FUNC register access (Jonathan Toppins) [1721711]
- [netdrv] ice: Do not always bring up PF VSI in ice_ena_vsi() (Jonathan Toppins) [1721711]
- [netdrv] ice: allow empty Rx descriptors (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix kernel hang with DCB reset in CEE mode (Jonathan Toppins) [1721711]
- [netdrv] ice: Set WB_ON_ITR when we don't re-enable interrupts (Jonathan Toppins) [1721711]
- [netdrv] ice: fix set pause param autoneg check (Jonathan Toppins) [1721711]
- [netdrv] ice: Restructure VFs initialization flows (Jonathan Toppins) [1721711]
- [netdrv] ice: Assume that more than one Rx queue is rare in ice_napi_poll (Jonathan Toppins) [1721711]
- [netdrv] ice: Use the software based tail when checking for hung Tx ring (Jonathan Toppins) [1721711]
- [netdrv] ice: Bump version number (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove flag to track VF interrupt status (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove unnecessary flag ICE_FLAG_MSIX_ENA (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't return error for disabling LAN Tx queue that does exist (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove duplicate code in ice_alloc_rx_bufs (Jonathan Toppins) [1721711]
- [netdrv] ice: Add stats for Rx drops at the port level (Jonathan Toppins) [1721711]
- [netdrv] ice: Update number of VF queue before setting VSI resources (Jonathan Toppins) [1721711]
- [netdrv] ice: Set up Tx scheduling tree based on alloc VSI Tx queues (Jonathan Toppins) [1721711]
- [netdrv] ice: Only bump Rx tail and release buffers once per napi_poll (Jonathan Toppins) [1721711]
- [netdrv] ice: Disable VFs until reset is completed (Jonathan Toppins) [1721711]
- [netdrv] ice: Do not configure port with no media (Jonathan Toppins) [1721711]
- [netdrv] ice: separate out control queue lock creation (Jonathan Toppins) [1721711]
- [netdrv] ice: Always set prefena when configuring an Rx queue (Jonathan Toppins) [1721711]
- [netdrv] ice: Move vector base setup to PF VSI (Jonathan Toppins) [1721711]
- [netdrv] ice: track hardware stat registers past rollover (Jonathan Toppins) [1721711]
- [netdrv] ice: add lp_advertising flow control support (Jonathan Toppins) [1721711]
- [netdrv] ice: Use struct_size() helper (Jonathan Toppins) [1721711]
- [netdrv] ice: Use LLDP ethertype define ETH_P_LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Trivial cosmetic changes (Jonathan Toppins) [1721711]
- [netdrv] ice: Recognize higher speeds (Jonathan Toppins) [1721711]
- [netdrv] ice: Use a different ICE_DBG bit for firmware log messages (Jonathan Toppins) [1721711]
- [netdrv] ice: Update function header (Jonathan Toppins) [1721711]
- [netdrv] ice: Move define for ICE_AQC_DRIVER_UNLOADING (Jonathan Toppins) [1721711]
- [netdrv] ice: Align to updated AQ command formats (Jonathan Toppins) [1721711]
- [netdrv] ice: Use continue instead of an else block (Jonathan Toppins) [1721711]
- [netdrv] ice: Change minimum descriptor count value for Tx/Rx rings (Jonathan Toppins) [1721711]
- [netdrv] ice: Add switch rules to handle LLDP packets (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup ice_update_link_info (Jonathan Toppins) [1721711]
- [netdrv] ice: Use right type for ice_cfg_vsi_lan return (Jonathan Toppins) [1721711]
- [netdrv] ice: Add support for Forward Error Correction (FEC) (Jonathan Toppins) [1721711]
- [netdrv] ice: Add support for virtchnl_vector_map.[rxq|txq]_map (Jonathan Toppins) [1721711]
- [netdrv] ice: Introduce ice_init_mac_fltr and move ice_napi_del (Jonathan Toppins) [1721711]
- [netdrv] ice: Use GLINT_DYN_CTL to disable VF's interrupts (Jonathan Toppins) [1721711]
- [netdrv] ice: Add a helper to trigger software interrupt (Jonathan Toppins) [1721711]
- [netdrv] ice: Configure RSS LUT key only if RSS is enabled (Jonathan Toppins) [1721711]
- [netdrv] ice: Add ice_get_fw_log_cfg to init FW logging (Jonathan Toppins) [1721711]
- [netdrv] ice: Minor cleanup in ice_switch.h (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove redundant and premature event config (Jonathan Toppins) [1721711]
- [netdrv] ice: Change message level (Jonathan Toppins) [1721711]
- [netdrv] ice: Check all VFs for MDD activity, don't disable (Jonathan Toppins) [1721711]
- [netdrv] ice: Refactor interrupt tracking (Jonathan Toppins) [1721711]
- [netdrv] ice: Add handler for ethtool selftest (Jonathan Toppins) [1721711]
- [netdrv] ice: Don't call ice_cfg_itr() for SR-IOV (Jonathan Toppins) [1721711]
- [netdrv] ice: Set minimum default Rx descriptor count to 512 (Jonathan Toppins) [1721711]
- [netdrv] ice: Resolve static analysis warning (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement toggling ethtool rx-vlan-filter (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove direct write for GLLAN_RCTL_0 (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix LINE_SPACING style issue (Jonathan Toppins) [1721711]
- [netdrv] ice: Silence semantic parser warnings (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix couple of issues in ice_vsi_release (Jonathan Toppins) [1721711]
- [netdrv] ice: Reorganize ice_vf struct (Jonathan Toppins) [1721711]
- [netdrv] ice: Use bitfields when possible (Jonathan Toppins) [1721711]
- [netdrv] ice: Reorganize tx_buf and ring structs (Jonathan Toppins) [1721711]
- [netdrv] ice: Format ethtool reported stats (Jonathan Toppins) [1721711]
- [netdrv] ice: Gracefully handle reset failure in ice_alloc_vfs() (Jonathan Toppins) [1721711]
- [netdrv] ice: Refactor the LLDP MIB change event handling (Jonathan Toppins) [1721711]
- [netdrv] ice: Advertise supported link modes if none requested (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix hang when ethtool disables FW LLDP (Jonathan Toppins) [1721711]
- [netdrv] ice: Call out dev/func caps when printing (Jonathan Toppins) [1721711]
- [netdrv] ice: Remove braces for single statement blocks (Jonathan Toppins) [1721711]
- [netdrv] ice: Cleanup an unnecessary variable initialization (Jonathan Toppins) [1721711]
- [netdrv] ice: Implement LLDP persistence (Jonathan Toppins) [1721711]
- [netdrv] ice: Fix double spacing (Jonathan Toppins) [1721711]
- [kernel] sched/debug: Fix potential deadlock when writing to sched_features (Vladis Dronov) [1760060]
- [kernel] sched/debug: Use match_string() helper instead of open-coded logic (Vladis Dronov) [1760060]
- [hid] HID: intel-ish-hid: ipc: add EHL device id (Tony Camuso) [1716756]
- [hid] HID: remove NO_D3 flag when remove driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: fix wrong driver_data usage (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Fix a use after free in load_fw_from_host() (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add SPDX license identifier - Makefile/Kconfig (Tony Camuso) [1716756]
- [platform] platform/chrome: Add ChromeOS EC ISHTP driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: prefix header search paths with $(srctree)/ (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add Comet Lake PCI device ID (Tony Camuso) [1716756]
- [platform] platform/chrome: cros_ec: Add EC host command support using rpmsg (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: fix spelling mistake "multipe" -> "multiple" (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ISH firmware loader client driver (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add interface function for PCI device pointer (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Use the new interface functions in HID ish client (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move functions related to bus and device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add interface functions for struct ishtp_cl (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move the common functions from client.h (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Store ishtp_cl_device instance in device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Move driver registry functions (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Simplify ishtp_cl_link() (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Hide members of struct ishtp_cl_device (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Add match callback to ishtp bus type (Tony Camuso) [1716756]
- [hid] HID: intel-ish: enable raw interface to HID devices on ISH (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Use VID/PID from ISH (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: Switch to use new generic UUID API (Tony Camuso) [1716756]
- [hid] HID: intel-ish: ipc: handle PIMR before ish_wakeup also clear PISR busy_clear bit (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function to search client id (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper function for client search (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function to access client buffer (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper functions for client buffer operation (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: use helper function for private driver data set/get (Tony Camuso) [1716756]
- [hid] HID: intel-ish-hid: ishtp: add helper function for driver data get/set (Tony Camuso) [1716756]
- [platform] platform/chrome: Move cros-ec transport drivers to drivers/platform. (Tony Camuso) [1716756]
- [tools] tools: PCI: Fix compiler warning in pcitest (Myron Stowe) [1753749]
- [iommu] iommu: Fix integer truncation (Myron Stowe) [1753749]
- [pci] PCI/P2PDMA: Ignore root complex whitelist when an IOMMU is present (Myron Stowe) [1753749]
- [pci] PCI: Cleanup setup-bus.c comments and whitespace (Myron Stowe) [1753749]
- [include] CPER: Remove unnecessary use of user-space types (Myron Stowe) [1753749]
- [include] CPER: Add UEFI spec references (Myron Stowe) [1753749]
- [pci] PCI: Fix comment typos (Myron Stowe) [1753749]
- [pci] PCI: Cleanup register definition width and whitespace (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pointless MY_NAME definition (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pointless PCIE_MODULE_NAME definition (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove unused dbg/err/info/warn() wrappers (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Replace pciehp_debug module param with dyndbg (Myron Stowe) [1753749]
- [pci] PCI: pciehp: Remove pciehp_debug uses (Myron Stowe) [1753749]
- [pci] PCI/AER: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI/DPC: Log messages with pci_dev, not pcie_device (Myron Stowe) [1753749]
- [pci] PCI/PME: Replace dev_printk(KERN_DEBUG) with dev_info() (Myron Stowe) [1753749]
- [pci] PCI/AER: Replace dev_printk(KERN_DEBUG) with dev_info() (Myron Stowe) [1753749]
- [pci] PCI: Replace dev_printk(KERN_DEBUG) with dev_info(), etc (Myron Stowe) [1753749]
- [pci] PCI: Replace printk(KERN_INFO) with pr_info(), etc (Myron Stowe) [1753749]
- [pci] PCI: Use dev_printk() when possible (Myron Stowe) [1753749]
- [iommu] iommu/dma: Reserve IOVA for PCIe inaccessible DMA address (Myron Stowe) [1753749]
- [pci] PCI: Add dma_ranges window list (Myron Stowe) [1753749]
- [pci] PCI: endpoint: Fix a potential NULL pointer dereference (Myron Stowe) [1753749]
- [tools] tools: PCI: Handle pcitest.sh independently from pcitest (Myron Stowe) [1753749]
- [tools] tools: PCI: Add 'h' in optstring of getopt() (Myron Stowe) [1753749]
- [tools] tools: PCI: Change pcitest compiling process (Myron Stowe) [1753749]
- [tools] tools: PCI: Fix compilation warnings (Myron Stowe) [1753749]
- [tools] tools: PCI: Exit with error code when test fails (Myron Stowe) [1753749]
- [pci] PCI: Mark Atheros AR9462 to avoid bus reset (Myron Stowe) [1753749]
- [pci] switchtec: Fix unintended mask of MRPC event (Myron Stowe) [1753749]
- [pci] switchtec: Increase PFF limit from 48 to 255 (Myron Stowe) [1753749]
- [pci] PCI/LINK: Disable bandwidth notification interrupt during suspend (Myron Stowe) [1753749]
- [pci] PCI/P2PDMA: Allow P2P DMA between any devices under AMD ZEN Root Complex (Myron Stowe) [1753749]
- [maintainers] MAINTAINERS: Add Karthikeyan Mitran and Hou Zhiqiang for Mobiveil PCI (Myron Stowe) [1753749]
- [platform] platform/chrome: chromeos_laptop: use pci_dev_id() helper (Myron Stowe) [1753749]
- [iommu] iommu/amd: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [drm] drm/amdkfd: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [powerpc] powerpc/powernv/npu: Use pci_dev_id() helper (Myron Stowe) [1753749]
- [x86] x86/PCI: Fix PCI IRQ routing table memory leak (Myron Stowe) [1753749]
- [pci] PCI: Remove unused pci_request_region_exclusive() (Myron Stowe) [1753749]
- [pci] PCI: Mark expected switch fall-throughs (Myron Stowe) [1753749]
- [pci] PCI/ACPI: Remove the need for 'struct hotplug_params' (Myron Stowe) [1753749]
- [pci] PCI/ACPI: Do not export pci_get_hp_params() (Myron Stowe) [1753749]
- [pci] PCI: rpaphp: Get/put device node reference during slot alloc/dealloc (Myron Stowe) [1753749]
- [pci] PCI: rpadlpar: Fix leaked device_node references in add/remove paths (Myron Stowe) [1753749]
- [pci] PCI: Assign bus numbers present in EA capability for bridges (Myron Stowe) [1753749]
- [pci] PCI: OF: Support "external-facing" property (Myron Stowe) [1753749]
- [documentation] dt-bindings: Add "external-facing" PCIe port property (Myron Stowe) [1753749]
- [pci] PCI: Init PCIe feature bits for managed host bridge alloc (Myron Stowe) [1753749]
- [pci] PCI/AER: Change pci_aer_init() stub to return void (Myron Stowe) [1753749]
- [s390] s390/zcrypt: CEX7S exploitation support (Philipp Rudo) [1726416]
- [s390] s390/pkey: Add sysfs attributes to emit AES CIPHER key blobs (Philipp Rudo) [1726416]
- [s390] s390/crypto: Support for SHA3 via CPACF (MSA6) (Philipp Rudo) [1726416]
- [s390] s390/crypto: xts-aes-s390 fix extra run-time crypto self tests finding (Philipp Rudo) [1726416]
- [s390] s390: vfio-ap: fix warning reset not completed (Philipp Rudo) [1726416]
- [s390] crypto: s390 - Rename functions to avoid conflict with crypto/sha256.h (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: fix wrong handling of cca cipher keygenflags (Philipp Rudo) [1726416]
- [s390] crypto: s390/xts-aes - invoke fallback for ciphertext stealing (Philipp Rudo) [1726416]
- [s390] s390/paes: Prepare paes functions for large key blobs (Philipp Rudo) [1726416]
- [s390] s390/pkey: add CCA AES cipher key support (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: Add low level functions for CCA AES cipher keys (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: extend cca_findcard function and helper (Philipp Rudo) [1726416]
- [s390] s390/pkey: pkey cleanup: narrow in-kernel API, fix some variable types (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: adjust switch fall through comments for -Wimplicit-fallthrough (Philipp Rudo) [1726416]
- [s390] crypto: s390/aes - fix name clash after AES library refactor (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: new sysfs attributes serialnr and mkvps (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: add base code for cca crypto card info support (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: move cca misc functions to new code file (Philipp Rudo) [1726416]
- [s390] s390: use __u{16, 32, 64} instead of uint{16, 32, 64}_t in uapi header (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: remove the exporting of ap_query_configuration (Philipp Rudo) [1726416]
- [s390] s390/crypto: sha: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/crypto: prng: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/crypto: ghash: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/pkey: Use -ENODEV instead of -EOPNOTSUPP (Philipp Rudo) [1726416]
- [s390] s390/zcrypt: support special flagged EP11 cprbs (Philipp Rudo) [1726416]
- [s390] s390/crypto: fix possible sleep during spinlock aquired (Philipp Rudo) [1726416]
- [s390] s390/crypto: use TRNG for seeding/reseeding (Philipp Rudo) [1726416]
- [s390] s390/crypto: rework generate_entropy function for pseudo random dd (Philipp Rudo) [1726416]
- [s390] s390: zcrypt: initialize variables before_use (Philipp Rudo) [1726416]
- [powerpc] powerpc/pseries: Track LMB nid instead of using device tree (Steve Best) [1758742]
- [powerpc] powerpc/pseries/memory-hotplug: Only update DT once per memory DLPAR request (Steve Best) [1758742]
- [net] hv_sock: Fix hang when a connection is closed (Cathy Avery) [1739477]
- [net] hv_sock: Use consistent types for UUIDs (Cathy Avery) [1739477]
- [net] hvsock: fix epollout hang from race condition (Cathy Avery) [1739477]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Cathy Avery) [1739477]
- [net] hv_sock: perf: loop in send() to maximize bandwidth (Cathy Avery) [1739477]
- [net] hv_sock: perf: Allow the socket buffer size options to influence the actual socket buffers (Cathy Avery) [1739477]
- [net] hv_sock: Add support for delayed close (Cathy Avery) [1739477]
- [powerpc] powerpc/rtas: allow rescheduling while changing cpu states (Steve Best) [1758651]
- [powerpc] powerpc/pseries/mobility: use cond_resched when updating device tree (Steve Best) [1758651]
- [tools] selftests/powerpc: Fix compile error on tlbie_test due to newer gcc (Desnes Augusto Nunes do Rosario) [1755707]
- [tools] selftests/powerpc: Add test case for tlbie vs mtpidr ordering issue (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on POWER9 (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag (Desnes Augusto Nunes do Rosario) [1755707]
- [powerpc] powerpc/book3s64/mm: Don't do tlbie fixup for some hardware revisions (Desnes Augusto Nunes do Rosario) [1755707]
- [scsi] scsi: zfcp: make DIX experimental, disabled, and independent of DIF (Philipp Rudo) [1723829]
- [s390] s390: add support for IBM z15 machines (Philipp Rudo) [1757015]
- [s390] s390/pci: add mio_enabled attribute (Philipp Rudo) [1757118]
- [s390] s390: fix setting of mio addressing control (Philipp Rudo) [1757118]
- [s390] s390/pci: correctly handle MIO opt-out (Philipp Rudo) [1757118]
- [s390] s390/pci: deal with devices that have no support for MIO instructions (Philipp Rudo) [1757118]
- [s390] s390/pci: fix assignment of bus resources (Philipp Rudo) [1757118]
- [s390] s390/pci: fix struct definition for set PCI function (Philipp Rudo) [1757118]
- [s390] s390/pci: fix MSI message data (Philipp Rudo) [1757123]
- [powerpc] powerpc/tm: Add tm-poison test (Steve Best) [1756721]
- [powerpc] powerpc/powernv: Add new opal message type (Desnes Augusto Nunes do Rosario) [1706975]
- [powerpc] powerpc/powernv: Enhance opal message read interface (Desnes Augusto Nunes do Rosario) [1706975]
- [char] hwrng: core - don't wait on add_early_randomness() (Laurent Vivier) [1660802]
- [firmware] efi: Export Runtime Configuration Interface table to sysfs (Al Stone) [1665518]
- [nvme] nvme: Treat discovery subsystems as unique subsystems (Ewan Milne) [1757525]
- [powerpc] powerpc/powernv/opal: Use standard interrupts property when available (Steve Best) [1757173]
- [powerpc] powerpc: dump kernel log before carrying out fadump or kdump (Steve Best) [1756922]
- [kernel] genirq/affinity: Create affinity mask for single vector (Ming Lei) [1733420]
- [virt] kvm: arm/arm64: Only skip MMIO insn once (Andrew Jones) [1733928]
- [vfio] type1: remove duplicate retrieval of reserved regions (Auger Eric) [1704597]
- [vfio] type1: Add IOVA range capability support (Auger Eric) [1704597]
- [vfio] type1: check dma map request is within a valid iova range (Auger Eric) [1704597]
- [vfio] type1: Update iova list on detach (Auger Eric) [1704597]
- [vfio] type1: Check reserved region conflict and update iova list (Auger Eric) [1704597]
- [vfio] type1: Introduce iova list and add iommu aperture validity check (Auger Eric) [1704597]
- [iommu] Revisit iommu_insert_resv_region() implementation (Auger Eric) [1704597]
- [iommu] vt-d: Differentiate relaxable and non relaxable RMRRs (Auger Eric) [1704597]
- [iommu] Introduce IOMMU_RESV_DIRECT_RELAXABLE reserved memory regions (Auger Eric) [1704597]
- [iommu] vt-d: Handle PCI bridge RMRR device scopes in intel_iommu_get_resv_regions (Auger Eric) [1704597]
- [iommu] vt-d: Handle RMRR with PCI bridge device scopes (Auger Eric) [1704597]
- [iommu] vt-d: Introduce is_downstream_to_pci_bridge helper (Auger Eric) [1704597]
- [iommu] vt-d: Duplicate iommu_resv_region objects per device list (Auger Eric) [1704597]
- [iommu] Fix a leak in iommu_insert_resv_region (Auger Eric) [1704597]
- [pci] hv: Avoid use of hv_pci_dev->pci_slot after freeing it (Mohammed Gamal) [1737569]

* Thu Oct 17 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.8.el8]
- [x86] kvm: x86: omit "impossible" pmu MSRs from MSR list (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Fix consistency check on injected exception error code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: omit absent pmu MSRs from MSR list (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: Fix libkvm build error (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Limit guest PMCs to those supported on the host (Vitaly Kuznetsov) [1749495]
- [virt] kvm: x86, powerpc: do not allow clearing largepages debugfs entry (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: x86: clarify what is reported on KVM_GET_MSRS failure (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Set VMENTER_L1D_FLUSH_NOT_REQUIRED if !X86_BUG_L1TF (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: add test for dirty logging inside nested guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix nested guest live migration with PML (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: assign two bits to track SPTE kinds (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Expose XSAVEERPTR to the guest (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Enumerate support for CLZERO instruction (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use AMD CPUID semantics for AMD vCPUs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Improve emulation of CPUID leaves 0BH and 1FH (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix userspace set invalid CR4 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix a spurious -E2BIG in __do_cpuid_func (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Loosen filter for adaptive tuning of lapic_timer_advance_ns (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: cleanup and fix host 64-bit mode checks (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix build warnings in hv_enable_direct_tlbflush() on i386 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't check kvm_rebooting in __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Drop ____kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Add error handling to VMREAD helper (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Optimize VMX instruction error and fault handling (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Check kvm_rebooting in kvm_spurious_fault() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: limit atomic switch MSRs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Intercept RDPRU (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add "significant index" flag to a few CPUID leaves (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Skip invalid pages during zapping iff root_count is zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Explicitly track only a single invalid mmu generation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "kvm: x86/mmu: Remove is_obsolete() call" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: reclaim the zapped-obsolete page first"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: collapse TLB flushes when zap all pages"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: zap pages in batch"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: add tracepoint for kvm_mmu_invalidate_all_pages"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: revert "revert "kvm: mmu: show mmu_valid_gen in shadow page related tracepoints"" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Use fast invalidate mechanism to zap MMIO sptes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Treat invalid shadow pages as obsolete (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Tune lapic_timer_advance_ns smoothly (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add comments to document various emulation types (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Handle single-step #DB for EMULTYPE_SKIP on EPT misconfig (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Remove emulation_result enums, EMULATE_{DONE, FAIL, USER_EXIT} (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Remove EMULATE_FAIL handling in handle_invalid_guest_state() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move triple fault request into RM int injection (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Handle emulation failure directly in kvm_task_switch() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Exit to userspace on emulation skip failure (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move #UD injection for failed emulation into emulation code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add explicit flag for forced emulation on #UD (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move #GP injection for VMware into x86_emulate_instruction() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't attempt VMWare emulation on #GP with non-zero error code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Refactor kvm_vcpu_do_singlestep() to remove out param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Clean up handle_emulation_failure() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Relocate MMIO exit stats counting (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check Host Address Space Size on vmentry of nested guests (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: hyperv_cpuid: add check for NoNonArchitecturalCoreSharing bit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: hyper-v: set NoNonArchitecturalCoreSharing CPUID bit when SMT is impossible (Vitaly Kuznetsov) [1749495]
- [kernel] cpu/smt: create and export cpu_smt_possible() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: hyperv: Fix Direct Synthetic timers assert an interrupt w/o lapic_in_kernel (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Manually flush collapsible SPTEs only when toggling flags (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove duplicate guest mode handling (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Introduce VM_MODE_PXXV48_4K (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Create VM earlier for dirty log test (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Move vm type into _vm_create() internally (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: announce KVM_CAP_HYPERV_ENLIGHTENED_VMCS support only when it is available (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: svm: remove unneeded nested_enable_evmcs() hook (Vitaly Kuznetsov) [1749495]
- [x86] kvm/hyper-v/vmx: Add direct tlb flush support (Vitaly Kuznetsov) [1749495]
- [documentation] kvm/hyper-v: Add new KVM capability KVM_CAP_HYPERV_DIRECT_TLBFLUSH (Vitaly Kuznetsov) [1749495]
- [x86] hyper-v: Fix definition of struct hv_vp_assist_page (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add Intel PMU MSRs to msrs_to_save[] (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use IPI shorthands in kvm guest when support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix INIT signal handling in various CPU states (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Introduce exit reason for receiving INIT signal on guest-mode (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Stop the preemption timer during vCPU reset (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Micro optimize IPI latency (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Nested KVM MMUs need PAE root too (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: set ctxt->have_exception in x86_decode_insn() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: always stop emulation on page fault (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: trace nested VM-Enter failures detected by H/W (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: add tracepoint for failed nested VM-Enter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Fix a check in nested_svm_vmrun() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Return to userspace with internal error on unexpected exit reason (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add kvm_emulate_{rd, wr}msr() to consolidate VXM/SVM code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Refactor up kvm_{g, s}et_msr() to simplify callers (Vitaly Kuznetsov) [1749495]
- [documentation] doc: kvm: Fix return description of KVM_SET_MSRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Tune PLE Window tracepoint (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Change ple_window type to unsigned int (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Remove tailing newline for tracepoints (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Trace vcpu_id for vmexit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Manually calculate reserved bits when loading PDPTRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Disable posted interrupts for non-standard IRQs delivery modes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix and tweak the comments for VM-Enter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Assert that struct kvm_vcpu is always as offset zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add pv tlb shootdown tracepoint (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Unconditionally call x86 ops that are always implemented (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Consolidate "is MMIO SPTE" code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Add explicit access mask for MMIO SPTEs (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: x86: Rename access permissions cache member in struct kvm_vcpu_arch (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: eliminate hardcoded RIP advancement from vmrun_interception() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: eliminate weird goto from vmrun_interception() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: remove hardcoded instruction length from intercepts (Vitaly Kuznetsov) [1749495]
- [x86] kvm: add xsetbv to the emulator (Vitaly Kuznetsov) [1749495]
- [x86] kvm: clear interrupt shadow on EMULTYPE_SKIP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: propagate errors from skip_emulated_instruction() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: don't pretend to advance RIP in case wrmsr_interception() results in #GP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix x86_decode_insn() return when fetching insn bytes fails (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use Intel speculation bugs and features as derived in generic x86 code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: always expose VIRT_SSBD to guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix reporting of AMD speculation bug CPUID leaf (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Call kvm_arch_vcpu_blocking early into the blocking sequence (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/mmu: Reintroduce fast invalidate/zap for flushing memslot (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: work around leak of uninitialized stack contents (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: handle page fault in vmread (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Don't update RIP or do single-step on faulting emulation (Vitaly Kuznetsov) [1749495]
- [tools] selftests/kvm: make platform_info_test pass on AMD (Vitaly Kuznetsov) [1749495]
- [x86] revert "kvm: x86/mmu: Zap only the relevant pages when removing a memslot" (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: fix state save/load on processors without XSAVE (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: fix vmx_set_nested_state_test (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: provide common function to enable eVMCS (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: do not try running the VM in vmx_set_nested_state_test (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: svm: remove redundant assignment of var new_entry (Vitaly Kuznetsov) [1749495]
- [tools] selftests: kvm: Adding config fragments (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Update gitignore file for latest changes (Vitaly Kuznetsov) [1749495]
- [virt] kvm: remove unnecessary PageReserved check (Vitaly Kuznetsov) [1749495]
- [x86] kvm: remove useless calls to kvm_para_available (Vitaly Kuznetsov) [1749495]
- [x86] kvm: no need to check return value of debugfs_create functions (Vitaly Kuznetsov) [1749495]
- [s390] kvm: remove kvm_arch_has_vcpu_debugfs() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix leak vCPU's VMCS value into other pCPU (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Check preempted_in_kernel for involuntary preemption (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Don't need to wakeup vCPU twice afer timer fire (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Boost queue head vCPU to mitigate lock waiter preemption (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: move Documentation/virtual to Documentation/virt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add fixed counters to PMU filter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: dump VMCS on failed entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/vpmu: refine kvm_pmu err msg when event creation failed (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Boost vCPUs that are delivering interrupts (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove superfluous define from vmx.c (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: Fix detection of AMD Errata 1096 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Inject timer interrupt via posted interrupt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Don't call kvm_spurious_fault() from .fixup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Replace vmx_vmenter()'s call to kvm_spurious_fault() with UD2 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Fix fastop function ELF metadata (Vitaly Kuznetsov) [1749495]
- [x86] paravirt: Fix callee-saved function ELF sizes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Make lapic timer unpinned (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/vpmu: reset pmc->counter to 0 for pmu fixed_counters (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Ignore segment base for VMX memory operand when segment not FS or GS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: ioapic and apic debug macros cleanup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: some tsc debug cleanup (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix coccinelle warnings (Vitaly Kuznetsov) [1749495]
- [x86] kvm: avoid constant-conversion warning (Vitaly Kuznetsov) [1749495]
- [x86] kvm: avoid -Wsometimes-uninitized warning (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: virtual: Add toctree hooks (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: Convert cpuid.txt to .rst (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Unconditionally enable irqs in guest context (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: PMU Event Filter (Vitaly Kuznetsov) [1749495]
- [kernel] kvm: x86: Fix -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Properly check if "page" is valid in kvm_vcpu_unmap (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Retry tune per-vCPU timer_advance_ns if adaptive tuning goes insane (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: write down valid APIC registers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: ARBPRI is a reserved register for x2APIC (Vitaly Kuznetsov) [1749495]
- [x86] kvm nvmx: Check Host Segment Registers and Descriptor Tables on vmentry of nested guests (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Stash L1's CR3 in vmcs01.GUEST_CR3 on nested entry w/o EPT (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: add tracepoints around __direct_map and FNAME(fetch) (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: change kvm_mmu_page_get_gfn BUG_ON to WARN_ON (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: remove now unneeded hugepage gfn adjustment (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: make FNAME(fetch) and __direct_map more similar (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Do not release the page inside mmu_set_spte() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: remove has_leaf_count from struct kvm_cpuid_param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: rename do_cpuid_1_ent (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: set struct kvm_cpuid_entry2 flags in do_cpuid_1_ent (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: extract do_cpuid_7_mask and support multiple subleafs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: cpuid: do_cpuid_ent works on a whole CPUID function (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: remove the trailing newline used in the fmt parameter of TP_printk (Vitaly Kuznetsov) [1749495]
- [x86] kvm: svm: add nrips module parameter (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: degrade WARN to pr_warn_ratelimited (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Pass through AMD_STIBP_ALWAYS_ON in GET_SUPPORTED_CPUID (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Remove unnecessary sync_roots from handle_invept (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: document CPUID bit for MSR_KVM_POLL_CONTROL (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: x86: Expose PV_SCHED_YIELD CPUID feature bit to guest (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Implement PV sched yield hypercall (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Yield to IPI target if necessary (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: list VMX MSRs in KVM_GET_MSR_INDEX_LIST (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: allow setting the VMFUNC controls MSR (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: include conditional controls in /dev/kvm KVM_GET_MSRS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix apic dangling pointer in vcpu (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: check CPUID before allowing read/write of IA32_XSS (Vitaly Kuznetsov) [1749495]
- [tools] tests: kvm: Check for a kernel warning (Vitaly Kuznetsov) [1749495]
- [tools] kvm: tests: Sort tests in the Makefile alphabetically (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: fix typo in documentation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: shadow pin based execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Leave preemption timer running when it's disabled (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Drop hv_timer_armed from 'struct loaded_vmcs' (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Preset *DT exiting in vmcs02 when emulating UMIP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Preserve last USE_MSR_BITMAPS when preparing vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Explicitly initialize controls shadow at VMCS allocation (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't reset VMCS controls shadow on VMCS switch (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Shadow VMCS controls on a per-VMCS basis (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS secondary execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS primary execution controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Shadow VMCS pin controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Add builder macros for shadowing controls (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Use adjusted pin controls for vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Copy PDPTRs to/from vmcs12 only when necessary (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't update GUEST_BNDCFGS if it's clean in HV eVMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for MSR_IA32_DEBUGCTLMSR when it's written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for SYSENTER MSRs when they're written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Update vmcs12 for MSR_IA32_CR_PAT when it's written (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't speculatively write APIC-access page address (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't speculatively write virtual-APIC page address (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't dump VMCS if virtual APIC page can't be mapped (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't reread VMCS-agnostic state when switching VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't "put" vCPU or host state when switching VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: simplify vmx_prepare_switch_to_{guest, host} (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Don't rewrite GUEST_PML_INDEX during nested VM-Entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Write ENCLS-exiting bitmap once per vmcs02 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Always sync GUEST_BNDCFGS when it comes from vmcs01 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Always signal #GP on WRMSR to MSR_IA32_CR_PAT with bad value (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Rename prepare_vmcs02_*_full to prepare_vmcs02_*_rare (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Sync rarely accessed guest fields only when needed (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Add helpers to identify shadowed VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Use descriptive names for VMCS sync functions and flags (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Lift sync_vmcs12() out of prepare_vmcs12() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Track vmcs12 offsets for shadowed VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Intercept VMWRITEs to GUEST_{CS, SS}_AR_BYTES (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Intercept VMWRITEs to read-only shadow VMCS fields (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Handle NMIs, #MCs and async #PFs in common irqs-disabled fn (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move kvm_{before, after}_interrupt() calls to vendor code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Store the host kernel's IDT base in a global variable (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Read cached VM-Exit reason to detect external interrupt (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: small cleanup in handle_exception (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix handling of #MC that occurs during VM-Entry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: move MSR_IA32_POWER_CTL handling to common code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: offset is ensure to be in range (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use same convention to name kvm_lapic_{set, clear}_vector() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: check kvm_apic_sw_enabled() is enough (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: add host poll control msrs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: segment limit check: use access length (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: fix limit checking in get_vmx_mem_address() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add Intel CPUID.1F cpuid emulation support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Use DR_TRAP_BITS instead of hard-coded 15 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: clean up conditions for asynchronous page fault handling (Vitaly Kuznetsov) [1749495]
- [documentation] docs: amd-memory-encryption.rst get rid of warnings (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Convert kvm_lock to a mutex (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: remove unneeded 'asm volatile ("")' from vmcs_write64 (Vitaly Kuznetsov) [1749495]
- [virt] kvm: irqchip: Use struct_size() in kzalloc() (Vitaly Kuznetsov) [1749495]
- [x86] kvm/vmx: drop bad asm() clobber from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: hide vcpu_setup in processor code (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Emulate MSR_IA32_MISC_ENABLE MWAIT bit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Provide a capability to disable cstate msr read intercepts (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: documentation: Add disable pause exits to KVM_CAP_X86_DISABLE_EXITS (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: refine kvm_get_arch_capabilities() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Directly return result from kvm_arch_check_processor_compat() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Optimize timer latency further (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Delay trace_kvm_wait_lapic_expire tracepoint to after vmexit (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Extract adaptive tune timer advancement logic (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nsvm: properly map nested VMCB (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix reserved bits related calculation errors caused by MKTME (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Move kvm_set_mmio_spte_mask() from x86.c to mmu.c (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compile on s390 part 2 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: fix return value for reserved EFER (Vitaly Kuznetsov) [1749495]
- [tools] kvm_stat: fix fields filter for child events (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: aarch64: compile with warnings on (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/pmu: do not mask the value that is written to fixed PMUs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86/pmu: mask the result of rdpmc according to the width of the counters (Vitaly Kuznetsov) [1749495]
- [x86] kvm/pmu: Set AMD's virt PMU version to 1 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: do not spam dmesg with VMCS/VMCB dumps (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Check irqchip mode before assign irqfd (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Remove duplicated TEST_ASSERT in hyperv_cpuid.c (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Expose per-vCPU timer_advance_ns to userspace (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Fix lapic_timer_advance_ns parameter overflow (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Fix -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Fix using __this_cpu_read() in preemptible context (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compilation on s390 (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Include CPUID leaf 0x8000001e in kvm's supported CPUID (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Include multiple indices with CPUID leaf 0x8000001d (Vitaly Kuznetsov) [1749495]
- [tools] kvm: selftests: Fix a condition in test_hv_cpuid() (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix spinlock taken warning during host resume (Vitaly Kuznetsov) [1749495]
- [virt] kvm: fix compilation on aarch64 (Vitaly Kuznetsov) [1749495]
- [x86] revert "kvm: nvmx: Expose RDPMC-exiting only when guest supports PMU" (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Fix L1TF mitigation for shadow MMU (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Disable intercept for FS/GS base MSRs in vmcs02 when possible (Vitaly Kuznetsov) [1749495]
- [tools] tests: kvm: Add tests to .gitignore (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: Introduce KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2 (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix kvm_clear_dirty_log_protect off-by-(minus-)one (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Fix the bitmap range to copy during clear dirty (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: use direct accessors for RIP and RSP (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Use accessors for GPRs outside of dedicated caching logic (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Omit caching logic for always-available GPRs (Vitaly Kuznetsov) [1749495]
- [x86] kvm, x86: Properly check whether a pfn is an MMIO or not (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use page_address_valid in a few more locations (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map for accessing the enlightened VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map for accessing the shadow VMCS (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nsvm: Use the new mapping API for mapping guest memory (Vitaly Kuznetsov) [1749495]
- [x86] kvm/x86: Use kvm_vcpu_map in emulator_cmpxchg_emulated (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the posted interrupt descriptor table (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the virtual APIC page (Vitaly Kuznetsov) [1749495]
- [x86] kvm/nvmx: Use kvm_vcpu_map when mapping the L1 MSR bitmap (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: handle_vmptrld: Use kvm_vcpu_map when copying VMCS12 from guest memory (Vitaly Kuznetsov) [1749495]
- [virt] kvm: Introduce a new guest mapping API (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Handle PFNs outside of kernel reach when touching GPTEs (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: Update the PML table without mapping and unmapping the page (Vitaly Kuznetsov) [1749495]
- [x86] nvmx: handle_vmon: Read 4 bytes from guest memory (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Implement HWCR support (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Include architectural defs header in capabilities.h (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: clean up some debug output (Vitaly Kuznetsov) [1749495]
- [virt] kvm_main: fix some comments (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Skip delta_tsc shift-and-divide if the dividend is zero (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Check for a pending timer intr prior to start_hv_timer() (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Refactor ->set_hv_timer to use an explicit expired param (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Explicitly cancel the hv timer if it's pre-expired (Vitaly Kuznetsov) [1749495]
- [x86] kvm: lapic: Busy wait for timer to expire when using hv_timer (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: Nop emulation of MSR_IA32_POWER_CTL (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Add support of clear Trace_ToPA_PMI status (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Inject PMI for KVM guest (Vitaly Kuznetsov) [1749495]
- [documentation] revert "kvm: doc: Document the life cycle of a VM and its resources" (Vitaly Kuznetsov) [1749495]
- [documentation] documentation: kvm: fix dirty log ioctl arch lists (Vitaly Kuznetsov) [1749495]
- [x86] kvm: Make steal_time visible (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Inject #GP if guest attempts to set unsupported EFER bits (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Skip EFER vs. guest CPUID checks for host-initiated writes (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Return -EINVAL when signaling failure in VM-Entry helpers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Return -EINVAL when signaling failure in pre-VM-Entry helpers (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Rename and split top-level consistency checks to match SDM (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Move guest non-reg state checks to VM-Exit path (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check "load IA32_PAT" VM-entry control on vmentry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: nvmx: Check "load IA32_PAT" VM-exit control on vmentry (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: optimize check for valid PAT value (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: clear VM_EXIT_SAVE_IA32_PAT (Vitaly Kuznetsov) [1749495]
- [x86] kvm: vmx: print more APICv fields in dump_vmcs (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: Raise #GP when guest vCPU do not support PMU (Vitaly Kuznetsov) [1749495]
- [documentation] kvm: doc: Document the life cycle of a VM and its resources (Vitaly Kuznetsov) [1749495]
- [x86] kvm: x86: skip populating logical dest map if apic is not sw enabled (Bandan Das) [1728503]
- [powerpc] kvm: ppc: book3s: Fix incorrect guest-to-user-translation error handling (David Gibson) [1749504]
- [powerpc] kvm: Fall through switch case explicitly (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Fix CR0 setting in TM emulation (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Invalidate ERAT when flushing guest TLB entries (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Only write DAWR[X] when handling h_set_dawr in real mode (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: xive: Fix spelling mistake "acessing" -> "accessing" (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Make sure to load LPID for radix VCPUs (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Flush TLB on secondary radix threads (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Move HPT guest TLB flushing to C code (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Handle virtual mode in XIVE VCPU push code (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: smb->smp comment fixup (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s: Allocate guest TCEs on demand too (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Avoid lockdep debugging in TCE realmode handlers (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Fix lockdep warning when entering the guest (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Implement real mode H_PAGE_INIT handler (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s hv: Implement virtual mode H_PAGE_INIT handler (David Gibson) [1749504]
- [powerpc] kvm: ppc: book3s: Protect memslots while validating user address (David Gibson) [1749504]
- [pci] PCI: hv: Use bytes 4 and 5 from instance ID as the PCI domain numbers (Mohammed Gamal) [1671288]
- [pci] PCI: hv: Detect and fix Hyper-V PCI domain number collision (Mohammed Gamal) [1671288]
- [fs] Revert "lockd: Show pid of lockd for remote locks" (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix an Oops in nfs4_do_setattr (Benjamin Coddington) [1732409]
- [fs] NFSv4: Check the return value of update_open_stateid() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix delegation state recovery (Benjamin Coddington) [1732409]
- [fs] pnfs/flexfiles: Fix PTR_ERR() dereferences in ff_layout_track_ds_error (Benjamin Coddington) [1732409]
- [fs] Revert "NFS: readdirplus optimization by cache mechanism" (memleak) (Benjamin Coddington) [1732409]
- [fs] svcrdma: Ignore source port when computing DRC hash (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Use the correct TCP timeout for flexfiles I/O (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix bug only first CB_NOTIFY_LOCK is handled (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Again fix a race where CB_NOTIFY_LOCK fails to wake a waiter (Benjamin Coddington) [1732409]
- [fs] SUNRPC fix regression in umount of a secure mount (Benjamin Coddington) [1732409]
- [fs] NFS4: Fix v4.0 client state corruption when mount (Benjamin Coddington) [1732409]
- [fs] NFSv4: When recovering state fails with EAGAIN, retry the same recovery (Benjamin Coddington) [1732409]
- [fs] pnfs: Fix a problem where we gratuitously start doing I/O through the MDS (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure the bvecs are reset when we re-encode the RPC request (Benjamin Coddington) [1732409]
- [fs] sunrpc/cache: remove the exporting of cache_seq_next (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a use after free when a server rejects the RPCSEC_GSS credential (Benjamin Coddington) [1732409]
- [fs] xprtrdma: Fix an frwr_map recovery nit (Benjamin Coddington) [1732409]
- [fs] NFSv4.1 fix incorrect return value in copy_file_range (Benjamin Coddington) [1732409]
- [fs] NFS: Fix handling of reply page vector (Benjamin Coddington) [1732409]
- [fs] NFS: Forbid setting AF_INET6 to "struct sockaddr_in"->sin_family. (Benjamin Coddington) [1732409]
- [fs] nfsd: Don't release the callback slot unless it was actually held (Benjamin Coddington) [1732409]
- [fs] nfsd/nfsd3_proc_readdir: fix buffer count and page pointers (Benjamin Coddington) [1732409]
- [fs] sunrpc: don't mark uninitialised items as VALID. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: fix uninitialized variable warning (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: Fix layoutstats handling during read failovers (Benjamin Coddington) [1732409]
- [fs] NFS: Fix a typo in nfs_init_timeout_values() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't let RPC_SOFTCONN tasks time out if the transport is connected (Benjamin Coddington) [1732409]
- [fs] NFS: fix mount/umount race in nlmclnt. (Benjamin Coddington) [1732409]
- [fs] NFS: Fix nfs4_lock_state refcounting in nfs4_alloc_{lock, unlock}data() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove redundant check for the reply length in call_decode() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Handle the SYSTEM_ERR rpc error (Benjamin Coddington) [1732409]
- [fs] SUNRPC: rpc_decode_header() must always return a non-zero value on error (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use the ENOTCONN error on socket disconnect (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix the minimal size for reply buffer allocation (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a client regression when handling oversized replies (Benjamin Coddington) [1732409]
- [fs] pNFS: Fix a typo in pnfs_update_layout (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Take the transport send lock before binding+connecting (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Micro-optimise when the task is known not to be sleeping (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Check whether the task was transmitted before rebind/reconnect (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove redundant calls to RPC_IS_QUEUED() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up (Benjamin Coddington) [1732409]
- [fs] nfsd: allow nfsv3 readdir request to be larger. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Respect RPC call timeouts when retrying transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up RPC back channel transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Prevent thundering herd when the socket is not connected (Benjamin Coddington) [1732409]
- [fs] nfsd: fix wrong check in write_v4_end_grace() (Benjamin Coddington) [1732409]
- [fs] nfsd: fix memory corruption caused by readdir (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow dynamic allocation of back channel slots (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Bump the default callback session slot count to 16 (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert remaining GFP_NOIO, and GFP_NOWAIT sites in sunrpc (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Clean up mirror DS initialisation (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Remove dead code in ff_layout_mirror_valid() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfile: Simplify nfs4_ff_layout_select_ds_stateid() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfile: Simplify nfs4_ff_layout_ds_version() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify ff_layout_get_ds_cred() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify nfs4_ff_find_or_create_ds_client() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Simplify nfs4_ff_layout_select_ds_fh() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Speed up read failover when DSes are down (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Don't invalidate DS deviceids for being unresponsive (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Remove bogus checks for invalid deviceids (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Avoid unnecessary layout invalidations (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: refactor calls to fs4_ff_layout_prepare_ds() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Handle early exit in layoutget by returning an error (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Send LAYOUTERROR when failing over mirrored reads (Benjamin Coddington) [1732409]
- [fs] NFSv4.2: Add client support for the generic 'layouterror' RPC call (Benjamin Coddington) [1732409]
- [fs] NFSv4/flexfiles: Abort I/O early if the layout segment was invalidated (Benjamin Coddington) [1732409]
- [fs] NFSv4/pnfs: Fix barriers in nfs4_mark_deviceid_unavailable() (Benjamin Coddington) [1732409]
- [fs] NFS/flexfiles: Fix up sparse RCU annotations (Benjamin Coddington) [1732409]
- [fs] NFSv4/flexfiles: Fix invalid deref in FF_LAYOUT_DEVID_NODE() (Benjamin Coddington) [1732409]
- [fs] NFS: Add missing encode / decode sequence_maxsz to v4.2 operations (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Don't process the sequence op more than once. (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Reinitialise sequence results before retransmitting a request (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix an Oops in udp_poll() (Benjamin Coddington) [1732409]
- [fs] NFS/pnfs: Bulk destroy of layouts needs to be safe w.r.t. umount (Benjamin Coddington) [1732409]
- [fs] NFS: Fix a soft lockup in the delegation recovery code (Benjamin Coddington) [1732409]
- [fs] nfsd: fix performance-limiting session calculation (Benjamin Coddington) [1732409]
- [fs] svcrpc: fix UDP on servers with lots of threads (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove the redundant 'zerocopy' argument to xs_sendpages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Further cleanups of xs_sendpages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert socket page send code to use iov_iter() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert xs_send_kvec() to use iov_iter_kvec() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Initiate a connection close on an ESHUTDOWN error in stream receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't suppress socket errors when a message read completes (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Handle zero length fragments correctly (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't reset the stream record info when the receive worker is running (Benjamin Coddington) [1732409]
- [fs] nfs: fix xfstest generic/099 failed on nfsv3 (Benjamin Coddington) [1732409]
- [fs] NFS: Fix typo in comments of nfs_readdir_alloc_pages() (Benjamin Coddington) [1732409]
- [fs] NFS: Remove redundant semicolon (Benjamin Coddington) [1732409]
- [fs] NFS: readdirplus optimization by cache mechanism (Benjamin Coddington) [1732409]
- [fs] fs/nfs: Fix nfs_parse_devname to not modify it's argument (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove pointless test in unx_match() (Benjamin Coddington) [1732409]
- [fs] NFS: drop useless LIST_HEAD (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure rq_bytes_sent is reset before request transmission (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use poll() to fix up the socket requeue races (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Set memalloc_nofs_save() on all rpciod/xprtiod jobs (Benjamin Coddington) [1732409]
- [fs] NFS: Fix sparse annotations for nfs_set_open_stateid_locked() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix up documentation warnings (Benjamin Coddington) [1732409]
- [fs] NFS: ENOMEM should also be a fatal error. (Benjamin Coddington) [1732409]
- [fs] NFS: EINTR is also a fatal error. (Benjamin Coddington) [1732409]
- [fs] NFS: Ensure NFS writeback allocations don't recurse back into NFS. (Benjamin Coddington) [1732409]
- [fs] NFS: Pass error information to the pgio error cleanup routine (Benjamin Coddington) [1732409]
- [fs] NFS: Clean up list moves of struct nfs_page (Benjamin Coddington) [1732409]
- [fs] NFS: Don't recoalesce on error in nfs_pageio_complete_mirror() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix an I/O request leakage in nfs_do_recoalesce (Benjamin Coddington) [1732409]
- [fs] NFS: Fix I/O request leakages (Benjamin Coddington) [1732409]
- [fs] Revert "nfsd4: return default lease period" (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use au_rslack when computing reply buffer size (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add rpc_auth::au_ralign field (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Make AUTH_SYS and AUTH_NULL set au_verfsize (Benjamin Coddington) [1732409]
- [fs] NFS: Account for XDR pad of buf->pages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Introduce rpc_prepare_reply_pages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove xdr_buf_trim() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Introduce trace points in rpc_auth_gss.ko (Benjamin Coddington) [1732409]
- [fs] xprtrdma: Squelch a sparse warning (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use struct xdr_stream when decoding RPC Reply header (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up rpc_verify_header() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use struct xdr_stream when constructing RPC Call header (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add build option to disable support for insecure enctypes (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove rpc_xprt::tsh_size (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove some dprintk() call sites from auth functions (Benjamin Coddington) [1732409]
- [fs] NFS: Add trace events to report non-zero NFS status codes (Benjamin Coddington) [1732409]
- [fs] NFS: Remove print_overflow_msg() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add trace event that reports reply page vector alignment (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add XDR overflow trace event (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add xdr_stream::rqst field (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Display symbolic flag names in RPC trace events (Benjamin Coddington) [1732409]
- [fs] rpc: properly check debugfs dentry before using it (Benjamin Coddington) [1732409]
- [fs] svcrpc: fix unlikely races preventing queueing of sockets (Benjamin Coddington) [1732409]
- [fs] svcrpc: svc_xprt_has_something_to_do seems a little long (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't allow compiler optimisation of svc_xprt_release_slot() (Benjamin Coddington) [1732409]
- [fs] nfsd: fix an IS_ERR() vs NULL check (Benjamin Coddington) [1732409]
- [fs] nfsd: Fix error return values for nfsd4_clone_file_range() (Benjamin Coddington) [1732409]
- [fs] nfs: Fix NULL pointer dereference of dev_name (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Address Kerberos performance/behavior regression (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure we respect the RPCSEC_GSS sequence number limit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Ensure rq_bytes_sent is reset before request transmission (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 fix unnecessary retry in nfs4_copy_file_range (Benjamin Coddington) [1732409]
- [fs] sunrpc: kernel BUG at kernel/cred.c:825! (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix TCP receive code on archs with flush_dcache_page() (Benjamin Coddington) [1732409]
- [fs] sunrpc: convert to DEFINE_SHOW_ATTRIBUTE (Benjamin Coddington) [1732409]
- [fs] sunrpc: Add xprt after nfs4_test_session_trunk() (Benjamin Coddington) [1732409]
- [fs] sunrpc: convert unnecessary GFP_ATOMIC to GFP_NOFS (Benjamin Coddington) [1732409]
- [fs] sunrpc: handle ENOMEM in rpcb_getport_async (Benjamin Coddington) [1732409]
- [fs] NFS: remove unnecessary test for IS_ERR(cred) (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 fix async copy reboot recovery (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix some kernel doc complaints (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify defining common RPC trace events (Benjamin Coddington) [1732409]
- [fs] NFS: Fix NFSv4 symbolic trace point output (Benjamin Coddington) [1732409]
- [fs] nfs: fixed broken compilation in nfs_callback_up_net() (Benjamin Coddington) [1732409]
- [fs] nfs: minor typo in nfs4_callback_up_net() (Benjamin Coddington) [1732409]
- [fs] sunrpc: fix debug message in svc_create_xprt() (Benjamin Coddington) [1732409]
- [fs] sunrpc: remove svc_rdma_bc_class (Benjamin Coddington) [1732409]
- [fs] sunrpc: remove unused bc_up operation from rpc_xprt_ops (Benjamin Coddington) [1732409]
- [fs] sunrpc: use SVC_NET() in svcauth_gss_* functions (Benjamin Coddington) [1732409]
- [fs] nfsd: drop useless LIST_HEAD (Benjamin Coddington) [1732409]
- [fs] SUNRPC discard cr_uid from struct rpc_cred. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: simplify auth_unix. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove crbind rpc_cred operation (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove generic cred code. (Benjamin Coddington) [1732409]
- [fs] NFS/NFSD/SUNRPC: replace generic creds with 'struct cred'. (Benjamin Coddington) [1732409]
- [fs] NFS: struct nfs_open_dir_context: convert rpc_cred pointer to cred. (Benjamin Coddington) [1732409]
- [fs] NFS: change access cache to use 'struct cred'. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove RPCAUTH_AUTH_NO_CRKEY_TIMEOUT (Benjamin Coddington) [1732409]
- [fs] NFS: move credential expiry tracking out of SUNRPC into NFS. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: add side channel to use non-generic cred for rpc call. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: introduce RPC_TASK_NULLCREDS to request auth_none (Benjamin Coddington) [1732409]
- [fs] NFS/SUNRPC: don't lookup machine credential until rpcauth_bindcred(). (Benjamin Coddington) [1732409]
- [fs] SUNRPC: discard RPC_DO_ROOTOVERRIDE() (Benjamin Coddington) [1732409]
- [fs] NFSv4: don't require lock for get_renew_cred or get_machine_cred (Benjamin Coddington) [1732409]
- [fs] NFSv4: add cl_root_cred for use when machine cred is not available. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove machine_cred field from struct auth_cred (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove uid and gid from struct auth_cred (Benjamin Coddington) [1732409]
- [fs] SUNRPC: remove groupinfo from struct auth_cred. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: add 'struct cred *' to auth_cred and rpc_cred (Benjamin Coddington) [1732409]
- [fs] cred: allow get_cred() and put_cred() to be given NULL. (Benjamin Coddington) [1732409]
- [fs] cred: export get_task_cred(). (Benjamin Coddington) [1732409]
- [fs] cred: add get_cred_rcu() (Benjamin Coddington) [1732409]
- [fs] cred: add cred_fscmp() for comparing creds. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: allow /proc entries without CONFIG_SUNRPC_DEBUG (Benjamin Coddington) [1732409]
- [fs] nfs: fix comment to nfs_generic_pg_test which does the opposite (Benjamin Coddington) [1732409]
- [fs] NFSv4: cleanup remove unused nfs4_xdev_fs_type (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove xprt_connect_status() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a race with XPRT_CONNECTING (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix disconnection races (Benjamin Coddington) [1732409]
- [fs] Revert "[net] Revert "sunrpc: Ensure we always close the socket after a connection shuts down"" (Benjamin Coddington) [1732409]
- [fs] lockd: Show pid of lockd for remote locks (Benjamin Coddington) [1732409]
- [fs] NFSD remove OP_CACHEME from 4.2 op_flags (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't force a redundant disconnection in xs_read_stream() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up socket polling (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use the discard iterator rather than MSG_TRUNC (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Treat EFAULT as a truncated message in xs_read_stream_request() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up handling of the XDRBUF_SPARSE_PAGES flag (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix RPC receive hangs (Benjamin Coddington) [1732409]
- [fs] nfsd: Return EPERM, not EACCES, in some SETATTR cases (Benjamin Coddington) [1732409]
- [fs] sunrpc: fix cache_head leak due to queued request (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a potential race in xprt_connect() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a memory leak in call_encode() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix leak of krb5p encode pages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: call_connect_status() must handle tasks that got transmitted (Benjamin Coddington) [1732409]
- [fs] nfs: don't dirty kernel pages read by direct-io (Benjamin Coddington) [1732409]
- [fs] NFS: use locks_copy_lock() to copy locks. (Benjamin Coddington) [1732409]
- [fs] nfsd: clean up indentation, increase indentation in switch statement (Benjamin Coddington) [1732409]
- [fs] nfsd: fix a warning in __cld_pipe_upcall() (Benjamin Coddington) [1732409]
- [fs] lockd: fix decoding of TEST results (Benjamin Coddington) [1732409]
- [fs] nfsd4: fix crash on writing v4_end_grace before nfsd startup (Benjamin Coddington) [1732409]
- [fs] nfsd4: skip unused assignment (Benjamin Coddington) [1732409]
- [fs] nfsd4: forbid all renames during grace period (Benjamin Coddington) [1732409]
- [fs] nfsd4: remove unused nfs4_check_olstateid parameter (Benjamin Coddington) [1732409]
- [fs] nfsd4: zero-length WRITE should succeed (Benjamin Coddington) [1732409]
- [fs] NFSv4.2 copy do not allocate memory under the lock (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a NFSv4 state manager deadlock (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix an Oops during delegation callbacks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a bogus get/put in generic_key_to_expire() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a Oops when destroying the RPCSEC_GSS credential cache (Benjamin Coddington) [1732409]
- [fs] NFSv4: Ensure that the state manager exits the loop on SIGKILL (Benjamin Coddington) [1732409]
- [fs] NFSv4: Don't exit the state manager without clearing NFS4CLNT_MANAGER_RUNNING (Benjamin Coddington) [1732409]
- [fs] SUNRPC: drop pointless static qualifier in xdr_get_next_encode_buffer() (Benjamin Coddington) [1732409]
- [fs] nfsd: COPY and CLONE operations require the saved filehandle to be set (Benjamin Coddington) [1732409]
- [fs] sunrpc: correct the computation for page_ptr when truncating (Benjamin Coddington) [1732409]
- [fs] NFS: fix spelling mistake, EACCESS -> EACCES (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Use atomic(64)_t for seq_send(64) (Benjamin Coddington) [1732409]
- [fs] nfsd: Fix an Oops in free_session() (Benjamin Coddington) [1732409]
- [fs] nfsd: correctly decrement odstate refcount in error path (Benjamin Coddington) [1732409]
- [fs] nfsd: fix fall-through annotations (Benjamin Coddington) [1732409]
- [fs] knfsd: Improve lookup performance in the duplicate reply cache using an rbtree (Benjamin Coddington) [1732409]
- [fs] knfsd: Further simplify the cache lookup (Benjamin Coddington) [1732409]
- [fs] knfsd: Simplify NFS duplicate replay cache (Benjamin Coddington) [1732409]
- [fs] knfsd: Remove dead code from nfsd_cache_lookup (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify TCP receive code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Replace the cache_detail->hash_lock with a regular spinlock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove non-RCU protected lookup (Benjamin Coddington) [1732409]
- [fs] NFS: Fix up a typo in nfs_dns_ent_put (Benjamin Coddington) [1732409]
- [fs] NFS: Lockless DNS lookups (Benjamin Coddington) [1732409]
- [fs] knfsd: Lockless lookup of NFSv4 identities. (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Lockless server RPCSEC_GSS context lookup (Benjamin Coddington) [1732409]
- [fs] knfsd: Allow lockless lookups of the exports (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Make server side AUTH_UNIX use lockless lookups (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow cache lookups to use RCU protection rather than the r/w spinlock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert the auth cred cache to use refcount_t (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert auth creds to use refcount_t (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify lookup code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up the AUTH cache code (Benjamin Coddington) [1732409]
- [fs] NFS: change sign of nfs_fh length (Benjamin Coddington) [1732409]
- [fs] sunrpc: safely reallow resvport min/max inversion (Benjamin Coddington) [1732409]
- [fs] nfs: remove redundant call to nfs_context_set_write_error() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix a compile warning for cmpxchg64() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: use cmpxchg64() in gss_seq_send64_fetch_and_inc() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor sunrpc_cache_lookup (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add lockless lookup of the server's auth domain (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove the server 'authtab_lock' and just use RCU (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix lookup revalidate of regular files (Benjamin Coddington) [1732409]
- [fs] NFS: Refactor nfs_lookup_revalidate() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Replace krb5_seq_lock with a lockless scheme (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Lockless lookup of RPCSEC_GSS mechanisms (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Remove rpc_authflavor_lock in favour of RCU locking (Benjamin Coddington) [1732409]
- [fs] NFS: Remove private spinlock in struct nfs_pgio_header (Benjamin Coddington) [1732409]
- [fs] NFSv3: Improve NFSv3 performance when server returns no post-op attributes (Benjamin Coddington) [1732409]
- [fs] NFSv4: Split out NFS v4.2 copy completion functions (Benjamin Coddington) [1732409]
- [fs] NFS: Reduce indentation of nfs4_recovery_handle_error() (Benjamin Coddington) [1732409]
- [fs] NFS: Reduce indentation of the switch statement in nfs4_reclaim_open_state() (Benjamin Coddington) [1732409]
- [fs] NFS: Split out the body of nfs4_reclaim_open_state() (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix the r/wsize checking (Benjamin Coddington) [1732409]
- [fs] NFSv4: Convert struct nfs4_state to use refcount_t (Benjamin Coddington) [1732409]
- [fs] NFSv4: Convert open state lookup to use RCU (Benjamin Coddington) [1732409]
- [fs] NFS: Convert lookups of the open context to RCU (Benjamin Coddington) [1732409]
- [fs] NFS: Simplify internal check for whether file is open for write (Benjamin Coddington) [1732409]
- [fs] NFS: Convert lookups of the lock context to RCU (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't allocate more pages than we need to fit a layoutget response (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't zero out the array in nfs4_alloc_pages() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Unexport xdr_partial_copy_from_skb() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up xs_udp_data_receive() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow AF_LOCAL sockets to use the generic stream receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up - rename xs_tcp_data_receive() to xs_stream_data_receive() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify TCP receive code by switching to using iterators (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a bvec array to struct xdr_buf for use with iovec_iter() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a label for RPC calls that require allocation on receive (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert the xprt->sending queue back to an ordinary wait queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix priority queue fairness (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Convert xprt receive queue to use an rbtree (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't take transport->lock unnecessarily when taking XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Cleanup: remove the unused 'task' argument from the request_send() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Clean up transport write space handling (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Turn off throttling of RPC slots for TCP sockets (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow soft RPC calls to time out when waiting for the XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Allow calls to xprt_transmit() to drain the entire transmit queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Enqueue swapper tagged RPCs at the head of the transmit queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Support for congestion control when queuing is enabled (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Improve latency for interactive tasks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Move RPC retransmission stat counter to xprt_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify xprt_prepare_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't reset the request 'bytes_sent' counter when releasing XPRT_LOCK (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Treat the task and request as separate in the xprt_ops->send_request() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Fix up the back channel transmit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor RPC call encoding (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a transmission queue for RPC requests (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Distinguish between the slot allocation list and receive queue (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Minor cleanup for call_transmit() (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor xprt_transmit() to remove wait for reply code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor xprt_transmit() to remove the reply queue code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Rename xprt->recv_lock to xprt->queue_lock (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Don't wake queued RPC calls multiple times in xprt_transmit (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Test whether the task is queued before grabbing the queue spinlocks (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add a helper to wake up a sleeping rpc_task and set its status (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Refactor the transport request pinning (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify dealing with aborted partially transmitted messages (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Add socket transmit queue offset tracking (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Move reset of TCP state variables into the reconnect code (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Rename TCP receive-specific state variables (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Avoid holding locks across the XDR encoding of the RPC message (Benjamin Coddington) [1732409]
- [fs] SUNRPC: Simplify identification of when the message send/receive is complete (Benjamin Coddington) [1732409]
- [fs] SUNRPC: The transmitted message must lie in the RPCSEC window of validity (Benjamin Coddington) [1732409]
- [fs] SUNRPC: If there is no reply expected, bail early from call_decode (Benjamin Coddington) [1732409]
- [fs] nfsd: remove set but not used variable 'dirp' (Benjamin Coddington) [1732409]
- [fs] NFSD introduce async copy feature (Benjamin Coddington) [1732409]
- [fs] NFSD OFFLOAD_CANCEL xdr (Benjamin Coddington) [1732409]
- [fs] NFSD OFFLOAD_STATUS xdr (Benjamin Coddington) [1732409]
- [fs] NFSD CB_OFFLOAD xdr (Benjamin Coddington) [1732409]
- [fs] NFS: Don't open code clearing of delegation state (Benjamin Coddington) [1732409]
- [fs] NFSv4.1 fix infinite loop on I/O. (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a tracepoint Oops in initiate_file_draining() (Benjamin Coddington) [1732409]
- [fs] pNFS: Ensure we return the error if someone kills a waiting layoutget (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a tracepoint Oops in initiate_file_draining() (Benjamin Coddington) [1732409]
- [fs] sunrpc: Add comment defining gssd upcall API keywords (Benjamin Coddington) [1732409]
- [fs] nfsd: Remove callback_cred (Benjamin Coddington) [1732409]
- [fs] nfsd: Use correct credential for NFSv4.0 callback with GSS (Benjamin Coddington) [1732409]
- [fs] sunrpc: Extract target name into svc_cred (Benjamin Coddington) [1732409]
- [fs] sunrpc: Enable the kernel to specify the hostname part of service principals (Benjamin Coddington) [1732409]
- [fs] pNFS: Remove unwanted optimisation of layoutget (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: ff_layout_pg_init_read should exit on error (Benjamin Coddington) [1732409]
- [fs] pNFS: Treat RECALLCONFLICT like DELAY... (Benjamin Coddington) [1732409]
- [fs] pNFS: When updating the stateid in layoutreturn, also update the recall range (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a sleep in atomic context in nfs4_callback_sequence() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix locking in pnfs_generic_recover_commit_reqs (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix a typo in nfs4_init_channel_attrs() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Don't busy wait if NFSv4 session draining is interrupted (Benjamin Coddington) [1732409]
- [fs] NFS recover from destination server reboot for copies (Benjamin Coddington) [1732409]
- [fs] nfsd: use true and false for boolean values (Benjamin Coddington) [1732409]
- [fs] nfsd: constify write_op[] (Benjamin Coddington) [1732409]
- [fs] fs/nfsd: Delete invalid assignment statements in nfsd4_decode_exchange_id (Benjamin Coddington) [1732409]
- [fs] NFSD: Handle full-length symlinks (Benjamin Coddington) [1732409]
- [fs] NFSD: Refactor the generic write vector fill helper (Benjamin Coddington) [1732409]
- [fs] nfsd: Mark expected switch fall-through (Benjamin Coddington) [1732409]
- [fs] nfsd: fix leaked file lock with nfs exported overlayfs (Benjamin Coddington) [1732409]
- [fs] NFS add a simple sync nfs4_proc_commit after async COPY (Benjamin Coddington) [1732409]
- [fs] NFS handle COPY ERR_OFFLOAD_NO_REQS (Benjamin Coddington) [1732409]
- [fs] NFS send OFFLOAD_CANCEL when COPY killed (Benjamin Coddington) [1732409]
- [fs] NFS export nfs4_async_handle_error (Benjamin Coddington) [1732409]
- [fs] NFS handle COPY reply CB_OFFLOAD call race (Benjamin Coddington) [1732409]
- [fs] NFS add support for asynchronous COPY (Benjamin Coddington) [1732409]
- [fs] NFS COPY xdr handle async reply (Benjamin Coddington) [1732409]
- [fs] NFS OFFLOAD_CANCEL xdr (Benjamin Coddington) [1732409]
- [fs] NFS CB_OFFLOAD xdr (Benjamin Coddington) [1732409]
- [fs] NFS: Use an appropriate work queue for direct-write completion (Benjamin Coddington) [1732409]
- [fs] NFSv4: Fix error handling in nfs4_sp4_select_mode() (Benjamin Coddington) [1732409]
- [fs] pnfs: Use true and false for boolean values (Benjamin Coddington) [1732409]
- [fs] pnfs: pnfs_find_lseg() should not check NFS_LSEG_LAYOUTRETURN (Benjamin Coddington) [1732409]
- [fs] NFS: Mark expected switch fall-throughs (Benjamin Coddington) [1732409]
- [fs] NFSv4: Mark the inode change attribute up to date in update_changeattr() (Benjamin Coddington) [1732409]
- [fs] NFSv4: Detect nlink changes on cross-directory renames too (Benjamin Coddington) [1732409]
- [fs] NFSv4: bump/drop the nlink count on the parent dir when we mkdir/rmdir (Benjamin Coddington) [1732409]
- [fs] pnfs: Fix handling of NFS4ERR_OLD_STATEID replies to layoutreturn (Benjamin Coddington) [1732409]
- [fs] sunrpc: whitespace fixes (Benjamin Coddington) [1732409]
- [fs] NFSv4 client live hangs after live data migration recovery (Benjamin Coddington) [1732409]
- [fs] NFSv4.0 fix client reference leak in callback (Benjamin Coddington) [1732409]
- [fs] sunrpc: kstrtoul() can also return -ERANGE (Benjamin Coddington) [1732409]
- [fs] NFS: silence a harmless uninitialized variable warning (Benjamin Coddington) [1732409]
- [fs] net/sunrpc: Make rpc_auth_create_args a const (Benjamin Coddington) [1732409]
- [fs] pnfs/blocklayout: off by one in bl_map_stripe() (Benjamin Coddington) [1732409]
- [fs] nfs: Referrals not inheriting proto setting from parent (Benjamin Coddington) [1732409]
- [fs] nfs: initiate returning delegation when reclaiming one that's been recalled (Benjamin Coddington) [1732409]
- [fs] fs: nfs: Adding new return type vm_fault_t (Benjamin Coddington) [1732409]
- [fs] nfs: add error check in nfs_idmap_prepare_message() (Benjamin Coddington) [1732409]
- [fs] NFS: More excessive attribute revalidation in nfs_execute_ok() (Benjamin Coddington) [1732409]
- [fs] NFS: Fix excessive attribute revalidation in nfs_execute_ok() (Benjamin Coddington) [1732409]
- [fs] NFS: Ensure we immediately start writeback on rescheduled writes (Benjamin Coddington) [1732409]
- [fs] NFSv4.1: Fix a potential layoutget/layoutrecall deadlock (Benjamin Coddington) [1732409]
- [fs] pNFS: Parse the results of layoutget on open even if permissions checks fail (Benjamin Coddington) [1732409]
- [fs] NFS: Allow optimisation of lseek(fd, SEEK_CUR, 0) on directories (Benjamin Coddington) [1732409]
- [fs] pNFS: Wait for stale layoutget calls to complete in pnfs_update_layout() (Benjamin Coddington) [1732409]
- [fs] pNFS/flexfiles: Ensure we always return a layout if it has layoutstats (Benjamin Coddington) [1732409]
- [fs] pNFS: Ignore non-recalled layouts in pnfs_layout_need_return() (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't update the stateid when replying NFS4ERR_DELAY to a layout recall (Benjamin Coddington) [1732409]
- [fs] pNFS: Don't discard layout segments that are marked for return (Benjamin Coddington) [1732409]
- [fs] nfsd: don't advertise a SCSI layout for an unsupported request_queue (Benjamin Coddington) [1732409]
- [fs] nfsd: fix corrupted reply to badly ordered compound (Benjamin Coddington) [1732409]
- [fs] nfsd: clarify check_op_ordering (Benjamin Coddington) [1732409]
- [fs] nfsd: update obselete comment referencing the BKL (Benjamin Coddington) [1732409]
- [fs] nfsd4: cleanup sessionid in nfsd4_destroy_session (Benjamin Coddington) [1732409]
- [fs] nfsd4: less confusing nfsd4_compound_in_session (Benjamin Coddington) [1732409]
- [fs] nfsd4: support change_attr_type attribute (Benjamin Coddington) [1732409]
- [fs] nfsd: fix NFSv4 time_delta attribute (Benjamin Coddington) [1732409]
- [fs] nfsd4: return default lease period (Benjamin Coddington) [1732409]
- [fs] nfsd4: extend reclaim period for reclaiming clients (Benjamin Coddington) [1732409]
- [netdrv] i40e: Do not check VF state in i40e_ndo_get_vf_config (Stefan Assmann) [1752498]
- [netdrv] i40e: Add support for X710 device (Stefan Assmann) [1752891]
- [mm] mm/oom_kill.c: add task UID to info message on an oom kill (Joel Savitz) [1693039]
- [pci] ACPICA: Increase total number of possible Owner IDs (Al Stone) [1713050]
- [powerpc] powerpc/pseries: correctly track irq state in default idle (Steve Best) [1751971]
- [powerpc] powerpc/imc: Dont create debugfs files for cpu-less nodes (Steve Best) [1726031]
- [fs] userfaultfd_release: always remove uffd flags and clear vm_userfaultfd_ctx (Alex Gladkov) [1749763]
- [infiniband] RDMA/bnxt_re: Fix stack-out-of-bounds in bnxt_qplib_rcfw_send_message (Selvin Xavier) [1643312]
- [drm] drm/bochs: Fix connector leak during driver unload (Sam Bobroff) [1463490]
- [tools] selftests: Remove forced unbuffering for test running (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Add test plan API to kselftest.h and adjust callers (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Remove KSFT_TAP_LEVEL (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Move test output to diagnostic lines (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Distinguish between missing and non-executable (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Add plan line and fix result line syntax (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Extract logic for multiple test runs (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Use runner.sh for emit targets (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] selftests: Extract single-test shell logic from lib.mk (Desnes Augusto Nunes do Rosario) [1721461]
- [tools] x86/selftests/pkeys: Fork() to check for state being preserved (Vladis Dronov) [1738880]
- [x86] x86/pkeys: Properly copy pkey state at fork() (Vladis Dronov) [1738880]
- [netdrv] cxgb4: fix a memory leak bug (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Prefer pcie_capability_read_word() (Jonathan Toppins) [1725776]
- [netdrv] allocate_flower_entry: should check for null deref (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: reduce kernel stack usage in cudbg_collect_mem_region() (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS refcounting for alloc/free mac filters (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS TCAM refcounting for cxgb4 change mac (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Add MPS TCAM refcounting for raw mac filters (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Re-work the logic for mps refcounting (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/libcxgb/cxgb4i/cxgbit: enable eDRAM page pods for iSCSI (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Set initial IRQ affinity hints (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Make t4_get_tp_e2c_map static (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Revert "cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size" (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: offload VLAN flows regardless of VLAN ethtype (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: use firmware API for validating filter spec (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Enable hash filter with offload (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Fix error path in cxgb4_init_module (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Delete all hash and TCAM filters before resource cleanup (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/cxgb4vf_main: Mark expected switch fall-through (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/cxgb4vf: Display advertised FEC in ethtool (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Update 1.23.3.0 as the latest firmware supported. (Jonathan Toppins) [1725776]
- [netdrv] cxgb4: Update 1.22.9.0 as the latest firmware supported. (Jonathan Toppins) [1725776]
- [netdrv] cxgb4/l2t: Use struct_size() in kvzalloc() (Jonathan Toppins) [1725776]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Jonathan Toppins) [1725776]
- [netdrv] crypto/chelsio/chtls: macro correction in tx path (Jonathan Toppins) [1725776]

* Tue Oct 15 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.7.el8]
- [kernel] rcu: Add sparse check to rcu_assign_pointer() (Waiman Long) [1737054]
- [kernel] rcu: Fix obsolete DYNTICK_IRQ_NONIDLE comment (Waiman Long) [1737054]
- [kernel] rcu: Repair rcu_nmi_exit() docbook header (Waiman Long) [1737054]
- [kernel] rcu: Remove preemption disabling from expedited CPU selection (Waiman Long) [1737054]
- [kernel] rcu: Rename rcu_process_callbacks() to rcu_core() for Tree RCU (Waiman Long) [1737054]
- [kernel] rcu: Rename rcu_check_callbacks() to rcu_sched_clock_irq() (Waiman Long) [1737054]
- [kernel] rcu: Docbook for rcu_head_init() and rcu_head_after_call_rcu() (Waiman Long) [1737054]
- [documentation] doc: Fix outdated links (Waiman Long) [1737054]
- [documentation] doc: CPU-hotplug notifiers cannot invoke synchronize_srcu() or srcu_barrier() (Waiman Long) [1737054]
- [documentation] doc: Now jiffies_till_sched_qs solicits help from cond_resched() (Waiman Long) [1737054]
- [kernel] rcuperf: Stop abusing IS_ENABLED() (Waiman Long) [1737054]
- [kernel] rcutorture: Add grace period after CPU offline (Waiman Long) [1737054]
- [kernel] torture: Explain and simplify odd "for" loop in mkinitrd.sh (Waiman Long) [1737054]
- [kernel] rcutorture: Record grace periods in forward-progress histogram (Waiman Long) [1737054]
- [kernel] rcu: Prevent needless ->gp_seq_needed update in __note_gp_changes() (Waiman Long) [1737054]
- [kernel] rcu: Do RCU GP kthread self-wakeup from softirq and interrupt (Waiman Long) [1737054]
- [kernel] rcu: Add sysrq rcu_node-dump capability (Waiman Long) [1737054]
- [kernel] rcu: Protect rcu_check_gp_kthread_starvation() access to ->gp_flags (Waiman Long) [1737054]
- [kernel] rcu: Improve diagnostics for failed RCU grace-period start (Waiman Long) [1737054]
- [kernel] rcu: Update NOCB comments (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_cpu_kthread_cpu per-CPU variable (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_has_work to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_cpu_kthread_loops per-CPU variable (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_kthread_status to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Move rcu_cpu_kthread_task to rcu_data structure (Waiman Long) [1737054]
- [kernel] rcu: Accommodate zero jiffies_till_first_fqs and kthread kicking (Waiman Long) [1737054]
- [kernel] rcu: Remove wrapper definitions for obsolete RCU update functions (Waiman Long) [1737054]
- [kernel] rcu: Discard separate per-CPU callback counts (Waiman Long) [1737054]
- [kernel] rcu: Inline _synchronize_rcu_expedited() into synchronize_rcu_expedited() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate PREEMPT and !PREEMPT synchronize_rcu() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate PREEMPT and !PREEMPT synchronize_rcu_expedited() (Waiman Long) [1737054]
- [kernel] rcu: Determine expedited-GP IPI handler at build time (Waiman Long) [1737054]
- [kernel] rcu: Inline rcu_kthread_do_work() into its sole remaining caller (Waiman Long) [1737054]
- [kernel] rcu: Eliminate RCU_BH_FLAVOR and RCU_SCHED_FLAVOR (Waiman Long) [1737054]
- [kernel] rcu: Inline force_quiescent_state() into rcu_force_quiescent_state() (Waiman Long) [1737054]
- [kernel] rcu: Make expedited IPI handler return after handling critical section (Waiman Long) [1737054]
- [kernel] rcu: Rename and comment changes due to only one rcuo kthread per CPU (Waiman Long) [1737054]
- [kernel] sched: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] sched: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [net] net/core: Replace call_rcu_bh() and synchronize_rcu_bh() (Waiman Long) [1737054]
- [net] netpoll: allow cleanup to be synchronous (Waiman Long) [1737054]
- [net] netfilter: Replace call_rcu_bh(), rcu_barrier_bh(), and synchronize_rcu_bh() (Waiman Long) [1737054]
- [kernel] uprobes: Use synchronize_rcu() not synchronize_sched() (Waiman Long) [1737054]
- [kernel] rcutorture: Don't do busted forward-progress testing (Waiman Long) [1737054]
- [kernel] rcutorture: Use 100ms buckets for forward-progress callback histograms (Waiman Long) [1737054]
- [kernel] rcutorture: Recover from OOM during forward-progress tests (Waiman Long) [1737054]
- [kernel] rcutorture: Print forward-progress test age upon failure (Waiman Long) [1737054]
- [kernel] rcutorture: Print time since GP end upon forward-progress failure (Waiman Long) [1737054]
- [kernel] rcutorture: Print histogram of CB invocation at OOM time (Waiman Long) [1737054]
- [kernel] rcutorture: Print GP age upon forward-progress failure (Waiman Long) [1737054]
- [kernel] rcu: Print per-CPU callback counts for forward-progress failures (Waiman Long) [1737054]
- [kernel] rcu: Account for nocb-CPU callback counts in RCU CPU stall warnings (Waiman Long) [1737054]
- [kernel] rcutorture: Dump grace-period diagnostics upon forward-progress OOM (Waiman Long) [1737054]
- [kernel] rcutorture: Prepare for asynchronous access to rcu_fwd_startat (Waiman Long) [1737054]
- [kernel] torture: Remove unnecessary "ret" variables (Waiman Long) [1737054]
- [kernel] rcutorture: Affinity forward-progress test to avoid housekeeping CPUs (Waiman Long) [1737054]
- [kernel] rcutorture: Break up too-long rcu_torture_fwd_prog() function (Waiman Long) [1737054]
- [kernel] rcutorture: Remove cbflood facility (Waiman Long) [1737054]
- [kernel] torture: Bring any extra CPUs online during kernel startup (Waiman Long) [1737054]
- [kernel] rcutorture: Add call_rcu() flooding forward-progress tests (Waiman Long) [1737054]
- [tools] rcutorture/formal: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [tools] tools/kernel.h: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [net] net/decnet: Replace rcu_barrier_bh() with rcu_barrier() (Waiman Long) [1737054]
- [net] net/core/skmsg: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] cgroups: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] types: Remove call_rcu_bh() and call_rcu_sched() (Waiman Long) [1737054]
- [include] percpu-rwsem: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [net] net/bridge: Replace call_rcu_bh() and rcu_barrier_bh() (Waiman Long) [1737054]
- [kernel] srcu: Use "ssp" instead of "sp" for srcu_struct pointer (Waiman Long) [1737054]
- [kernel] srcu: Lock srcu_data structure in srcu_gp_start() (Waiman Long) [1737054]
- [mm] mm: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] percpu-refcount: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] events: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] workqueue: Replace call_rcu_sched() with call_rcu() (Waiman Long) [1737054]
- [kernel] modules: Replace synchronize_sched() and call_rcu_sched() (Waiman Long) [1737054]
- [kernel] sched/membarrier: synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] lockdep: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] kprobes: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [init] main: Replace rcu_barrier_sched() with rcu_barrier() (Waiman Long) [1737054]
- [kernel] tracing: Replace synchronize_sched() and call_rcu_sched() (Waiman Long) [1737054]
- [kernel] tracepoints: Free early tracepoints after RCU is initialized (Waiman Long) [1737054]
- [kernel] tracing: Fix synchronizing to event changes with tracepoint_synchronize_unregister() (Waiman Long) [1737054]
- [kernel] tracepoint: Make rcuidle tracepoint callers use SRCU (Waiman Long) [1737054]
- [fs] fs/file: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [cpufreq] cpufreq/cpufreq_governor: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [cpufreq] cpufreq/intel_pstate: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [vhost] drivers/vhost: Replace synchronize_rcu_bh() with synchronize_rcu() (Waiman Long) [1737054]
- [netdrv] ethernet/sis: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [char] drivers/ipmi: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [crypto] crypto/pcrypt: Replace synchronize_rcu_bh() with synchronize_rcu() (Waiman Long) [1737054]
- [mm] mm: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [kernel] locking/mutex: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [fs] userfaultfd: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [net] smsc: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [scripts] checkpatch.pl: Suggest lockdep instead of asserting !spin_is_locked() (Waiman Long) [1737054]
- [scripts] checkpatch: Create table of obsolete APIs and apply to RCU (Waiman Long) [1737054]
- [maintainers] MAINTAINERS: Add Joel Fernandes as RCU reviewer (Waiman Long) [1737054]
- [kernel] rcu: Avoid signed integer overflow in rcu_preempt_deferred_qs() (Waiman Long) [1737054]
- [kernel] rcu: Replace this_cpu_ptr() with __this_cpu_read() (Waiman Long) [1737054]
- [kernel] rcu: Speed up expedited GPs when interrupting RCU reader (Waiman Long) [1737054]
- [kernel] rcu: Trace end of grace period before end of grace period (Waiman Long) [1737054]
- [kernel] rcu: Adjust the comment of function rcu_is_watching (Waiman Long) [1737054]
- [kernel] rcu: Add jiffies-since-GP-activity to show_rcu_gp_kthreads() (Waiman Long) [1737054]
- [kernel] rcu: Add state name to show_rcu_gp_kthreads() output (Waiman Long) [1737054]
- [kernel] rcu: Parameterize rcu_check_gp_start_stall() (Waiman Long) [1737054]
- [kernel] rcu: Avoid double multiply by HZ (Waiman Long) [1737054]
- [documentation] doc: Fix "struction" typo in RCU memory-ordering documentation (Waiman Long) [1737054]
- [documentation] doc: Correct parameter in stallwarn (Waiman Long) [1737054]
- [documentation] doc: RCU scheduler spinlock rcu_read_unlock() restriction remains (Waiman Long) [1737054]
- [documentation] doc: Make listing in RCU perf/scale requirements use rcu_assign_pointer() (Waiman Long) [1737054]
- [documentation] doc: Remove obsolete (non-)requirement about disabling preemption (Waiman Long) [1737054]
- [documentation] doc: Make reader aware of rcu_dereference_protected (Waiman Long) [1737054]
- [documentation] doc: rcu: Encourage use of rcu_barrier in checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Remove obsolete checklist item about synchronize_rcu usage (Waiman Long) [1737054]
- [documentation] doc: rcu: Remove obsolete suggestion from checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Add more rationale for using rcu_read_lock_sched in checklist (Waiman Long) [1737054]
- [documentation] doc: rcu: Update core and full API in whatisRCU (Waiman Long) [1737054]
- [documentation] doc: Document rcutorture forward-progress test kernel parameters (Waiman Long) [1737054]
- [documentation] doc: rcu: Update description of gp_seq fields in rcu_data (Waiman Long) [1737054]
- [documentation] doc: rcu: Better clarify the rcu_segcblist ->len field (Waiman Long) [1737054]
- [documentation] doc: rcu: Update Data-Structures for RCU flavor consolidation (Waiman Long) [1737054]
- [documentation] doc: Remove rcu_dynticks from Data-Structures (Waiman Long) [1737054]
- [documentation] doc: Update information about resched_cpu (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/update.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/tree_plugin.h (Waiman Long) [1737054]
- [kernel] rcu: Stop expedited grace periods from relying on stop-machine (Waiman Long) [1737054]
- [kernel] srcu: Prevent __call_srcu() counter wrap with read-side critical section (Waiman Long) [1737054]
- [include] srcu: Fix kernel-doc missing notation (Waiman Long) [1737054]
- [x86] x86/PCI: Replace spin_is_locked() with lockdep (Waiman Long) [1737054]
- [tools] rcutorture: Make use of nolibc when available (Waiman Long) [1737054]
- [tools] rcutorture: Import a copy of nolibc (Waiman Long) [1737054]
- [tools] rcutorture: Check initrd/init instead of initrd only (Waiman Long) [1737054]
- [tools] rcutorture: Always strip using the cross-compiler (Waiman Long) [1737054]
- [tools] rcutorture: Add cross-compile capability to initrd.sh (Waiman Long) [1737054]
- [tools] rcutorture: Make initrd/init execute in userspace (Waiman Long) [1737054]
- [tools] rcutorture: Add initrd support for systems lacking dracut (Waiman Long) [1737054]
- [tools] rcutorture: Automatically create initrd directory (Waiman Long) [1737054]
- [documentation] doc: Remove rcu_preempt_state reference in stallwarn (Waiman Long) [1737054]
- [documentation] doc: Clarify RCU data-structure comment about rcu_tree fanout (Waiman Long) [1737054]
- [documentation] doc: Set down forward-progress requirements (Waiman Long) [1737054]
- [powerpc] powerpc: Convert hugepd_free() to use call_rcu() (Waiman Long) [1737054]
- [s390] s390/mm: Convert tlb_table_flush() to use call_rcu() (Waiman Long) [1737054]
- [kernel] sparc/oprofile: Convert timer_stop() to use synchronize_rcu() (Waiman Long) [1737054]
- [kernel] sched/membarrier: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1737054]
- [kernel] rcu: Consolidate the RCU update functions invoked by sync.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate synchronize_rcu_mult() (Waiman Long) [1737054]
- [kernel] rcu: Fix rcu_{node, data} comments about gp_seq_needed (Waiman Long) [1737054]
- [kernel] rcu: Remove unused rcu_state externs (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for kernel/rcu/tree.c (Waiman Long) [1737054]
- [kernel] rcu: Eliminate BUG_ON() for sync.c (Waiman Long) [1737054]
- [include] srcu: Add notrace variant of srcu_dereference (Waiman Long) [1737054]
- [documentation] PM/EM: Document the Energy Model framework (Phil Auld) [1718927]
- [kernel] sched/doc: Document Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] sched/fair: Remove unneeded prototype of capacity_of() (Phil Auld) [1718927]
- [kernel] sched/fair: Skip LLC NOHZ logic for asymmetric systems (Phil Auld) [1718927]
- [kernel] sched/fair: Tune down misfit NOHZ kicks (Phil Auld) [1718927]
- [kernel] sched/fair: Comment some nohz_balancer_kick() kick conditions (Phil Auld) [1718927]
- [kernel] sched/fair: Prune, fix and simplify the nohz_balancer_kick() comment block (Phil Auld) [1718927]
- [kernel] sched/fair: Explain LLC nohz kick condition (Phil Auld) [1718927]
- [kernel] sched/fair: Simplify nohz_balancer_kick() (Phil Auld) [1718927]
- [kernel] sched/topology: Fix percpu data types in struct sd_data & struct s_data (Phil Auld) [1718927]
- [kernel] sched/fair: Simplify post_init_entity_util_avg() by calling it with a task_struct pointer argument (Phil Auld) [1718927]
- [kernel] sched/fair: Fix util_avg of new tasks for asymmetric systems (Phil Auld) [1718927]
- [kernel] sched/fair: Optimize update_blocked_averages() (Phil Auld) [1718927]
- [kernel] sched/topology: Introduce a sysctl for Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] Revert "sched/core: Take the hotplug lock in sched_init_smp()" (Phil Auld) [1718927]
- [kernel] cpu/hotplug: Mute hotplug lockdep during init (Phil Auld) [1718927]
- [kernel] sched/fair: Select an energy-efficient CPU on task wake-up (Phil Auld) [1718927]
- [kernel] sched/fair: Introduce an energy estimation helper function (Phil Auld) [1718927]
- [kernel] sched/fair: Add over-utilization/tipping point indicator (Phil Auld) [1718927]
- [kernel] sched/fair: Clean-up update_sg_lb_stats parameters (Phil Auld) [1718927]
- [kernel] sched/toplogy: Introduce the 'sched_energy_present' static key (Phil Auld) [1718927]
- [kernel] sched/topology: Make Energy Aware Scheduling depend on schedutil (Phil Auld) [1718927]
- [kernel] sched/topology: Disable EAS on inappropriate platforms (Phil Auld) [1718927]
- [kernel] sched/topology: Add lowest CPU asymmetry sched_domain level pointer (Phil Auld) [1718927]
- [kernel] sched/topology: Reference the Energy Model of CPUs when available (Phil Auld) [1718927]
- [kernel] PM: Introduce an Energy Model management framework (Phil Auld) [1718927]
- [kernel] sched/cpufreq: Prepare schedutil for Energy Aware Scheduling (Phil Auld) [1718927]
- [kernel] sched/topology: Relocate arch_scale_cpu_capacity() to the internal header (Phil Auld) [1718927]
- [kernel] sched/core: Take the hotplug lock in sched_init_smp() (Phil Auld) [1718927]
- [kernel] sched/core: Disable SD_PREFER_SIBLING on asymmetric CPU capacity domains (Phil Auld) [1718927]
- [kernel] sched/fair: Don't move tasks to lower capacity CPUs unless necessary (Phil Auld) [1718927]
- [kernel] sched/fair: Set rq->rd->overload when misfit (Phil Auld) [1718927]
- [kernel] sched/fair: Wrap rq->rd->overload accesses with READ/WRITE_ONCE() (Phil Auld) [1718927]
- [kernel] sched/core: Change root_domain->overload type to int (Phil Auld) [1718927]
- [kernel] sched/fair: Change 'prefer_sibling' type to bool (Phil Auld) [1718927]
- [kernel] sched/fair: Kick nohz balance if rq->misfit_task_load (Phil Auld) [1718927]
- [kernel] sched/fair: Consider misfit tasks when load-balancing (Phil Auld) [1718927]
- [kernel] sched/fair: Add sched_group per-CPU max capacity (Phil Auld) [1718927]
- [kernel] sched/fair: Add 'group_misfit_task' load-balance type (Phil Auld) [1718927]
- [kernel] sched/topology: Add static_key for asymmetric CPU capacity optimizations (Phil Auld) [1718927]
- [kernel] sched/core, workqueues: Distangle worker accounting from rq lock (Phil Auld) [1737067]
- [kernel] workqueue: Use normal rcu (Phil Auld) [1737067]
- [kernel] tick/broadcast: Fix warning about undefined tick_broadcast_oneshot_offline() (Phil Auld) [1737067]
- [kernel] timer/trace: Improve timer tracing (Phil Auld) [1737067]
- [include] timer/trace: Replace deprecated vsprintf pointer extension pf by ps (Phil Auld) [1737067]
- [kernel] timer: Move trace point to get proper index (Phil Auld) [1737067]
- [kernel] tick/sched: Update tick_sched struct documentation (Phil Auld) [1737067]
- [kernel] tick: Remove outgoing CPU from broadcast masks (Phil Auld) [1737067]
- [kernel] timekeeping: Consistently use unsigned int for seqcount snapshot (Phil Auld) [1737067]
- [kernel] sched/fair: Robustify CFS-bandwidth timer locking (Phil Auld) [1737067]
- [kernel] tick/sched : Remove redundant cpu_online() check (Phil Auld) [1737067]
- [misc] sched/swait: Rename to exclusive (Phil Auld) [1737067]
- [kernel] sched/swait: Switch to full exclusive mode (Phil Auld) [1737067]
- [kernel] sched/swait: Remove __prepare_to_swait (Phil Auld) [1737067]
- [netdrv] net: ena: don't wake up tx queue when down (John Linville) [1722628]
- [netdrv] Revert "net: ena: ethtool: add extra properties retrieval via get_priv_flags" (John Linville) [1722628]
- [netdrv] net: ena: Fix bug where ring allocation backoff stopped too late (John Linville) [1722628]
- [netdrv] net: ena: update driver version from 2.0.3 to 2.1.0 (John Linville) [1722628]
- [netdrv] net: ena: remove inline keyword from functions in *.c (John Linville) [1722628]
- [netdrv] net: ena: add ethtool function for changing io queue sizes (John Linville) [1722628]
- [netdrv] net: ena: allow queue allocation backoff when low on memory (John Linville) [1722628]
- [netdrv] net: ena: make ethtool show correct current and max queue sizes (John Linville) [1722628]
- [netdrv] net: ena: enable negotiating larger Rx ring size (John Linville) [1722628]
- [netdrv] net: ena: add MAX_QUEUES_EXT get feature admin command (John Linville) [1722628]
- [netdrv] net: ena: use dev_info_once instead of static variable (John Linville) [1722628]
- [netdrv] net: ena: add good checksum counter (John Linville) [1722628]
- [netdrv] net: ena: optimise calculations for CQ doorbell (John Linville) [1722628]
- [netdrv] net: ena: add support for changing max_header_size in LLQ mode (John Linville) [1722628]
- [netdrv] net: ena: allow automatic fallback to polling mode (John Linville) [1722628]
- [netdrv] net: ena: add newline at the end of pr_err prints (John Linville) [1722628]
- [netdrv] net: ena: arrange ena_probe() function variables in reverse christmas tree (John Linville) [1722628]
- [netdrv] net: ena: replace free_tx/rx_ids union with single free_ids field in ena_ring (John Linville) [1722628]
- [netdrv] net: ena: ethtool: add extra properties retrieval via get_priv_flags (John Linville) [1722628]
- [netdrv] net: ena: add handling of llq max tx burst size (John Linville) [1722628]
- [netdrv] net: ena: gcc 8: fix compilation warning (John Linville) [1722628]
- [netdrv] net: ena: fix ena_com_fill_hash_function() implementation (John Linville) [1722628]
- [netdrv] net: ena: improve latency by disabling adaptive interrupt moderation by default (John Linville) [1722628]
- [netdrv] net: ena: fix return value of ena_com_config_llq_info() (John Linville) [1722628]
- [netdrv] net: ena: fix incorrect test of supported hash function (John Linville) [1722628]
- [netdrv] net: ena: fix: Free napi resources when ena_up() fails (John Linville) [1722628]
- [netdrv] net: ena: fix: set freed objects to NULL to avoid failing future allocations (John Linville) [1722628]
- [netdrv] net: ena: fix swapped parameters when calling ena_com_indirect_table_fill_entry (John Linville) [1722628]
- [arm64] arm64: kexec: Add comment to explain use of __flush_icache_range() (Mark Salter) [1757450]
- [arm64] arm64: kexec: machine_kexec should call __flush_icache_range (Mark Salter) [1757450]
- [arm64] arm64: Do not issue IPIs for user executable ptes (Mark Salter) [1757450]
- [arm64] arm64: hibernate: Avoid sending cross-calling with interrupts disabled (Mark Salter) [1757450]
- [arm64] arm64: mm: Export __flush_icache_range() to modules (Mark Salter) [1757450]
- [arm64] arm64: IPI each CPU after invalidating the I-cache for kernel mappings (Mark Salter) [1757450]
- [s390] s390/dasd: Handle out-of-space constraint (Philipp Rudo) [1525398]
- [s390] s390/dasd: Use ALIGN_DOWN macro (Philipp Rudo) [1525398]
- [s390] s390/dasd: Make dasd_setup_queue() a discipline function (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add new ioctl to release space (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add dasd_sleep_on_queue_interruptible() (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add missing intensity definition (Philipp Rudo) [1525398]
- [s390] s390/dasd: Fix whitespace (Philipp Rudo) [1525398]
- [s390] s390/dasd: Add dynamic formatting support for ESE volumes (Philipp Rudo) [1525398]
- [s390] s390/dasd: Recognise data for ESE volumes (Philipp Rudo) [1525398]
- [s390] s390/dasd: Put sub-order definitions in a separate section (Philipp Rudo) [1525398]
- [s390] s390/dasd: Make layout analysis ESE compatible (Philipp Rudo) [1525398]
- [s390] s390/dasd: Remove old defines and function (Philipp Rudo) [1525398]
- [s390] s390/dasd: Remove unused structs and function prototypes (Philipp Rudo) [1525398]
- [tools] perf report: Dump s390 counter set data to file (Philipp Rudo) [1731036]
- [tools] perf report: Display arch specific diagnostic counter sets, starting with s390 (Philipp Rudo) [1731036]
- [tools] perf report: Add s390 diagnosic sampling descriptor size (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf_diag: Add support for CPU-MF SVN 6 (Philipp Rudo) [1731036]
- [s390] s390/cpumf: Fix warning from check_processor_id (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf_diag: Add support for s390 counter facility diagnostic trace (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Handle EBUSY return code from CPU counter facility reservation (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: add ctr_stcctm() function (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: move common functions into a separate file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: introduce kernel_cpumcf_avail() function (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: replace stcctm5() with the stcctm() function (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: add store cpu counter multiple instruction support (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Add minimal in-kernel interface for counter measurements (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: introduce kernel_cpumcf_alert() to obtain measurement alerts (Philipp Rudo) [1731036]
- [s390] s390/cpu_mf: move struct cpu_cf_events and per-CPU variable to header file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: rename per-CPU counter facility structure and variables (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: prepare for in-kernel counter measurements (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: move counter set controls to a new header file (Philipp Rudo) [1731036]
- [s390] s390/cpum_cf: Reject request for sampling in event initialization (Philipp Rudo) [1731036]
- [s390] s390/perf: Change CPUM_CF return code in event init function (Philipp Rudo) [1731036]
- [acpi] ACPI / property: Add two new Thunderbolt property GUIDs to the list (Jarod Wilson) [1483494]
- [acpi] ACPI: property: restore _DSD data subnodes GUID comment (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for Intel Ice Lake (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Expose active parts of NVM even if upgrade is not supported (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Hide switch attributes that are not set (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not fail adding switch if some port is not implemented (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Use 32-bit writes when writing ring producer/consumer (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Move NVM upgrade support flag to struct icm (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Correct path indices for PCIe tunnel (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Show key using *pE not *pEp (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Switch to use device_property_count_uXX() (Jarod Wilson) [1483494]
- [include] device property: Add helpers to count items in an array (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Implement CIO reset correctly for Titan Ridge (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make sure device runtime resume completes before taking domain lock (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add SPDX license identifier for more missed files (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make priority unsigned in struct tb_path (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: shash - remove shash_desc::flags (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Start firmware on Titan Ridge Apple systems (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Reword output of tb_dump_hop() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make rest of the logging to happen at debug level (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make __TB_[SW|PORT]_PRINT take const parameters (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for XDomain connections (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Make tb_switch_alloc() return ERR_PTR() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for DMA tunnels (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add XDomain UUID exchange support (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Run tb_xdp_handle_request() in system workqueue (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not tear down tunnels when driver is unloaded (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for Display Port tunnels (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Rework NFC credits handling (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Generalize port finding routines to support all port types (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Scan only valid NULL adapter ports in hotplug (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add support for full PCIe daisy chains (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Discover preboot PCIe paths the boot firmware established (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Deactivate all paths before restarting them (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Extend tunnel creation to more than 2 adjacent switches (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add helper function to iterate from one port to another (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Assign remote for both ports in case of dual link (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add functions for allocating and releasing HopIDs (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Generalize tunnel creation functionality (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Rename tunnel_pci to tunnel (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Cache adapter specific capability offset into struct port (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Properly disable path (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Set sleep bit when suspending switch (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Configure lanes when switch is initialized (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Move LC specific functionality into a separate file (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Add dummy read after port capability list walk on Light Ridge (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Enable TMU access when accessing port space on legacy devices (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Do not allocate switch if depth is greater than 6 (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Take domain lock in switch sysfs attribute callbacks (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Block reads and writes if switch is unplugged (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Drop duplicated get_switch_at_route() (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Remove unused work field in struct tb_switch (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check the return value of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: property: Fix a missing check of kzalloc (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: xdomain: Fix to check return value of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check return value of ida_simple_get (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix to check for kmemdup failure (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Fix a missing check of kmemdup (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: property: Fix a NULL pointer dereference (Jarod Wilson) [1483494]
- [thunderbolt] thunderbolt: Prevent root port runtime suspend during NVM upgrade (Jarod Wilson) [1483494]
- [netdrv] net/ibmvnic: prevent more than one thread from running in reset (Steve Best) [1756943]
- [netdrv] net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can run (Steve Best) [1756943]
- [netdrv] sfc: don't score irq moderation points for GRO (Jarod Wilson) [1736303]
- [netdrv] sfc: Use dev_get_drvdata where possible (Jarod Wilson) [1736303]
- [netdrv] sfc: Remove 'PCIE error reporting unavailable' (Jarod Wilson) [1736303]
- [netdrv] sfc: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jarod Wilson) [1736303]
- [netdrv] sfc: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1736303]
- [netdrv] bonding: no need to print a message if debugfs_create_dir() fails (Jarod Wilson) [1756517]
- [netdrv] bonding: Add vlan tx offload to hw_enc_features (Jarod Wilson) [1756517]
- [netdrv] bonding: fix value exported by Netlink for peer_notif_delay (Jarod Wilson) [1756517]
- [netdrv] bonding: add an option to specify a delay between peer notifications (Jarod Wilson) [1756517]
- [netdrv] bonding: validate ip header before check IPPROTO_IGMP (Jarod Wilson) [1756517]
- [netdrv] bonding/main: fix NULL dereference in bond_select_active_slave() (Jarod Wilson) [1756517]
- [netdrv] bonding: Always enable vlan tx offload (Jarod Wilson) [1756517]
- [netdrv] bonding/options: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/alb: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/802.3ad: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding/main: convert to using slave printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding: add slave_foo printk macros (Jarod Wilson) [1756517]
- [netdrv] bonding: fix error messages in bond_do_fail_over_mac (Jarod Wilson) [1756517]
- [netdrv] bonding: improve event debug usability (Jarod Wilson) [1756517]
- [netdrv] net: bonding: Inherit MPLS features from slave devices (Jarod Wilson) [1756517]
- [netdrv] bonding: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jarod Wilson) [1756517]
- [netdrv] bonding: Replace GPLv2 boilerplate/reference with SPDX - rule 90 (Jarod Wilson) [1756517]
- [netdrv] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 5 (Jarod Wilson) [1756517]
- [netdrv] bonding: Add SPDX license identifier - Makefile/Kconfig (Jarod Wilson) [1756517]
- [powerpc] powerpc/fadump: support holes in kernel boot memory area (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: remove RMA_START and RMA_END macros (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: update documentation about option to release opalcore (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: consider f/w load area (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: provide an option to invalidate /sys/firmware/opal/core file (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: enable CONFIG_OPAL_CORE for FADUMP (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opalcore: export /sys/firmware/opal/core for analysing opal crashes (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: update documentation about CONFIG_PRESERVE_FA_DUMP (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add support to preserve crash data on FADUMP disabled kernel (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: improve how crashed kernel's memory is reserved (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: consider reserved ranges while releasing memory (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: make crash memory ranges array allocation generic (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: process architected register state data provided by firmware (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: make use of memblock's bottom up allocation mode (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Update documentation about OPAL platform support (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: handle invalidation of crashdump and re-registraion (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Warn before processing partial crashdump (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: process the crashdump by exporting it as /proc/vmcore (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: support copying multiple kernel boot memory regions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: define OPAL register/un-register callback functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: reset metadata address during clean up (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: register kernel metadata address with opal (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: improve fadump_reserve_mem() (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add fadump support on powernv (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/opal: add MPIPL interface definitions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/powernv: Make possible for user to force a full ipl cec reboot (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: use FADump instead of fadump for how it is pronounced (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] pseries/fadump: move out platform specific support from generic code (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: release all the memory above boot memory size (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add source info while displaying region contents (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] pseries/fadump: define RTAS register/un-register callback functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: introduce callbacks for platform specific operations (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: move rtas specific definitions to platform code (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: define an empty fadump_cleanup() (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: use helper functions to reserve/release cpu notes buffer (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: Improve fadump documentation (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: declare helper functions in internal header file (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: add helper functions (Desnes Augusto Nunes do Rosario) [1524687]
- [powerpc] powerpc/fadump: move internal macros/definitions to a new header (Desnes Augusto Nunes do Rosario) [1524687]
- [watchdog] watchdog: iTCO: Add support for Cannon Lake PCH iTCO (Alexander Beregalov) [1724532]
- [i2c] i2c: i801: Use iTCO version 6 in Cannon Lake PCH and beyond (Alexander Beregalov) [1724532]
- [i2c] i2c: i801: Allow ACPI AML access I/O ports not reserved for SMBus (Alexander Beregalov) [1724532]
- [block] loop: set PF_MEMALLOC_NOIO for the worker thread (Ming Lei) [1741392]
- [fs] bdev: Fixup error handling in blkdev_get() (Ming Lei) [1741392]
- [block] loop: Fix mount(2) failure due to race with LOOP_SET_FD (Ming Lei) [1741392]
- [block] block, bfq: handle NULL return value by bfq_init_rq() (Ming Lei) [1741392]
- [block] block, bfq: move update of waker and woken list to queue freeing (Ming Lei) [1741392]
- [block] block, bfq: reset last_completed_rq_bfqq if the pointed queue is freed (Ming Lei) [1741392]
- [block] block: aoe: Fix kernel crash due to atomic sleep when exiting (Ming Lei) [1741392]
- [block] rq-qos: use a mb for got_token (Ming Lei) [1741392]
- [block] rq-qos: set ourself TASK_UNINTERRUPTIBLE after we schedule (Ming Lei) [1741392]
- [block] rq-qos: don't reset has_sleepers on spurious wakeups (Ming Lei) [1741392]
- [block] rq-qos: fix missed wake-ups in rq_qos_throttle (Ming Lei) [1741392]
- [include] wait: add wq_has_single_sleeper helper (Ming Lei) [1741392]
- [block] block, bfq: check also in-flight I/O in dispatch plugging (Ming Lei) [1741392]
- [block] block: fix sysfs module parameters directory path in comment (Ming Lei) [1741392]
- [block] block: Allow mapping of vmalloc-ed buffers (Ming Lei) [1741392]
- [block] block/bio-integrity: fix a memory leak bug (Ming Lei) [1741392]
- [block] block: Disable write plugging for zoned block devices (Ming Lei) [1741392]
- [block] blk-throttle: fix zero wait time for iops throttled group (Ming Lei) [1741392]
- [block] block: Fix potential overflow in blk_report_zones() (Ming Lei) [1741392]
- [block] blk-cgroup: turn on psi memstall stuff (Ming Lei) [1741392]
- [block] block: init flush rq ref count to 1 (Ming Lei) [1741392]
- [lib] sbitmap: Replace cmpxchg with xchg (Ming Lei) [1741392]
- [block] block: Remove unused code (Ming Lei) [1741392]
- [block] block, bfq: Init saved_wr_start_at_switch_to_srt in unlikely case (Ming Lei) [1741392]
- [block] block, bfq: re-schedule empty queues if they deserve I/O plugging (Ming Lei) [1741392]
- [block] block, bfq: preempt lower-weight or lower-priority queues (Ming Lei) [1741392]
- [block] block, bfq: detect wakers and unconditionally inject their I/O (Ming Lei) [1741392]
- [block] block, bfq: bring forward seek&think time update (Ming Lei) [1741392]
- [block] block, bfq: update base request service times when possible (Ming Lei) [1741392]
- [block] block, bfq: fix rq_in_driver check in bfq_update_inject_limit (Ming Lei) [1741392]
- [block] block, bfq: reset inject limit when think-time state changes (Ming Lei) [1741392]
- [kernel] cgroup: export css_next_descendant_pre for bfq (Ming Lei) [1741392]
- [block] block: update print_req_error() (Ming Lei) [1741392]
- [block] block: use blk_op_str() in blk-mq-debugfs.c (Ming Lei) [1741392]
- [block] block: add centralize REQ_OP_XXX to string helper (Ming Lei) [1741392]
- [block] block: improve print_req_error (Ming Lei) [1741392]
- [block] block: rename CONFIG_DEBUG_BLK_CGROUP to CONFIG_BFQ_CGROUP_DEBUG (Ming Lei) [1741392]
- [block] bfq-iosched: move bfq_stat_recursive_sum into the only caller (Ming Lei) [1741392]
- [block] blk-cgroup: move struct blkg_stat to bfq (Ming Lei) [1741392]
- [block] blk-cgroup: introduce a new struct blkg_rwstat_sample (Ming Lei) [1741392]
- [block] blk-cgroup: pass blkg_rwstat structures by reference (Ming Lei) [1741392]
- [block] blk-cgroup: factor out a helper to read rwstat counter (Ming Lei) [1741392]
- [block] block: drbd: no need to check return value of debugfs_create functions (Ming Lei) [1741392]
- [block] blk-core: Remove blk_end_request*() declarations (Ming Lei) [1741392]
- [block] block: code cleanup queue_poll_stat_show() (Ming Lei) [1741392]
- [block] block: use right format specifier for op (Ming Lei) [1741392]
- [block] block: get rid of redundant else (Ming Lei) [1741392]
- [block] block: use req_op() to maintain consistency (Ming Lei) [1741392]
- [fs] blkcg, writeback: dead memcgs shouldn't contribute to writeback ownership arbitration (Ming Lei) [1741392]
- [block] blkcg: blkcg_activate_policy() should initialize ancestors first (Ming Lei) [1741392]
- [block] blkcg: perpcu_ref init/exit should be done from blkg_alloc/free() (Ming Lei) [1741392]
- [block] blkcg: update blkcg_print_stat() to handle larger outputs (Ming Lei) [1741392]
- [block] block: bio: Use struct_size() in kmalloc() (Ming Lei) [1741392]
- [block] block: genhd: Use struct_size() helper (Ming Lei) [1741392]
- [block] block: null_blk: fix race condition for null_del_dev (Ming Lei) [1741392]
- [block] blk-mq/debugfs: Fix improper print qualifier (Ming Lei) [1741392]
- [block] loop: Don't change loop device under exclusive opener (Ming Lei) [1741392]

* Wed Oct 09 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.6.el8]
- [documentation] timekeeping.txt: Correct maxCount of n-bit binary counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: clk: Add (devm_)clk_get_optional() functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: uapi: align comments with firmware files (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: rename SOUNDWIRE to ALH (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: add ALH parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: remove SPDX "WITH Linux-syscall-note" from kernel-space headers again (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: fe_compr can be bit field (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: fixup for_each_card_links() macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Define a set of DAPM pre/post-up events (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: use bit field for bus_control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple_card_utils.h: care NULL dai at asoc_simple_debug_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: remove an unused field from struct hda_codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Avoid polluting led_* namespace (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add Hiby device family to quirks for native DSD support (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: DSD auto-detection for Playback Designs (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: remove some dead code (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix possible NULL dereference at create_yamaha_midi_quirk() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Clean up check_input_term() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Remove superfluous bLength checks (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Unify the release of usb_mixer_elem_info objects (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Simplify parse_audio_unit() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: More validations of descriptor units (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Check mixer unit bitmap yet more strictly (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix memory leak at line6_init_pcm() error path (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix invalid NULL check in snd_emuusb_set_samplerate() (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add implicit fb quirk for Behringer UFX1604 (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix a stack buffer overflow bug in check_input_term (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix an OOB bug in parse_audio_mixer_unit (Jaroslav Kysela) [1738610]
- [sound] ALSA: hiface: fix multiple memory leak bugs (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Add Pioneer DDJ-SX3 PCM quirck (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Skip bSynchAddress endpoint check if it is invalid (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix PCM device order (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Unify audioformat release code (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix gpf in snd_usb_pipe_sanity_check (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Scarlett Gen 2 mixer interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: sizeof (byte) is always 1, use that fact. (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix a typo (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix wrong altsetting for LINE6_PODHD500_1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix Line6 Helix audio format rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Fix parse of UAC2 Extension Units (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Fix write on zero-sized buffer (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: fix sign unintended sign extension on left shifts (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Sanity checks for each pipe and EP types (Jaroslav Kysela) [1738610]
- [sound] ALSA: usb-audio: Enable .product_name override for Emagic, Unitor 8. (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Use container_of() (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Drop superfluous timer helper function (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: variax: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: podhd: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: pod: Rewrite complex timer & work combo with a delayed work (Jaroslav Kysela) [1738610]
- [sound] ALSA: line6: Assure canceling delayed work at disconnection (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 33 (Jaroslav Kysela) [1738610]
- [sound] ALSA: sparc: Mark expected switch fall-throughs (Jaroslav Kysela) [1738610]
- [sound] ALSA: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ux500: mop500: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: txx9: txx9aclc-generic: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: osk5912: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap3pandora: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-twl4030: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-hdmi: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: omap-abe-twl6040: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: n810: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Fix slot mask settings when using multiple AXRs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Set unused serializers as INACTIVE (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Fix SDMA users not providing channel names (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Support for auxclk-fs-ratio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: ams-delta: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: trimslice: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm9712: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8903: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_wm8753: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5677: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: tegra_alc5632: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: pass volume min/max linear value to FW (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ignore unrecoverable CTX_SAVE IPC errors at suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Add earpiece (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun4i-codec: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: spdifrx: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: dfsdm: add 16 bits audio record support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add cpu_dai_name for DAIs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add min/max step for volume_table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sof: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: clarify operator precedence (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASOC: SOF: ipc: prevent logging trace messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add new macro hstream_to_sof_hda_stream() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: make sure RUN bit setting to 0 during clear stream status (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: fix a deadlock with bus->reg_lock (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: modify stream interrupt handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: save handle to sdev in sof_intel_hda_stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove misleading error trace from IRQ thread (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: dont wake dsp up in kcontrol IO (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Fix handling of custom_stop_condition on DAPM graph walks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: compress: Fix memory leak from snd_soc_new_compress (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: sirf-audio: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sh: sh7760-ac97: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: ssiu: tidyup SSI_MODE1/2 settings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: fixup mod ID calculation in rsnd_ctu_probe_ (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: add missing pin sharing with SSI9 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sh: migor: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tobermory: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: speyside: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: snow: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994pcm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8994: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_wm8580: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smdk_spdif: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: smartq_wm8987: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_uda134x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec_tlv320aic23: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec_hermes: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: rx1950_uda1380: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: fix a double-free issue for cpu_dai (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: fix an use-after-free issue for codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: odroid: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: lowland: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: littlemill: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: jive_wm8750: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: h1940_uda1380: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: bells: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: arndale_rt5631: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip-max98090: Remove MICBIAS as supply of input pin IN34 (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: rockchip: rockchip_max98090: Enable MICBIAS for headset keypress detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3399_gru_sound: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rk3399_gru_sound: Support 32, 44.1 and 88.2 kHz sample rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rk3288_hdmi_analog: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: pdm: select CONFIG_RATIONAL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: storm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: Fix oops with multiple DAI links (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: tosa: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: hx4700: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: kernel: fix typos and some coding style in comments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Add missing Slimbus0 audio route (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: apq8016_sbc: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: zylonite: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: z2: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: ttc-dkb: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: spitz: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: pxa2xx-ac97.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: poodle: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: palm27x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: mioa701_wm9713: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: magician: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: imote2: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: em-x270: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e800_wm9712: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e750_wm9705: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: e740_wm9705: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: corgi: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pxa: brownstone: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs: mxs-sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-toddr: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-toddr: expose all 8 inputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: tdmout: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdmout: right_j is not supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: tdmin: expose all 16 inputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdmin: right_j is not supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm: fix sample clock inversion (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm: consistently use SND_SOC_DAIFMT defines (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: require regmap mmio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: free reset on device removal (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: add reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-spdifout: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-spdifin: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-pdm: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-frddr: expose all 8 outputs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-frddr: add sm1 support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-fifo: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5676: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-rt5650-rt5514: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8173-max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt6797-mt6351: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701-wm8960: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701-cs42448: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Add missing newline at end of file (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood: armada-370-db: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: jz4740: qi_lb60: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 239 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Fix incorrect capture position reporting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Fix NULL ptr dereference when unloading clk dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Don't return failure on machine driver reload (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Do not disable FW notifications (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof_rt5682: use GFP_KERNEL instead of GFP_ATOMIC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: correct naming for dmic16k (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof_rt5682: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for Irbis NB41 netbook (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt-da7219-max98357a: add BE dailink for dmic16k (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add MCLK support for BYT platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_rt286: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_ssm4567: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_nau88l25_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_common: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_rt5514_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5663_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: kbl_da7219_max98927: add dai_trigger function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: haswell: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_nocodec: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_cx2072x: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: byt-rt5640: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: byt-max98090: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt_rt298: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: broadwell: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix use-after-free in graph_for_each_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: add missing const at graph_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: phycore-ac97: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card-utils: care no Platform for DPCM (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix use-after-free in graph_dai_link_of_dpcm() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph-card: fix an use-after-free in graph_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: wm1133-ev1: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: pcm030-audio-fabric: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: mx27vis-aic32x4: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-spdif: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-sgtl5000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-mc13783: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-es8328: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: imx-audmix: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: mpc8610_hpcd/p1022_ds/p1022_rdk: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: fsl-asoc-card: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: eukrea-tlv320: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl: efika-audio-fabric: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm_adsp: Allow bus error handler to be called directly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm_adsp: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: remove multiple defines. (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: add irqflag IRQF_ONESHOT flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: Fix misuse of GENMASK macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tas571x: Fix -Wunused-const-variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix charge pump source assignment (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix of unmute outputs on probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: add ADC mute control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Improve VAG power and mute control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sgtl5000: Fix definition of VAG Ramp Control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5682: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677-spi: Rename driver to differentiate from main codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5665: remove redundant assignment to variable idx (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5514-spi: don't use snd_soc_lookup_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: simplify the EFUSE read function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Remove executable attribute from source files (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: add silence detection and manual PDB control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Convert headers to SPDX (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: fix DC calibration offset not applying (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Relocate my e-mail to .com domain zone (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nau8825: fix fake interruption when booting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nau8822: support master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: soc: codecs: mt6358: change return type of mt6358_codec_init_reg (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Add sidetone support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98383: fix i2c probe failure (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 496 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hdmi: report codec link up/down status to bus (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec: hdac_hdmi: fix pin connections at cvt enable (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 463 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: mark PM function as __maybe_unused (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: use mdelay for sdmode-delay (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: avoid speaker pop when playback startup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Fix MFREQ selection issue for async mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cros_ec_codec: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4118: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: spi: AD ASoC: declare missing of table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ab8500: add range to usleep_range (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: snappercl15: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: simone: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: ep93xx-i2s.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cirrus: edb93xx: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: bcm: cygnus-pcm: Unneeded variable: "ret". (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: psc-i2s.c: use devm_snd_soc_register_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: db1200: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: db1000: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: tse850-pcm5142: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9x5_wm8731: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: sam9g20_wm8731: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: mikroe-proto: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-wm8904: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-pdmic: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-pcm-dma.c: use devm_snd_dmaengine_pcm_register() (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 234 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: atmel-classd: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp-rt5645: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp-da7219-max98357a: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 200 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ps3: Remove Unneeded variable: "ret" (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 277 (Jaroslav Kysela) [1738610]
- [sound] ALSA: rme9652: Unneeded variable: "result". (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 274 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdspm: Fix single speed ADAT capture and playback with RME HDSPe AIO (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 264 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 404 (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es - Remove set but not used variables 'orun_mask, urun_mask' (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es: Remove unneeded variable err (Jaroslav Kysela) [1738610]
- [sound] ALSA: lx6464es - add support for LX6464ESe pci express variant (Jaroslav Kysela) [1738610]
- [sound] ALSA: ice1712: Check correct return value to snd_i2c_sendbytes (EWS/DMX 6Fire) (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 29 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 46 (Jaroslav Kysela) [1738610]
- [sound] ALSA: emu10k1: Remove unneeded variable "change" (Jaroslav Kysela) [1738610]
- [sound] ALSA: echoaudio: Replace kmalloc + memcpy with kmemdup (Jaroslav Kysela) [1738610]
- [sound] ALSA: pci: echoaudio: remove variable which is a constant (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 364 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 118 (Jaroslav Kysela) [1738610]
- [sound] ALSA: cs4281: remove redundant assignment to variable val and remove a goto (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 32 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 116 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 456 (Jaroslav Kysela) [1738610]
- [sound] ALSA: au88x0: Remove unneeded variable: "changed" (Jaroslav Kysela) [1738610]
- [sound] ALSA: asihpi: Remove unneeded variable change (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 88 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ac97: remove unused variable 'snd_ac97_controls_master_mono' (Jaroslav Kysela) [1738610]
- [sound] ALSA: dmasound_atari: Mark expected switch fall-through (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 176 (Jaroslav Kysela) [1738610]
- [sound] ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference in build_adc_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: isa/wavefront: remove redundant assignment to pointer bptr (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 370 (Jaroslav Kysela) [1738610]
- [sound] ALSA: sb: remove redundant assignment to variable result (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: hda: Add codec on bus address table lately" (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Unexport a few more stuff (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Drop export of snd_hdac_bus_add/remove_device() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add codec on bus address table lately (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: readl/writel need linux/io.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: intel-nhlt: handle NHLT VENDOR_DEFINED DMIC geometry (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: move parts of NHLT code to new module (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix 1-minute detection delay when i915 module is not available (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix a headphone detection issue when using SOF (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: fix: lock reg_lock before calling snd_hdac_bus_update_rirb (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: add polling mode in snd_hdac_bus_get_response (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sdm845: remove unneeded semicolon (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dmaengine: Replace strncpy() with strscpy_pad() for pcm->name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: remove redundant use of ret variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: Add an op to set callback function for plug event (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_unbind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_unbind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_bind_aux_dev() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_link_dais() next to soc_remove_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_probe_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add new soc_link_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_dai() next to soc_remove_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_remove_link_dais() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_remove_link_components() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: self contained soc_probe_link_components() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1305: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: make array pd static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: simple-card-utils: set 0Hz to sysclk when shutdown (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: ignore 0Hz sysclk (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: make two arrays static const, makes object smaller (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Use regmap_multi_reg_write() when initializing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Reset used registers at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Group register initialization at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: ad193x: Fix memory corruption on BE 64b systems (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: support fixed and variable both clock rates (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix redundant codes of clock (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: add DT-bindings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dmaengine: Make the pcm->name equal to pcm->id if the name is not set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix COMPILE_TEST error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Include link-name in error messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: consider CPU-Platform possibility (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: don't select unnecessary Platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Fix NULL pointer in of parser (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: Mark links as nonatomic (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qcom: common: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add comment to jack at soc_remove_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf-audio: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ep93xx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: add clock control of MCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: audio-graph: indicate rebind issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: indicate rebind issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: fix an use-after-free in simple_for_each_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: fix an use-after-free in simple_dai_link_of_dpcm() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for cpu (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_link_components() position (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add snd_soc_dapm_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: dapm related setup at one place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_probe_component() position (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_rtd_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix space issues (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove forward declaration of headset_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move headset jack to card-specific storage (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move private structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF/Intel: fix selection of SND_INTEL_NHTL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: broadwell: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: haswell: Simplify device probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Haswell: Adjust machine device private context (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-evm: Do not fail if the dai_set_sysclk returns -ENOTSUPP (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: edma-pcm: Fix for legacy dma_slave_map based channel lookup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-i2s: Add S32_LE as support format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-i2s: Move the XSYNCERR workaround to .prepare callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Baytrail: Fix implicit fallthrough warning (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_ssi: Fix clock control issue in master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wcd9335: Fix primary interpolator max rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix tdm out data is valid on rising edge (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: tdm hw support tdm out and 8ch i2s out (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel_ssc_dai: implement left-justified data mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel_ssc_dai: rework DAI format configuration (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: atmel: enable SOC_SSC_PDC and SOC_SSC_DMA in Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Force suspend/resume during system suspend/resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: fix tdm out data align issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: add mutex protection to set_fmt/set_tdm_slot (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix inverted L/R of headphone mixer volume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8316: fix headphone mixer volume table (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Release topology when we are done with it (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove memory available check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove MCPS available check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Remove static table index when parsing topology (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Print module type instead of id (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: NHLT: Fix debug print format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Expose snd_soc_dapm_new_control_unlocked properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: fix memory leaks on sm, se and sbe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: Consolidate and fix asoc_tplg_dapm_widget_*_create flow (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: topology: Consolidate how dtexts and dvalues are freed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: fix modern dai link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use correct function to access iomem space (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix an is IS_ERR() vs NULL check (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i: Revert A83t description (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Fix return value check in imx8_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove unused DAPM-related variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: Revert initial A83t support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmix: register the card on a proper dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx8: Make some functions static (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: rename soc_post_component_init() to soc_rtd_init() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: initialize list at one place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: fix get control data return type and arguments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: initialize component list (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-topology: use for_each_component_dais() at remove_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_cleanup_card_resources() become void (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add NOTE to snd_soc_rtdcom_lookup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use device_register() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: switch tdm pins gpio function when playback on or off (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt2701: Fix -Wunused-const-variable warnings (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8988: fix typo in wm8988_right_line_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: imx: Add i.MX8 HW support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add OF DSP device support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: AMD: Fix Kconfig warning without GPIOLIB (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add support for DSP formats (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Replace call to params_width by local variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use the actual format width instead of an hardcoded one (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use the physical / slot width for the clocks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add support for TDM slots (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove unneeded dai_link check from snd_soc_remove_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: merge snd_soc_initialize_card_lists() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for imx8qm (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Fix simultaneous capture and playback in master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is running (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Support more channels (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Pass the channels number as an argument (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Remove duplicated quirks structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the LRCK period on A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix MCLK Enable bit offset on A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix WSS and SR fields for the A83t (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the LRCK polarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix LRCK and BCLK polarity offsets on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: RX and TX counter registers are swapped (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix the MCLK and BCLK dividers on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Use module clock as BCLK parent on newer SoCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Move the format configuration to a callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Move the channel configuration to a callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Rework MCLK divider calculation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Replace call to params_channels by local variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Switch to devm for PCM register (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Register regmap and PCM before our component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8904: implement input mode select as a mux (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8904: fix typo in DAPM kcontrol name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add all Chromebooks that need pmc_plt_clk_0 quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: Fix double reset assersion when transitioning to suspend state (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: initial support for Intel ALH DAI type (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: Add dummy support for i.MX8 DAIs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmux: Add driver suspend and resume to support MEGA Fast (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for EHL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for Tiger Lake (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Add Cometlake machine driver support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Move pcm_mutex up to card level from snd_soc_pcm_runtime (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: 88pm860x: remove unused variables 'pcm_switch_controls' and 'aif1_mux' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42l56: remove unused variable 'adc_swap_enum' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8328: remove unused variable 'pga_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic31xx: remove unused variable 'cm_m_enum' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic23: remove unused variable 'tlv320aic23_rec_src' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: remove unused variable 'dac_vol_tlv' and 'adc_vol_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98371: remove unused variable 'max98371_noload_gain_tlv' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42l73: remove unused variables 'vsp_output_mux' and 'xsp_output_mux' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Print constant literals from format specifier (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt6358: add delay after dmic clock on (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: remove unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: remove unused variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt2701: remove unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: Fix -Wunused-const-variable warning (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs4349: Use PM ops 'cs4349_runtime_pm' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: es8328: Fix copy-paste error in es8328_right_line_controls (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: hsw: remove i386 build warning w/ size_t argument (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Fix typos in ti/Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: Set period size to 240 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Allow reconfiguration of tdm_slots and slot_width (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Retain the independence of DAC and ADC side of the codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: make headset codec optional (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max9850: remove unused variable 'max9850_reg' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98926: remove two unused variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove legacy style of aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: rx51: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun4i-codec: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: speyside: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: rockchip_max98090: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183-da7219-max98357: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: support snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hdmi: Offload dapm update at jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: byt: Refactor fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: bdw: Use generic function for fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Remove call to snd_sof_dsp_mailbox_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ml26124: remove unused variable 'ngth' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt6351: remove unused variable 'mt_lineout_control' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: intel: skl_hda_dsp_common: create HDMI jack kctl (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tscs454: remove unused variable 'PLL_48K_RATE' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: fix module_put() warning in soc_cleanup_component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: dai_link check under soc_dpcm_debugfs_add() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: define soc_dpcm_debugfs_add() for non CONFIG_DEBUG_FS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for card->deferred_resume_work (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove unneeded list_empty() check for snd_soc_try_rebind_card() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: call snd_soc_dapm_debugfs_init() at soc_init_card_debugfs() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_add_card_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_dapm_add_routes() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_add_component_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdac_hda: fix page fault issue by removing race (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Direct MMIO accesses (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for imx7ulp/imx8mq (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: mark regmap as fast_io (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: large_config_get overhaul (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Implement set_bclk_ratio (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add support for SAI new version (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: derive TX FIFO watermark from FIFO depth (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: add of_match data (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Update Tx/Rx channel enable mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Add registers definition for multiple datalines (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup for snd_soc_dapm_new_controls() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: reuse rtdcom at snd_soc_rtdcom_add() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use for_each_card_links_safe() at snd_soc_find_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: check return value of snd_soc_add_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add comment for for_each_xxx (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: set component->debugfs_root NULL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add a flag for the R0 calibration test (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add R0 temperature and TDM1 ADC2DAT Swap control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: don't call clk_get_rate() under atomic context (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98373: Remove executable bits (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pcm_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pcm_new() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_mmap() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_page() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_copy_user() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_ioctrl() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_pcm_component_pointer() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_set_bias_level() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_stream_event() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: move snd_soc_component_seq_notifier() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_of_xlate_dai_name() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_of_xlate_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_remove() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_is_suspended() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_suspend() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_hw_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_hw_params() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_prepare() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_close() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_open() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-component: add snd_soc_component_get/put() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: add soc-component.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_fill_silence() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_rtdcom_copy_kernel() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: remove soc_rtdcom_ack() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp3x: use dma address for acp3x dma driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: acp3x: use dma_ops of parent device for acp3x dma driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: zx-tdm: remove redundant assignment to ts_width on error return path (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: SoC: skylake: no need to check return value of debugfs_create functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: fill some of the runtime stream parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: remove ephemeral variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: create pcm for codec2codec links as well (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: use common NHLT module (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Merge skl_sst and skl into skl_dev struct (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Limit large_config_get to single frame (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix use of potentially uninitialized variable (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Update request-reply IPC model (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Common: Fix NULL dereference in tx_wait_done (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 174 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix race condition in IPC rx list (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 490 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Read HIPCT extension before clearing DONE bit (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: move NHLT header to common directory (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: au1x: psc-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: psc-ac97: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: aio-dma: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: uniphier: evea: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: inno_rk3036: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: jz4740: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mmp-sspa: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: jz4725b: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: msm8916-wcd: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: sai: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun8i-codec: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun8i-codec-analog: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: xlnx: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs4271: Fix a typo in the CS4171_NR_RATIOS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: Mark expected switch fall-throughs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: xtfpga-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: kirkwood-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: spear: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mxs-saif: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sirf: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: bcm2835-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_audmix: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: imx-audmux: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt6797: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mt8173: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ep93xx-i2s: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tegra20_das: use devm_platform_ioremap_resource() to simplify code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: g12a-tohdmitx: override codec2codec params (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98373: add 88200 and 96000 sampling rate support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Incorrect SR and WSS computation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: fix missing return of error return code (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Support for correct symmetric sample bits (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Correct slot_width posed constraint (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rockchip: Fix mono capture (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Fix some acpi vs apci typo in somme comments (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Fix clk PDIR handling for i2s master mode (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: deal with params when necessary (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: name link using stream direction (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codec2codec: run callbacks in order (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: codecs: Add uda1334 codec driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1308: Add RT1308 amplifier driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Makefile - fix the top-level kernel module names (add snd- prefix) (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Improve serializer handling in multi AXR setups (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for RIGHT_J format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Cleanup skl_module_cfg declaration (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Make MCPS and CPS params obsolete (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Combine snd_soc_skl_ipc and snd_soc_skl (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Reset pipeline before its deletion (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Strip T and L from TLV IPCs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Properly cleanup on component removal (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Initialize lists before access so they are safe to use (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Add function to cleanup debugfs interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use recommended SDxFMT programming sequence (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Switch to modern UUID API (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-pcm: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: wm8955: Fix a typo in 'wm8995_pll_factors()' function name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Fail card instantiation if DAI format setup fails (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: move snd_soc_dai_stream_valid() to soc-dai.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use existing snd_soc_dai_digital_mute() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_compress_new() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_remove() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_probe() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_suspend() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_delay() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_bespoke_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_trigger() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_prepare() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_shutdown() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_startup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: add snd_soc_dai_hw_free() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dai: mv soc_dai_hw_params() to soc-dai (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: add soc-dai.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Return -ENOTSUPP from set_channel_map() if no operation provided (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: support dai_link with platforms_num != 1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: defer card registration if codec component is missing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use soc_find_component() at snd_soc_find_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use soc_find_component() at snd_soc_find_dai() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_find_component() uses snd_soc_dai_link_component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: soc_find_component() uses snd_soc_is_matching_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: move soc_find_component() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: call snd_soc_unbind_card() under mutex_lock; (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: allow no Platform on dai_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: remove legacy style dai_link (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc.h: add sound dai_link connection macro (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: Support hw_free() callback at DAI level (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5665: Fix a typo in the name of a function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Remove dev_err() usage after platform_get_irq() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: recover the channel swap after xrun (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Wrap some operations to be functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Add pm runtime function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ssp: BCLK delay parameter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add DMIC token for unmute gain ramp time (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix stream id setting (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix link DMA config (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reset link DMA state in prepare (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reserve host DMA channel for hostless streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: assign link DMA channel at run-time (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: initial support for Elkhart Lake (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: initial support for Tiger Lake. (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Use generic function for fw ready / mem windows creation (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: make sure DMA is start/stop by read the RUN bit (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix HDA direct MMIO access (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove duplicated clear WAKESTS (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: clear stream status and wakests properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add function for hda stop chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: set position buffer in init chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: correct ROM state mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_window_offset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_mailbox_offset (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add runtime idle callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: docs: timers: convert docs to ReST and rename to *.rst (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use SOF defined init chip in resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Enable jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: reduce ifdef usage for hda (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: remove unused state variable in suspend function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: implement runtime idle for CNL/APL (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the defined stop chip in suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the SOF defined ppcap functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: release link DMA for paused streams during suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: loader: Don't ignore SRAM block types (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: loader: Use the BAR provided by FW (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Introduce snd_sof_dsp_get_bar_index ops (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: increase default IPC timeouts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: use timeout configured at probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: add ALH support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: use common code to send PCM_FREE IPC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: reset DMA state in prepare (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: couple host and link DMA during FE hw_free (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pci: mark last_busy value at runtime PM init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fixup HDaudio topology name with DMIC number (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: Add missing include file hdac_hda.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: Initialize hdaudio bus properly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix MSI handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Initialize HDA controller after i915 init (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: add a parameter to disable MSI (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: remove duplicated include from hda.c (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: disallow building without CONFIG_PCI again (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: intel: extend IPC dump information (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Allow all channels in case of parallel DIN/DOUT setup (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Fix a typo in the name of a constant (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Add support for multi DIN/DOUT with TDM slots parameter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Rename min_frame_size to slot_width (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: add dmic dapm widget and route (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: skl-hda-dsp-generic: add dependency to dmic driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Match Product Family instead of product (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Invalidate only paths reachable for a given stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: use set_get_data in process load (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_esai: Add compatible string for imx6ull (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: keep analog power register at SND_SOC_BIAS_OFF (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Remove magic number register writes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Revert remove superfluous set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: remove superfluous set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: depop stereo dac (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: handle concurrent interrupts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: clear interrupts by polarity flip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: move jack-detect init to i2c probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: fall back to DT prop names on error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Add component driver name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: use more of the volume range from DACs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: remove w90x900/nuc900 platform drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: nuc900: nuc900-audio: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add dmic dapm widget to support dmic PCM (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add for_each_xxx macro for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: use snd_soc_dai_link_component for aux_dev (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: remove useless check on codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: fix null pointer dereference in clean up (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: use modern dai_link style (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sst: fix kmalloc call with wrong flags (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Fix deadlock in snd_soc_instantiate_card() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Remove erroneous soc_cleanup_card_resources() call (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use snd_soc_dai_link_component for CPU (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: move DAI pre-links initiation to snd_soc_instantiate_card (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: fix warning reported by kbuild test robot and minor issue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Mark format integer literals as unsigned (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: Tell codec that jack is being removed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Change SR and WSS computation (Jaroslav Kysela) [1738610]
- [sound] ALSA: SoC: rt274: Fix internal jack assignment in set_jack callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090: fix kernel oops with platform_name override (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 441 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 422 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 395 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 340 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 288 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 284 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Add offset to RX channel select (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-i2s: Fix sun8i tx channel offset mask (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98090: remove 24-bit format support if RJ is 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: da7219: Fix build error without CONFIG_I2C (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Fix COMPILE_TEST build error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: pcm3168a: Implement set_tdm_slot callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: Make some symbols static (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: remove set but not used variable 'is_right_j ' (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt1011: Add RT1011 amplifier driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: debug: add new debugfs entries for IPC flood test (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: Introduce SOF_IPC_GLB_TEST_MSG IPC command (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: uapi: mirror firmware changes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: send time stamp to FW for alignment (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: bump to ABI 3.6 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: soundwire: add initial soundwire support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: add support for mux/demux component (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix DSP oops definitions in FW ABI (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ipc: don't check for HIPCCTL register value (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: re-enable IPC IRQ at end of handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: read all IPC registers first (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: re-enable IPC IRQ at end of handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: move code around for clarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: cnl-ipc: read all IPC registers first (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Do not send cmd via SHIM register (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add mode parameter for snd_sof_debugfs_buf_item (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ASoC: core: use component driver name as component name" (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: sai: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: replace fw ready bitfield with explicit bit ordering (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Baytrail: add quirk for Aegex 10 (RU2) tablet (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: fix typos of SPDX-License-Identifier (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 201 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 194 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 177 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 162 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 149 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: use the defined ppcap functions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: add COMPILE_TEST for PCI options (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: Add COMPILE_TEST for new machine drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: remove dependency on asm/platform_sst_audio.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoc: fix sound/soc/intel/skylake/slk-ssp-clk.c build error on IA64 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: use common helpers to detect CPUs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677: Add missing voice activation register definitions (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: use component driver name as component name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Fix build error with CONFIG_GPIOLIB is not set (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix undefined references with Baytrail-only support (Jaroslav Kysela) [1738610]
- [sound] ALSA: wcd9335: fix a incorrect use of kstrndup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-codec: fix first delay on Speaker (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Add support for H6 SoC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Add TX fifo bit flush quirks (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: sun4i-spdif: Move quirks to the top (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: fix spelling mistake "configued" -> "configured" (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: fix integer overflow on unsigned int multiply (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: force end-of-file for debugfs trace at suspend (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: trace: remove code duplication in sof_wait_trace_avail() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Use struct_size() in kmemdup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: Show KConfig entry (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: topology: Use struct_size() helper (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cx2072x: remove redundant assignment to pulse_len (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: fix the hda init chip (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: ipc: fix a race, leading to IPC timeouts (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: control: correct the copy size for bytes kcontrol put (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: remove warning - initialize workqueue on open (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: clear hw_params_upon_resume flag correctly (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: fix error handling with the probe workqueue (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: remove snd_soc_unregister_component in case of error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: core: remove DSP after unregistering machine driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: fixup references at soc_cleanup_card_resources() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Force polling mode on CFL and CNL (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 119 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 64 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: core: lock client_mutex while removing link components (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: Restore original configuration of DAI format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: qdsp6: q6core: Use struct_size() in kmemdup() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Use struct_size() helper (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: Use struct_size() in krealloc() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: boards: remove unnecessary inclusion of skl.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: move card registration to the end of probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: mediatek: mt8183: remove unused DAPM pins (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: enable dev runtime suspend and resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Add machine driver for CX2072X on BYT/CHT platforms (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Add support for Conexant CX2072X CODEC (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: Unify the supported input and output rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: fixup try_module_get()/module_put() timing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: add newline for clarity (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: fix compile error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: fix compile error (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix AMP quirk support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: sof-rt5682: fix for codec button mapping (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 4 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 3 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 1 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: simple-card: Fix configuration of DAI format (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: WARN() is not related to component->driver->probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rsnd: move pcm_new from snd_soc_component_driver to snd_soc_dai_driver (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: Remap button control-function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: enable IIR filter (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rename functions that pollute the simple_xxx namespace (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: soc-acpi: Fix machine selection order (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: rt5677-spi: Handle over reading when flipping bytes (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-dpm: fixup DAI active unbalance (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: tlv320aic3x: Add support for high power analog output (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Add reset gpio handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: cs42xx8: Add regcache mask dirty (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: replace the process_option table with function (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_asrc: Fix the issue about unsupported rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: add g12a tohdmitx control (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: add basic codec-to-codec link support (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: dapm: allow muxes to force a disconnect (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: meson: axg-card: set link name based on link node name (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: MT8183: set data align (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Mediatek: add memory interface data align (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4458: rstn_control - return a non-zero on error only (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: re-introduce mutex locking (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: add soc_pcm_components_open() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: add missing cpu_dai->rate = 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: do cpu_dai related operation at same place (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use soc_find_component() at snd_soc_get_dai_id() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: add soc_component_to_node() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: tidyup soc_bind_dai_link() comment balance (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: don't use codec_dais on soc_bind_dai_link() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-core: use i on snd_soc_resume() (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: max98357a: request GPIO when device get probed (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ICL add Icelake chip info struct (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: ICL: add Icelake SSP count (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: pcm: remove runtime PM calls during pcm open/close (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: Intel: Skylake: Add Cometlake PCI IDs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Add Comet Lake PCI IDs (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: amd: Reporting accurate hw_ptr for acp3x dma (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-pcm: BE dai needs prepare when pause release after resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: ak4458: add return value for ak4458_probe (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC : cs4265 : readable register too low (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix error in verbose ipc command parsing (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: fix race in FW boot timeout handling (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: nocodec: fix undefined reference (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: soc-acpi: fix implicit header use of module.h/export.h (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: fsl_sai: Move clock operation to PM runtime (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: stm32: i2s: manage identification registers (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove ops dependency on the dai id (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove reference to the dai drivers in the private data (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove reference to the current substream (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hdmi-codec: remove function name debug traces (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 282 (Jaroslav Kysela) [1738610]
- [sound] ALSA: xen-front: fix unintention integer overflow on left shifts (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - PCI quirk for Medion E4254 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Apply AMD controller workaround for Raven platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix alienware headset mic (Jaroslav Kysela) [1738610]
- [sound] ALSA: Add Acer Aspire Ethos 8951G model quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi: remove redundant assignment to variable pcm_idx (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix the problem of two front mics on a ThinkCentre (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Enable internal speaker & headset mic of ASUS UX431FL (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add quirk for HP Pavilion 15 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix overridden device-specific initialization (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix potential endless loop at applying quirks (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Allow runtime PM for controller if component notifier is used (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre M73/93 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Check beep whitelist before assigning in all codecs (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132 - Add new SBZ quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fixes inverted Conexant GPIO mic mute led (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Define a fallback_pin_fixup_tbl for alc269 family (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Expand pin_match function to match upcoming new tbls (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Drop unsol event handler for Intel HDMI codecs (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a generic reboot_notify (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Let all conexant codec enter D3 when rebooting (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/sigmatel - remove unused variable 'stac9200_core_init' (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add quirk for HP Envy x360 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Set fifo_size for both playback and capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a quirk model for fixing Huawei Matebook X right speaker (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Add model description for Chrome headset button quirk (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fix a typo in model documentation (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Inform too slow responses (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Apply workaround for another AMD chip 1022:1487 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Remove page allocation redirection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Workaround for crackled sound on AMD controller (1022:1457) (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Don't override global PCM hw info flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add support of Zhaoxin controller (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/intel: stop probe if DMICS are detected on Skylake+ platforms (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Show the fatal CORB/RIRB error more clearly (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Add a conexant codec entry to let mute led work (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Fix intermittent CORB/RIRB stall on Intel chips (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: SOF: Intel: hda: Make hdac_device device-managed (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Flush interrupts on disabling (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Allow audio component for AMD/ATI and Nvidia HDMI (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Don't report spurious jack state changes (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Optimize resume for codecs without jack detection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Don't resume forcibly i915 HDMI/DP codec (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Fix i915 reverse port/pin mapping (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/hdmi - Remove duplicated define (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek: apply ALC891 headset fixup to one Dell machine (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Fixed Headphone Mic can't record on Dell platform (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Simplify snd_hdac_refresh_widgets() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Fix widget_mutex incomplete protection (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132 - remove redundant assignment to variable 'changed' (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Change front mic location for Lenovo M710q (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek: Add quirks for several Clevo notebook barebones (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: hda/realtek - Improve the headset mic for Acer Aspire laptops" (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Add Elkhart Lake PCI ID (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: fix a mask for unsolicited event tags (Jaroslav Kysela) [1738610]
- [sound] ALSA: ASoC: hda: fix unbalanced codec dev refcount for HDA_DEV_ASOC (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/ca0132: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Update headset mode for ALC256 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: move polling_mode flag to struct hdac_bus (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda: assign polling_mode after azx_bus_init (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Improve the headset mic for Acer Aspire laptops (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda - Force polling mode on CNL for fixing codec communication (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Enable micmute LED for Huawei laptops (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Set default power save node to 0 (Jaroslav Kysela) [1738610]
- [sound] ALSA: hda/realtek - Check headset type by unplug and resume (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdac: Fix codec name after machine driver is unloaded and reloaded (Jaroslav Kysela) [1738610]
- [sound] ALSA: hdac: fix memory release for SST and SOF drivers (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 371 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier for missed files (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier for more missed files (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 130 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 336 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 157 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 13 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 285 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 295 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 273 (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix wrong packet parameter for Alesis iO26 (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: check intermediate state of clock status and retry (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: handle error code when getting current source of clock (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: remove WARN_ON() at destruction of AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: add note for FE-8 (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: add support for MOTU 4pre (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix isoc cycle count to which rx packet is scheduled (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix error path for initialization of stream structures (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix to handle correct stream for PCM playback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix NULL pointer dereference to unused stream structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire: fix a memory leak bug (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: localize kernel APIs to start/stop each AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: support AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for initialization/destruction of AMDTP stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for bus reset handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for initialization/destruction of AMDTP streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to start AMDTP streams in AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to add AMDTP stream into AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add a kernel API to stop a couple of AMDTP streams in AMDTP domain (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add AMDTP domain structure to handle several isoc contexts (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: more code refactoring for MOTU data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: process payload of isoc context according to packet descriptors (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for FF data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for MOTU data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for TASCAM data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for DOT data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for AM824 data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass packet descriptor to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to process context payloads (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to process PCM substream (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use packet descriptor for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use packet descriptor for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add list of packet descriptor (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass no syt information to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add syt_override member for some protocols (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: operate data block counter in top level of processing for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: operate data block counter in top level of processing for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass data block counter to data block processing layer (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: pass data block count as an argument to tracepoints event (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: obsolete ctx_data.tx.first_dbc with CIP_UNALIGHED_DBC flag (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for local variables (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for post operation to data block counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring for error path of parser for CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix different data block counter between probed event and transferred isochronous packet (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix initial value of data block count for IR context without CIP_DBC_IS_END_EVENT (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib/fireface: fix initial value of data block counter for IR context with CIP_NO_HEADER (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix invalid length of rx packet payload for tracepoint events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: fix wrong reference count for stream functionality at error path of rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib/fireworks: fix miss detection of received MIDI messages (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix to process MIDI conformant data channel for AM824 format (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: cache next data_block_counter after probing tracepoints event for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify common tracepoints for both direction (Jaroslav Kysela) [1738610]
- [sound] ALSA: Revert "ALSA: firewire-lib: fix inverted node IDs for amdtp_packet events" (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: ensure to release isochronous resources in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: unify stop and release method for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: minor code refactoring to stop isochronous context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: rename helper functions to begin/finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: code refactoring for condition to stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: add helper function to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify midi callback function (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: unify the count of subscriber for packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split allocation of isochronous resources from establishment of connection (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: change the range of critical section for stream data in PCM.hw_free callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring for error path to start duplex stream (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: change the range of critical section for stream data in PCM.hw_free callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring for callback function to rawmidi interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code rafactoring for callback functions to PCM interface (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: fix compiler warning due to returning uninitialized value (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: configure stream parameter in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: configure packet format in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: unify substreams counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: rename helper functions for duplex streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: expand stop procedure for packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: break packet streaming at bus-reset handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: start duplex streams if supported (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: set packet parameter according to current configuration (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: code refactoring for stop condition of packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: don't set XRUN in stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: configure stream parameters in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: configure sampling transfer frequency in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for pcm.hw_params/hw_free (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: code refactoring for rawmidi.open/close (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireworks: unify substream counter (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: code refactoring to initialize/destroy stream data (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: obsolete useless member of private structure (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: don't set XRUN in stop streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: bebob: configure sampling transfer frequency in pcm.hw_params callback (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: code refactoring to stop packet streaming (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring to keep isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: simplify error path to begin streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-digi00x: refactoring to move timing of registration for isochronous channel (Jaroslav Kysela) [1738610]
- [sound] ALSA: oxfw: allow PCM capture for Stanton SCS.1m (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: minor code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: update isochronous resources when starting packet streaming after bus-reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in latter protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in ff400 protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: support allocate_resources operation in ff800 protocol (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: add protocol-specific operation to allocate isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: minor code refactoring to finish streaming session (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: update isochronous resources when starting packet streaming after bus reset (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: reserve/release isochronous resources in pcm.hw_params/hw_free callbacks (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for release of isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for reservation of isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-tascam: code refactoring for registration of isochronous channels (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-motu: fix destruction of data for isochronous resources (Jaroslav Kysela) [1738610]
- [sound] ALSA: fireface: Use ULL suffixes for 64-bit constants (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: refactoring to obsolete IR packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: refactoring to obsolete IT packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix inverted node IDs for amdtp_packet events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: fix data block counter for incoming packet without CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use 8 byte packet header for IT context to separate CIP header from CIP payload (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: code refactoring to queueing packets (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify packet handler for IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split helper function to generate CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify packet handler for IR context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use 16 bytes IR context header to separate CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: split helper function to check incoming CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: compute pointer to payload buffer in context handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: calculate the length of packet payload in packet handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use clear name for variable of CIP header (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use IT context header to compute cycle count for scheduling packet (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: obsolete macro for header of IT context (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add helper function to cancel context inner callback handler (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use union for directional parameters (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: unify tracing events to 'amdtp_packet' event (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use dynamic array for CIP header of tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use the same unit for payload argument in tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: add data_blocks/data_block_counter parameter to in_packet/out_packet tracing events (Jaroslav Kysela) [1738610]
- [sound] ALSA: firewire-lib: use the same type of argument for CIP header for tracing event (Jaroslav Kysela) [1738610]
- [sound] ALSA: dice: add stream format parameters for PreSonus FireStudio (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 61 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 102 (Jaroslav Kysela) [1738610]
- [sound] ALSA: aoa: onyx: always initialize register read value (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 250 (Jaroslav Kysela) [1738610]
- [sound] ALSA: ac97: Fix double free of ac97_codec_device (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Add SPDX license identifier - Makefile/Kconfig (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: add support for 352.8KHz and 384KHz sample rate (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: Fix potential concurrent access to the deleted pool (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: fix lost wakeup event scenarios in snd_pcm_drain (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Be more restrictive about when a drain is allowed (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Don't allow paritial drain operations on capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Prevent bypasses of set_params (Jaroslav Kysela) [1738610]
- [sound] ALSA: compress: Fix regression on compressed capture streams (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: Fix refcount_inc() on zero usage (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: Break too long mutex context in the write loop (Jaroslav Kysela) [1738610]
- [sound] ALSA: seq: fix incorrect order of dest_client/dest_ports arguments (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 372 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 345 (Jaroslav Kysela) [1738610]
- [sound] ALSA: control: Use struct_size() (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 167 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 156 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 152 (Jaroslav Kysela) [1738610]
- [sound] ALSA: treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 151 (Jaroslav Kysela) [1738610]
- [sound] ALSA: pcm: oss: Use struct_size() helper (Jaroslav Kysela) [1738610]

* Tue Oct 08 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.5.el8]
- [tools] selftests/powerpc: Retry on host facility unavailable (Desnes Augusto Nunes do Rosario) [1739770]
- [tools] selftests/powerpc: Do not fail with reschedule (Desnes Augusto Nunes do Rosario) [1739770]
- [tools] libperf: Warn when exceeding MAX_NR_CPUS in cpumap (Frank Ramsay) [1753332]
- [tools] perf header: Replace MAX_NR_CPUS with cpu__max_cpu() (Frank Ramsay) [1753332]
- [tools] perf machine: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf session: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf stat: Replace MAX_NR_CPUS with cpu__max_cpu() (Frank Ramsay) [1753332]
- [tools] perf svghelper: Replace MAX_NR_CPUS with perf_env::nr_cpus_online (Frank Ramsay) [1753332]
- [tools] perf timechart: Refactor svg_build_topology_map() (Frank Ramsay) [1753332]
- [tools] perf tools: Increase MAX_NR_CPUS and MAX_CACHES (Frank Ramsay) [1753332]
- [crypto] crypto: chelsio - count incomplete block in IV (Jonathan Toppins) [1725813]
- [crypto] crypto: chelsio - Fix softlockup with heavy I/O (Jonathan Toppins) [1725813]
- [crypto] crypto: chelsio - Fix NULL pointer dereference (Jonathan Toppins) [1725813]
- [nvme] nvme-pci: Allow PCI bus-level PM to be used if ASPM is disabled (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI/ASPM: Add pcie_aspm_enabled() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Fix async probe remove race (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix controller removal race with scan work (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-rdma: fix possible use-after-free in connect error flow (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix a possible deadlock when passthru commands sent to a multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-core: Fix extra device_put() call on error path (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-file: fix nvmet_file_flush() always returning an error (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-loop: Flush nvme_delete_wq when removing the port (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: Fix use-after-free bug when a port is removed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: revalidate nvme_ns_head gendisk in nvme_validate_ns (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] Revert "nvme-pci: don't create a read hctx mapping without read queues" (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix multipath crash when ANA is deactivated (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix memory leak caused by incorrect subsystem free (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: ignore subnqn for ADATA SX6000LNP (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix NULL deref for fabrics options (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix regression upon hot device removal and insertion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fc: fix module unloads while lports still pending (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: set the STABLE_WRITES flag when data digests are enabled (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: print a hint while rejecting NSID 0 or 0xffffffff (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: don't use sendpage for SLAB pages (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: do not select namespaces which are about to be removed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: also check for a disabled path if there is a single sibling (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-multipath: factor out a nvme_path_is_disabled helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: export I/O characteristics attributes in Identify (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: set physical block size and optimal I/O size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: add delete completion and submission queue to admin cmds tracer (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: fix spelling mistake "spcecific" -> "specific" (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check for NULL return from pci_alloc_p2pmem() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: limit max_hw_sectors based on the DMA max mapping size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't fall back to a 32-bit DMA mask (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't create a read hctx mapping without read queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: make nvme_dev_pm_ops static (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: resolve warnings on RCU usage and sleep warnings (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: fix inconsistent lock state warnings (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI: PM: Skip devices in D0 for (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [pci] PCI: PM: Avoid possible suspend-to-idle issue (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add I/O characteristics fields (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: enable to inject errors into admin commands (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: prepare for fault injection into admin commands (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: introduce target-side trace (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: print result and status in hex format (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: support for fabrics commands in host-side (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: move opcode symbol print to nvme.h (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: do not export nvme_trace_disk_name (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: properly report state change failure in nvme_reset_work (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: clean up nvme_remove_dead_ctrl a bit (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: set the errno on ctrl state change error (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: adjust irq max_vector using num_possible_cpus() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use host managed power state for suspend (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove unnecessary zero for static var (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: introduce nvme_is_fabrics to check fabrics cmd (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fc: add message when creating new association (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove queue_count_ops for write_queues and poll_queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix possible io failures when removing multipathed ns (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: export get and set features (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: add transport discovery change op (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fcloop: add support for nvmet discovery_event op (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: remove blk_init_request_from_bio (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: initialize the write priority (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: Fix u32 overflow in the number of namespace list calculation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: add transport discovery change event callback support (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: don't limit DMA segement size (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix data_len to 0 for bdev-backed write_zeroes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-tcp: fix queue mapping when queue count is limited (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use blk-mq mapping for unmanaged irqs (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: copy MTFA field from identify controller (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: release namespace SRCU protection before performing controller ioctls (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: merge nvme_ns_ioctl into nvme_ioctl (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: remove the ifdef around nvme_nvm_ioctl (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: fix srcu locking on error return in nvme_get_ns_from_disk (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: Fix known effects (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Sync queues on reset (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Unblock reset_work on IO failure (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Don't disable on timeout in reset state (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: Fix controller freeze wait disabling (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: validate cntlid during controller initialisation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: change locking for the per-subsystem controller list (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: trace all async notice events (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fabrics: remove unused argument (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: add known admin effects to augument admin effects log page (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: init shadow doorbell after each reset (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: mark expected switch fall-through (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: mark nvme_core_init and nvme_core_exit static (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: protect discovery change log event list iteration (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: move command size checks to the core (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check more command sizes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-fabrics: check more command sizes (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove an unneeded variable initialization (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: unquiesce admin queue on shutdown (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: shutdown on timeout during deletion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: set 0 capacity if namespace block size exceeds PAGE_SIZE (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-rdma: fix a NULL deref when an admin connect times out (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-file: clamp-down file namespace lba_shift (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: include <linux/scatterlist.h> (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: rename nvme_completion instances from rsp to cqe (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-rdma: remove p2p_client initialization from fast-path (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: return a specified error it subsys_alloc fails (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix discover log page when offsets are used (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: never fail double namespace enablement (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: log the error status on Identify Namespace failure (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: tidy up nvme_map_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: add safety check for subsystem lock during nvmet_ns_changed (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: only call nvme_unmap_data for requests transferring data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove q_dmadev from nvme_queue (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: merge nvme_free_iod into nvme_unmap_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: move the call to nvme_cleanup_cmd out of nvme_unmap_data (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove nvme_init_iod (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: use a flag for polled queues (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add a rq_integrity_vec helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add dma_map_bvec helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [block] block: add a rq_dma_dir helper (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: use zero-sized array and struct_size() in kzalloc() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: remove unused nvme_iod member (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: avoid double errno conversions (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: avoid double dereference to convert le to cpu (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix error flow during ns enable (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add proper write zeroes setup for the multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: disable Write Zeroes for qemu controllers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: bring Disconnect into compliance with FC-NVME spec (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add proper discard setup for the multipath device (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: remove nvme_ns_config_oncs (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet-fc: fix issues with targetport assoc_list list walking (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: add get-feature to admin cmds tracer (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-loop: init nvmet_ctrl fatal_err_work when allocate (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: put ns_head ref if namespace fails allocation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-trace: fix cdw10 buffer overrun (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: don't warn on block content change effects (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: update comment to make the code easier to read (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: convert to SPDX identifiers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-lightnvm: convert to SPDX identifiers (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: return error from (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: avoid that deleting a controller triggers a circular locking complaint (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: introduce a helper function for controller deletion (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme: unexport nvme_delete_ctrl_sync() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvme-pci: check kstrtoint() return value in queue_count_set() (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [nvme] nvmet: fix indentation (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [lightnvm] lightnvm: simplify geometry (Gopal Tiwari) [1718463 1711181 1724950 1725066]
- [powerpc] powerpc/tm: Fix FP/VMX unavailable exceptions inside a transaction (Gustavo Duarte) [1750653]
- [powerpc] powerpc/tm: Fix restoring FP/VMX facility incorrectly on interrupts (Gustavo Duarte) [1750653]
- [block] block: split .sysfs_lock into two locks (Ming Lei) [1697383]
- [block] block: add helper for checking if queue is registered (Ming Lei) [1697383]
- [block] blk-mq: don't hold q->sysfs_lock in blk_mq_map_swqueue (Ming Lei) [1697383]
- [block] block: don't hold q->sysfs_lock in elevator_init_mq (Ming Lei) [1697383]
- [block] block: Remove blk_mq_register_dev() (Ming Lei) [1697383]
- [x86] KVM: X86: Fix fpu state crash in kvm guest (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Don't use current->mm to check for a kthread (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Update kernel's FPU state before using for the fsave header (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Use fault_in_pages_writeable() for pre-faulting (Prarit Bhargava) [1737070]
- [mm] mm/gup: continue VM_FAULT_RETRY processing even for pre-faults (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Fault-in user stack if copy_fpstate_to_sigframe() fails (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Add PKRU value to init_fpstate (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Restore regs in copy_fpstate_to_sigframe() in order to use the fastpath (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add a fastpath to copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add a fastpath to __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Defer FPU state load until return to userspace (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Merge the two code paths in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Restore from kernel memory on the 64-bit path too (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Inline copy_user_to_fpregs_zeroing() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Update xstate's PKRU value on write_pkru() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Prepare copy_fpstate_to_sigframe() for TIF_NEED_FPU_LOAD (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Always store the registers in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/entry: Add TIF_NEED_FPU_LOAD (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Eager switch PKRU state (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Don't check if PKRU is zero before writing it (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Only write PKRU if it is different from current (Prarit Bhargava) [1737070]
- [x86] x86/pkeys: Provide *pkru() helpers (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Use a feature number instead of mask in two more helpers (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Make __raw_xsave_addr() use a feature number instead of mask (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Add an __fpregs_load_activate() internal helper (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove user_fpu_begin() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Don't save fxregs for ia32 frames in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized usage in copy_fpstate_to_sigframe() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Always init the state in fpu__clear() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove preempt_disable() in fpu__clear() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu__restore() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove fpu->initialized usage in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [x86] x86/entry: Remove unneeded need_resched() loop (Prarit Bhargava) [1737070]
- [x86] x86/uaccess: Introduce user_access_{save, restore}() (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Fix i486 + no387 boot crash by only saving FPU registers on context switch if there is an FPU (Prarit Bhargava) [1737070]
- [x86] x86/fpu: Remove second definition of fpu in __fpu__restore_sig() (Prarit Bhargava) [1737070]
- [net] udp: correct reuseport selection with connected sockets (Paolo Abeni) [1665807]
- [net] udp6: add missing rehash callback to udplite (Paolo Abeni) [1665807]
- [net] udp: add missing rehash callback to udplite (Paolo Abeni) [1665807]
- [net] udp6: prefer listeners bound to an address (Paolo Abeni) [1665807]
- [net] udp: prefer listeners bound to an address (Paolo Abeni) [1665807]
- [net] sched: fix race between deactivation and dequeue for NOLOCK qdisc (Davide Caratti) [1744397]
- [net] check extack._msg before print (Ivan Vecera) [1751279]
- [net] report invalid mtu value via netlink extack (Ivan Vecera) [1751279]
- [net] report min and max mtu network device settings (Ivan Vecera) [1751279]
- [net] failover: change mtu has RTNL (Ivan Vecera) [1751279]
- [net] neigh: fix multiple neigh timer scheduling (Lorenzo Bianconi) [1730632]
- [net] virtchnl: fix 'Unknown bps' in dmesg for 2.5Gb/5Gb speeds (Ivan Vecera) [1748437]
- [net] Add a define for LLDP ethertype (Ivan Vecera) [1748428]
- [net] devlink: Add support for direct reporter health state update (Petr Oros) [1746363]
- [netdrv] Add IANA_VXLAN_UDP_PORT definition to vxlan header file (Ivan Vecera) [1731347]
- [netdrv] Move the definition of the default Geneve udp port to public header file (Ivan Vecera) [1731347]
- [net] openvswitch: Add a new action check_pkt_len (Numan Siddique) [1700733]

* Thu Oct 03 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.4.el8]
- [pci] PCI: Add pci_dev_id() helper (Myron Stowe) [1735874]
- [netdrv] ibmvnic: Warn unknown speed message only when carrier is present (Steve Best) [1749873]
- [netdrv] net/ibmvnic: Fix missing { in __ibmvnic_reset (Steve Best) [1749873]
- [netdrv] net/ibmvnic: free reset work of removed device from queue (Steve Best) [1749873]
- [netdrv] ibmvnic: Do not process reset during or after device removal (Steve Best) [1749873]
- [cpufreq] cpufreq: intel_pstate: Show different max frequency with turbo 3 and HWP (Alexander Beregalov) [1752053]
- [char] hpet: Fix missing '=' character in the __setup() code of hpet_mmap_enable (Prarit Bhargava) [1660796]
- [hwtracing] intel_th: pci: Add support for another Lewisburg PCH (Jiri Olsa) [1714486]
- [x86] x86/entry/32: Fix ENDPROC of common_spurious (Prarit Bhargava) [1730447]
- [x86] x86/irq: Seperate unused system vectors from spurious entry again (Prarit Bhargava) [1730447]
- [vfio] vfio/type1: Handle different mdev isolation type (Tarun Gupta) [1498341]
- [vfio] vfio/type1: Add domain at(de)taching group helpers (Tarun Gupta) [1498341]
- [vfio] vfio/mdev: Add iommu related member in mdev_device (Tarun Gupta) [1498341]
- [documentation] ipmb: place it at driver-api and convert to ReST (Tony Camuso) [1752071]
- [char] ipmi_si_intf: Fix race in timer shutdown handling (Tony Camuso) [1752071]
- [char] ipmi_ssif: avoid registering duplicate ssif interface (Tony Camuso) [1752071]
- [char] ipmi: Free receive messages when in an oops (Tony Camuso) [1752071]
- [char] ipmi_si: Only schedule continuously in the thread in maintenance mode (Tony Camuso) [1752071]
- [char] ipmi_si: Remove ipmi_ from the device attr names (Tony Camuso) [1752071]
- [char] ipmi_si: Convert device attr permissions to octal (Tony Camuso) [1752071]
- [char] ipmi_si: Rework some include files (Tony Camuso) [1752071]
- [char] ipmi_si: Convert timespec64 to timespec (Tony Camuso) [1752071]
- [char] Fix uninitialized variable in ipmb_dev_int.c (Tony Camuso) [1752071]
- [char] fix platform_no_drv_owner.cocci warnings (Tony Camuso) [1752071]
- [char] ipmi: ipmb: don't allocate i2c_client on stack (Tony Camuso) [1752071]
- [char] ipmi: ipmb: Fix build error while CONFIG_I2C is set to m (Tony Camuso) [1752071]
- [char] Add support for IPMB driver (Tony Camuso) [1752071]
- [char] drivers: ipmi: Drop device reference (Tony Camuso) [1752071]
- [char] ipmi_ssif: fix unexpected driver unregister warning (Tony Camuso) [1752071]
- [char] Add SPDX license identifier - Makefile/Kconfig (Tony Camuso) [1752071]
- [char] ipmi_si: use bool type for initialized variable (Tony Camuso) [1752071]
- [char] ipmi_si: fix unexpected driver unregister warning (Tony Camuso) [1752071]
- [char] ipmi: Remove warning if no slave address is present (Tony Camuso) [1752071]
- [char] ipmi:ssif: Only unregister the platform driver if it was registered (Tony Camuso) [1752071]
- [char] ipmi: Add the i2c-addr property for SSIF interfaces (Tony Camuso) [1752071]
- [char] ipmi: avoid atomic_inc in exit function (Tony Camuso) [1752071]
- [char] ipmi: Remove file from ipmi_file_private (Tony Camuso) [1752071]
- [char] ipmi_si: remove an unused variable in try_smi_init() (Tony Camuso) [1752071]
- [char] ipmi: Make ipmi_interfaces_srcu variable static (Tony Camuso) [1752071]
- [char] ipmi: Change to ktime_get_ts64() (Tony Camuso) [1752071]
- [char] ipmi: Free the address list on module cleanup (Tony Camuso) [1752071]
- [edac] EDAC, skx, i10nm: Fix source ID register offset (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Check ECC enabling status per channel (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Add Intel additional Ice-Lake support (Aristeu Rozanski) [1485543 1482412]
- [x86] x86/CPU: Add more Icelake model numbers (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx, i10nm: Make skx_common.c a pure library (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_common: Add code to recognise new compound error code (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Fix randconfig builds (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, i10nm: Add a driver for Intel 10nm server processors (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_edac: Delete duplicated code (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_common: Separate common code out from skx_edac (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Let EDAC core show the decoded result for debugfs (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Move debugfs node under EDAC's hierarchy (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Prepend hex formatting with '0x' (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx: Fix function calling order in skx_exit() (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, skx_edac: Fix logical channel intermediate decoding (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC, {i7core,sb,skx}_edac: Fix uncorrected error counting (Aristeu Rozanski) [1485543 1482412]
- [edac] EDAC: Correct DIMM capacity unit symbol (Aristeu Rozanski) [1485543 1482412]
- [x86] x86/mce: Add notifier_block forward declaration (Aristeu Rozanski) [1485543 1482412]
- [netdrv] net: thunderx: fix NULL pointer dereference in nicvf_open/nicvf_stop (Dean Nelson) [1657380]
- [netdrv] net: thunder: fix a potential NULL pointer dereference (Dean Nelson) [1657380]
- [netdrv] net: thunderx: remove link change polling code and info from nicpf (Dean Nelson) [1657380]
- [netdrv] net: thunderx: move link state polling function to VF (Dean Nelson) [1657380]
- [netdrv] net: thunderx: add mutex to protect mailbox from concurrent calls for same VF (Dean Nelson) [1657380]
- [netdrv] net: thunderx: rework xcast message structure to make it fit into 64 bit (Dean Nelson) [1657380]
- [netdrv] net: thunderx: add nicvf_send_msg_to_pf result check for set_rx_mode_task (Dean Nelson) [1657380]
- [netdrv] net: thunderx: make CFG_DONE message to run through generic send-ack sequence (Dean Nelson) [1657380]
- [netdrv] net: thunderx: replace global nicvf_rx_mode_wq work queue for all VFs to private for each of them. (Dean Nelson) [1657380]
- [netdrv] net: thunderx: set tso_hdrs pointer to NULL in nicvf_free_snd_queue (Dean Nelson) [1657380]
- [x86] perf/x86/intel/rapl: Cosmetic rename internal variables in response to multi-die/pkg support (David Arcari) [1616309]
- [x86] perf/x86/intel/uncore: Cosmetic renames in response to multi-die/pkg support (David Arcari) [1616309]
- [hwmon] hwmon/coretemp: Cosmetic: Rename internal variables to zones from packages (David Arcari) [1616309]
- [thermal] thermal/x86_pkg_temp_thermal: Cosmetic: Rename internal variables to zones from packages (David Arcari) [1616309]
- [x86] perf/x86/intel/cstate: Support multi-die/package (David Arcari) [1616309]
- [x86] perf/x86/intel/rapl: Support multi-die/package (David Arcari) [1616309]
- [x86] perf/x86/intel/uncore: Support multi-die/package (David Arcari) [1616309]
- [topology] topology: Create core_cpus and die_cpus sysfs attributes (David Arcari) [1616309]
- [topology] topology: Create package_cpus sysfs attribute (David Arcari) [1616309]
- [hwmon] hwmon/coretemp: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Update RAPL domain name and debug messages (David Arcari) [1616309]
- [thermal] thermal/x86_pkg_temp_thermal: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Support multi-die/package (David Arcari) [1616309]
- [powercap] powercap/intel_rapl: Simplify rapl_find_package() (David Arcari) [1616309]
- [x86] x86/topology: Define topology_logical_die_id() (David Arcari) [1616309]
- [x86] x86/topology: Define topology_die_id() (David Arcari) [1616309]
- [topology] cpu/topology: Export die_id (David Arcari) [1616309]
- [x86] x86/topology: Create topology_max_die_per_package() (David Arcari) [1616309]
- [x86] x86/topology: Add CPUID.1F multi-die/package support (David Arcari) [1616309]
- [x86] x86/smpboot: Rename match_die() to match_pkg() (David Arcari) [1616309]
- [documentation] topology: Simplify cputopology.txt formatting and wording (David Arcari) [1616309]
- [documentation] x86/topology: Fix documentation typo (David Arcari) [1616309]
- [mm] mm: remove stale comment from page struct (Rafael Aquini) [1737065]
- [mm] mm/slab.c: fix an infinite loop in leaks_show() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: update the comment about slab frozen (Rafael Aquini) [1737065]
- [mm] mm/slab.c: remove unneed check in cpuup_canceled (Rafael Aquini) [1737065]
- [mm] slub: remove useless kmem_cache_debug() before remove_full() (Rafael Aquini) [1737065]
- [mm] slab: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slub: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slob: use slab_list instead of lru (Rafael Aquini) [1737065]
- [mm] slob: respect list_head abstraction layer (Rafael Aquini) [1737065]
- [mm] slab: fix a crash by reading /proc/slab_allocators (Rafael Aquini) [1737065]
- [mm] mm: add support for kmem caches in DMA32 zone (Rafael Aquini) [1737065]
- [mm] mm, slub: make the comment of put_cpu_partial() complete (Rafael Aquini) [1737065]
- [mm] mm/slub.c: remove an unused addr argument (Rafael Aquini) [1737065]
- [mm] mm/slab.c: kmemleak no scan alien caches (Rafael Aquini) [1737065]
- [mm] mm/slub.c: freelist is ensured to be NULL when new_slab() fails (Rafael Aquini) [1737065]
- [mm] slab: alien caches must not be initialized if the allocation of the alien cache failed (Rafael Aquini) [1737065]
- [mm] include/linux/slab.h: fix sparse warning in kmalloc_type() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: record final state of slub action in deactivate_slab() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: page is always non-NULL in node_match() (Rafael Aquini) [1737065]
- [mm] mm/slub.c: remove validation on cpu_slab in __flush_cpu_slab() (Rafael Aquini) [1737065]
- [mm] mm, slab: remove unnecessary unlikely() (Rafael Aquini) [1737065]
- [mm] mm: move obj_to_index to include/linux/slab_def.h (Rafael Aquini) [1737065]
- [mm] slab: make kmem_cache_create{_usercopy} description proper kernel-doc (Rafael Aquini) [1737065]
- [mm] slub: extend slub debug to handle multiple slabs (Rafael Aquini) [1737065]
- [mm] mm/slub.c: switch to bitmap_zalloc() (Rafael Aquini) [1737065]
- [fs] io_uring: add need_resched() check in inner poll loop (Jeff Moyer) [1706143]
- [fs] io_uring: don't enter poll loop if we have CQEs pending (Jeff Moyer) [1706143]
- [fs] io_uring: fix potential hang with polled IO (Jeff Moyer) [1706143]
- [fs] io_uring: fix an issue when IOSQE_IO_LINK is inserted into defer list (Jeff Moyer) [1706143]
- [fs] io_uring: fix manual setup of iov_iter for fixed buffers (Jeff Moyer) [1706143]
- [fs] io_uring: fix KASAN use after free in io_sq_wq_submit_work (Jeff Moyer) [1706143]
- [fs] io_uring: ensure ->list is initialized for poll commands (Jeff Moyer) [1706143]
- [fs] io_uring: track io length in async_list based on bytes (Jeff Moyer) [1706143]
- [fs] io_uring: don't use iov_iter_advance() for fixed buffers (Jeff Moyer) [1706143]
- [fs] io_uring: add a memory barrier before atomic_read (Jeff Moyer) [1706143]
- [fs] io_uring: fix counter inc/dec mismatch in async_list (Jeff Moyer) [1706143]
- [fs] io_uring: fix the sequence comparison in io_sequence_defer (Jeff Moyer) [1706143]
- [fs] io_uring: fix io_sq_thread_stop running in front of io_sq_thread (Jeff Moyer) [1706143]
- [include] io_uring: add support for recvmsg() (Jeff Moyer) [1706143]
- [include] io_uring: add support for sendmsg() (Jeff Moyer) [1706143]
- [fs] signal: remove the wrong signal_pending() check in restore_user_sigmask() (Jeff Moyer) [1706143]
- [fs] io_uring: add support for sqe links (Jeff Moyer) [1706143]
- [fs] io_uring: ensure req->file is cleared on allocation (Jeff Moyer) [1706143]
- [fs] io_uring: fix memory leak of UNIX domain socket inode (Jeff Moyer) [1706143]
- [fs] io_uring: punt short reads to async context (Jeff Moyer) [1706143]
- [fs] uio: make import_iovec()/compat_import_iovec() return bytes on success (Jeff Moyer) [1706143]
- [fs] io_uring: Fix __io_uring_register() false success (Jeff Moyer) [1706143]
- [tools] tools/io_uring: sync with liburing (Jeff Moyer) [1706143]
- [tools] tools/io_uring: fix Makefile for pthread library link (Jeff Moyer) [1706143]
- [fs] io_uring: use wait_event_interruptible for cq_wait conditional wait (Jeff Moyer) [1706143]
- [fs] io_uring: adjust smp_rmb inside io_cqring_events (Jeff Moyer) [1706143]
- [fs] io_uring: fix infinite wait in khread_park() on io_finish_async() (Jeff Moyer) [1706143]
- [fs] io_uring: remove 'ev_flags' argument (Jeff Moyer) [1706143]
- [fs] io_uring: fix failure to verify SQ_AFF cpu (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition reading SQE data (Jeff Moyer) [1706143]
- [fs] io_uring: use cpu_online() to check p->sq_thread_cpu instead of cpu_possible() (Jeff Moyer) [1706143]
- [fs] io_uring: fix shadowed variable ret return code being not checked (Jeff Moyer) [1706143]
- [fs] req->error only used for iopoll (Jeff Moyer) [1706143]
- [fs] io_uring: add support for eventfd notifications (Jeff Moyer) [1706143]
- [fs] io_uring: add support for IORING_OP_SYNC_FILE_RANGE (Jeff Moyer) [1706143]
- [fs] fs: add sync_file_range() helper (Jeff Moyer) [1706143]
- [fs] io_uring: add support for marking commands as draining (Jeff Moyer) [1706143]
- [fs] io_uring: avoid page allocation warnings (Jeff Moyer) [1706143]
- [include] iov_iter: fix iov_iter_type (Jeff Moyer) [1706143]
- [fs] block: fix handling for BIO_NO_PAGE_REF (Jeff Moyer) [1706143]
- [fs] io_uring: drop req submit reference always in async punt (Jeff Moyer) [1706143]
- [fs] io_uring: free allocated io_memory once (Jeff Moyer) [1706143]
- [fs] io_uring: fix SQPOLL cpu validation (Jeff Moyer) [1706143]
- [fs] io_uring: have submission side sqe errors post a cqe (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after unsetting IORING_SQ_NEED_WAKEUP (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after incrementing dropped counter (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before reading SQ tail (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier after updating SQ head (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before reading cq head (Jeff Moyer) [1706143]
- [fs] io_uring: remove unnecessary barrier before wq_has_sleeper (Jeff Moyer) [1706143]
- [fs] io_uring: fix notes on barriers (Jeff Moyer) [1706143]
- [fs] io_uring: fix handling SQEs requesting NOWAIT (Jeff Moyer) [1706143]
- [fs] io_uring: remove 'state' argument from io_{read,write} path (Jeff Moyer) [1706143]
- [fs] io_uring: fix poll full SQ detection (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition when sq threads goes sleeping (Jeff Moyer) [1706143]
- [fs] io_uring: fix race condition reading SQ entries (Jeff Moyer) [1706143]
- [fs] io_uring: fail io_uring_register(2) on a dying io_uring instance (Jeff Moyer) [1706143]
- [fs] io_uring: fix CQ overflow condition (Jeff Moyer) [1706143]
- [fs] io_uring: fix possible deadlock between io_uring_{enter,register} (Jeff Moyer) [1706143]
- [powerpc] arch: add pidfd and io_uring syscalls everywhere (Jeff Moyer) [1706143]
- [fs] io_uring: drop io_file_put() 'file' argument (Jeff Moyer) [1706143]
- [fs] io_uring: only test SQPOLL cpu after we've verified it (Jeff Moyer) [1706143]
- [fs] io_uring: park SQPOLL thread if it's percpu (Jeff Moyer) [1706143]
- [fs] io_uring: restrict IORING_SETUP_SQPOLL to root (Jeff Moyer) [1706143]
- [tools] tools/io_uring: remove IOCQE_FLAG_CACHEHIT (Jeff Moyer) [1706143]
- [fs] io_uring: fix double free in case of fileset regitration failure (Jeff Moyer) [1706143]
- [fs] io_uring: offload write to async worker in case of -EAGAIN (Jeff Moyer) [1706143]
- [fs] io_uring: fix big-endian compat signal mask handling (Jeff Moyer) [1706143]
- [fs] block: add BIO_NO_PAGE_REF flag (Jeff Moyer) [1706143]
- [fs] iov_iter: add ITER_BVEC_FLAG_NO_REF flag (Jeff Moyer) [1706143]
- [maintainers] io_uring: mark me as the maintainer (Jeff Moyer) [1706143]
- [fs] io_uring: retry bulk slab allocs as single allocs (Jeff Moyer) [1706143]
- [fs] io_uring: fix poll races (Jeff Moyer) [1706143]
- [fs] io_uring: fix fget/fput handling (Jeff Moyer) [1706143]
- [fs] io_uring: add prepped flag (Jeff Moyer) [1706143]
- [fs] io_uring: make io_read/write return an integer (Jeff Moyer) [1706143]
- [fs] io_uring: use regular request ref counts (Jeff Moyer) [1706143]
- [fs] mm: refactor readahead defines in mm.h (Jeff Moyer) [1706143]
- [tools] io_uring: add a few test tools (Jeff Moyer) [1706143]
- [fs] io_uring: allow workqueue item to handle multiple buffered requests (Jeff Moyer) [1706143]
- [fs] io_uring: add support for IORING_OP_POLL (Jeff Moyer) [1706143]
- [fs] io_uring: add io_kiocb ref count (Jeff Moyer) [1706143]
- [fs] io_uring: add submission polling (Jeff Moyer) [1706143]
- [fs] io_uring: add file set registration (Jeff Moyer) [1706143]
- [net] net: split out functions related to registering inflight socket files (Jeff Moyer) [1706143]
- [include] io_uring: add support for pre-mapped user IO buffers (Jeff Moyer) [1706143]
- [block] block: implement bio helper to add iter bvec pages to bio (Jeff Moyer) [1706143]
- [fs] io_uring: batch io_kiocb allocation (Jeff Moyer) [1706143]
- [fs] io_uring: use fget/fput_many() for file references (Jeff Moyer) [1706143]
- [fs] fs: add fget_many() and fput_many() (Jeff Moyer) [1706143]
- [fs] io_uring: support for IO polling (Jeff Moyer) [1706143]
- [fs] io_uring: add fsync support (Jeff Moyer) [1706143]
- [include] Add io_uring IO interface (Jeff Moyer) [1706143]
- [fs] iomap: wire up the iopoll method (Jeff Moyer) [1706143]
- [fs] block: add bio_set_polled() helper (Jeff Moyer) [1706143]
- [fs] block: wire up block device iopoll method (Jeff Moyer) [1706143]
- [fs] signal: Add restore_user_sigmask() (Jeff Moyer) [1706143]
- [fs] signal: Add set_user_sigmask() (Jeff Moyer) [1706143]
- [net] iov_iter: Fix 9p virtio breakage (Benjamin Coddington) [1734762]
- [lib] iov_iter: Add I/O discard iterator (Benjamin Coddington) [1734762]
- [fs] iov_iter: Separate type from direction and use accessor functions (Benjamin Coddington) [1734762]
- [fs] iov_iter: Use accessor function (Benjamin Coddington) [1734762]

* Wed Oct 02 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.3.el8]
- [kernel] ftrace/x86: Anotate text_mutex split between ftrace_arch_code_modify_post_process() and ftrace_arch_code_modify_prepare() (Joe Lawrence) [1696461]
- [kernel] ftrace/x86: Remove possible deadlock between register_kprobe() and ftrace_run_update_code() (Joe Lawrence) [1696461]
- [kernel] Revert "livepatch: Remove reliable stacktrace check in klp_try_switch_task()" (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: push and pop dynamic debug config (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: add test skip handling (Joe Lawrence) [1696461]
- [kernel] module: Fix livepatch/ftrace module text permissions race (Joe Lawrence) [1696461]
- [kernel] kprobes: Mark ftrace mcount handler functions nokprobe (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: Add functions.sh to TEST_PROGS_EXTENDED (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: use TEST_PROGS for test scripts (Joe Lawrence) [1696461]
- [kernel] livepatch/selftests: use "$@" to preserve argument list (Joe Lawrence) [1696461]
- [kernel] livepatch: Module coming and going callbacks can proceed with all listed patches (Joe Lawrence) [1696461]
- [kernel] livepatch: Proper error handling in the shadow variables selftest (Joe Lawrence) [1696461]
- [kernel] livepatch: return -ENOMEM on ptr_id() allocation failure (Joe Lawrence) [1696461]
- [kernel] livepatch: Introduce klp_for_each_patch macro (Joe Lawrence) [1696461]
- [kernel] livepatch: core: Return EOPNOTSUPP instead of ENOSYS (Joe Lawrence) [1696461]
- [kernel] livepatch: samples: non static warnings fix (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove signal sysfs attribute (Joe Lawrence) [1696461]
- [kernel] livepatch: Send a fake signal periodically (Joe Lawrence) [1696461]
- [kernel] selftests/livepatch: introduce tests (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove ordering (stacking) of the livepatches (Joe Lawrence) [1696461]
- [kernel] livepatch: Atomic replace and cumulative patches documentation (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove Nop structures when unused (Joe Lawrence) [1696461]
- [kernel] livepatch: Add atomic replace (Joe Lawrence) [1696461]
- [kernel] livepatch: Use lists to manage patches, objects and functions (Joe Lawrence) [1696461]
- [kernel] livepatch: Simplify API by removing registration step (Joe Lawrence) [1696461]
- [kernel] livepatch: Don't block the removal of patches loaded after a forced transition (Joe Lawrence) [1696461]
- [kernel] livepatch: Consolidate klp_free functions (Joe Lawrence) [1696461]
- [kernel] livepatch: Shuffle klp_enable_patch()/klp_disable_patch() code (Joe Lawrence) [1696461]
- [kernel] livepatch: Change unsigned long old_addr -> void *old_func in struct klp_func (Joe Lawrence) [1696461]
- [kernel] livepatch: check kzalloc return values (Joe Lawrence) [1696461]
- [kernel] livepatch: Replace synchronize_sched() with synchronize_rcu() (Joe Lawrence) [1696461]
- [kernel] livepatch: Validate module/old func name length (Joe Lawrence) [1696461]
- [kernel] livepatch: Remove reliable stacktrace check in klp_try_switch_task() (Joe Lawrence) [1696461]
- [pci] PCI/LINK: Add Kconfig option (default off) (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Use shared MSI/MSI-X vector for Bandwidth Management (Myron Stowe) [1748141]
- [pci] PCI: Fix issue with "pci=disable_acs_redir" parameter being ignored (Myron Stowe) [1748141]
- [pci] PCI: Add function 1 DMA alias quirk for Marvell 9170 SATA controller (Myron Stowe) [1748141]
- [pci] PCI/LINK: Deduplicate bandwidth reports for multi-function devices (Myron Stowe) [1748141]
- [pci] PCI/LINK: Clear bandwidth notification interrupt before enabling it (Myron Stowe) [1748141]
- [pci] PCI/LINK: Supply IRQ handler so level-triggered IRQs are acked (Myron Stowe) [1748141]
- [pci] PCI/LINK: Report degraded links via link bandwidth notification (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Support PCIe services on subtractive decode bridges (Myron Stowe) [1748141]
- [pci] PCI/portdrv: Use conventional Device ID table formatting (Myron Stowe) [1748141]
- [pci] PCI: Update PCIEPORTBUS Kconfig help text (Myron Stowe) [1748141]
- [pci] PCI: Clean up usage of __u32 type (Myron Stowe) [1748141]
- [pci] PCI: Move Rohm Vendor ID to generic list (Myron Stowe) [1748141]
- [pci] PCI: pciehp: Add HXT quirk for Command Completed errata (Myron Stowe) [1748141]
- [pci] PCI: Add ACS quirk for HXT SD4800 (Myron Stowe) [1748141]
- [pci] PCI: Add HXT vendor ID (Myron Stowe) [1748141]
- [pci] PCI: Use of_node_name_eq() for node name comparisons (Myron Stowe) [1748141]
- [pci] PCI: Mark expected switch fall-through (Myron Stowe) [1748141]
- [pci] PCI: ibmphp: Turn semaphores into completions or mutexes (Myron Stowe) [1748141]
- [pci] x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub (Myron Stowe) [1748141]
- [pci] PCI: Rely on config space header type, not class code (Myron Stowe) [1748141]
- [pci] PCI: Make pci_size() return real BAR size (Myron Stowe) [1748141]
- [pci] PCI/DPC: Fix print AER status in DPC event handling (Myron Stowe) [1748141]
- [pci] PCI/ASPM: Save LTR Capability for suspend/resume (Myron Stowe) [1748141]
- [pci] PCI/ASPM: Use LTR if already enabled by platform (Myron Stowe) [1748141]
- [pci] PCI: Enable SERR# forwarding for all bridges (Myron Stowe) [1748141]
- [pci] PCI/AER: Use match_string() helper to simplify the code (Myron Stowe) [1748141]
- [fs] gfs2: Use async glocks for rename (Robert S Peterson) [1737561]
- [fs] gfs2: create function gfs2_glock_update_hold_time (Robert S Peterson) [1737561]
- [fs] gfs2: separate holder for rgrps in gfs2_rename (Robert S Peterson) [1737561]
- [netdrv] net: aquantia: reapply vlan filters on up (Igor Russkikh) [1740500]
- [s390] s390/setup: Fix kernel lock down for s390 (Philipp Rudo) [1748343]
- [powerpc] kvm: ppc: book3s hv: Fix XICS-on-XIVE H_IPI when priority = 0 (David Gibson) [1725800]
- [s390] vfio-ap: fix irq registration (Thomas Huth) [1660910]
- [s390] ap: kvm: Enable PQAP/AQIC facility for the guest (Thomas Huth) [1660910]
- [s390] ap: implement PAPQ AQIC interception in kernel (Thomas Huth) [1660910]
- [s390] vfio: ap: register IOMMU VFIO notifier (Thomas Huth) [1660910]
- [s390] ap: kvm: add PQAP interception for AQIC (Thomas Huth) [1660910]
- [s390] kvm: s390: Do not leak kernel stack data in the KVM_S390_INTERRUPT ioctl (Thomas Huth) [1749503]
- [s390] kvm: s390: vsie: Return correct values for Invalid CRYCB format (Thomas Huth) [1749503]
- [s390] kvm: s390: vsie: Do not shadow CRYCB when no AP and no keys (Thomas Huth) [1749503]
- [s390] kvm: s390: change default halt poll time to 50us (Thomas Huth) [1749503]
- [s390] kvm: s390: fix typo in parameter description (Thomas Huth) [1749503]
- [s390] kvm: s390: provide kvm_arch_no_poll function (Thomas Huth) [1749503]
- [kernel] kvm: polling: add architecture backend to disable polling (Thomas Huth) [1749503]
- [s390] vtime: steal time exponential moving average (Thomas Huth) [1749503]
- [tools] kvm: selftests: fix ucall on x86 (Thomas Huth) [1730412]
- [tools] kvm: selftests: Test invalid bits in kvm_valid_regs and kvm_dirty_regs on s390x (Thomas Huth) [1730412]
- [s390] kvm: s390: Disallow invalid bits in kvm_valid_regs and kvm_dirty_regs (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add a test for the KVM_S390_MEM_OP ioctl (Thomas Huth) [1730412]
- [s390] kvm: s390: Test for bad access register and size at the start of S390_MEM_OP (Thomas Huth) [1730412]
- [tools] kvm: selftests: Enable dirty_log_test on s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Implement ucall() for s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Split ucall.c into architecture specific files (Thomas Huth) [1730412]
- [tools] kvm: selftests: ucall improvements (Thomas Huth) [1730412]
- [tools] kvm: selftests: aarch64: dirty_log_test: fix unaligned memslot size (Thomas Huth) [1730412]
- [tools] kvm: selftests: Compile code with warnings enabled (Thomas Huth) [1730412]
- [tools] kvm: selftests: enable pgste option for the linker on s390 (Thomas Huth) [1730412]
- [tools] kvm: selftests: Move kvm_create_max_vcpus test to generic code (Thomas Huth) [1730412]
- [virt] kvm: s390: Do not report unusabled IDs via KVM_CAP_MAX_VCPU_ID (Thomas Huth) [1730412]
- [documentation] kvm: move KVM_CAP_NR_MEMSLOTS to common code (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add the sync_regs test for s390x (Thomas Huth) [1730412]
- [s390] kvm: s390: fix memory slot handling for KVM_SET_USER_MEMORY_REGION (Thomas Huth) [1730412]
- [tools] kvm: selftests: Add processor code for s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Align memory region addresses to 1M on s390x (Thomas Huth) [1730412]
- [tools] kvm: selftests: Introduce a VM_MODE_DEFAULT macro for the default bits (Thomas Huth) [1730412]
- [tools] kvm: selftests: aarch64: fix default vm mode (Thomas Huth) [1730412]
- [tools] kvm: selftests: Guard struct kvm_vcpu_events with __KVM_HAVE_VCPU_EVENTS (Thomas Huth) [1730412]
- [tools] kvm: selftests: Wrap vcpu_nested_state_get/set functions with x86 guard (Thomas Huth) [1730412]

* Fri Sep 27 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.2.el8]
- [fs] xfs: fix missing ILOCK unlock when xfs_setattr_nonsize fails due to EDQUOT (Bill O'Donnell) [1739607]
- [fs] xfs: fix reflink source file racing with directio writes (Bill O'Donnell) [1739607]
- [fs] xfs: implement cgroup aware writeback (Bill O'Donnell) [1274406]
- [fs] xfs: simplify xfs_chain_bio (Bill O'Donnell) [1274406]
- [fs] xfs: inode btree scrubber should calculate im_boffset correctly (Bill O'Donnell) [1739607]
- [fs] xfs: fix broken log reservation debugging (Bill O'Donnell) [1739607]
- [fs] xfs: don't reserve per-AG space for an internal log (Bill O'Donnell) [1739607]
- [fs] xfs: change some error-less functions to void types (Bill O'Donnell) [1739607]
- [fs] xfs: add online scrub for superblock counters (Bill O'Donnell) [1739607]
- [fs] xfs: don't parse the mtpt mount option (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should check incore counters against ondisk headers (Bill O'Donnell) [1739607]
- [fs] xfs: allow scrubbers to pause background reclaim (Bill O'Donnell) [1739607]
- [fs] xfs: rename the speculative block allocation reclaim toggle functions (Bill O'Donnell) [1739607]
- [fs] xfs: track delayed allocation reservations across the filesystem (Bill O'Donnell) [1739607]
- [fs] xfs: fix broken bhold behavior in xrep_roll_ag_trans (Bill O'Donnell) [1739607]
- [fs] xfs: unlock inode when xfs_ioctl_setattr_get_trans can't get transaction (Bill O'Donnell) [1739607]
- [fs] xfs: kill the xfs_dqtrx_t typedef (Bill O'Donnell) [1739607]
- [fs] xfs: widen inode delalloc block counter to 64-bits (Bill O'Donnell) [1739607]
- [fs] xfs: widen quota block counters to 64-bit integers (Bill O'Donnell) [1739607]
- [fs] xfs: assert that we don't enter agfl freeing with a non-permanent transaction (Bill O'Donnell) [1739607]
- [fs] xfs: make tr_growdata a permanent transaction (Bill O'Donnell) [1739607]
- [fs] xfs: merge adjacent io completions of the same type (Bill O'Donnell) [1739607]
- [fs] xfs: remove unused m_data_workqueue (Bill O'Donnell) [1739607]
- [fs] xfs: implement per-inode writeback completion queues (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should only cross-reference with healthy btrees (Bill O'Donnell) [1739607]
- [fs] xfs: scrub/repair should update filesystem metadata health (Bill O'Donnell) [1739607]
- [fs] xfs: hoist the already_fixed variable to the scrub context (Bill O'Donnell) [1739607]
- [fs] xfs: collapse scrub bool state flags into a single unsigned int (Bill O'Donnell) [1739607]
- [fs] xfs: refactor scrub context initialization (Bill O'Donnell) [1739607]
- [fs] xfs: report inode health via bulkstat (Bill O'Donnell) [1739607]
- [fs] xfs: report AG health via AG geometry ioctl (Bill O'Donnell) [1739607]
- [fs] xfs: report fs and rt health via geometry structure (Bill O'Donnell) [1739607]
- [fs] xfs: add a new ioctl to describe allocation group geometry (Bill O'Donnell) [1739607]
- [fs] xfs: bump XFS_IOC_FSGEOMETRY to v5 structures (Bill O'Donnell) [1739607]
- [fs] xfs: clear BAD_SUMMARY if unmounting an unhealthy filesystem (Bill O'Donnell) [1739607]
- [fs] xfs: replace the BAD_SUMMARY mount flag with the equivalent health code (Bill O'Donnell) [1739607]
- [fs] xfs: track metadata health status (Bill O'Donnell) [1739607]
- [fs] xfs,fstrim: fix to return correct minlen (Bill O'Donnell) [1739607]
- [fs] xfs: shutdown after buf release in iflush cluster abort path (Bill O'Donnell) [1739607]
- [fs] xfs: wake commit waiters on CIL abort before log item abort (Bill O'Donnell) [1739607]
- [fs] xfs: fix btree scrub checking with regards to root-in-inode (Bill O'Donnell) [1739607]
- [fs] xfs: dabtree scrub needs to range-check level (Bill O'Donnell) [1739607]
- [fs] xfs: clean up xfs_dir2_leaf_addname (Bill O'Donnell) [1739607]
- [fs] xfs: zero initialize highstale and lowstale in xfs_dir2_leaf_addname (Bill O'Donnell) [1739607]
- [fs] xfs: clean up xfs_dir2_leafn_add (Bill O'Donnell) [1739607]
- [fs] xfs: Zero initialize highstale and lowstale in xfs_dir2_leafn_add (Bill O'Donnell) [1739607]
- [fs] xfs: fix backwards endian conversion in scrub (Bill O'Donnell) [1739607]
- [fs] xfs: fix uninitialized error variables (Bill O'Donnell) [1739607]
- [fs] xfs: rework breaking of shared extents in xfs_file_iomap_begin (Bill O'Donnell) [1739607]
- [fs] xfs: don't pass iomap flags to xfs_reflink_allocate_cow (Bill O'Donnell) [1739607]
- [fs] xfs: fix uninitialized error variable (Bill O'Donnell) [1739607]
- [fs] xfs: introduce an always_cow mode (Bill O'Donnell) [1739607]
- [fs] xfs: report IOMAP_F_SHARED from xfs_file_iomap_begin_delay (Bill O'Donnell) [1739607]
- [fs] xfs: make COW fork unwritten extent conversions more robust (Bill O'Donnell) [1739607]
- [fs] xfs: merge COW handling into xfs_file_iomap_begin_delay (Bill O'Donnell) [1739607]
- [fs] xfs: also truncate holes covered by COW blocks (Bill O'Donnell) [1739607]
- [fs] xfs: don't use delalloc extents for COW on files with extsize hints (Bill O'Donnell) [1739607]
- [fs] xfs: fix SEEK_DATA for speculative COW fork preallocation (Bill O'Donnell) [1739607]
- [fs] xfs: make xfs_bmbt_to_iomap more useful (Bill O'Donnell) [1739607]
- [fs] xfs: fix xfs_buf magic number endian checks (Bill O'Donnell) [1739607]
- [fs] xfs: retry COW fork delalloc conversion when no extent was found (Bill O'Donnell) [1739607]
- [fs] xfs: remove the truncate short cut in xfs_map_blocks (Bill O'Donnell) [1739607]
- [fs] xfs: move xfs_iomap_write_allocate to xfs_aops.c (Bill O'Donnell) [1739607]
- [fs] xfs: move stat accounting to xfs_bmapi_convert_delalloc (Bill O'Donnell) [1739607]
- [fs] xfs: move transaction handling to xfs_bmapi_convert_delalloc (Bill O'Donnell) [1739607]
- [fs] xfs: split XFS_BMAPI_DELALLOC handling from xfs_bmapi_write (Bill O'Donnell) [1739607]
- [fs] xfs: factor out two helpers from xfs_bmapi_write (Bill O'Donnell) [1739607]
- [fs] xfs: simplify the xfs_bmap_btree_to_extents calling conventions (Bill O'Donnell) [1739607]
- [fs] xfs: remove the s_maxbytes checks in xfs_map_blocks (Bill O'Donnell) [1739607]
- [fs] xfs: remove the io_type field from the writeback context and ioend (Bill O'Donnell) [1739607]
- [fs] xfs: compile time offset checks for common v4/v5 metadata (Bill O'Donnell) [1739607]
- [fs] xfs: use buf ops magic to detect btree block type (Bill O'Donnell) [1739607]
- [fs] xfs: add magic numbers to dquot buffer ops (Bill O'Donnell) [1739607]
- [fs] xfs: add inode magic to inode verifier (Bill O'Donnell) [1739607]
- [fs] xfs: factor xfs_da3_blkinfo verification into common helper (Bill O'Donnell) [1739607]
- [fs] xfs: miscellaneous verifier magic value fixups (Bill O'Donnell) [1739607]
- [fs] xfs: use verifier magic field in dir2 leaf verifiers (Bill O'Donnell) [1739607]
- [fs] xfs: distinguish between bnobt and cntbt magic values (Bill O'Donnell) [1739607]
- [fs] xfs: split up allocation btree verifier (Bill O'Donnell) [1739607]
- [fs] xfs: distinguish between inobt and finobt magic values (Bill O'Donnell) [1739607]
- [fs] xfs: create a separate finobt verifier (Bill O'Donnell) [1739607]
- [fs] xfs: always check magic values in on-disk byte order (Bill O'Donnell) [1739607]
- [fs] xfs: clarify documentation for the function to reverify buffers (Bill O'Donnell) [1739607]
- [fs] xfs: cache unlinked pointers in an rhashtable (Bill O'Donnell) [1739607]
- [fs] xfs: add tracepoints for high level iunlink operations (Bill O'Donnell) [1739607]
- [fs] xfs: refactor inode update in iunlink_remove (Bill O'Donnell) [1739607]
- [fs] xfs: refactor unlinked list search and mapping to a separate function (Bill O'Donnell) [1739607]
- [fs] xfs: refactor inode unlinked pointer update functions (Bill O'Donnell) [1739607]
- [fs] xfs: strengthen AGI unlinked inode bucket pointer checks (Bill O'Donnell) [1739607]
- [fs] xfs: refactor AGI unlinked bucket updates (Bill O'Donnell) [1739607]
- [fs] xfs: add xfs_verify_agino_or_null helper (Bill O'Donnell) [1739607]
- [fs] xfs: clean up iunlink functions (Bill O'Donnell) [1739607]
- [fs] xfs: Introduce XFS_PTAG_VERIFIER_ERROR panic mask (Bill O'Donnell) [1739607]
- [fs] xfs: remove duplicated xfs_defer.h (Bill O'Donnell) [1739607]
- [fs] xfs: check attribute name validity (Bill O'Donnell) [1739607]
- [fs] xfs: check directory name validity (Bill O'Donnell) [1739607]
- [fs] xfs: fix off-by-one error in rtbitmap cross-reference (Bill O'Donnell) [1739607]
- [fs] xfs: scrub should flag dir/attr offsets that aren't mappable with xfs_dablk_t (Bill O'Donnell) [1739607]
- [fs] xfs: abort xattr scrub if fatal signals are pending (Bill O'Donnell) [1739607]
- [fs] xfs: consolidate scrub dinode mapping code into a single function (Bill O'Donnell) [1739607]
- [fs] xfs: scrub big block inode btrees correctly (Bill O'Donnell) [1739607]
- [fs] xfs: clean up the inode cluster checking in the inobt scrub (Bill O'Donnell) [1739607]
- [fs] xfs: hoist inode cluster checks out of loop (Bill O'Donnell) [1739607]
- [fs] xfs: check inobt record alignment on big block filesystems (Bill O'Donnell) [1739607]
- [fs] xfs: check the ir_startino alignment directly (Bill O'Donnell) [1739607]
- [fs] xfs: never try to scrub more than 64 inodes per inobt record (Bill O'Donnell) [1739607]
- [powerpc] powerpc: Allow flush_(inval_)dcache_range to work across ranges >4GB (Steve Best) [1744062]
- [scsi] scsi: lpfc: Fix port relogin failure due to GID_FT interaction (Dick Kennedy) [1733217]
- [rpmspec] redhat: Fix error messages during build of zfcpdump kernel (Philipp Rudo) [1745652]
- [s390] s390/protvirt: avoid memory sharing for diag 308 set/store (Philipp Rudo) [1745614]
- [infiniband] IB/hfi1: Remove extra brackets from an if (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Update I/O section to be clearer about CPU vs thread (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Fix style, spacing and grammar in I/O section (Petr Oros) [1737066]
- [powerpc] arch: Remove dummy mmiowb() definitions from arch code (Petr Oros) [1737066]
- [netdrv] net/ethernet/silan/sc92031: Remove stale comment about mmiowb() (Petr Oros) [1737066]
- [infiniband] i40iw: Redefine i40iw_mmiowb() to do nothing (Petr Oros) [1737066]
- [scsi] scsi/qla1280: Remove stale comment about mmiowb() (Petr Oros) [1737066]
- [netdrv] drivers: Remove explicit invocations of mmiowb() (Petr Oros) [1737066]
- [infiniband] drivers: Remove useless trailing comments from mmiowb() invocations (Petr Oros) [1737066]
- [documentation] Documentation: Kill all references to mmiowb() (Petr Oros) [1737066]
- [riscv] riscv/mmiowb: Hook up mmwiob() implementation to asm-generic code (Petr Oros) [1737066]
- [powerpc] powerpc/mmiowb: Hook up mmwiob() implementation to asm-generic code (Petr Oros) [1737066]
- [nds32] nds32/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [x86] x86/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [arm64] arm64/io: Remove useless definition of mmiowb() (Petr Oros) [1737066]
- [include] mmiowb: Hook up mmiowb helpers to spinlocks and generic I/O accessors (Petr Oros) [1737066]
- [arm64] arch: Use asm-generic header for asm/mmiowb.h (Petr Oros) [1737066]
- [kernel] asm-generic/mmiowb: Add generic implementation of mmiowb() tracking (Petr Oros) [1737066]
- [documentation] docs/memory-barriers.txt: Rewrite "KERNEL I/O BARRIER EFFECTS" section (Petr Oros) [1737066]
- [s390] s390/cpum_sf: save TOD clock base in SDBs for time conversion (Philipp Rudo) [1743504]
- [net] netns: provide pure entropy for net_hash_mix() (Paolo Abeni) [1737439] {CVE-2019-10639}
- [net] netns: get more entropy from net_hash_mix() (Paolo Abeni) [1737439] {CVE-2019-10639}
- [netdrv] net: phy: improve pause handling (Petr Oros) [1735763]
- [netdrv] net: phy: fix reading fixed phy status (Petr Oros) [1735763]
- [netdrv] net: phy: allow a PHY driver to define neither features nor get_features (Petr Oros) [1735763]
- [netdrv] net: phy: Add support for asking the PHY its abilities (Petr Oros) [1735763]
- [netdrv] net: phy: use genphy_read_abilities in genphy driver (Petr Oros) [1735763]
- [netdrv] net: phy: add genphy_read_abilities (Petr Oros) [1735763]
- [netdrv] net: phy: let genphy_c45_read_abilities also check aneg capability (Petr Oros) [1735763]
- [netdrv] net: phy: Add generic support for 2.5GBaseT and 5GBaseT (Petr Oros) [1735763]
- [netdrv] net: phy: Extract genphy_c45_pma_read_abilities from marvell10g (Petr Oros) [1735763]
- [netdrv] net: phy: Move of_set_phy_eee_broken to phy-core.c (Petr Oros) [1735763]
- [netdrv] net: phy: Mask-out non-compatible modes when setting the max-speed (Petr Oros) [1735763]
- [netdrv] net: phy: don't allow __set_phy_supported to add unsupported modes (Petr Oros) [1735763]
- [netdrv] net: phy: remove unneeded masking of PHY register read results (Petr Oros) [1735763]
- [netdrv] net: phy: probe the PHY before determining the supported features (Petr Oros) [1735763]
- [rpmspec] fix package summary and description for some kernel subpackages ("Herton R. Krzesinski") [1656863]
- [fs] mm/huge_memory: fix vmf_insert_pfn_{pmd, pud}() crash, handle unaligned addresses (Jeff Moyer) [1743159]
- [mm] mm/huge_memory.c: fix modifying of page protection by insert_pfn_pmd() (Jeff Moyer) [1743159]
- [arm64] arm64: disable improved unwind tables (Mark Langsdorf) [1684694]
- [arm64] arm64/stacktrace: Export save_stack_trace_regs() (Mark Langsdorf) [1684694]
- [fs] nfs4: flex_file: ignore synthetic uid/gid for tightly coupled DSes (Steve Dickson) [1655712]
- [include] futex: Update comments and docs about return values of arch futex code (Waiman Long) [1737058]
- [arm64] arm64: futex: Avoid copying out uninitialised stack in failed cmpxchg() (Waiman Long) [1737058]
- [arm64] arm64: futex: Bound number of LDXR/STXR loops in FUTEX_WAKE_OP (Waiman Long) [1737058]
- [kernel] locking/futex: Allow low-level atomic operations to return -EAGAIN (Waiman Long) [1737058]
- [arm64] arm64: futex: Fix FUTEX_WAKE_OP atomic ops with non-zero result value (Waiman Long) [1737058]
- [kernel] futex: Ensure that futex address is aligned in handle_futex_death() (Waiman Long) [1737058]
- [kernel] futex: Convert futex_pi_state.refcount to refcount_t (Waiman Long) [1737058]
- [kernel] sched/wake_q: Reduce reference counting for special users (Waiman Long) [1737058]
- [kernel] sched/wake_q: Add branch prediction hint to wake_q_add() cmpxchg (Waiman Long) [1737058]
- [kernel] futex: No need to check return value of debugfs_create functions (Waiman Long) [1737058]
- [kernel] futex: Handle early deadlock return correctly (Waiman Long) [1737058]
- [kernel] futex: Fix barrier comment (Waiman Long) [1737058]
- [kernel] futex: Cure exit race (Waiman Long) [1737058]
- [kernel] futex: Replace spin_is_locked() with lockdep (Waiman Long) [1737058]
- [kernel] futex: Mark expected switch fall-throughs (Waiman Long) [1737058]
- [kernel] sched/deadline: Correctly handle active 0-lag timers (Phil Auld) [1735907]
- [include] build_bug.h: add wrapper for _Static_assert (Ivan Vecera) [1735752]
- [include] build_bug.h: remove most of dummy BUILD_BUG_ON stubs for Sparse (Ivan Vecera) [1735752]
- [include] build_bug.h: remove negative-array fallback for BUILD_BUG_ON() (Ivan Vecera) [1735752]
- [mm] percpu: remove spurious lock dependency between percpu and sched (Rafael Aquini) [1731180]
- [mm] percpu: use chunk scan_hint to skip some scanning (Rafael Aquini) [1731180]
- [mm] percpu: convert chunk hints to be based on pcpu_block_md (Rafael Aquini) [1731180]
- [mm] percpu: make pcpu_block_md generic (Rafael Aquini) [1731180]
- [mm] percpu: use block scan_hint to only scan forward (Rafael Aquini) [1731180]
- [mm] percpu: remember largest area skipped during allocation (Rafael Aquini) [1731180]
- [mm] percpu: add block level scan_hint (Rafael Aquini) [1731180]
- [mm] percpu: set PCPU_BITMAP_BLOCK_SIZE to PAGE_SIZE (Rafael Aquini) [1731180]
- [mm] percpu: relegate chunks unusable when failing small allocations (Rafael Aquini) [1731180]
- [mm] percpu: manage chunks based on contig_bits instead of free_bytes (Rafael Aquini) [1731180]
- [mm] percpu: introduce helper to determine if two regions overlap (Rafael Aquini) [1731180]
- [mm] percpu: do not search past bitmap when allocating an area (Rafael Aquini) [1731180]
- [mm] percpu: update free path with correct new free region (Rafael Aquini) [1731180]
- [mm] mm/percpu: add checks for the return value of memblock_alloc*() (Rafael Aquini) [1731180]
- [mm] percpu: km: no need to consider pcpu_group_offsets[0] (Rafael Aquini) [1731180]
- [mm] percpu: use nr_groups as check condition (Rafael Aquini) [1731180]
- [mm] percpu: convert spin_lock_irq to spin_lock_irqsave. (Rafael Aquini) [1731180]
- [mm] mm: percpu: remove unnecessary unlikely() (Rafael Aquini) [1731180]
- [fs] /proc/meminfo: add percpu populated pages count (Rafael Aquini) [1731180]
- [netdrv] tg3: Use napi_alloc_frag() (Jonathan Toppins) [1724774]
- [fs] fuse: fix copy_file_range() in the writeback case (Miklos Szeredi) [1650518]
- [fs] fuse: add support for copy_file_range() (Miklos Szeredi) [1650518]

* Thu Sep 26 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-147.1.el8]
- [x86] perf/x86/intel: Fix spurious NMI on fixed counter (Michael Petlan) [1755110]
- [x86] perf/x86/intel: Fix race in intel_pmu_disable_event() (Michael Petlan) [1755110]
- [netdrv] drivers: tap.c: fix wrong backport causing WARN_ON_ONCE(1) in skb_flow_dissect() (Davide Caratti) [1750711]
- [virt] KVM: coalesced_mmio: add bounds checking (Bandan Das) [1746804] {CVE-2019-14821}

* Wed Sep 25 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-146.1.el8]
- [fs] gfs2: clear buf_in_tr when ending a transaction in sweep_bh_for_rgrps (Robert S Peterson) [1750939]
- [s390] kvm: s390: kvm_s390_vm_start_migration: check dirty_bitmap before using it as target for memset() (Thomas Huth) [1753260]
- [fs] cifs: fix credits leak for SMB1 oplock breaks (Leif Sahlberg) [1752243]

* Tue Sep 24 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-145.1.el8]
- Revert "[redhat] switch secureboot kernel image signing to release keys" (Phillip Lougher)
- [iommu] iommu/amd: Add support for X2APIC IOMMU interrupts (Suravee Suthikulpanit) [1734842]
- [vhost] vhost: make sure log_num < in_num (Eugenio Perez) [1750882] {CVE-2019-14835}

* Thu Sep 19 2019 Phillip Lougher <plougher@redhat.com> [4.18.0-144.1.el8]
- [kernel] open the RHEL 8.2 development (Phillip Lougher)
- [md] Revert "[md] dm: eliminate 'split_discard_bios' flag from DM target interface" (Mike Snitzer) [1749929]
- [md] Revert "[md] dm: make sure to obey max_io_len_target_boundary" (Mike Snitzer) [1749929]
- [pci] PCI: Restore Resizable BAR size bits correctly for 1MB BARs (Myron Stowe) [1717760]
- [net] netfilter: nft_fib_netdev: Terminate rule eval if protocol=IPv6 and ipv6 module is disabled (Phil Sutter) [1743945]
- [net] netfilter: bridge: Drops IPv6 packets if IPv6 module is not loaded (Phil Sutter) [1743945]
- [drm] drm/qxl: get vga ioports (Gerd Hoffmann) [1728936]
- [drm] drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe() (Lyude Paul) [1724363]

* Thu Sep 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-144.el8]
- [md] Revert "[md] dm: eliminate 'split_discard_bios' flag from DM target interface" (Mike Snitzer) [1749929]
- [md] Revert "[md] dm: make sure to obey max_io_len_target_boundary" (Mike Snitzer) [1749929]
- [pci] PCI: Restore Resizable BAR size bits correctly for 1MB BARs (Myron Stowe) [1717760]
- [net] netfilter: nft_fib_netdev: Terminate rule eval if protocol=IPv6 and ipv6 module is disabled (Phil Sutter) [1743945]
- [net] netfilter: bridge: Drops IPv6 packets if IPv6 module is not loaded (Phil Sutter) [1743945]
- [drm] drm/qxl: get vga ioports (Gerd Hoffmann) [1728936]
- [drm] drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe() (Lyude Paul) [1724363]

* Mon Sep 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-143.el8]
- [net] netfilter: nft_set: fix allocation size overflow in privsize callback. (Florian Westphal) [1746338]
- [net] net: route dump netlink NLM_F_MULTI flag missing (Stefano Brivio) [1745971]
- [net] sched: pfifo_fast: fix wrong dereference in pfifo_fast_enqueue (Davide Caratti) [1745390]
- [net] sched: pfifo_fast: fix wrong dereference when qdisc is reset (Davide Caratti) [1745387]
- [scsi] scsi: vmw_pscsi: Fix use-after-free in pvscsi_queue_lck() (David Milburn) [1746597]

* Fri Sep 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-142.el8]
- [drm] drm/virtio: use virtio_max_dma_size (Gerd Hoffmann) [1739291]
- [mm] hwpoison, memory_hotplug: allow hwpoisoned pages to be offlined (Rafael Aquini) [1706088]
- [powerpc] kvm: ppc: book3s: Enable XIVE native capability only if OPAL has required functions [BZ1744884] (David Gibson) [1744884]
- [scsi] scsi: lpfc: Fix oops when fewer hdwqs than cpus (Dick Kennedy) [1745731]
- [scsi] scsi: lpfc: Limit xri count for kdump environment (Dick Kennedy) [1745731]
- [scsi] scsi: lpfc: Mitigate high memory pre-allocation by SCSI-MQ (Dick Kennedy) [1745731]
- [scsi] scsi: qla2xxx: Fix hardirq-unsafe locking (Himanshu Madhani) [1719941]
- [x86] Revert "[x86] x86/kexec/64: Prevent kexec from 5-level paging to a 4-level only kernel" (Baoquan He) [1669088]
- [x86] Revert "[x86] x86/boot: Add xloadflags bits to check for 5-level paging support" (Baoquan He) [1669088]

* Fri Aug 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-141.el8]
- [wireless] mwifiex: fix 802.11n/WPA detection (Jarod Wilson) [1714476] {CVE-2019-3846}

* Thu Aug 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-140.el8]
- [x86] x86/kdump: Reserve extra memory when SME or SEV is active (Kairui Song) [1728519]
- [scsi] scsi: qla2xxx: Fix hardlockup in abort command during driver remove (Himanshu Madhani) [1690041]
- [scsi] qla2xxx: Update driver version to 10.01.00.15.08.1-k1 (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix panic from use after free in qla2x00_async_tm_cmd (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: cleanup trace buffer initialization (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: qla2x00_alloc_fw_dump: set ha->eft (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Use mutex protection during qla2x00_sysfs_read_fw_dump() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: move IO flush to the front of NVME rport unregistration (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix NVME cmd and LS cmd timeout race condition (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Complain loudly about reference count underflow (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix race conditions in the code for aborting SCSI commands (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Use an on-stack completion in qla24xx_control_vp() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Change abort wait_loop from msleep to wait_event_timeout (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Set the SCSI command result before calling the command done (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: on session delete, return nvme cmd (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix kernel crash after disconnecting NVMe devices (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Remove the fcport test from qla_nvme_abort_work() (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix driver unload when FC-NVMe LUNs are connected (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Set remote port devloss timeout to 0 (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix panic in qla_dfs_tgt_counters_show (Himanshu Madhani) [1690041]
- [scsi] scsi: qla2xxx: Fix fw dump corruption (Himanshu Madhani) [1690041]
- [x86] kvm: disable nested virt on pre-haswell processors (Paolo Bonzini) [1739739]
- [x86] kvm: taint kernel for tech-preview when using nested virtualization (Paolo Bonzini) [1739739]
- [x86] kvm: x86: hyper-v: don't crash on KVM_GET_SUPPORTED_HV_CPUID when kvm_intel.nested is disabled (Vitaly Kuznetsov) [1746100]

* Tue Aug 27 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-139.el8]
- [char] ipmi: move message error checking to avoid deadlock (Tony Camuso) [1731388 1718699]
- [crypto] crypto: testmgr - mark crc32 checksum as FIPS allowed (Neil Horman) [1738887]
- [include] dma-mapping: use dma_get_mask in dma_addressing_limited (Don Dutile) [1738631]
- [kernel] dma-direct: correct the physical addr in dma_direct_sync_sg_for_cpu/device (Don Dutile) [1738631]
- [kernel] dma-direct: only limit the mapping size if swiotlb could be used (Don Dutile) [1738631]
- [include] dma-mapping: add a dma_addressing_limited helper (Don Dutile) [1738631]
- [kernel] dma-direct: Force unencrypted DMA under SME for certain DMA masks (Don Dutile) [1738631]
- [lib] lib/genalloc: introduce chunk owners (Don Dutile) [1738631]
- [lib] lib/genalloc: add gen_pool_dma_zalloc() for zeroed DMA allocations (Don Dutile) [1738631]
- [lib] lib/genalloc.c: fix allocation of aligned buffer from non-aligned chunk (Don Dutile) [1738631]
- [include] dma-mapping: remove dma_max_pfn (Don Dutile) [1738631]
- [mmc] mmc: core: let the dma map ops handle bouncing (Don Dutile) [1738631]
- [mmc] mmc: core: align max segment size with logical block size (Don Dutile) [1738631]
- [kernel] swiotlb: no need to check return value of debugfs_create functions (Don Dutile) [1738631]
- [xen] swiotlb: fix phys_addr_t overflow warning (Don Dutile) [1738631]
- [kernel] swiotlb: Return consistent SWIOTLB segments/nr_tbl (Don Dutile) [1738631]
- [kernel] swiotlb: Group identical cleanup in swiotlb_cleanup() (Don Dutile) [1738631]
- [kernel] swiotlb: save io_tlb_used to local variable before leaving critical section (Don Dutile) [1738631]
- [kernel] swiotlb: dump used and total slots when swiotlb buffer is full (Don Dutile) [1738631]
- [kernel] swiotlb: add checks for the return value of memblock_alloc*() (Don Dutile) [1738631]
- [kernel] swiotlb: add debugfs to track swiotlb buffer usage (Don Dutile) [1738631]
- [kernel] dma-direct: fix DMA_ATTR_NO_KERNEL_MAPPING (Don Dutile) [1738631]
- [kernel] dma-direct: handle DMA_ATTR_NO_KERNEL_MAPPING in common code (Don Dutile) [1738631]
- [kernel] dma-direct: fix DMA_ATTR_NO_KERNEL_MAPPING for remapped allocations (Don Dutile) [1738631]
- [kernel] dma-mapping: remove a pointless memset in dma_atomic_pool_init (Don Dutile) [1738631]
- [kernel] dma-mapping: fix lack of DMA address assignment in generic remap allocator (Don Dutile) [1738631]
- [kernel] dma-remap: support DMA_ATTR_NO_KERNEL_MAPPING (Don Dutile) [1738631]
- [kernel] dma-mapping: support highmem in the generic remap allocator (Don Dutile) [1738631]
- [kernel] dma-direct: handle DMA_ATTR_NON_CONSISTENT in common code (Don Dutile) [1738631]
- [kernel] dma-mapping: add a dma_alloc_need_uncached helper (Don Dutile) [1738631]
- [kernel] dma-mapping: truncate dma masks to what dma_addr_t can hold (Don Dutile) [1738631]
- [kernel] dma-remap: Avoid de-referencing NULL atomic_pool (Don Dutile) [1738631]
- [include] dma-buf: add DMA_BUF_SET_NAME ioctls (Don Dutile) [1738631]
- [include] dma-buf: give each buffer a full-fledged inode (Don Dutile) [1738631]
- [fs] new wrapper: alloc_file_pseudo() (Don Dutile) [1738631]
- [kernel] dma-direct: provide generic support for uncached kernel segments (Don Dutile) [1738631]
- [include] dma-contiguous: fix !CONFIG_DMA_CMA version of dma_{alloc, free}_contiguous() (Don Dutile) [1738631]
- [kernel] dma-contiguous: use fallback alloc_pages for single pages (Don Dutile) [1738631]
- [kernel] dma-contiguous: add dma_{alloc,free}_contiguous() helpers (Don Dutile) [1738631]
- [iommu] iommu/dma: Fix condition check in iommu_dma_unmap_sg (Don Dutile) [1738631]
- [iommu] iommu/dma: move the arm64 wrappers to common code (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu.c: convert to use vm_map_pages() (Don Dutile) [1738631]
- [mm] mm: introduce new vm_map_pages() and vm_map_pages_zero() API (Don Dutile) [1738631]
- [mm] arm64/iommu: handle non-remapped addresses in ->mmap and ->get_sgtable (Don Dutile) [1738631]
- [arm64] arm64/mm: wire up CONFIG_ARCH_HAS_SET_DIRECT_MAP (Don Dutile) [1738631]
- [kernel] mm/hibernation: Make hibernation handle unmapped pages (Don Dutile) [1738631]
- [mm] page_poison: play nicely with KASAN (Don Dutile) [1738631]
- [mm] mm/vmalloc: Avoid rare case of flushing TLB with weird arguments (Don Dutile) [1738631]
- [mm] mm/vmalloc: Fix calculation of direct map addr range (Don Dutile) [1738631]
- [mm] mm/vmalloc: Add flag for freeing of special permsissions (Don Dutile) [1738631]
- [x86] x86/mm/cpa: Add set_direct_map_*() functions (Don Dutile) [1738631]
- [arm64] dma-mapping: add a kconfig symbol for arch_setup_dma_ops availability (Don Dutile) [1738631]
- [iommu] iommu/dma: Remove the flush_page callback (Don Dutile) [1738631]
- [include] iommu/dma: Cleanup dma-iommu.h (Don Dutile) [1738631]
- [dma] dmaengine: Add matching device node validation in __dma_request_channel() (Don Dutile) [1738631]
- [dma] dmaengine: dma_request_chan_by_mask() to handle deferred probing (Don Dutile) [1738631]
- [include] dma-buf: start caching of sg_table objects v2 (Don Dutile) [1738631]
- [kernel] dma-mapping: add a Kconfig symbol to indicate arch_dma_prep_coherent presence (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu: Remove iommu_dma_map_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/ls-scfg-msi: Don't map the MSI page in ls_scfg_msi_compose_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-mbi: Don't map the MSI page in mbi_compose_m{b, s}i_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gicv2m: Don't map the MSI page in gicv2m_compose_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-its: Don't map the MSI page in its_irq_compose_msi_msg() (Don Dutile) [1738631]
- [irqchip] irqchip/gic-v3-its: Align PCI Multi-MSI allocation on their size (Don Dutile) [1738631]
- [iommu] iommu/dma-iommu: Split iommu_dma_map_msi_msg() in two parts (Don Dutile) [1738631]
- [iommu] iommu/dma: Remove unused variable (Don Dutile) [1738631]
- [iommu] iommu/dma: Use NUMA aware memory allocations in __iommu_dma_alloc_pages() (Don Dutile) [1738631]
- [kernel] genirq/msi: Add a new field in msi_desc to store an IOMMU cookie (Don Dutile) [1738631]
- [pci] PCI/MSI: Remove unused mask_msi_irq() and unmask_msi_irq() (Don Dutile) [1738631]
- [include] PCI/MSI: Remove unused __write_msi_msg() and write_msi_msg() (Don Dutile) [1738631]
- [include] genirq/msi: Clean up usage of __u8/__u16 types (Don Dutile) [1738631]
- [base] platform-msi: Free descriptors in platform_msi_domain_free() (Don Dutile) [1738631]
- [base] genirq/msi: Allow creation of a tree-based irqdomain for platform-msi (Don Dutile) [1738631]
- [kernel] dma-debug: only skip one stackframe entry (Don Dutile) [1738631]
- [dma] dmaengine: idma64: Move driver name to the header (Don Dutile) [1738631]
- [kernel] dma-mapping: remove an unnecessary NULL check (Don Dutile) [1738631]
- [include] dma-buf: Update [un]map documentation to match the other functions (Don Dutile) [1738631]
- [include] dma-buf: Remove leftover [un]map_atomic comments (Don Dutile) [1738631]
- [x86] x86/dma: Remove the x86_dma_fallback_dev hack (Don Dutile) [1738631]
- [kernel] dma-mapping: remove leftover NULL device support (Don Dutile) [1738631]
- [kernel] dma: select GENERIC_ALLOCATOR for DMA_REMAP (Don Dutile) [1738631]
- [crypto] crypto: ccp - Ignore unconfigured CCP device on suspend/resume (Gary Hook) [1743999]
- [md] dm snapshot: fix oversights in optional discard support (Mike Snitzer) [1744291]
- [md] dm snapshot: add optional discard support features (Mike Snitzer) [1744291]
- [md] dm snapshot: Use fine-grained locking scheme (Mike Snitzer) [1744291]
- [md] dm snapshot: Make exception tables scalable (Mike Snitzer) [1744291]
- [md] dm snapshot: Replace mutex with rw semaphore (Mike Snitzer) [1744291]
- [md] dm snapshot: Don't sleep holding the snapshot lock (Mike Snitzer) [1744291]
- [include] list_bl: Add hlist_bl_add_before/behind helpers (Mike Snitzer) [1744291]
- [powerpc] powerpc/rtas: use device model APIs and serialization during LPM (Steve Best) [1741643]
- [firmware] firmware/efi: Add NULL pointer checks in efivars API functions (Jarod Wilson) [1741949]
- [fs] ovl: fix wrong flags check in FS_IOC_FS[SG]ETXATTR ioctls (Miklos Szeredi) [1724518]
- [include] mm: page_cache_add_speculative(): refactor out some code duplication (Michael Petlan) [1738331]
- [netdrv] ibmvnic: Unmap DMA address of TX descriptor buffers after use (Steve Best) [1743155]
- [fs] NFSv4.1 don't free interrupted slot on open (Steve Dickson) [1708345]
- [fs] NFSv4.1: Avoid false retries when RPC calls are interrupted (Steve Dickson) [1708345]
- [net] ipv6: Fix return value of ipv6_mc_may_pull() for malformed packets (Stefano Brivio) [1743203]
- [net] inet: frags: re-introduce skb coalescing for local delivery (Guillaume Nault) [1719418]

* Mon Aug 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-138.el8]
- [net] xfrm: fix sa selector validation (Sabrina Dubroca) [1738871]
- [net] xfrm: Fix xfrm sel prefix length validation (Sabrina Dubroca) [1738871]
- [kernel] locking/rwsem: Prevent decrement of reader count before increment (Waiman Long) [1740338]
- [include] include/list: Backport list_cut_before() (Waiman Long) [1740338]
- [vhost] vhost: vsock: add weight support (Jason Wang) [1738494]
- [vhost] vhost_net: fix possible infinite loop (Jason Wang) [1738494]
- [vhost] vhost: introduce vhost_exceeds_weight() (Jason Wang) [1738494]
- [vhost] vhost: reject zero size iova range (Jason Wang) [1738494]
- [vhost] vhost: silence an unused-variable warning (Jason Wang) [1738494]
- [vhost] vhost: correctly check the return value of translate_desc() in log_used() (Jason Wang) [1738494]
- [vhost] vhost: return EINVAL if iovecs size does not match the message size (Jason Wang) [1738494]
- [vhost] Revert "net: vhost: lock the vqs one by one" (Jason Wang) [1738494]
- [vhost] vhost_net: switch to use mutex_trylock() in vhost_net_busy_poll() (Jason Wang) [1738494]
- [vhost] vhost: make sure used idx is seen before log in vhost_add_used_n() (Jason Wang) [1738494]
- [vhost] vhost: fix IOTLB locking (Jason Wang) [1738494]
- [netdrv] tun: wake up waitqueues after IFF_UP is set (Jason Wang) [1738494]
- [netdrv] tuntap: synchronize through tfiles array instead of tun->numqueues (Jason Wang) [1738494]
- [netdrv] tuntap: fix dividing by zero in ebpf queue selection (Jason Wang) [1738494]
- [netdrv] tun: Remove unused first parameter of tun_get_iff() (Jason Wang) [1738494]
- [netdrv] tun: Add ioctl() TUNGETDEVNETNS cmd to allow obtaining real net ns of tun device (Jason Wang) [1738494]
- [netdrv] tun: add a missing rcu_read_unlock() in error path (Jason Wang) [1738494]
- [netdrv] tun: properly test for IFF_UP (Jason Wang) [1738494]
- [netdrv] tun: remove unnecessary memory barrier (Jason Wang) [1738494]
- [netdrv] tun: fix blocking read (Jason Wang) [1738494]
- [netdrv] tun: move the call to tun_set_real_num_queues (Jason Wang) [1738494]
- [netdrv] tun: publish tfile after it's fully initialized (Jason Wang) [1738494]
- [netdrv] tun: replace get_cpu_ptr with this_cpu_ptr when bh disabled (Jason Wang) [1738494]
- [netdrv] tun: remove skb access after netif_receive_skb (Jason Wang) [1738494]
- [netdrv] tun: remove unnecessary check in tun_flow_update (Jason Wang) [1738494]
- [netdrv] tuntap: fix multiqueue rx (Jason Wang) [1738494]
- [netdrv] tun: Adjust on-stack tun_page initialization. (Jason Wang) [1738494]
- [netdrv] tuntap: free XDP dropped packets in a batch (Jason Wang) [1738494]
- [vhost] vhost_net: mitigate page reference counting during page frag refill (Jason Wang) [1738494]
- [vhost] net: vhost: remove bad code line (Jason Wang) [1738494]
- [vhost] net: vhost: add rx busy polling in tx path (Jason Wang) [1738494]
- [vhost] net: vhost: factor out busy polling logic to vhost_net_busy_poll() (Jason Wang) [1738494]
- [vhost] net: vhost: replace magic number of lock annotation (Jason Wang) [1738494]
- [vhost] net: vhost: lock the vqs one by one (Jason Wang) [1738494]
- [vhost] vhost_net: add a missing error return (Jason Wang) [1738494]
- [netdrv] net: tun: remove useless codes of tun_automq_select_queue (Jason Wang) [1738494]
- [vhost] vhost_net: batch submitting XDP buffers to underlayer sockets (Jason Wang) [1738494]
- [netdrv] tap: accept an array of XDP buffs through sendmsg() (Jason Wang) [1738494]
- [netdrv] tuntap: accept an array of XDP buffs through sendmsg() (Jason Wang) [1738494]
- [netdrv] tun: switch to new type of msg_control (Jason Wang) [1738494]
- [netdrv] tuntap: move XDP flushing out of tun_do_xdp() (Jason Wang) [1738494]
- [netdrv] tuntap: split out XDP logic (Jason Wang) [1738494]
- [netdrv] tuntap: tweak on the path of skb XDP case in tun_build_skb() (Jason Wang) [1738494]
- [netdrv] tuntap: simplify error handling in tun_build_skb() (Jason Wang) [1738494]
- [netdrv] tuntap: enable bh early during processing XDP (Jason Wang) [1738494]
- [netdrv] tuntap: switch to use XDP_PACKET_HEADROOM (Jason Wang) [1738494]
- [netdrv] net: sock: introduce SOCK_XDP (Jason Wang) [1738494]
- [vhost] vhost: correctly check the iova range when waking virtqueue (Jason Wang) [1738494]
- [vhost] vhost: switch to use new message format (Jason Wang) [1738494]
- [vhost] vhost_net: batch update used ring for datacopy TX (Jason Wang) [1738494]
- [vhost] vhost_net: rename VHOST_RX_BATCH to VHOST_NET_BATCH (Jason Wang) [1738494]
- [vhost] vhost_net: rename vhost_rx_signal_used() to vhost_net_signal_used() (Jason Wang) [1738494]
- [vhost] vhost_net: split out datacopy logic (Jason Wang) [1738494]
- [vhost] vhost_net: introduce tx_can_batch() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce get_tx_bufs() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce vhost_exceeds_weight() (Jason Wang) [1738494]
- [vhost] vhost_net: introduce helper to initialize tx iov iter (Jason Wang) [1738494]
- [vhost] vhost_net: drop unnecessary parameter (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid rx vring kicks during busyloop (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid rx queue wake-ups during busypoll (Jason Wang) [1738494]
- [vhost] vhost_net: Avoid tx vring kicks during busyloop (Jason Wang) [1738494]
- [vhost] vhost_net: Rename local variables in vhost_net_rx_peek_head_len (Jason Wang) [1738494]
- [mm] x86/mm/fault: Allow stack access below rsp (Waiman Long) [1739341]
- [mm] x86/mm: Clarify hardware vs. software "error_code" (Waiman Long) [1739341]
- [net] libceph: handle an empty authorize reply (Ilya Dryomov) [1720582]

* Thu Aug 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-137.el8]
- [drm] drm: Don't retry infinitely when receiving no data on i2c over AUX (Lyude Paul) [1672361]
- [scsi] scsi: hpsa: update revision to RH3 (Joseph Szczypek) [1739615]
- [scsi] scsi: hpsa: remove printing internal cdb on tag collision (Joseph Szczypek) [1739615]
- [scsi] scsi: hpsa: correct scsi command status issue after reset (Joseph Szczypek) [1739615]
- [scsi] hpsa: docs: fix broken doc references due to renames (Joseph Szczypek) [1739615]
- [scsi] hpsa: docs: pci: fix broken links due to conversion from pci.txt to pci.rst (Joseph Szczypek) [1739615]

* Tue Aug 20 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-136.el8]
- [drm] drm/nouveau: Only recalculate PBN/VCPI on mode/connector changes (Lyude Paul) [1734452 1734444]
- [drm] drm/nouveau: Only release VCPI slots on mode changes (Lyude Paul) [1734452 1734444]
- [infiniband] RDMA/srp: turn off 'use_imm_data' by default (Honggang Li) [1725158]
- [gpu] vga_switcheroo: Fix missing gpu_bound call at audio client registration (Lyude Paul) [1739727]
- [net] Bluetooth: Fix faulty expression for minimum encryption key size check (Gopal Tiwari) [1743076] {CVE-2019-9506}
- [net] Bluetooth: Fix regression with minimum encryption key size alignment (Gopal Tiwari) [1743076] {CVE-2019-9506}
- [net] Bluetooth: Align minimum encryption key size for LE and BR/EDR connections (Gopal Tiwari) [1743076] {CVE-2019-9506}

* Fri Aug 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-135.el8]
- [rpmspec] perf: package tips.txt (Michael Petlan) [1663816]
- [mm] mm/memblock.c: skip kmemleak for kasan_init() (Mark Langsdorf) [1722741]
- [kernel] mm/resource: Return real error codes from walk failures (Kairui Song) [1740443]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64 (Michael Petlan) [1733231]
- [tools] selftests/powerpc: Fix Makefiles for headers_install change (Steve Best) [1740127]
- [tools] selftests/powerpc: Add more version checks to alignment_handler test (Steve Best) [1740127]
- [tools] selftests/powerpc: Skip earlier in alignment_handler test (Steve Best) [1740127]
- [tools] selftests/powerpc: Consolidate copy/paste test logic (Steve Best) [1740127]
- [s390] s390/bpf: use 32-bit index for tail calls (Yauheni Kaliuta) [1719377]
- [s390] s390/bpf: fix lcgr instruction encoding (Yauheni Kaliuta) [1719377]
- [tools] selftests/bpf: fix "alu with different scalars 1" on s390 (Yauheni Kaliuta) [1719377]
- [net] bpf: fix use after free in bpf_evict_inode (Yauheni Kaliuta) [1719377]
- [arm64] bpf, arm64: remove prefetch insn in xadd mapping (Yauheni Kaliuta) [1719377]
- [scsi] scsi: lpfc: Fix crash when cpu count is 1 and null irq affinity mask (Dick Kennedy) [1720905]
- [md] md: add bitmap_abort label in md_run (Nigel Croxon) [1721944]
- [md] md-bitmap: create and destroy wb_info_pool with the change of bitmap (Nigel Croxon) [1721944]
- [md] md-bitmap: create and destroy wb_info_pool with the change of backlog (Nigel Croxon) [1721944]
- [md] md: introduce mddev_create/destroy_wb_pool for the change of member device (Nigel Croxon) [1721944]
- [md] md/raid1: fix potential data inconsistency issue with write behind device (Nigel Croxon) [1721944]
- [md] md: fix for divide error in status_resync (Nigel Croxon) [1721944]
- [md] md/raid10: read balance chooses idlest disk for SSD (Nigel Croxon) [1721944]
- [md] md: raid1-10: Unify r{1,10}bio_pool_free (Nigel Croxon) [1721944]
- [md] md: raid10: Use struct_size() in kmalloc() (Nigel Croxon) [1721944]
- [md] md/raid1: get rid of extra blank line and space (Nigel Croxon) [1721944]
- [md] md: fix spelling typo and add necessary space (Nigel Croxon) [1721944]
- [md] md: md.c: Return -ENODEV when mddev is NULL in rdev_attr_show (Nigel Croxon) [1721944]
- [md] raid5-cache: Need to do start() part job after adding journal device (Nigel Croxon) [1721944]
- [md] drivers: md: Unify common definitions of raid1 and raid10 (Nigel Croxon) [1721944]
- [kernel] userfaultfd: use RCU to free the task struct when fork fails (Andrea Arcangeli) [1718498]

* Thu Aug 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-134.el8]
- [efi] efi/arm: Revert "Defer persistent reservations until after paging_init()" (Mark Salter) [1699961]
- [s390] s390/ipl: Fix detection of has_secure attribute (Philipp Rudo) [1740653]
- [fs] xfs: don't crash on null attr fork xfs_bmapi_read (Bill O'Donnell) [1719094]
- [powerpc] powerpc/mm: Don't report PUDs as memory leaks when using kmemleak (Desnes Augusto Nunes do Rosario) [1716952]
- [x86] kvm: x86: introduce is_pae_paging (Vitaly Kuznetsov) [1720556]
- [s390] s390/kasan: Fix recursion loop when triggering kdump (Philipp Rudo) [1740249]
- [s390] s390/dasd: fix endless loop after read unit address configuration (Philipp Rudo) [1740251]
- [tools] selftests/powerpc: Give some tests longer to run (Steve Best) [1740420]
- [nvme] nvme-rdma: use dynamic dma mapping per command (David Milburn) [1738252]
- [nvme] nvme-rdma: remove redundant reference between ib_device and tagset (David Milburn) [1738252]
- [x86] kvm: svm/avic: Do not send AVIC doorbell to self (Janakarajan Natarajan) [1720981]
- [net] tipc: initialise addr_trial_end when setting node addresses (Jon Maloy) [1740317]
- [net] tipc: ensure head->lock is initialised (Jon Maloy) [1740317]
- [net] netfilter: nf_tables: fix oops during rule dump (Stefano Brivio) [1739734]
- [include] netfilter: nf_tables: correct NFT_LOGLEVEL_MAX value (Stefano Brivio) [1739734]
- [net] netfilter: nft_compat: do not dump private area (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: fix register ordering (Stefano Brivio) [1739734]
- [net] ipvs: defer hook registration to avoid leaks (Stefano Brivio) [1739734]
- [net] ipvs: Fix use-after-free in ip_vs_in (Stefano Brivio) [1739734]
- [net] netfilter: nf_conntrack_h323: restore boundary check correctness (Stefano Brivio) [1739734]
- [net] netfilter: fix nf_l4proto_log_invalid to log invalid packets (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: prevent shift wrap in nft_chain_parse_hook() (Stefano Brivio) [1739734]
- [net] netfilter: nft_set_rbtree: check for inactive element after flag mismatch (Stefano Brivio) [1739734]
- [net] netfilter: nft_compat: use-after-free when deleting targets (Stefano Brivio) [1739734]
- [net] netfilter: nf_tables: fix leaking object reference count (Stefano Brivio) [1739734]
- [net] ip6_gre: reload ipv6h in prepare_ip6gre_xmit_ipv6 (Stefano Brivio) [1739640]
- [net] ipv6: Unlink sibling route in case of failure (Stefano Brivio) [1739640]
- [net] ipv6: Default fib6_type to RTN_UNICAST when not set (Stefano Brivio) [1739640]
- [net] inet: frags: call inet_frags_fini() after unregister_pernet_subsys() (Stefano Brivio) [1739640]
- [net] ipv6: flowlabel: fl6_sock_lookup() must use atomic_inc_not_zero (Stefano Brivio) [1739640]
- [net] netfilter: ipset: Fix rename concurrency with listing (Stefano Brivio) [1739578]
- [net] netfilter: ipset: Fix error path in set_target_v3_checkentry() (Stefano Brivio) [1739578]
- [net] netfilter: ipset: Fix the last missing check of nla_parse_deprecated() (Stefano Brivio) [1739578]
- [net] netfilter: ipset: fix a missing check of nla_parse (Stefano Brivio) [1739578]
- [netdrv] ipvlan, l3mdev: fix broken l3s mode wrt local routes (Guillaume Nault) [1738329]
- [net] sched: use temporary variable for actions indexes (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] sched: cbs: Fix error path of cbs_module_init (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] netem: fix use after free and double free with packet corruption (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [net] netem: fix backlog accounting for corrupted GSO frames (Marcelo Leitner) [1739244 1729822 1729818 1729398]
- [netdrv] macsec: fix checksumming after decryption (Sabrina Dubroca) [1738237]
- [netdrv] macsec: fix use-after-free of skb during RX (Sabrina Dubroca) [1738237]
- [net] xfrm interface: fix memory leak on creation (Sabrina Dubroca) [1738267]
- [net] tls: fix socket wmem accounting on fallback with netem (Sabrina Dubroca) [1739260]
- [net] tls: fix poll ignoring partially copied records (Sabrina Dubroca) [1739260]
- [net] tls: make sure offload also gets the keys wiped (Sabrina Dubroca) [1739260]
- [net] tls: reject offload of TLS 1.3 (Sabrina Dubroca) [1739260]
- [net] tls: fix page double free on TX cleanup (Sabrina Dubroca) [1739260]
- [net] tls, correctly account for copied bytes with multiple sk_msgs (Sabrina Dubroca) [1739260]
- [net] tcp: fix tcp_set_congestion_control() use from bpf hook (Guillaume Nault) [1738272]
- [net] tcp: Reset bytes_acked and bytes_received when disconnecting (Guillaume Nault) [1738272]
- [net] tcp: Ensure DCTCP reacts to losses (Guillaume Nault) [1738272]
- [net] tcp: tcp_v4_err() should be more careful (Guillaume Nault) [1738272]
- [net] tcp: avoid resetting ACK timer upon receiving packet with ECN CWR flag (Guillaume Nault) [1738272]
- [net] tcp: always ACK immediately on hole repairs (Guillaume Nault) [1738272]
- [net] tcp: avoid resetting ACK timer in DCTCP (Guillaume Nault) [1738272]
- [net] tcp: mandate a one-time immediate ACK (Guillaume Nault) [1738272]
- [net] tipc: fix unitilized skb list crash (Xin Long) [1734298]
- [net] tipc: compat: allow tipc commands without arguments (Xin Long) [1738397]
- [net] sctp: factor out sctp_connect_add_peer (Xin Long) [1738393]
- [net] sctp: factor out sctp_connect_new_asoc (Xin Long) [1738393]
- [net] sctp: clean up __sctp_connect (Xin Long) [1738393]
- [net] sctp: check addr_size with sa_family_t size in __sctp_setsockopt_connectx (Xin Long) [1738393]
- [net] sctp: only copy the available addr data in sctp_transport_init (Xin Long) [1738393]
- [net] sctp: drop unneeded likely() call around IS_ERR() (Xin Long) [1738393]
- [net] sctp: fix warning "NULL check before some freeing functions is not needed" (Xin Long) [1738393]
- [net] sctp: remove rcu_read_lock from sctp_bind_addr_state (Xin Long) [1738393]
- [net] sctp: rename sp strm_interleave to ep intl_enable (Xin Long) [1738393]
- [net] sctp: rename asoc intl_enable to asoc peer.intl_capable (Xin Long) [1738393]
- [net] sctp: remove prsctp_enable from asoc (Xin Long) [1738393]
- [net] sctp: remove reconf_enable from asoc (Xin Long) [1738393]
- [net] sctp: count data bundling sack chunk for outctrlchunks (Xin Long) [1738393]
- [net] sctp: fix error handling on stream scheduler initialization (Xin Long) [1738393]
- [net] sctp: not bind the socket in sctp_connect (Xin Long) [1738393]
- [net] sctp: change to hold sk after auth shkey is created successfully (Xin Long) [1738393]
- [net] sctp: Free cookie before we memdup a new one (Xin Long) [1738393]
- [net] Fix memory leak in sctp_process_init (Xin Long) [1738393]
- [net] sctp: deduplicate identical skb_checksum_ops (Xin Long) [1738393]
- [net] sctp: Check address length before reading address family (Xin Long) [1738393]
- [net] sctp: Pass sk_buff_head explicitly to sctp_ulpq_tail_event(). (Xin Long) [1738393]
- [net] sctp: Make sctp_enqueue_event tak an skb list. (Xin Long) [1738393]
- [net] sctp: Use helper for sctp_ulpq_tail_event() when hooked up to ->enqueue_event (Xin Long) [1738393]
- [net] sctp: Always pass skbs on a list to sctp_ulpq_tail_event(). (Xin Long) [1738393]
- [net] sctp: Remove superfluous test in sctp_ulpq_reasm_drain(). (Xin Long) [1738393]
- [netdrv] ppp: Remove direct skb_queue_head list pointer access. (Xin Long) [1738393]
- [net] ipv6: fix neighbour resolution with raw socket (Stefano Brivio) [1728320]
- [net] ipv6: constify rt6_nexthop() (Stefano Brivio) [1728320]
- [net] openvswitch: fix csum updates for MPLS actions (Marcelo Leitner) [1738654]
- [net] udp_gso: Allow TX timestamp with UDP GSO (Paolo Abeni) [1738585]
- [net] bpf: udp: ipv6: Avoid running reuseport's bpf_prog from __udp6_lib_err (Paolo Abeni) [1738585]
- [net] fix ifindex collision during namespace removal (Paolo Abeni) [1738492]
- [net] rtnl: return early from rtnl_unregister_all when protocol isn't registered (Paolo Abeni) [1738492]
- [net] neigh: fix use-after-free read in pneigh_get_next (Paolo Abeni) [1738492]
- [net] socket: set sock->sk to NULL after calling proto_ops::release() (Paolo Abeni) [1738492]
- [net] socket: make bond ioctls go through compat_ifreq_ioctl() (Paolo Abeni) [1738492]
- [net] socket: fix SIOCGIFNAME in compat (Paolo Abeni) [1738492]
- [net] Revert "kill dev_ifsioc()" (Paolo Abeni) [1738492]
- [net] revert "socket: fix struct ifreq size in compat ioctl" (Paolo Abeni) [1738492]
- [net] ip6_tunnel: fix possible use-after-free on xmit (Guillaume Nault) [1737105]
- [net] genetlink: Fix a memory leak on error path (Guillaume Nault) [1737821]
- [net] netfilter: ipset: Copy the right MAC address in bitmap:ip, mac and hash:ip, mac sets (Stefano Brivio) [1723605]
- [net] netfilter: ipset: Actually allow destination MAC address for hash:ip, mac sets too (Stefano Brivio) [1723605]
- [net] igmp: fix memory leak in igmpv3_del_delrec() (Hangbin Liu) [1736816]
- [net] don't clear sock->sk early to avoid trouble in strparser (Hangbin Liu) [1736816]
- [net] ipv4/igmp: fix build error if !CONFIG_IP_MULTICAST (Hangbin Liu) [1736816]
- [net] ipv4/igmp: fix another memory leak in igmpv3_del_delrec() (Hangbin Liu) [1736816]
- [net] route: set the deleted fnhe fnhe_daddr to 0 in ip_del_fnhe to fix a race (Hangbin Liu) [1736816]
- [net] netlabel: fix out-of-bounds memory accesses (Hangbin Liu) [1736816]
- [net] ipv4: Fix memory leak in network namespace dismantle (Hangbin Liu) [1736816]
- [net] bridge: delete local fdb on device init failure (Hangbin Liu) [1736824]
- [net] bridge: stp: don't cache eth dest pointer before skb pull (Hangbin Liu) [1736824]
- [net] bridge: don't cache ether dest pointer on input (Hangbin Liu) [1736824]
- [net] bridge: mcast: fix stale ipv6 hdr pointer when handling v6 query (Hangbin Liu) [1736824]
- [net] bridge: mcast: fix stale nsrcs pointer in igmp3/mld2 report handling (Hangbin Liu) [1736824]
- [net] bridge: fix per-port af_packet sockets (Hangbin Liu) [1736824]
- [include] ip: fix ip_mc_may_pull() return value (Hangbin Liu) [1736824]
- [net] bridge: use struct_size() helper (Hangbin Liu) [1736824]
- [net] bridge: simplify ip_mc_check_igmp() and ipv6_mc_check_mld() calls (Hangbin Liu) [1736824]
- [net] net/bridge/br_multicast: remove redundant variable "err" (Hangbin Liu) [1736824]
- [x86] x86/kdump/64: Restrict kdump kernel reservation to <64TB (Baoquan He) [1669090]
- [x86] x86/kexec/64: Prevent kexec from 5-level paging to a 4-level only kernel (Baoquan He) [1669088]
- [x86] x86/boot: Add xloadflags bits to check for 5-level paging support (Baoquan He) [1669088]
- [tools] perf header: Fix wrong node write in NUMA_TOPOLOGY feature (Michael Petlan) [1722044]
- [tools] perf c2c: Fix c2c report for empty numa node (Michael Petlan) [1722044]
- [x86] kvm: svm/avic: fix off-by-one in checking host APIC ID (Janakarajan Natarajan) [1720983]

* Wed Aug 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-133.el8]
- [fs] gfs2: gfs2_walk_metadata fix (Andreas Grunbacher) [1724361]
- [netdrv] mlx4/en_netdev: allow offloading VXLAN over VLAN (Paolo Abeni) [1733532]
- [fs] xfs: always rejoin held resources during defer roll (Bill O'Donnell) [1706588]
- [bluetooth] Bluetooth: hci_uart: check for missing tty operations (Gopal Tiwari) [1734239] {CVE-2019-10207}

* Tue Aug 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-132.el8]
- [documentation] Documentation: Add swapgs description to the Spectre v1 documentation (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [documentation] Documentation: Add section about CPU vulnerabilities for Spectre (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation/swapgs: Exclude ATOMs from speculation through SWAPGS (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/entry/64: Use JMP instead of JMPQ (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation: Enable Spectre v1 swapgs mitigations (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/speculation: Prepare entry code for Spectre v1 swapgs mitigations (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/cpufeatures: Combine word 11 and 12 into a new scattered features word (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [x86] x86/cpufeatures: Carve out CQM features retrieval (Josh Poimboeuf) [1724501] {CVE-2019-1125}
- [netdrv] ibmveth: fix DMA unmap error in ibmveth_xmit_start error path (Steve Best) [1739431]
- [rpmspec] rpmspec: use make macro to do headers_install with rpm CFLAGS/LDFLAGS ("Herton R. Krzesinski") [1738659]
- [rpmspec] rpmspec: use tools_make for building tools ("Herton R. Krzesinski") [1738659]
- [tools] tools gpio: Allow overriding CFLAGS ("Herton R. Krzesinski") [1738659]
- [tools] tools thermal tmon: Allow overriding CFLAGS assignments ("Herton R. Krzesinski") [1738659]
- [tools] tools iio: Override CFLAGS assignments ("Herton R. Krzesinski") [1738659]
- [fs] NFS: Fix dentry revalidation on NFSv4 lookup (Steve Dickson) [1667774]
- [fs] pNFS: Avoid read/modify/write when it is not necessary (Benjamin Coddington) [1680649]
- [fs] pNFS: Fix potential corruption of page being written (Benjamin Coddington) [1680649]
- [fs] gfs2: Inode dirtying fix (Andreas Grunbacher) [1724361]
- [net] sunrpc: make visible processing error in bc_svc_process() ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: remove unused xpo_prep_reply_hdr callback ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: remove svc_tcp_bc_class ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: replace svc_serv->sv_bc_xprt by boolean flag ("J. Bruce Fields") [1660823] {CVE-2018-16884}
- [net] sunrpc: use-after-free in svc_process_common() ("J. Bruce Fields") [1660823] {CVE-2018-16884}

* Mon Aug 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-131.el8]
- [scsi] scsi: implement .cleanup_rq callback (Ming Lei) [1696256]
- [md] blk-mq: add callback of .cleanup_rq (Ming Lei) [1696256]
- [block] blk-mq: insert rq with DONTPREP to hctx dispatch list when requeue (Ming Lei) [1696256]
- [scsi] scsi: core: Fix race on creating sense cache (Ming Lei) [1696256]
- [block] blk-mq: balance mapping between present CPUs and queues (Ming Lei) [1733040]
- [block] blk-mq: Fix spelling in a source code comment (Ming Lei) [1733040]
- [drm] drm/i915: Don't dereference request if it may have been retired when printing (Lyude Paul) [1715997]
- [drm] drm/i915/icl: whitelist PS_(DEPTH|INVOCATION)_COUNT (Lyude Paul) [1715997]
- [drm] drm/i915: whitelist PS_(DEPTH|INVOCATION)_COUNT (Lyude Paul) [1715997]
- [drm] drm/i915: Support flags in whitlist WAs (Lyude Paul) [1715997]
- [drm] drm/i915: Disable SAMPLER_STATE prefetching on all Gen11 steppings. (Lyude Paul) [1715997]
- [drm] drm/i915/userptr: Acquire the page lock around set_page_dirty() (Lyude Paul) [1715997]
- [drm] drm/i915/perf: fix ICL perf register offsets (Lyude Paul) [1715997]
- [drm] drm/virtio: Add memory barriers for capset cache. (Lyude Paul) [1715997]
- [drm] drm/amd/display: Always allocate initial connector state state (Lyude Paul) [1715997]
- [drm] drm/vkms: Forward timer right after drm_crtc_handle_vblank (Lyude Paul) [1715997]
- [drm] drm/crc-debugfs: Also sprinkle irqrestore over early exits (Lyude Paul) [1715997]
- [drm] drm/crc-debugfs: User irqsafe spinlock in drm_crtc_add_crc_entry (Lyude Paul) [1715997]
- [drm] drm/amd/display: Increase Backlight Gain Step Size (Lyude Paul) [1715997]
- [drm] drm/amd/display: CS_TFM_1D only applied post EOTF (Lyude Paul) [1715997]
- [drm] drm/edid: Fix a missing-check bug in drm_load_edid_firmware() (Lyude Paul) [1715997]
- [drm] drm/amdkfd: Fix sdma queue map issue (Lyude Paul) [1715997]
- [drm] drm/amdkfd: Fix a potential memory leak (Lyude Paul) [1715997]
- [drm] drm/amd/display: Disable ABM before destroy ABM struct (Lyude Paul) [1715997]
- [drm] drm/amdgpu/sriov: Need to initialize the HDP_NONSURFACE_BAStE (Lyude Paul) [1715997]
- [drm] drm/amdgpu: Reserve shared fence for eviction fence (Lyude Paul) [1715997]
- [drm] drm/amd/display: Disable cursor when offscreen in negative direction (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fill prescale_params->scale for RGB565 (Lyude Paul) [1715997]
- [drm] drm/virtio: set seqno for dma-fence (Lyude Paul) [1715997]
- [drivers] dma-buf: Discard old fence_excl on retrying get_fences_rcu for realloc (Lyude Paul) [1715997]
- [drivers] dma-buf: balance refcount inbalance (Lyude Paul) [1715997]
- [drm] drm/edid: parse CEA blocks embedded in DisplayID (Lyude Paul) [1715997]
- [drm] drm/nouveau/i2c: Enable i2c pads & busses during preinit (Lyude Paul) [1715997]
- [drm] drm: return -EFAULT if copy_to_user() fails (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: fix a warning due to missing dma_parms (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Honor the sg list segment size limitation (Lyude Paul) [1715997]
- [drm] drm/virtio: move drm_connector_update_edid_property() call (Lyude Paul) [1715997]
- [drm] drm/amdgpu/gfx9: use reset default for PA_SC_FIFO_SIZE (Lyude Paul) [1715997]
- [drm] drm/amdgpu: Don't skip display settings in hwmgr_resume() (Lyude Paul) [1717138 1715997]
- [drm] drm/amd/powerplay: use hardware fan control if no powerplay fan table (Lyude Paul) [1715997]
- [drm] drm/i915/ringbuffer: EMIT_INVALIDATE *before* switch context (Lyude Paul) [1715997]
- [drm] drm/i915: Skip modeset for cdclk changes if possible (Lyude Paul) [1715997]
- [drm] drm/i915: Remove redundant store of logical CDCLK state (Lyude Paul) [1715997]
- [drm] drm/i915: Save the old CDCLK atomic state (Lyude Paul) [1715997]
- [drm] drm/i915: Force 2*96 MHz cdclk on glk/cnl when audio power is enabled (Lyude Paul) [1715997]
- [drm] drm/i915: Don't clobber M/N values during fastset check (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Use the backdoor port if the HB port is not available (Lyude Paul) [1715997]
- [drm] drm: add fallback override/firmware EDID modes workaround (Lyude Paul) [1715997]
- [drm] drm/edid: abstract override/firmware EDID retrieval (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: NULL pointer dereference from vmw_cmd_dx_view_define() (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: integer underflow in vmw_cmd_dx_set_shader() leading to an invalid read (Lyude Paul) [1715997]
- [drm] drm/amdgpu: keep stolen memory on picasso (Lyude Paul) [1715997]
- [drm] drm/i915/dmc: protect against reading random memory (Lyude Paul) [1715997]
- [drm] drm/i915: Fix per-pixel alpha with CCS (Lyude Paul) [1715997]
- [drm] drm/i915/dsi: Use a fuzzy check for burst mode clock check (Lyude Paul) [1715997]
- [drm] drm/i915/sdvo: Implement proper HDMI audio support for SDVO (Lyude Paul) [1715997]
- [drm] drm/amdgpu/{uvd,vcn}: fetch ring's read_ptr after alloc (Lyude Paul) [1715997]
- [drm] drm/amd/display: Use plane->color_space for dpp if specified (Lyude Paul) [1715997]
- [drm] drm/amd/display: disable link before changing link settings (Lyude Paul) [1715997]
- [drm] Revert "drm: allow render capable master with DRM_AUTH ioctls" (Lyude Paul) [1715997]
- [drm] drm/amd: fix fb references in async update (Lyude Paul) [1715997]
- [drm] drm/i915/gvt: Initialize intel_gvt_gtt_entry in stack (Lyude Paul) [1715997]
- [drm] drm: don't block fb changes for async plane updates (Lyude Paul) [1715997]
- [drm] drm/i915/gvt: emit init breadcrumb for gvt request (Lyude Paul) [1715997]
- [drm] drm/amdgpu: fix ring test failure issue during s3 in vce 3.0 (V2) (Lyude Paul) [1715997]
- [drm] drm/amd/display: Add ASICREV_IS_PICASSO (Lyude Paul) [1715997]
- [drm] drm/amdgpu/soc15: skip reset on init (Lyude Paul) [1715997]
- [include] drm/i915: Fix I915_EXEC_RING_MASK (Lyude Paul) [1715997]
- [drm] drm/amdgpu: remove ATPX_DGPU_REQ_POWER_FOR_DISPLAYS check when hotplug-in (Lyude Paul) [1715997]
- [drm] drm/radeon: prefer lower reference dividers (Lyude Paul) [1715997]
- [drm] drm/amdgpu/psp: move psp version specific function pointers to early_init (Lyude Paul) [1715997]
- [drm] drm: add non-desktop quirks to Sensics and OSVR headsets. (Lyude Paul) [1715997]
- [drm] drm: add non-desktop quirk for Valve HMDs (Lyude Paul) [1715997]
- [drm] drm/cma-helper: Fix drm_gem_cma_free_object() (Lyude Paul) [1715997]
- [drm] drm/lease: Make sure implicit planes are leased (Lyude Paul) [1715997]
- [drm] drm: Expose "FB_DAMAGE_CLIPS" property to atomic aware user-space only (Lyude Paul) [1715997]
- [drm] drm/atomic: Wire file_priv through for property changes (Lyude Paul) [1715997]
- [drm] drm/fb-helper: generic: Call drm_client_add() after setup is done (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Don't send drm sysfs hotplug events on initial master set (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Fix compat mode shader operation (Lyude Paul) [1715997]
- [drm] drm/vmwgfx: Fix user space handle equal to zero (Lyude Paul) [1715997]
- [drm] drm: Wake up next in drm_read() chain if we are forced to putback the event (Lyude Paul) [1715997]
- [drm] drm/drv: Hold ref on parent device during drm_device lifetime (Lyude Paul) [1715997]
- [drm] drm/amd/display: Reset planes that were disabled in init_pipes (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fix exception from AUX acquire failure (Lyude Paul) [1715997]
- [drm] drm: writeback: Fix leak of writeback job (Lyude Paul) [1715997]
- [drm] drm/amd/display: Set stream->mode_changed when connectors change (Lyude Paul) [1715997]
- [drm] drm/amd/display: half bandwidth for YCbCr420 during validation (Lyude Paul) [1715997]
- [drm] drm/amd/display: Re-add custom degamma support (Lyude Paul) [1715997]
- [drm] drm/amd/display: Fix Divide by 0 in memory calculations (Lyude Paul) [1715997]
- [drm] drm/amd/display: add pipe lock during stream update (Lyude Paul) [1715997]
- [drm] drm/amd/display: Reset alpha state for planes to the correct values (Lyude Paul) [1715997]
- [drm] drm/amd/display: Update ABM crtc state on non-modeset (Lyude Paul) [1715997]
- [drm] drm/amd/display: Link train only when link is DP and backend is enabled (Lyude Paul) [1715997]
- [drm] drm/amd/display: fix releasing planes when exiting odm (Lyude Paul) [1715997]
- [drm] drm/amd/display: Prevent cursor hotspot overflow for RV overlay planes (Lyude Paul) [1715997]
- [drm] drm/amd/display: use proper formula to calculate bandwidth from timing (Lyude Paul) [1715997]
- [drm] drm/amdgpu: fix old fence check in amdgpu_fence_emit (Lyude Paul) [1715997]
- [drm] drm/nouveau/bar/nv50: ensure BAR is mapped (Lyude Paul) [1715997]
- [pci] PCI: Mark AMD Stoney Radeon R7 GPU ATS as broken (Lyude Paul) [1715997]
- [kernel] locking/rwsem: Add missing ACQUIRE to read_slowpath exit when queue is empty (Waiman Long) [1737089]
- [tools] perf vendor events power9: Added missing event descriptions (Michael Petlan) [1581405]
- [crypto] crypto: skcipher - fix crash flushing dcache in error path (David Gibson) [1724370]
- [netdrv] bnx2x: Prevent load reordering in tx completion processing (Manish Chopra) [1729599]
- [x86] x86/boot/KASLR: Always return a value from process_mem_region (Baoquan He) [1564822]
- [x86] x86/kexec: Add the ACPI NVS region to the ident map (Baoquan He) [1564822]
- [x86] x86/boot: Call get_rsdp_addr() after console_init() (Baoquan He) [1564822]
- [x86] x86/boot: Use efi_setup_data for searching RSDP on kexec-ed kernels (Baoquan He) [1564822]
- [x86] x86/kexec: Add the EFI system tables and ACPI tables to the ident map (Baoquan He) [1564822]
- [x86] x86/boot: Fix incorrect ifdeffery scope (Baoquan He) [1564822]
- [x86] x86/boot: Correct RSDP parsing with 32-bit EFI (Baoquan He) [1564822]
- [x86] x86/boot: Fix randconfig build error due to MEMORY_HOTREMOVE (Baoquan He) [1564822]
- [x86] x86/boot: Fix cmdline_find_option() prototype visibility (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Limit KASLR to extract the kernel in immovable memory only (Baoquan He) [1564822]
- [x86] x86/boot: Parse SRAT table and count immovable memory regions (Baoquan He) [1564822]
- [x86] x86/boot: Early parse RSDP and save it in boot_params (Baoquan He) [1564822]
- [x86] x86/boot: Search for RSDP in memory (Baoquan He) [1564822]
- [x86] x86/boot: Search for RSDP in the EFI tables (Baoquan He) [1564822]
- [x86] x86/boot: Add "acpi_rsdp=" early parsing (Baoquan He) [1564822]
- [x86] x86/boot: Copy kstrtoull() to boot/string.c (Baoquan He) [1564822]
- [x86] x86/boot: Use CC_SET()/CC_OUT() instead of open coding it (Baoquan He) [1564822]
- [x86] x86/boot: Build the command line parsing code unconditionally (Baoquan He) [1564822]
- [x86] x86/boot: Clear RSDP address in boot_params for broken loaders (Baoquan He) [1564822]
- [x86] x86/acpi, x86/boot: Take RSDP address from boot params if available (Baoquan He) [1564822]
- [x86] x86/boot: Mostly revert commit ae7e1238e68f2a ("Add ACPI RSDP address to setup_header") (Baoquan He) [1564822]
- [x86] x86/acpi, x86/boot: Take RSDP address for boot params if available (Baoquan He) [1564822]
- [x86] x86/boot: Add ACPI RSDP address to setup_header (Baoquan He) [1564822]
- [x86] x86/xen: Fix boot loader version reported for PVH guests (Baoquan He) [1564822]
- [x86] x86/boot: Add missing va_end() to die() (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Remove return value from handle_mem_options() (Baoquan He) [1564822]
- [x86] x86/boot/KASLR: Make local variable mem_limit static (Baoquan He) [1564822]
- [crypto] crypto: user - prevent operating on larval algorithms (Herbert Xu) [1728835]

* Thu Aug 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-130.el8]
- [scsi] scsi: mpt3sas: Use 63-bit DMA addressing on SAS35 HBA (Tomas Henzl) [1734769]
- [netdrv] bonding: Force slave speed check after link state recovery for 802.3ad (Jarod Wilson) [1732820]
- [pci] PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(), if necessary (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Add hv_pci_remove_slots() when we unload the driver (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Fix a use-after-free bug in hv_eject_device_work() (Mohammed Gamal) [1733302]
- [pci] PCI: hv: Fix a memory leak in hv_eject_device_work() (Mohammed Gamal) [1733302]
- [nvme] nvmet: fix setting ns queue's segment boundary (Ming Lei) [1734458]

* Wed Aug 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-129.el8]
- [tools] perf script python: Remove explicit shebang from setup.py (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Remove explicit shebang from tests/attr.c (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Remove explicit shebang from Python scripts (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Use PyBytes for attr in trace-event-python (Michael Petlan) [1664768 1663814]
- [tools] perf script python: Add trace_context extension module to sys.modules (Michael Petlan) [1663814 1664768]
- [tools] perf scripts python: exported-sql-viewer.py: Fix python3 support (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to export-to-sqlite.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to export-to-postgresql.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to exported-sql-viewer.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to intel-pt-events.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to event_analyzing_sample.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: add Python3 support to check-perf-trace.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to futex-contention.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Remove mixed indentation (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to syscall-counts-by-pid.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to syscall-counts.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to stackcollapse.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to sctop.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to powerpc-hcalls.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to net_dropmonitor.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to mem-phys-addr.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to failed-syscalls-by-pid.py (Michael Petlan) [1663814 1664768]
- [tools] perf script python: Add Python3 support to netdev-times.py (Michael Petlan) [1663814 1664768]
- [powerpc] mm_iommu: Allow pinning large regions (David Gibson) [1629531]
- [powerpc] mm_iommu: Fix potential deadlock (David Gibson) [1629531]
- [powerpc] mm/iommu: allow large IOMMU page size only for hugetlb backing (David Gibson) [1629531]
- [powerpc] mm/iommu: allow migration of cma allocated pages during mm_iommu_do_alloc (David Gibson) [1629531]
- [mm] update get_user_pages_longterm to migrate pages allocated from CMA region (David Gibson) [1629531]
- [kernel] mm/cma: add PF flag to force non cma alloc (David Gibson) [1629531]
- [net] tcp: be more careful in tcp_fragment() (Marcelo Leitner) [1732103]
- [net] tipc: initialize 'validated' field of received packets (Jon Maloy) [1730574]
- [documentation] networking: fix default_ttl typo in mpls-sysctl (Hangbin Liu) [1724882]

* Fri Aug 02 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-128.el8]
- [powerpc] powerpc/mm: Limit rma_size to 1TB when running without HV mode (Suraj Jitindar Singh) [1723297]
- [x86] kvm: nvmx: Set cached_vmcs12 and cached_shadow_vmcs12 NULL after free (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: do not use dangling shadow VMCS after guest reset (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Clear pending KVM_REQ_GET_VMCS12_PAGES when leaving nested (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Change KVM_STATE_NESTED_EVMCS to signal vmcs12 is copied from eVMCS (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Allow restore nested-state to enable eVMCS when vCPU in SMM (Paolo Bonzini) [1732096]
- [tools] kvm: nvmx: reorganize initial steps of vmx_set_nested_state (Paolo Bonzini) [1732096]
- [x86] kvm: x86: Modify struct kvm_nested_state to have explicit fields for data (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Clear nested_run_pending if setting nested state fails (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: really fix the size checks on KVM_SET_NESTED_STATE (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: Set nested_run_pending in vmx_set_nested_state after checks complete (Paolo Bonzini) [1732096]
- [x86] kvm: nvmx: KVM_SET_NESTED_STATE - Tear down old EVMCS state before setting new state (Paolo Bonzini) [1732096]
- [tools] kvm: selftests: avoid type punning (Paolo Bonzini) [1732096]
- [tools] tests: kvm: Add tests for KVM_SET_NESTED_STATE (Paolo Bonzini) [1732096]
- [x86] kvm: x86/mmu: Allocate PAE root array when using SVM's 32-bit NPT (Paolo Bonzini) [1732096]
- [x86] kvm: lapic: Fix pending interrupt in IRR blocked by software disable LAPIC (Paolo Bonzini) [1732096]
- [x86] kvm: x86: Dynamically allocate user_fpu (Paolo Bonzini) [1732096]
- [x86] revert "kvm: x86: Use task structs fpu field for user" (Paolo Bonzini) [1732096]
- [x86] hyperv: suppress "pci: fatal: No config space access function found" (Raghavendra Rao) [1734265]
- [powerpc] [kvm] kvm: ppc: book3s hv: Save and restore guest visible PSSCR bits on pseries (Suraj Jitindar Singh) [1710726]
- [powerpc] pmu: Set pmcregs_in_use in paca when running as LPAR (Suraj Jitindar Singh) [1710726]
- [powerpc] [kvm] kvm: ppc: book3s hv: Always save guest pmu for guest capable of nesting (Suraj Jitindar Singh) [1710726]
- [powerpc] kvm: ppc: book3s hv: xive: fix rollback when kvmppc_xive_create fails (David Gibson) [1731900]
- [powerpc] powerpc/pseries: Fix xive=off command line (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: don't use string functions from lib/ (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc: remove CONFIG_CMDLINE #ifdef mess (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc: Move `path` variable inside DEBUG_PROM (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Generate "phandle" instead of "linux, phandle" (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Move a few remaining statics to appropriate sections (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Move prom_radix_disable to __prombss (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Remove support for OPAL v2 (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Replace __initdata with __prombss when applicable (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/prom_init: Make of_workarounds static (Desnes Augusto Nunes do Rosario) [1731400]
- [powerpc] powerpc/powernv/idle: Restore AMR/UAMOR/AMOR after idle (David Gibson) [1730183]
- [powerpc] powerpc/powernv/idle: Restore IAMR after idle (David Gibson) [1730183]

* Thu Aug 01 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-127.el8]
- [kernel] fork: report pid exhaustion correctly (Don Dutile) [1726448]
- [lib] idr: Fix idr_get_next race with idr_remove (Don Dutile) [1726448]
- [kernel] Fix failure path in alloc_pid() (Don Dutile) [1726448]
- [target] scsi: iscsi: set auth_protocol back to NULL if CHAP_A value is not supported (Maurizio Lombardi) [1733498]

* Wed Jul 31 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-126.el8]
- [infiniband] IB/umem: Add missing down_read on umem_rwsem (Alaa Hleihel) [1733188]
- [fs] gfs2: Fix rounding error in gfs2_iomap_page_prepare (Andreas Grunbacher) [1733621]
- [s390] s390/qeth: cancel cmd on early error (Philipp Rudo) [1731430]
- [s390] s390/qeth: simplify reply object handling (Philipp Rudo) [1731430]
- [s390] s390/qeth: release cmd buffer in error paths (Philipp Rudo) [1731430]
- [mm] mm: hugetlb: soft-offline: dissolve_free_huge_page() return zero on !PageHuge (Rafael Aquini) [1706088]
- [mm] mm: soft-offline: return -EBUSY if set_hwpoison_free_buddy_page() fails (Rafael Aquini) [1706088]
- [mm] mm: soft-offline: close the race against page allocation (Rafael Aquini) [1706088]
- [mm] mm: fix race on soft-offlining free huge pages (Rafael Aquini) [1706088]
- [pci] PCI: Probe bridge window attributes once at enumeration-time (Myron Stowe) [1730763]
- [mm] swap_readpage(): avoid blk_wake_io_task() if !synchronous (Ming Lei) [1724016]
- [mm] mm/page_io.c: fix polled swap page in (Ming Lei) [1724016]
- [include] fs: fix kABI for struct pipe_buf_operations (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [fs] fs: prevent page refcount overflow in pipe_buf_get (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [mm] mm: prevent get_user_pages() from overflowing page refcount (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [include] mm: add 'try_get_page()' helper function (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [include] mm: make page ref count overflow check tighter and more explicit (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [fs] fuse: call pipe_buf_release() under pipe lock (Miklos Szeredi) [1705007] {CVE-2019-11487}
- [kernel] trace: Fix preempt_enable_no_resched() abuse (Phil Auld) [1705550]
- [kernel] sched/numa: Fix a possible divide-by-zero (Phil Auld) [1705550]
- [kernel] sched/core: Fix buffer overflow in cgroup2 property cpu.max (Phil Auld) [1705550]
- [kernel] sched/fair: Remove unused 'sd' parameter from select_idle_smt() (Phil Auld) [1705550]
- [kernel] sched/topology: Remove the ::smt_gain field from 'struct sched_domain' cleanups (Phil Auld) [1705550]
- [kernel] sched/numa: Remove unused code from update_numa_stats() (Phil Auld) [1705550]

* Tue Jul 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-125.el8]
- [s390] virtio/s390: fix race on airq_areas[] (Cornelia Huck) [1733499]
- [powerpc] powerpc: ignore __GFP_DMA/DMA32 if we left an empty ZONE_DMA/DMA32 enabled for kABI purposes (David Gibson) [1728314]
- [netdrv] bnx2x: Disable multi-cos feature. (Manish Chopra) [1679024]
- [char] tpm: tpm_ibm_vtpm: Fix unallocated banks (Jerry Snitselaar) [1726126]
- [scsi] scsi: ibmvfc: fix WARN_ON during event pool release (Steve Best) [1731133]
- [tools] perf vendor events power9: General metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Branch_prediction, instruction_stats, latency, lsu_rejects, memory, prefetch & translation metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Dl1_reloads, instruction_misses, l[23]_stats & pteg_reloads metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power9: Cpi_breakdown & estimated_dcache_miss_cpi metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Translaton & general metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Branch_prediction, latency, bus_stats, instruction_mix & instruction_stats metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Dl1_reload, instruction_misses, l2_stats, lsu_rejects, memory & pteg_reloads metrics (Michael Petlan) [1694638]
- [tools] perf vendor events power8: Cpi_breakdown & estimated_dcache_miss_cpi metrics (Michael Petlan) [1694638]
- [powerpc] powerpc/tm: Fix oops on sigreturn on systems without TM (Steve Best) [1732753]
- [net] net/mlx5e: Add ndo_set_feature for uplink representor (Alaa Hleihel) [1727708]
- [misc] VMCI: Fix integer overflow in VMCI handle arrays (Cathy Avery) [1729587]
- [tools] perf version: Fix segfault due to missing OPT_END() (Michael Petlan) [1732065]
- [sound] ALSA: hda/realtek - Headphone Mic can't record after S3 (Jaroslav Kysela) [1727676]
- [char] random: fix CRNG initialization when random.trust_cpu=1 (Oleksandr Natalenko) [1728583]
- [char] random: move rand_initialize() earlier (Oleksandr Natalenko) [1728583]
- [char] random: make CPU trust a boot parameter (Oleksandr Natalenko) [1728583]
- [char] random: add a config option to trust the CPU's hwrng (Oleksandr Natalenko) [1728583]
- [fs] blockdev: Fix livelocks on loop device (Ming Lei) [1683593]
- [block] nbd: Use set_blocksize() to set device blocksize (Ming Lei) [1683593]
- [kernel] ptrace: Fix ->ptracer_cred handling for PTRACE_TRACEME (Aristeu Rozanski) [1730959] {CVE-2019-13272}

* Mon Jul 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-124.el8]
- [include] linux/printk.h: use DYNAMIC_DEBUG_BRANCH in pr_debug_ratelimited (Mike Snitzer) [1729301]
- [include] dm: use printk ratelimiting functions (Mike Snitzer) [1729301]
- [md] dm crypt: move detailed message into debug level (Mike Snitzer) [1729301]
- [powerpc] powerpc/xive: Fix loop exit-condition in xive_find_target_in_mask() (Steve Best) [1731838]
- [s390] s390/qeth: be drop monitor friendly (Philipp Rudo) [1731200]
- [s390] s390/cpumf: Add extended counter set definitions for model 8561 and 8562 (Philipp Rudo) [1731195]
- [s390] s390/qdio: handle PENDING state for QEBSM devices (Philipp Rudo) [1731194]
- [net] net/af_iucv: build proper skbs for HiperTransport (Philipp Rudo) [1731193]
- [net] net/af_iucv: remove GFP_DMA restriction for HiperTransport (Philipp Rudo) [1731193]
- [wireless] iwlwifi: mvm: disable TX-AMSDU on older NICs (Jarod Wilson) [1728992]
- [wireless] carl9170: fix misuse of device driver API (Jarod Wilson) [1728992]
- [wireless] p54: fix crash during initialization (Jarod Wilson) [1728992]
- [wireless] p54usb: Fix race between disconnect and firmware loading (Jarod Wilson) [1728992]
- [wireless] mwifiex: Don't abort on small, spec-compliant vendor IEs (Jarod Wilson) [1728992]
- [wireless] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 507 (Jarod Wilson) [1728992]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 505 (Jarod Wilson) [1728992]
- [wireless] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 501 (Jarod Wilson) [1728992]
- [net] treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 500 (Jarod Wilson) [1728992]
- [wireless] brcmfmac: sdio: Don't tune while the card is off (Jarod Wilson) [1728992]
- [wireless] brcmfmac: sdio: Disable auto-tuning around commands expected to fail (Jarod Wilson) [1728992]
- [mmc] mmc: core: Add sdio_retune_hold_now() and sdio_retune_release() (Jarod Wilson) [1728992]
- [mmc] mmc: core: API to temporarily disable retuning for SDIO CRC errors (Jarod Wilson) [1728992]
- [wireless] Revert "brcmfmac: disable command decode in sdio_aos" (Jarod Wilson) [1728992]
- [net] cfg80211: report measurement start TSF correctly (Jarod Wilson) [1728992]
- [net] cfg80211: fix memory leak of wiphy device name (Jarod Wilson) [1728992]
- [net] cfg80211: util: fix bit count off by one (Jarod Wilson) [1728992]
- [net] mac80211: do not start any work during reconfigure flow (Jarod Wilson) [1728992]
- [net] cfg80211: use BIT_ULL in cfg80211_parse_mbssid_data() (Jarod Wilson) [1728992]
- [net] mac80211: only warn once on chanctx_conf being NULL (Jarod Wilson) [1728992]
- [net] mac80211: drop robust management frames from unknown TA (Jarod Wilson) [1728992]
- [wireless] mwifiex: Fix heap overflow in mwifiex_uap_parse_tail_ies() (Jarod Wilson) [1728992 1721749] {CVE-2019-10126}
- [wireless] iwlwifi: mvm: change TLC config cmd sent by rs to be async (Jarod Wilson) [1728992]
- [wireless] iwlwifi: Fix double-free problems in iwl_req_fw_callback() (Jarod Wilson) [1728992]
- [wireless] iwlwifi: fix AX201 killer sku loading firmware issue (Jarod Wilson) [1728992]
- [wireless] iwlwifi: print fseq info upon fw assert (Jarod Wilson) [1728992]
- [wireless] iwlwifi: clear persistence bit according to device family (Jarod Wilson) [1728992]
- [wireless] iwlwifi: fix load in rfkill flow for unified firmware (Jarod Wilson) [1728992]
- [wireless] iwlwifi: mvm: remove d3_sram debugfs file (Jarod Wilson) [1728992]
- [wireless] mwifiex: Abort at too short BSS descriptor element (Jarod Wilson) [1728992 1714476] {CVE-2019-3846}
- [wireless] mwifiex: Fix possible buffer overflows at parsing bss descriptor (Jarod Wilson) [1728992 1714476] {CVE-2019-3846}
- [net] mac80211: free peer keys before vif down in mesh (Jarod Wilson) [1728992]
- [wireless] rtw88: Make some symbols static (Jarod Wilson) [1728992]
- [wireless] rtw88: avoid circular locking between local->iflist_mtx and rtwdev->mutex (Jarod Wilson) [1728992]
- [wireless] rtw88: fix unassigned rssi_level in rtw_sta_info (Jarod Wilson) [1728992]
- [wireless] rtw88: fix subscript above array bounds compiler warning (Jarod Wilson) [1728992]
- [net] mac80211: mesh: fix RCU warning (Jarod Wilson) [1728992]
- [net] nl80211: fix station_info pertid memory leak (Jarod Wilson) [1728992]
- [net] mac80211: Do not use stack memory with scatterlist for GMAC (Jarod Wilson) [1728992]
- [net] {nl,mac}80211: allow 4addr AP operation on crypto controlled devices (Jarod Wilson) [1728992]
- [wireless] mac80211_hwsim: mark expected switch fall-through (Jarod Wilson) [1728992]
- [net] mac80211: fix rate reporting inside cfg80211_calculate_bitrate_he() (Jarod Wilson) [1728992]
- [net] mac80211: remove set but not used variable 'old' (Jarod Wilson) [1728992]
- [net] mac80211: handle deauthentication/disassociation from TDLS peer (Jarod Wilson) [1728992]
- [net] wireless: Skip directory when generating certificates (Jarod Wilson) [1728992]
- [netdrv] i40e: Check and set the PF driver state first in i40e_ndo_set_vf_mac (Stefan Assmann) [1719538]
- [fs] cifs: fix crash in smb2_compound_op()/smb2_set_next_command() (Leif Sahlberg) [1722704]
- [firmware] efi/arm: Show SMBIOS bank/device location in CPER and GHES error logs (Robert Richter) [1721386]

* Thu Jul 25 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-123.el8]
- [x86] x86/speculation: Allow guests to use SSBD even if host does not (Waiman Long) [1728341]
- [block] block: kill BLK_MQ_F_SG_MERGE (Ming Lei) [1716595]
- [block] block: kill QUEUE_FLAG_NO_SG_MERGE (Ming Lei) [1716595]

* Wed Jul 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-122.el8]
- [x86] x86/insn-eval: Fix use-after-free access to LDT entry (Rafael Aquini) [1728561] {CVE-2019-13233}
- [arm64] arm64/mm: Correct the cache line size warning with non coherent device (Mark Salter) [1715061]
- [arm64] arm64: cacheinfo: Update cache_line_size detected from DT or PPTT (Mark Salter) [1715061]
- [base] drivers: base: cacheinfo: Add variable to record max cache line size (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: Trap CTR_EL0 access only where it is necessary (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: Fix handling of CTR_EL0.IDC field (Mark Salter) [1715061]
- [arm64] arm64: cpufeature: ctr: Fix cpu capability check for late CPUs (Mark Salter) [1715061]
- [arm64] arm64: cpu_errata: Remove ARM64_MISMATCHED_CACHE_LINE_SIZE (Mark Salter) [1715061]
- [fs] gfs2: Clean up freeing struct gfs2_sbd (Robert S Peterson) [1683698]
- [target] scsi: target/iblock: Fix overrun in WRITE SAME emulation (Maurizio Lombardi) [1729503]
- [x86] kvm/nvmx: fix VMCLEAR when Enlightened VMCS is in use (Vitaly Kuznetsov) [1717785]
- [x86] kvm/nvmx: don't use clean fields data on enlightened VMLAUNCH (Vitaly Kuznetsov) [1717785]
- [x86] kvm: nvmx: use correct clean fields when copying from eVMCS (Vitaly Kuznetsov) [1717785]
- [fs] NFS4: Only set creation opendata if O_CREAT (Benjamin Coddington) [1708471]
- [tools] perf test: Fix failure of 'evsel-tp-sched' test on s390 (Michael Petlan) [1729213]
- [fs] PNFS fallback to MDS if no deviceid found (Benjamin Coddington) [1708386]
- [mm] mm, memcg: add a memcg_slabinfo debugfs file (Waiman Long) [1699202]
- [mm] mm: memcg/slab: reparent memcg kmem_caches on cgroup removal (Waiman Long) [1699202]
- [mm] mm: memcg/slab: stop setting page->mem_cgroup pointer for slab pages (Waiman Long) [1699202]
- [mm] mm: memcg/slab: rework non-root kmem_cache lifecycle management (Waiman Long) [1699202]
- [mm] mm: memcg/slab: synchronize access to kmem_cache dying flag using a spinlock (Waiman Long) [1699202]
- [mm] mm: memcg/slab: don't check the dying flag on kmem_cache creation (Waiman Long) [1699202]
- [mm] mm: memcg/slab: unify SLAB and SLUB page accounting (Waiman Long) [1699202]
- [mm] mm: memcg/slab: introduce __memcg_kmem_uncharge_memcg() (Waiman Long) [1699202]
- [mm] mm: memcg/slab: generalize postponed non-root kmem_cache deactivation (Waiman Long) [1699202]
- [mm] mm: memcg/slab: rename slab delayed deactivation functions and fields (Waiman Long) [1699202]
- [mm] mm: memcg/slab: postpone kmem_cache memcg pointer initialization to memcg_link_cache() (Waiman Long) [1699202]
- [mm] slub: add comments to endif pre-processor macros (Waiman Long) [1699202]
- [mm] mm, slab: shorten kmalloc cache names for large sizes (Waiman Long) [1699202]
- [base] mm, proc: add KReclaimable to /proc/meminfo (Waiman Long) [1699202]
- [mm] mm: rename and change semantics of nr_indirectly_reclaimable_bytes (Waiman Long) [1699202]
- [fs] dcache: allocate external names from reclaimable kmalloc caches (Waiman Long) [1699202]
- [mm] mm, slab/slub: introduce kmalloc-reclaimable caches (Waiman Long) [1699202]
- [mm] mm, slab: combine kmalloc_caches and kmalloc_dma_caches (Waiman Long) [1699202]
- [mm] mm: don't warn about large allocations for slab (Waiman Long) [1699202]
- [mm] slab: Replace synchronize_sched() with synchronize_rcu() (Waiman Long) [1699202]
- [acpi] ACPI / PM: LPIT: Register sysfs attributes based on FADT (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Quirk to ignore XTAL shutdown (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Add Package cstates residency info (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc_core: Add ICL platform support (Lenny Szubowicz) [1493461]
- [platform] platform/x86: intel_pmc: Sort headers alphabetically (Lenny Szubowicz) [1493461]
- [net] Revert "[net] net: openvswitch: Add a new action check_pkt_len" ("Herton R. Krzesinski")

* Tue Jul 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-121.el8]
- [nvme] nvme-rdma: use nr_phys_segments when map rq to sgl (David Milburn) [1729113]
- [nvme] nvme-loop: kill timeout handler (Ming Lei) [1692744]
- [netdrv] bnxt_en: Suppress error messages when querying DSCP DCB capabilities. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Cap the returned MSIX vectors to the RDMA driver. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix statistics context reservation logic for RDMA driver. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix ethtool selftest crash under error conditions. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Disable bus master during PCI shutdown and driver unload. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Reduce memory usage when running in kdump kernel. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix possible BUG() condition when calling pci_disable_msix(). (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix aggregation buffer leak under OOM condition. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Improve NQ reservations. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix uninitialized variable usage in bnxt_rx_pkt(). (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix statistics context reservation logic. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Pass correct extended TX port statistics size to firmware. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Fix possible crash in bnxt_hwrm_ring_free() under error conditions. (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Free short FW command HWRM memory in error path in bnxt_init_one() (Selvin Xavier) [1727972]
- [netdrv] bnxt_en: Improve multicast address setup logic. (Selvin Xavier) [1727972]
- [net] net: openvswitch: Add a new action check_pkt_len (Numan Siddique) [1700733]

* Fri Jul 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-120.el8]
- [crypto] crypto: vmx - ghash: do nosimd fallback manually (Desnes Augusto Nunes do Rosario) [1729532]
- [crypto] crypto: vmx - CTR: always increment IV as quadword (Desnes Augusto Nunes do Rosario) [1729532]
- [net] vsock/virtio: fix flush of works during the .remove() (Stefano Garzarella) [1700312]
- [net] vsock/virtio: stop workers during the .remove() (Stefano Garzarella) [1700312]
- [net] vsock/virtio: use RCU to avoid use-after-free on the_virtio_vsock (Stefano Garzarella) [1700312]
- [net] vsock/virtio: Initialize core virtio vsock before registering the driver (Stefano Garzarella) [1700312]
- [nvme] nvme-fabrics: document the poll function argument (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: fix queue mapping when queue count is limited (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: rework queue maps handling (David Milburn) [1727784 1725132]
- [nvme] nvme-rdma: implement polling queue map (David Milburn) [1727784 1725132]
- [nvme] nvme-fabrics: allow nvmf_connect_io_queue to poll (David Milburn) [1727784 1725132]
- [hid] HID: multitouch: Add pointstick support for ALPS Touchpad (Benjamin Tissoires) [1672423]

* Thu Jul 18 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-119.el8]
- [tools] perf header: Assign proper ff->ph in perf_event__synthesize_features() (Michael Petlan) [1667983]
- [pci] PCI/IOV: Assume SR-IOV VFs support extended config space. (Myron Stowe) [1714978]
- [pci] Revert "PCI/IOV: Use VF0 cached config space size for other VFs" (Myron Stowe) [1714978]
- [x86] x86/crash: Add e820 reserved ranges to kdump kernel's e820 table (Lianbo Jiang) [1630108]
- [mm] x86/mm: Rework ioremap resource mapping determination (Lianbo Jiang) [1630108]
- [x86] x86/e820, ioport: Add a new I/O resource descriptor IORES_DESC_RESERVED (Lianbo Jiang) [1630108]
- [kernel] resource: Fix find_next_iomem_res() iteration issue (Lianbo Jiang) [1630108]
- [kernel] resource: Include resource end in walk_*() interfaces (Lianbo Jiang) [1630108]
- [x86] x86/kexec: Correct KEXEC_BACKUP_SRC_END off-by-one error (Lianbo Jiang) [1630108]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.3 (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix kernel warnings related to smp_processor_id() (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix BFS crash with DIX enabled (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix FDMI fc4type for nvme support (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix fcp_rsp_len checking on lun reset (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix poor use of hardware queues if fewer irq vectors (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix oops when driver is loaded with 1 interrupt vector (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix incorrect logical link speed on trunks when links down (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix memory leak in abnormal exit path from lpfc_eq_create (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Rework misleading nvme not supported in firmware message (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix hardlockup in scsi_cmd_iocb_cmpl (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Cancel queued work for an IO when processing a received ABTS (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Prevent 'use after free' memory overwrite in nvmet LS handling (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix PT2PT PLOGI collison stopping discovery (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Revert message logging on unsupported topology (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix nvmet handling of received ABTS for unmapped frames (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Separate CQ processing for nvmet_fc upcalls (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Revise message when stuck due to unresponsive adapter (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Correct nvmet buffer free race condition (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix nvmet target abort cmd matching (Dick Kennedy) [1717027]
- [scsi] scsi: lpfc: Fix alloc context on oas lun creations (Dick Kennedy) [1717027]

* Wed Jul 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-118.el8]
- [virt] kvm: fix guest initialization code mismerge (Marcelo Tosatti) [1726487]
- [powerpc] powerpc/watchpoint: Restore NV GPRs while returning from exception (Steve Best) [1728557]
- [fs] fs/proc/vmcore: Enable dumping of encrypted memory when SEV was active (Lianbo Jiang) [1646810]
- [x86] x86/kexec: Set the C-bit in the identity map page table when SEV is active (Lianbo Jiang) [1646810]
- [x86] x86/kexec: Do not map kexec area as decrypted when SEV is active (Lianbo Jiang) [1646810]
- [mm] x86/mm: Do not use set_{pud, pmd}_safe() when splitting a large page (Lianbo Jiang) [1646810]

* Tue Jul 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-117.el8]
- [net] sched: protect against stack overflow in TC act_mirred (Ivan Vecera) [1726399]
- [net] sched: refactor reinsert action (Ivan Vecera) [1726399]
- [net] mpls: Fix 6PE forwarding (Hangbin Liu) [1726533]
- [net] make skb_dst_force return true when dst is refcounted (Florian Westphal) [1704809]
- [net] ipv4: Fix off-by-one in route dump counter without netlink strict checking (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6: fix suspicious RCU usage in rt6_dump_route() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4: fix suspicious RCU usage in fib_dump_info_fnhe() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ip6_fib: Don't discard nodes with valid routing information in fib6_locate_1() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6: Dump route exceptions if requested (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv6/route: Change return code of rt6_dump_route() for partial node dumps (Stefano Brivio) [1725383 1725381 1574290]
- [net] revert "net/ipv6: Bail early if user only wants cloned entries" (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4: Dump route exceptions if requested (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4/route: Allow NULL flowinfo in rt_fill_info() (Stefano Brivio) [1725383 1725381 1574290]
- [net] ipv4/fib_frontend: Allow RTM_F_CLONED flag to be used for filtering (Stefano Brivio) [1725383 1725381 1574290]
- [net] fib_frontend, ip6_fib: Select routes or exceptions dump from RTM_F_CLONED (Stefano Brivio) [1725383 1725381 1574290]
- [tools] selftests: bpf: disable test_lwt_seg6local (Jiri Benc) [1716346]
- [netdrv] ipvlan: Fix ipvlan device tso disabled while NETIF_F_IP_CSUM is set (Matteo Croce) [1725125]
- [netdrv] ipvlan: disallow userns cap_net_admin to change global mode/flags (Matteo Croce) [1725124]
- [net] netfilter: nft_fib: Fix existence check support (Phil Sutter) [1680578]
- [net] ipset: Fix memory accounting for hash types on resize (Stefano Brivio) [1714111]
- [tools] selftests: pmtu: Make list_flush_ipv6_exception test more demanding (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce list_flush_ipv4_exception test case (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce list_flush_ipv6_exception test case (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Add support for routing via nexthop objects (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Move route installs to a new function (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Move running of test into a new function (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Fix encapsulating device in pmtu_vti6_link_change_mtu (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Simplify cleanup and namespace names (Stefano Brivio) [1725384]
- [tools] selftests: pmtu.sh: Remove quotes around commands in setup_xfrm (Stefano Brivio) [1725384]
- [tools] selftests: Add debugging options to pmtu.sh (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: add explicit tests for PMTU exceptions cleanup (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: disable DAD in all namespaces (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce FoU and GUE PMTU exceptions tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce tests for IPv4/IPv6 over GENEVE over IPv4/IPv6 (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce tests for IPv4/IPv6 over VXLAN over IPv4/IPv6 (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Add optional traffic captures for single tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Allow selection of single tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: add basic IPv4 and IPv6 PMTU tests (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: extend MTU parsing helper to locked MTU (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: Introduce check_pmtu_value() (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: properly redirect stderr to /dev/null (Stefano Brivio) [1725384]
- [tools] selftests: pmtu: detect correct binary to ping ipv6 addresses (Stefano Brivio) [1725384]
- [net] ipv6: icmp: Updating pmtu for link local route (Guillaume Nault) [1721961]
- [net] bridge: Mark FDB entries that were added by user as such (Ivan Vecera) [1724400]
- [net] tipc: change to use register_pernet_device (Xin Long) [1719136]
- [net] sched: cls_flower: fix infinite loop in fl_walk() (Davide Caratti) [1712739]

* Fri Jul 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-116.el8]
- [rpmspec] redhat: fix vmlinux debuginfo on ppc64le (Jan Stancek) [1727638]
- [powerpc] powerpc/rtas: retry when cpu offline races with suspend/migration (Steve Best) [1727051]
- [kernel] arm64/crashkernel: Reduce crashkernel size to 448M by default (Bhupesh Sharma) [1564422]

* Thu Jul 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-115.el8]
- [scsi] scsi: libiscsi: Fix race between iscsi_xmit_task and iscsi_complete_task (Chris Leech) [1718875]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.2 (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: add check for loss of ndlp when sending RRQ (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: correct rcu unlock issue in lpfc_nvme_info_show (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: resolve lockdep warnings (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Make lpfc_sli4_oas_verify static (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix a recently introduced compiler warning (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix missing wakeups on abort threads (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Change smp_processor_id() into raw_smp_processor_id() (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Remove unused functions (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Remove set-but-not-used variables (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Move trunk_errmsg[] from a header file into a .c file (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Annotate switch/case fall-through (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Fix indentation and balance braces (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: Declare local functions static (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: avoid uninitialized variable warning (Dick Kennedy) [1714795]
- [scsi] scsi: lpfc: change snprintf to scnprintf for possible overflow (Dick Kennedy) [1714795]
- [net] Bluetooth: hidp: fix buffer overflow (Gopal Tiwari) [1723654] {CVE-2019-11884}
- [s390] virtio/s390: make airq summary indicators DMA (Philipp Rudo) [1651752]
- [s390] virtio/s390: use DMA memory for ccw I/O and classic notifiers (Philipp Rudo) [1651752]
- [s390] virtio/s390: add indirection to indicators access (Philipp Rudo) [1651752]
- [s390] virtio/s390: use cacheline aligned airq bit vectors (Philipp Rudo) [1651752]
- [s390] s390/airq: use DMA memory for adapter interrupts (Philipp Rudo) [1651752]
- [s390] s390/cio: add basic protected virtualization support (Philipp Rudo) [1651752]
- [s390] s390/cio: introduce DMA pools to cio (Philipp Rudo) [1651752]
- [s390] s390/mm: force swiotlb for protected virtualization (Philipp Rudo) [1651752]
- [s390] virtio/s390: DMA support for virtio-ccw (Philipp Rudo) [1651752]
- [s390] virtio/s390: use vring_create_virtqueue (Philipp Rudo) [1651752]
- [block] virtio-blk: Consider virtio_max_dma_size() for maximum segment size (Philipp Rudo) [1651752]
- [virtio] virtio: Introduce virtio_max_dma_size() (Philipp Rudo) [1651752]
- [kernel] dma: Introduce dma_max_mapping_size() (Philipp Rudo) [1651752]
- [kernel] swiotlb: Add is_swiotlb_active() function (Philipp Rudo) [1651752]
- [kernel] swiotlb: Introduce swiotlb_max_mapping_size() (Philipp Rudo) [1651752]
- [mm] x86/mm: Create a workarea in the kernel for SME early encryption (Lianbo Jiang) [1564427]
- [x86] x86/mm: Identify the end of the kernel area to be reserved (Lianbo Jiang) [1564427]
- [x86] x86/kdump: Export the SME mask to vmcoreinfo (Lianbo Jiang) [1564427]
- [fs] proc/vmcore: Fix i386 build error of missing copy_oldmem_page_encrypted() (Lianbo Jiang) [1564427]
- [fs] kdump, proc/vmcore: Enable kdumping encrypted memory with SME enabled (Lianbo Jiang) [1564427]
- [iommu] iommu/amd: Remap the IOMMU device table with the memory encryption mask for kdump (Lianbo Jiang) [1564427]
- [kernel] kexec: Allocate decrypted control pages for kdump if SME is enabled (Lianbo Jiang) [1564427]
- [mm] x86/ioremap: Add an ioremap_encrypted() helper (Lianbo Jiang) [1564427]
- [documentation] Documentation: Add ARM64 to kernel-parameters.rst (Jeremy Linton) [1640855]
- [arm64] arm64/speculation: Support 'mitigations=' cmdline option (Jeremy Linton) [1640855]
- [arm64] arm64: ssbs: Don't treat CPUs with SSBS as unaffected by SSB (Jeremy Linton) [1640855]
- [arm64] arm64: enable generic CPU vulnerabilites support (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for speculative store bypass (Jeremy Linton) [1640855]
- [arm64] arm64: Always enable ssb vulnerability detection (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for spectre-v2 (Jeremy Linton) [1640855]
- [arm64] arm64: Always enable spectre-v2 vulnerability detection (Jeremy Linton) [1640855]
- [arm64] arm64: Use firmware to detect CPUs that are not affected by Spectre-v2 (Jeremy Linton) [1640855]
- [arm64] arm64: Advertise mitigation of Spectre-v2, or lack thereof (Jeremy Linton) [1640855]
- [arm64] arm64: add sysfs vulnerability show for meltdown (Jeremy Linton) [1640855]
- [arm64] arm64: Add sysfs vulnerability show for spectre-v1 (Jeremy Linton) [1640855]
- [arm64] arm64: Provide a command line to disable spectre_v2 mitigation (Jeremy Linton) [1640855]
- [documentation] powerpc/fsl: Add FSL_PPC_BOOK3E as supported arch for nospectre_v2 boot arg (Jeremy Linton) [1640855]
- [documentation] Documentation: Document arm64 kpti control (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Whitelist HiSilicon Taishan v110 CPUs (Jeremy Linton) [1640855]
- [arm64] arm64: Add MIDR encoding for HiSilicon Taishan CPUs (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Whitelist Cortex-A CPUs that don't implement the CSV3 field (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Update arm64_kernel_use_ng_mappings() when forced on (Jeremy Linton) [1640855]
- [arm64] arm64: kpti: Avoid rewriting early page tables when KASLR is enabled (Jeremy Linton) [1640855]
- [arm64] arm64: capabilities: Merge duplicate Cavium erratum entries (Jeremy Linton) [1640855]
- [arm64] arm64: capabilities: Merge entries for ARM64_WORKAROUND_CLEAN_CACHE (Jeremy Linton) [1640855]
- [arm64] arm64: Use a raw spinlock in __install_bp_hardening_cb() (Jeremy Linton) [1640855]
- [arm64] arm64: KVM: Guests can skip __install_bp_hardening_cb()s HYP work (Jeremy Linton) [1640855]
- [arm64] arm64: fix SSBS sanitization (Jeremy Linton) [1640855]
- [arm64] arm64: don't zero DIT on signal return (Jeremy Linton) [1640855]
- [kvm] KVM: arm64: Set SCTLR_EL2.DSSBS if SSBD is forcefully disabled and !vhe (Jeremy Linton) [1640855]
- [arm64] arm64: ssbd: Add support for PSTATE.SSBS rather than trapping to EL3 (Jeremy Linton) [1640855]
- [arm64] arm64: ssbd: Drop #ifdefs for PR_SPEC_STORE_BYPASS (Jeremy Linton) [1640855]
- [arm64] arm64: cpufeature: Detect SSBS and advertise to userspace (Jeremy Linton) [1640855]
- [arm64] arm64: move SCTLR_EL{1,2} assertions to <asm/sysreg.h> (Jeremy Linton) [1640855]

* Wed Jul 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-114.el8]
- [powerpc] powerpc/mm/64s/hash: Reallocate context ids on fork (Steve Best) [1723808]
- [powerpc] powerpc/perf: Use cpumask_last() to determine the designated cpu for nest/core units. (Steve Best) [1725746]
- [fs] iomap: fix page_done callback for short writes (Andreas Grunbacher) [1724361]
- [fs] fs: fold __generic_write_end back into generic_write_end (Andreas Grunbacher) [1724361]
- [fs] iomap: don't mark the inode dirty in iomap_write_end (Andreas Grunbacher) [1724361]
- [fs] gfs2: Fix iomap write page reclaim deadlock (Andreas Grunbacher) [1724361]
- [fs] iomap: Add a page_prepare callback (Andreas Grunbacher) [1724361]
- [fs] iomap: Fix use-after-free error in page_done callback (Andreas Grunbacher) [1724361]
- [fs] fs: Turn __generic_write_end into a void function (Andreas Grunbacher) [1724361]
- [fs] iomap: Clean up __generic_write_end calling (Andreas Grunbacher) [1724361]
- [kvm] KVM: PPC: Book3S HV: Clear pending decrementer exceptions on nested guest entry (Suraj Jitindar Singh) [1718822]
- [kvm] KVM: PPC: Book3S HV: Signed extend decrementer value if not using large decrementer (Suraj Jitindar Singh) [1718822]

* Tue Jul 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-113.el8]
- [hid] HID: chicony: add another quirk for PixArt mouse (Oleksandr Natalenko) [1724967]
- [scsi] scsi: smartpqi: properly set both the DMA mask and the coherent DMA mask (Don Brace) [1712272]
- [tools] perf beauty waitid options: Fix up prefix showing logic (Michael Petlan) [1715507]
- [include] redhat: perf kABI-check failure fix (Michael Petlan) [1715507]
- [tools] perf script python: Add Python3 support to tests/attr.py (Michael Petlan) [1715507]
- [tools] perf trace: Support multiple "vfs_getname" probes (Michael Petlan) [1715507]
- [tools] perf symbols: Filter out hidden symbols from labels (Michael Petlan) [1715507]
- [tools] perf symbols: Add fallback definitions for GELF_ST_VISIBILITY() (Michael Petlan) [1715507]
- [tools] perf clang: Do not use 'return std::move(something)' (Michael Petlan) [1715507]
- [tools] perf tests evsel-tp-sched: Fix bitwise operator (Michael Petlan) [1715507]
- [tools] perf script: Fix crash when processing recorded stat data (Michael Petlan) [1715507]
- [tools] perf top: Fix wrong hottest instruction highlighted (Michael Petlan) [1715507]
- [tools] perf tools: Handle TOPOLOGY headers with no CPU (Michael Petlan) [1715507]
- [tools] perf python: Remove -fstack-clash-protection when building with some clang versions (Michael Petlan) [1715507]
- [tools] perf script: Fix crash with printing mixed trace point and other events (Michael Petlan) [1715507]
- [tools] perf ordered_events: Fix crash in ordered_events__free (Michael Petlan) [1715507]
- [tools] tools headers powerpc: Remove unistd.h (Michael Petlan) [1715507]
- [tools] perf powerpc: Rework syscall table generation (Michael Petlan) [1715507]
- [tools] perf symbols: Add 'arch_cpu_idle' to the list of kernel idle symbols (Michael Petlan) [1715507]
- [tools] perf beauty: Switch from using uapi/linux/fs.h to uapi/linux/mount.h (Michael Petlan) [1715507]
- [tools] tools include uapi: Grab a copy of linux/mount.h (Michael Petlan) [1715507]
- [tools] perf top: Lift restriction on using callchains without "sym" in --sort (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Remove tep_data_event_from_type() API (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename tep_is_file_bigendian() to tep_file_bigendian() (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Changed return logic of tep_register_event_handler() API (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Changed return logic of trace_seq_printf() and trace_seq_vprintf() APIs (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename struct cmdline to struct tep_cmdline (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Initialize host_bigendian at tep_handle allocation (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Introduce new libtracevent API: tep_override_comm() (Michael Petlan) [1715507]
- [tools] perf tests: Add a test for the ARM 32-bitpage (Michael Petlan) [1715507]
- [tools] perf tools: Make find_vdso_map() more modular (Michael Petlan) [1715507]
- [tools] perf trace: Fix alignment forlines (Michael Petlan) [1715507]
- [tools] perf trace: Fix ')' placement in "interrupted" syscall lines (Michael Petlan) [1715507]
- [tools] perf test shell: Use a fallback to get the pathname in vfs_getname (Michael Petlan) [1715507]
- [tools] perf python: Make sure the python binding output directory is in place (Michael Petlan) [1715507]
- [tools] perf strbuf: Remove redundant va_end() in strbuf_addv() (Michael Petlan) [1715507]
- [tools] perf annotate: Pass filename to objdump via execl (Michael Petlan) [1715507]
- [tools] perf report: Fix wrong iteration count in --branch-history (Michael Petlan) [1715507]
- [tools] tools headers uapi: Sync copy of asm-generic/unistd.h with the kernel sources (Michael Petlan) [1715507]
- [tools] tools beauty: Make the prctl option table generator catch all PR_ options (Michael Petlan) [1715507]
- [tools] perf stat: Fix endless wait for child process (Michael Petlan) [1715507]
- [tools] perf session: Add comment for perf_session__register_idle_thread() (Michael Petlan) [1715507]
- [tools] perf thread-stack: Fix thread stack processing for the idle task (Michael Petlan) [1715507]
- [tools] perf thread-stack: Allocate an array of thread stacks (Michael Petlan) [1715507]
- [tools] perf thread-stack: Factor out thread_stack__init() (Michael Petlan) [1715507]
- [tools] perf thread-stack: Allow for a thread stack array (Michael Petlan) [1715507]
- [tools] perf thread-stack: Avoid direct reference to the thread's stack (Michael Petlan) [1715507]
- [tools] perf thread-stack: Tidy thread_stack__bottom() usage (Michael Petlan) [1715507]
- [tools] perf thread-stack: Simplify some code in thread_stack__process() (Michael Petlan) [1715507]
- [tools] perf c2c: Increase the HITM ratio limit for displayed cachelines (Michael Petlan) [1715507]
- [tools] perf c2c: Change the default coalesce setup (Michael Petlan) [1715507]
- [tools] perf trace beauty ioctl: Beautify USBDEVFS_ commands (Michael Petlan) [1715507]
- [tools] perf trace beauty: Export function to get the files for a thread (Michael Petlan) [1715507]
- [tools] perf trace: Wire up ioctl's USBDEBFS_ cmd table generator (Michael Petlan) [1715507]
- [tools] perf beauty ioctl: Add generator for USBDEVFS_ ioctl commands (Michael Petlan) [1715507]
- [tools] tools headers uapi: Grab a copy of usbdevice_fs.h (Michael Petlan) [1715507]
- [tools] perf trace: Store the major number for a file when storing its pathname (Michael Petlan) [1715507]
- [tools] perf trace: Move the files table resizing to outside set_pathname() (Michael Petlan) [1715507]
- [tools] perf trace: Rename thread_thread->paths to thread_trace->files (Michael Petlan) [1715507]
- [tools] perf script: Fix LBR skid dump problems in brstackinsn (Michael Petlan) [1715507]
- [tools] perf trace: Use correct SECCOMP prefix spelling, "SECOMP_*" -> "SECCOMP_*" (Michael Petlan) [1715507]
- [tools] perf trace: Do not hardcode the size of the tracepoint common_ fields (Michael Petlan) [1715507]
- [tools] perf build: Don't unconditionally link the libbfd feature test to -liberty and -lz (Michael Petlan) [1715507]
- [tools] perf beauty mmap: PROT_WRITE should come before PROT_EXEC (Michael Petlan) [1715507]
- [tools] perf trace: Check if the raw_syscalls:sys_{enter, exit} are setup before setting tp filter (Michael Petlan) [1715507]
- [tools] perf symbols: Relax checks on perf-PID.map ownership (Michael Petlan) [1715507]
- [tools] perf trace: Wire up the fadvise 'advice' table generator (Michael Petlan) [1715507]
- [tools] perf beauty: Add generator for fadvise64's 'advice' arg constants (Michael Petlan) [1715507]
- [tools] tools headers uapi: Grab a copy of fadvise.h (Michael Petlan) [1715507]
- [tools] perf beauty mmap: Print mmap's 'offset' arg in hexadecimal (Michael Petlan) [1715507]
- [tools] perf beauty mmap: Print PROT_READ before PROT_EXEC to match strace output (Michael Petlan) [1715507]
- [tools] perf trace beauty: Beautify arch_prctl()'s arguments (Michael Petlan) [1715507]
- [tools] perf trace: When showing string prefixes show prefix + ??? for unknown entries (Michael Petlan) [1715507]
- [tools] perf trace: Move strarrays to beauty.h for further reuse (Michael Petlan) [1715507]
- [tools] perf beauty: Wire up the x86_arch prctl code table generator (Michael Petlan) [1715507]
- [tools] perf beauty: Add a string table generator for x86's 'arch_prctl' codes (Michael Petlan) [1715507]
- [tools] tools include arch: Grab a copy of x86's prctl.h (Michael Petlan) [1715507]
- [tools] perf trace: Show NULL when syscall pointer args are 0 (Michael Petlan) [1715507]
- [tools] perf trace: Enclose the errno strings with () (Michael Petlan) [1715507]
- [tools] perf augmented_raw_syscalls: Copy 'access' arg as well (Michael Petlan) [1715507]
- [tools] perf trace: Add alignment spaces after the closing parens (Michael Petlan) [1715507]
- [tools] perf trace beauty: Print O_RDONLY when (flags & O_ACCMODE) == 0 (Michael Petlan) [1715507]
- [tools] perf trace: Allow asking for not suppressing common string prefixes (Michael Petlan) [1715507]
- [tools] perf trace: Add a prefix member to the strarray class (Michael Petlan) [1715507]
- [tools] perf trace: Enclose strings with double quotes (Michael Petlan) [1715507]
- [tools] perf trace: Make the alignment of the syscall args be configurable (Michael Petlan) [1715507]
- [tools] perf trace: Allow suppressing the syscall argument names (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if the syscall start timestamp should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring default for perf_event_attr.inherit (Michael Petlan) [1715507]
- [tools] perf config: Show the configuration when no arguments are provided (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if the syscall duration should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow configuring if zeroed syscall args should be printed (Michael Petlan) [1715507]
- [tools] perf trace: Allow specifying a set of events to add in perfconfig (Michael Petlan) [1715507]
- [tools] perf augmented_raw_syscalls: Do not include stdio.h (Michael Petlan) [1715507]
- [tools] perf cs-etm: Generate branch sample for exception packet (Michael Petlan) [1715507]
- [tools] perf cs-etm: Treat EO_TRACE element as trace discontinuity (Michael Petlan) [1715507]
- [tools] perf cs-etm: Treat NO_SYNC element as trace discontinuity (Michael Petlan) [1715507]
- [tools] perf cs-etm: Rename CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY (Michael Petlan) [1715507]
- [tools] perf cs-etm: Refactor enumeration cs_etm_sample_type (Michael Petlan) [1715507]
- [tools] perf cs-etm: Remove unused 'trace_on' in cs_etm_decoder (Michael Petlan) [1715507]
- [tools] perf cs-etm: Avoid stale branch samples when flush packet (Michael Petlan) [1715507]
- [tools] perf cs-etm: Correct packets swapping in cs_etm__flush() (Michael Petlan) [1715507]
- [tools] perf trace: Switch to using a struct for the aumented_raw_syscalls syscalls map values (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Switch to using a struct for the syscalls map values (Michael Petlan) [1715507]
- [tools] perf bpf: Move perf_event_output() from stdio.h to bpf.h (Michael Petlan) [1715507]
- [tools] perf trace: Implement syscall filtering in augmented_syscalls (Michael Petlan) [1715507]
- [tools] perf trace: Avoid using raw_syscalls in duplicity with eBPF augmentation (Michael Petlan) [1715507]
- [tools] perf trace: Rename set_ev_qualifier_filter to clarify its a tracepoint filter (Michael Petlan) [1715507]
- [tools] perf tools: Cast off_t to s64 to avoid warning on bionic libc (Michael Petlan) [1715507]
- [tools] perf tools: Add missing open_memstream() prototype for systems lacking it (Michael Petlan) [1715507]
- [tools] perf header: Fix up argument to ctime() (Michael Petlan) [1715507]
- [tools] perf tools: Add missing sigqueue() prototype for systems lacking it (Michael Petlan) [1715507]
- [tools] tools lib subcmd: Don't add the kernel sources to the include path (Michael Petlan) [1715507]
- [tools] perf trace beauty: renameat's newdirfd may also be AT_FDCWD (Michael Petlan) [1715507]
- [tools] perf trace: Beautify renameat2's flags argument (Michael Petlan) [1715507]
- [tools] perf beauty: Wire up the renameat flags table generator to the Makefile (Michael Petlan) [1715507]
- [tools] perf beauty: Add a string table generator for renameat2's flags constants (Michael Petlan) [1715507]
- [tools] perf trace beauty: Beautify renameat2's fd arg wrt AT_FDCWD (Michael Petlan) [1715507]
- [tools] perf trace: Allow selecting use the use of the ordered_events code (Michael Petlan) [1715507]
- [tools] perf trace: Rename delivery functions to ease making ordered_events selectable (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix processing of dereferenced args in bprintk events (Michael Petlan) [1715507]
- [tools] perf stat: Avoid segfaults caused by negated options (Michael Petlan) [1715507]
- [tools] perf auxtrace: Alter addr_filter__entire_dso() to work if there are no symbols (Michael Petlan) [1715507]
- [tools] perf dso: Export data_file_size() method there are no symbols (Michael Petlan) [1715507]
- [tools] perf trace: Add ordered processing (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add first_time() method (Michael Petlan) [1715507]
- [tools] perf trace: Move event delivery to a new deliver_event() function (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add ordered_events__flush_time interface (Michael Petlan) [1715507]
- [tools] perf annotate: Introduce basic support for ARC (Michael Petlan) [1715507]
- [tools] perf config: Modify size factor of snprintf (Michael Petlan) [1715507]
- [tools] perf record: Fix memory leak on AIO objects deallocation (Michael Petlan) [1715507]
- [tools] perf vendor events intel: Fix Load_Miss_Real_Latency on SKL/SKX (Michael Petlan) [1715507]
- [tools] perf parse-events: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf probe: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf ui helpline: Use strlcpy() as a shorter form of strncpy() + explicit set nul (Michael Petlan) [1715507]
- [tools] perf svghelper: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf help: Remove needless use of strncpy() (Michael Petlan) [1715507]
- [tools] perf header: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf header: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf dso: Fix unchecked usage of strncpy() (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add support for PTMv1.1 decoding (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add support for ETMv3 trace decoding (Michael Petlan) [1715507]
- [tools] perf cs-etm: Add configuration for ETMv3 trace protocol (Michael Petlan) [1715507]
- [tools] perf top: Move perf_top__reset_sample_counters() to after counts display (Michael Petlan) [1715507]
- [tools] perf top: Display slow reader warning when droping samples (Michael Petlan) [1715507]
- [tools] perf top: Save and display the drop count stats (Michael Petlan) [1715507]
- [tools] perf top: Drop samples which are behind the refresh rate (Michael Petlan) [1715507]
- [tools] perf top: Set the 'session_done' volatile variable when exiting (Michael Petlan) [1715507]
- [tools] perf top: Use cond variable instead of a lock (Michael Petlan) [1715507]
- [tools] perf top: Add processing thread (Michael Petlan) [1715507]
- [tools] perf top: Move lost events warning to helpline (Michael Petlan) [1715507]
- [tools] perf top: Save and display the lost count stats (Michael Petlan) [1715507]
- [tools] perf ordered_events: Add private data member (Michael Petlan) [1715507]
- [tools] perf ordered_events: Rework show_progress for __ordered_events__flush (Michael Petlan) [1715507]
- [tools] perf tools: Support 'srccode' output (Michael Petlan) [1715507]
- [tools] perf trace: We need to consider "nr" if "__syscall_nr" is not there (Michael Petlan) [1715507]
- [tools] perf tools: Allow specifying proc-map-timeout in config file (Michael Petlan) [1715507]
- [tools] tools lib subcmd: Fix a few source code comment typos (Michael Petlan) [1715507]
- [tools] perf tools: Fix diverse comment typos (Michael Petlan) [1715507]
- [tools] perf bpf-loader: Fix debugging message typo (Michael Petlan) [1715507]
- [tools] perf tools Documentation: Fix diverse typos (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix diverse typos in comments (Michael Petlan) [1715507]
- [tools] perf vendor events intel: Fix diverse typos (Michael Petlan) [1715507]
- [tools] perf tests ARM: Disable breakpoint tests 32-bit (Michael Petlan) [1715507]
- [tools] perf cs-etm: Support for ARM A32/T32 instruction sets in CoreSight trace (Michael Petlan) [1715507]
- [tools] perf beauty mmap_flags: Fixed syntax error Fixed missing ']' error (Michael Petlan) [1715507]
- [tools] tools lib traceevent: traceevent API cleanup (Michael Petlan) [1715507]
- [tools] perf tools: traceevent API cleanup, remove __tep_data2host*() (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Rename tep_free_format() to tep_free_event() (Michael Petlan) [1715507]
- [tools] tools lib traceevent, perf tools: Rename 'struct tep_event_format' to 'struct tep_event' (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Install trace-seq.h API header file (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Added support for pkg-config (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Implement new API tep_get_ref() (Michael Petlan) [1715507]
- [tools] perf report: Documentation average IPC and IPC coverage (Michael Petlan) [1715507]
- [tools] perf report: Display average IPC and IPC coverage per symbol (Michael Petlan) [1715507]
- [tools] perf annotate: Create a annotate2 flag in struct symbol (Michael Petlan) [1715507]
- [tools] perf annotate: Compute average IPC and IPC coverage per symbol (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Add sanity check to is_timestamp_in_us() (Michael Petlan) [1715507]
- [tools] perf beauty mmap_flags: Check if the arch has a mmap.h file (Michael Petlan) [1715507]
- [tools] perf record: Extend trace writing to multi AIO (Michael Petlan) [1715507]
- [tools] perf record: Enable asynchronous trace writing (Michael Petlan) [1715507]
- [tools] perf mmap: Map data buffer for preserving collected data (Michael Petlan) [1715507]
- [tools] tools build feature: Check if libaio is available (Michael Petlan) [1715507]
- [tools] perf intel-pt: Fix error with config term "pt=0" (Michael Petlan) [1715507]
- [tools] perf top: Allow passing a kallsyms file (Michael Petlan) [1715507]
- [tools] perf bpf: Use ERR_CAST instead of ERR_PTR(PTR_ERR()) (Michael Petlan) [1715507]
- [tools] tools include: Adopt ERR_CAST() from the kernel err.h header (Michael Petlan) [1715507]
- [tools] perf tests record: Allow for 'sleep' being 'coreutils' (Michael Petlan) [1715507]
- [tools] tools lib traceevent: Fix compile warnings in tools/lib/traceevent/event-parse.c (Michael Petlan) [1715507]
- [tools] perf script: Use fallbacks for branch stacks (Michael Petlan) [1715507]
- [tools] perf tools: Use fallback for sample_addr_correlates_sym() cases (Michael Petlan) [1715507]
- [tools] perf thread: Add fallback functions for cases where cpumode is insufficient (Michael Petlan) [1715507]
- [tools] perf machine: Record if a arch has a single user/kernel address space (Michael Petlan) [1715507]
- [tools] perf env: Also consider env->arch == NULL as local operation (Michael Petlan) [1715507]
- [tools] perf map: Remove extra indirection from map__find() (Michael Petlan) [1715507]
- [tools] perf stat: Fix CSV mode column output for non-cgroup events (Michael Petlan) [1715507]
- [tools] perf stat: Fix shadow stats for clock events (Michael Petlan) [1715507]
- [tools] perf build: Give better hint about devel package for libssl (Michael Petlan) [1715507]
- [tools] perf pmu: Move *_cpuid_str() weak functions to header.c (Michael Petlan) [1715507]
- [tools] perf symbols: Fix slowness due to -ffunction-section (Michael Petlan) [1715507]
- [tools] perf jvmti: Separate jvmti cmlr check (Michael Petlan) [1715507]
- [tools] perf vendor events: Add JSON metrics for Cascadelake server (Michael Petlan) [1715507]
- [tools] perf vendor events: Add stepping in CPUID string for x86 (Michael Petlan) [1715507]
- [tools] perf stat: Use perf_evsel__is_clocki() for clock events (Michael Petlan) [1715507]
- [tools] perf pmu: Suppress potential format-truncation warning (Michael Petlan) [1715507]
- [tools] perf tools: Add Hygon Dhyana support (Michael Petlan) [1715507]
- [tools] perf bench: Add epoll_ctl(2) benchmark (Michael Petlan) [1715507]
- [tools] perf bench: Add epoll parallel epoll_wait benchmark (Michael Petlan) [1715507]
- [tools] tools build feature: Check if eventfd() is available (Michael Petlan) [1715507]
- [tools] perf bench: Move HAVE_PTHREAD_ATTR_SETAFFINITY_NP into bench.h (Michael Petlan) [1715507]
- [tools] perf script: Share code and output format for uregs and iregs output (Michael Petlan) [1715507]
- [tools] perf bpf: Reduce the hardcoded .max_entries for pid_maps (Michael Petlan) [1715507]
- [tools] perf script: Add newline after uregs output (Michael Petlan) [1715507]
- [tools] Revert "perf augmented_syscalls: Drop 'write', 'poll' for testing without self pid filter" (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Remove example hardcoded set of filtered pids (Michael Petlan) [1715507]
- [tools] perf trace: Fill in BPF "filtered_pids" map when present (Michael Petlan) [1715507]
- [tools] perf trace: See if there is a map named "filtered_pids" (Michael Petlan) [1715507]
- [tools] perf trace: Add "_from_option" suffix to trace__set_filter() (Michael Petlan) [1715507]
- [tools] perf evlist: Rename perf_evlist__set_filter* to perf_evlist__set_tp_filter* (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Use pid_filter (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Drop 'write', 'poll' for testing without self pid filter (Michael Petlan) [1715507]
- [tools] perf bpf: Add simple pid_filter class accessible to BPF proggies (Michael Petlan) [1715507]
- [tools] perf bpf: Add defines for map insertion/lookup (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Remove needless linux/socket.h include (Michael Petlan) [1715507]
- [tools] perf augmented_syscalls: Filter on a hard coded pid (Michael Petlan) [1715507]
- [tools] perf bpf: Add unistd.h to the headers accessible to bpf proggies (Michael Petlan) [1715507]
- [kernel] perf/core: Fix impossible ring-buffer sizes warning (Michael Petlan) [1715507]
- [x86] perf/x86: Add check_period PMU callback (Michael Petlan) [1715507]
- [kernel] perf/core: Don't WARN() for impossible ring-buffer sizes (Michael Petlan) [1715507]
- [x86] perf/x86/intel/uncore: Add Node ID mask (Michael Petlan) [1715507]
- [kernel] perf core: Fix perf_proc_update_handler() bug (Michael Petlan) [1715507]
- [tools] powerpc/perf: Update perf_regs structure to include MMCRA (Michael Petlan) [1715507]
- [powerpc] powerpc/perf: Update perf_regs structure to include SIER (Michael Petlan) [1715507]
- [include] perf/core: Declare the __percpu attribute on non-deref types (Michael Petlan) [1715507]
- [kernel] perf: Fix typos in comments (Michael Petlan) [1715507]
- [arm64] arm64: perf: Add support for Armv8.1 PMCEID register format (Michael Petlan) [1715507]

* Fri Jul 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-112.el8]
- [fs] xfs: abort unaligned nowait directio early (Brian Foster) [1690458]
- [fs] xfs: serialize unaligned dio writes against all other dio writes (Brian Foster) [1690458]
- [sound] ALSA: hda/hdmi: consider eld_valid also in sync_eld_via_acomp() (Jaroslav Kysela) [1708555]
- [fs] Fix error code in nfs_lookup_verify_inode() (Scott Mayhew) [1722315]
- [md] dm table: don't copy from a NULL pointer in realloc_argv() (Jerome Marchand) [1571628]
- [net] netfilter: ipset: replace a strncpy() with strscpy() (Jerome Marchand) [1571628]
- [lib] lib/ubsan.c: don't mark __ubsan_handle_builtin_unreachable as noreturn (Jerome Marchand) [1571628]
- [include] netfilter: avoid erronous array bounds warning (Jerome Marchand) [1571628]
- [x86] x86/mm/KASLR: Compute the size of the vmemmap section properly (Baoquan He) [1669076]
- [security] selinux: fix empty write to keycreate file (Ondrej Mosnacek) [1719067]
- [netdrv] net: aquantia: fix vlans not working over bridged network (Igor Russkikh) [1718716]
- [s390] s390/jump_label: replace stop_machine with smp_call_function (Philipp Rudo) [1722161]
- [s390] s390/dumpstack: print psw mask and address again (Philipp Rudo) [1722157]
- [s390] s390/crypto: fix gcm-aes-s390 selftest failures (Philipp Rudo) [1722156]
- [wireless] Backport mt76 drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709867 1709828]
- [wireless] Add rtw88 driver from linux-5.2-rc5 (Stanislaw Gruszka) [1487086 1709828]
- [wireless] Backport mt7601u driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport mwifiex driver from linux-5.2-rc2 (Stanislaw Gruszka) [1709828]
- [wireless] Backport rtl8xxxu driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport rtlwifi drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport ath9k driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport ath10k driver from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport brcm80211 drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [wireless] Backport iwlwifi drivers from linux-5.2-rc5 (Stanislaw Gruszka) [1696052 1662020 1662015 1650016 1650015 1650014 1650013 1622445 1494008 1494001 1709828]
- [net] Backport mac80211 from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [net] Backport core wireless code from linux-5.2-rc5 (Stanislaw Gruszka) [1709828]
- [include] netlink: add nl_set_extack_cookie_u64() (Stanislaw Gruszka) [1709828]
- [netdrv] r8152: Fix an error on RTL8153-BD MAC Address Passthrough support (Torez Smith) [1683883 1683882]
- [netdrv] r8152: Add support for MAC address pass through on RTL8153-BD (Torez Smith) [1683883 1683882]
- [netdrv] nfp: abm: fix spelling mistake "offseting" -> "offsetting" (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: remove vlan CFI bit from push vlan action (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: replace CFI with vlan present (Pablo Cascon) [1713258]
- [netdrv] nfp: flower: remove double new line (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: fix ALU32 high bits clearance bug (Pablo Cascon) [1713258]
- [netdrv] bpf: do not pass netdev to translate() and prepare() offload callbacks (Pablo Cascon) [1713258]
- [netdrv] bpf: pass prog instead of env to bpf_prog_offload_verifier_prep() (Pablo Cascon) [1713258]
- [netdrv] bpf: pass destroy() as a callback and remove its ndo_bpf subcommand (Pablo Cascon) [1713258]
- [netdrv] bpf: pass translate() as a callback and remove its ndo_bpf subcommand (Pablo Cascon) [1713258]
- [netdrv] bpf: call verifier_prep from its callback in struct bpf_offload_dev (Pablo Cascon) [1713258]
- [netdrv] bpf: pass a struct with offload callbacks to bpf_offload_dev_create() (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: move nfp_bpf_analyzer_ops from verifier.c to offload.c (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: relax prog rejection through max_pkt_offset (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: double check vNIC capabilities after object sharing (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: optimise save/restore for R6~R9 based on register usage (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: fix return address from register-saving subroutine to callee (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: update fixup function for BPF-to-BPF calls support (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: account for additional stack usage when checking stack limit (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: add main logics for BPF-to-BPF calls support in nfp driver (Pablo Cascon) [1713258]
- [netdrv] nfp: bpf: copy eBPF subprograms information from kernel verifier (Pablo Cascon) [1713258]
- [netdrv] bpf: add verifier callback to get stack usage info for offloaded progs (Pablo Cascon) [1713258]

* Wed Jul 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-111.el8]
- [rpmspec] Enable kernel signing for ppc64le (Gustavo Duarte) [1504169]
- [nvme] nvme: fix memory leak for power latency tolerance (David Milburn) [1724793]
- [rpmspec] redhat: fix missing files for mlxsw specific self-tests (Ivan Vecera) [1724735]
- [rpmspec] redhat: Package the signing key for s390 (Philipp Rudo) [1714194]
- [rpmspec] redhat: Enable kernel signing for s390 (Philipp Rudo) [1714194]
- [rpmspec] redhat: Rename secure boot sources (Philipp Rudo) [1714194]
- [powerpc] powerpc: fix max_zone_pfns initialization (Laurent Vivier) [1706560]
- [crypto] crypto: dh - update test for public key verification (Herbert Xu) [1722692]
- [hid] HID: i2c-hid: Don't reset device upon system resume (Perry Yuan) [1715385]
- [rpmspec] correct the ghost initramfs attributes (Rafael Aquini) [1678881]
- [s390] s390/mm: fix address space detection in exception handling (Philipp Rudo) [1722160]
- [s390] s390/zcrypt: Fix wrong dispatching for control domain CPRBs (Philipp Rudo) [1722158]
- [virt] kvm: arm/arm64: Fix emulated ptimer irq injection (Andrew Jones) [1716383]
- [x86] kvm/nested: mark as TechPreview on first VM creation (Vitaly Kuznetsov) [1723447]
- [powerpc] bpf: powerpc64: add JIT support for bpf line info (Yauheni Kaliuta) [1722423]
- [fs] cifs: add spinlock for the openFileList to cifsInodeInfo (Leif Sahlberg) [1712197]
- [fs] cifs: fix GlobalMid_Lock bug in cifs_reconnect (Leif Sahlberg) [1716743]
- [mm] powerpc/numa: document topology_updates_enabled, disable by default (Desnes Augusto Nunes do Rosario) [1705465]
- [mm] powerpc/numa: improve control of topology updates (Desnes Augusto Nunes do Rosario) [1705465]
- [kernel] bpf: decouple the lifetime of cgroup_bpf from cgroup itself (Jiri Olsa) [1656432]
- [netdrv] USB: hso: Fix OOB memory access in hso_probe/hso_get_config_data (Torez Smith) [1689308 1666662] {CVE-2018-19985}
- [usb] USB: check usb_get_extra_descriptor for proper size (Torez Smith) [1689308 1666662] {CVE-2018-20169}
- [kvm] KVM: PPC: Book3S HV: Restore SPRG3 in kvmhv_p9_guest_entry() (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Fix lockdep warning when entering guest on POWER9 (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Fix page offset when clearing ESB pages (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Take the srcu read lock when accessing memslots (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Do not clear IRQ data of passthrough interrupts (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Introduce a new mutex for the XIVE device (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Fix the enforced limit on the vCPU identifier (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Do not test the EQ flag validity when resetting (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: XIVE: Clear file mapping when device is released (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Don't take kvm->lock around kvm_for_each_vcpu (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S: Use new mutex to synchronize access to rtas token list (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Use new mutex to synchronize MMU setup (David Gibson) [1719524]
- [kvm] KVM: PPC: Book3S HV: Avoid touching arch.mmu_ready in XIVE release functions (David Gibson) [1719524]
- [mm] mm, oom: don't kill global init via memory.oom.group (Waiman Long) [1711604]
- [mm] mm, oom: remove 'prefer children over parent' heuristic (Waiman Long) [1711604]
- [mm] mm, oom: fix use-after-free in oom_kill_process (Waiman Long) [1711604]
- [kernel] fork, memcg: fix crash in free_thread_stack on memcg charge fail (Waiman Long) [1711604]
- [mm] memcg: localize memcg_kmem_enabled() check (Waiman Long) [1711604]
- [mm] memcg, oom: notify on oom killer invocation from the charge path (Waiman Long) [1711604]
- [mm] mm: handle no memcg case in memcg_kmem_charge() properly (Waiman Long) [1711604]
- [kernel] mm: rework memcg kernel stack accounting (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: convert mem_cgroup_id::ref to refcount_t type (Waiman Long) [1711604]
- [mm] memcg: remove memcg_kmem_skip_account (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: fix memory.stat item ordering (Waiman Long) [1711604]
- [mm] mm: drain memcg stocks on css offlining (Waiman Long) [1711604]
- [mm] mm: memcontrol: print proper OOM header when no eligible victim left (Waiman Long) [1711604]
- [mm] mm, oom: introduce memory.oom.group (Waiman Long) [1711604]
- [mm] mm, oom: refactor oom_kill_process() (Waiman Long) [1711604]
- [mm] memcg: reduce memcg tree traversals for stats collection (Waiman Long) [1711604]
- [mm] mm/vmscan.c: clear shrinker bit if there are no objects related to memcg (Waiman Long) [1711604]
- [mm] mm: add SHRINK_EMPTY shrinker methods return value (Waiman Long) [1711604]
- [mm] mm/vmscan.c: generalize shrink_slab() calls in shrink_node() (Waiman Long) [1711604]
- [mm] mm/vmscan.c: iterate only over charged shrinkers during memcg shrink_slab() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: set bit in memcg shrinker bitmap on first list_lru item appearance (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: export mem_cgroup_is_root() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: pass lru argument to memcg_drain_list_lru_node() (Waiman Long) [1711604]
- [mm] mm/list_lru: pass dst_memcg argument to memcg_drain_list_lru_node() (Waiman Long) [1711604]
- [mm] mm/list_lru.c: add memcg argument to list_lru_from_kmem() (Waiman Long) [1711604]
- [mm] fs: propagate shrinker::id to list_lru (Waiman Long) [1711604]
- [fs] fs: Don't need to put list_lru into its own cacheline (Waiman Long) [1711604]
- [fs] fs/super.c: refactor alloc_super() (Waiman Long) [1711604]
- [mm] mm/workingset.c: refactor workingset_init() (Waiman Long) [1711604]
- [mm] mm, memcg: assign memcg-aware shrinkers bitmap to memcg (Waiman Long) [1711604]
- [mm] mm/memcontrol.c: move up for_each_mem_cgroup{, _tree} defines (Waiman Long) [1711604]
- [mm] mm: assign id to every memcg-aware shrinker (Waiman Long) [1711604]
- [mm] mm: introduce CONFIG_MEMCG_KMEM as combination of CONFIG_MEMCG && !CONFIG_SLOB (Waiman Long) [1711604]
- [mm] mm/list_lru.c: combine code under the same define (Waiman Long) [1711604]
- [mm] memcg, oom: move out_of_memory back to the charge path (Waiman Long) [1711604]
- [fs] fs, mm: account buffer_head to kmemcg (Waiman Long) [1711604]
- [fs] fs: fsnotify: account fsnotify metadata to kmemcg (Waiman Long) [1711604]
- [include] mm: introduce mem_cgroup_put() helper (Waiman Long) [1711604]
- [net] tcp: refine memory limit test in tcp_fragment() (Florian Westphal) [1724584]
- [net] tcp: enforce tcp_min_snd_mss in tcp_mtu_probing() (Florian Westphal) [1719923] {CVE-2019-11479}
- [net] tcp: add tcp_min_snd_mss sysctl (Florian Westphal) [1719923] {CVE-2019-11479}
- [net] tipc: pass tunnel dev as NULL to udp_tunnel(6)_xmit_skb (Xin Long) [1722751]
- [include] ip6_tunnel: allow not to count pkts on tstats by passing dev as NULL (Xin Long) [1722751]
- [net] ip_tunnel: allow not to count pkts on tstats by setting skb's dev to NULL (Xin Long) [1722751]
- [net] netfilter: ipv6: nf_defrag: accept duplicate fragments again (Guillaume Nault) [1717106]
- [net] netfilter: ipv6: nf_defrag: fix leakage of unqueued fragments (Guillaume Nault) [1717106]
- [net] ethtool: fix potential userspace buffer overflow (Paolo Abeni) [1718393]
- [net] net-gro: fix use-after-free read in napi_gro_frags() (Paolo Abeni) [1718393]
- [net] ethtool: Check for vlan etype or vlan tci when parsing flow_rule (Paolo Abeni) [1718393]
- [include] test nouarg before dereferencing zerocopy pointers (Paolo Abeni) [1718393]
- [net] avoid weird emergency message (Paolo Abeni) [1718393]
- [net] net-gro: Fix GRO flush when receiving a GSO packet. (Paolo Abeni) [1718393]
- [net] sock_diag: fix autoloading of the raw_diag module (Paolo Abeni) [1718393]
- [net] make skb_partial_csum_set() more robust against overflows (Paolo Abeni) [1718393]
- [net] packets: Always register packet sk in the same order (Paolo Abeni) [1718393]
- [net] net-sysfs: call dev_hold if kobject_init_and_add success (Paolo Abeni) [1718393]
- [net] gro_cells: make sure device is up in gro_cells_receive() (Paolo Abeni) [1718393]
- [net] net-sysfs: Fix mem leak in netdev_register_kobject (Paolo Abeni) [1718393]
- [include] avoid false positives in untrusted gso validation (Paolo Abeni) [1718393]
- [include] net: validate untrusted gso packets without csum offload (Paolo Abeni) [1718393]
- [net] Do not allocate page fragments that are not skb aligned (Paolo Abeni) [1718393]
- [net] set default network namespace in init_dummy_netdev() (Paolo Abeni) [1718393]
- [net] Fix usage of pskb_trim_rcsum (Paolo Abeni) [1718393]
- [net] call sk_dst_reset when set SO_DONTROUTE (Paolo Abeni) [1718393]
- [net] net, skbuff: do not prefer skb allocation fails early (Paolo Abeni) [1718393]
- [net] ethtool: check the return value of get_regs_len (Paolo Abeni) [1718393]
- [net] packet: copy user buffers before orphan or clone (Paolo Abeni) [1718393]
- [net] don't keep lonely packets forever in the gro hash (Paolo Abeni) [1718393]
- [net] net-gro: reset skb->pkt_type in napi_reuse_skb() (Paolo Abeni) [1718393]
- [net] flow_dissector: do not dissect l4 ports for fragments (Paolo Abeni) [1718393]
- [net] net-ethtool: ETHTOOL_GUFO did not and should not require CAP_NET_ADMIN (Paolo Abeni) [1718393]
- [net] tipc: fix modprobe tipc failed after switch order of device registration (Jon Maloy) [1718064]
- [net] tipc: switch order of device registration to fix a crash (Jon Maloy) [1718064]
- [net] tipc: fix hanging clients using poll with EPOLLOUT flag (Jon Maloy) [1718064]
- [net] tipc: fix missing Name entries due to half-failover (Jon Maloy) [1718064]
- [net] tipc: remove rcu_read_unlock() left in tipc_udp_recv() (Jon Maloy) [1718064]
- [net] tipc: tipc_udp_recv() cleanup vs rcu verbs (Jon Maloy) [1718064]
- [net] tipc: introduce new socket option TIPC_SOCK_RECVQ_USED (Jon Maloy) [1718064]
- [net] tipc: set sysctl_tipc_rmem and named_timeout right range (Jon Maloy) [1718064]
- [net] tipc: fix link established but not in session (Jon Maloy) [1718064]
- [net] tipc: use standard write_lock & unlock functions when creating node (Jon Maloy) [1718064]
- [net] tipc: missing entries in name table of publications (Jon Maloy) [1718064]
- [net] tipc: adapt link failover for new Gap-ACK algorithm (Jon Maloy) [1718064]
- [net] tipc: reduce duplicate packets for unicast traffic (Jon Maloy) [1718064]
- [net] tipc: improve TIPC throughput by Gap ACK blocks (Jon Maloy) [1718064]
- [net] tipc: add NULL pointer check (Jon Maloy) [1718064]
- [net] tipc: fix return value check in tipc_mcast_send_sync() (Jon Maloy) [1718064]
- [net] tipc: fix a null pointer deref (Jon Maloy) [1718064]
- [net] tipc: fix use-after-free in tipc_sk_filter_rcv (Jon Maloy) [1718064]
- [net] tipc: smooth change between replicast and broadcast (Jon Maloy) [1718064]
- [net] tipc: introduce new capability flag for cluster (Jon Maloy) [1718064]
- [net] tipc: support broadcast/replicast configurable for bc-link (Jon Maloy) [1718064]
- [net] sched: avoid double free on matchall reoffload (Ivan Vecera) [1688236 1687456]
- [net] taprio: add null check on sched_nest to avoid potential null pointer dereference (Ivan Vecera) [1688236 1687456]
- [net] nfp: flower: remove unused index from nfp_fl_pedit() (Ivan Vecera) [1688236 1687456]
- [net] mlx5e: Fix calling wrong function to get inner vlan key and mask (Ivan Vecera) [1688236 1687456]
- [net] flow_offload: support CVLAN match (Ivan Vecera) [1688236 1687456]
- [net] nfp: flower: fix masks for tcp and ip flags fields (Ivan Vecera) [1688236 1687456]
- [net] sched: use the hardware intermediate representation for matchall (Ivan Vecera) [1688236 1687456]
- [net] sched: add sample action to the hardware intermediate representation (Ivan Vecera) [1688236 1687456]
- [net] cls_cgroup: avoid panic when receiving a packet before filter set (Ivan Vecera) [1688236 1687456]
- [net] cls_matchall: avoid panic when receiving a packet before filter set (Ivan Vecera) [1688236 1687456]
- [net] add a generic tracepoint for TX queue timeout (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: use struct_size() helper (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support for cycle-time-extension (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support for setting the cycle-time manually (Ivan Vecera) [1688236 1687456]
- [net] taprio: Add support adding an admin schedule (Ivan Vecera) [1688236 1687456]
- [net] taprio: Fix potencial use of invalid memory during dequeue() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Fix taprio_dequeue() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Fix taprio_peek() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Remove should_restart_cycle() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Refactor taprio_get_start_time() (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: Remove pointless variable assigment (Ivan Vecera) [1688236 1687456]
- [net] tc_act: drop include of module.h from tc_ife.h (Ivan Vecera) [1688236 1687456]
- [net] fib: drop include of module.h from fib_notifier.h (Ivan Vecera) [1688236 1687456]
- [net] ife: drop include of module.h from net/ife.h (Ivan Vecera) [1688236 1687456]
- [net] psample: drop include of module.h from psample.h (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: fix build without 64bit div (Ivan Vecera) [1688236 1687456]
- [net] revert: "net: sched: put back q.qlen into a single location" (Ivan Vecera) [1688236 1687456]
- [net] sched: when clearing NOLOCK, clear TCQ_F_CPUSTATS, too (Ivan Vecera) [1688236 1687456]
- [net] sched: always do stats accounting according to TCQ_F_CPUSTATS (Ivan Vecera) [1688236 1687456]
- [net] sched: prefer qdisc_is_empty() over direct qlen access (Ivan Vecera) [1688236 1687456]
- [net] caif: avoid using qdisc_qlen() (Ivan Vecera) [1688236 1687456]
- [net] sched: cbs: fix port_rate miscalculation (Ivan Vecera) [1688236 1687456]
- [net] sched: taprio: fix picos_per_byte miscalculation (Ivan Vecera) [1688236 1687456]
- [net] selftests: add a tc matchall test case (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Make sure we can write the IP header before changing DSCP bits (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Use tc_skb_protocol() helper for getting packet protocol (Ivan Vecera) [1688236 1687456]
- [net] sched: act_sample: fix divide by zero in the traffic path (Ivan Vecera) [1688236 1687456]
- [net] sched: don't set tunnel for decap action (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce and use qdisc tree flush/purge helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce and use qstats read helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: fix ->get helper of the matchall cls (Ivan Vecera) [1688236 1687456]
- [net] sched: Kconfig: update reference link for PIE (Ivan Vecera) [1688236 1687456]
- [net] dev: introduce support for sch BYPASS for lockless qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: add empty status flag for NOLOCK qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: fix cleanup NULL pointer exception in act_mirr (Ivan Vecera) [1688236 1687456]
- [net] sched: let actions use RCU to access 'goto_chain' (Ivan Vecera) [1688236 1687456]
- [net] sched: don't dereference a->goto_chain to read the chain index (Ivan Vecera) [1688236 1687456]
- [net] sched: act_vlan: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbmod: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbedit: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_simple: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_sample: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_police: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_pedit: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_nat: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_connmark: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_mirred: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_ife: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_gact: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_csum: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: act_bpf: validate the control action inside init() (Ivan Vecera) [1688236 1687456]
- [net] sched: prepare TC actions to properly validate the control action (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Interpret fwmark parameter as a bitmask (Ivan Vecera) [1688236 1687456]
- [net] net_sched: return correct value for *notify* functions (Ivan Vecera) [1688236 1687456]
- [net] sched: fix potential use-after-free in __tcf_chain_put() (Ivan Vecera) [1688236 1687456]
- [net] sched: flower: insert new filter to idr after setting its mask (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: Fix double free dst_cache (Ivan Vecera) [1688236 1687456]
- [net] sched: avoid unused-label warning (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Simplify logic in cake_select_tin() (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Permit use of connmarks as tin classifiers (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Make the dual modes fairer (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Allow test cases to be skipped (Ivan Vecera) [1688236 1687456]
- [net] sched: put back q.qlen into a single location (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: avoid slow division in drop probability decay (Ivan Vecera) [1688236 1687456]
- [net] netem: fix skb length BUG_ON in __skb_to_sgvec (Ivan Vecera) [1688236 1687456]
- [net] revert "net: sched: fw: don't set arg->stop in fw_walk() when empty" (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix 64-bit division (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: gitignore, ignore local tdc config file (Ivan Vecera) [1688236 1687456]
- [net] sched: fix typo in walker_check_empty() (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix mistake in reference link (Ivan Vecera) [1688236 1687456]
- [net] sched: act_csum: Fix csum calc for tagged packets (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: update references (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: add derandomization mechanism (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: add more cases to auto-tune alpha and beta (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change initial value of pie_vars->burst_time (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change default value of pie_params->tupdate (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change default value of pie_params->target (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: change value of QUEUE_THRESHOLD (Ivan Vecera) [1688236 1687456]
- [net] sched: don't release block->lock when dumping chains (Ivan Vecera) [1688236 1687456]
- [net] sched: set dedicated tcf_walker flag when tp is empty (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix metadata handling (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix NULL pointer dereference during init (Ivan Vecera) [1688236 1687456]
- [net] Use RCU_POINTER_INITIALIZER() to init static variable (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel replace/delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel add/delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify concurrent delete (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify concurrent replace (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules replace (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules deletion (Ivan Vecera) [1688236 1687456]
- [net] selftests: concurrency: add test to verify parallel rules insertion (Ivan Vecera) [1688236 1687456]
- [net] selftests: tdc_batch.py: add options needed for concurrency tests (Ivan Vecera) [1688236 1687456]
- [net] sched: act_skbedit: fix refcount leak when replace fails (Ivan Vecera) [1688236 1687456]
- [net] sched: act_ipt: fix refcount leak when replace fails (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: Add dst_cache support (Ivan Vecera) [1688236 1687456]
- [net] net_sched: initialize net pointer inside tcf_exts_init() (Ivan Vecera) [1687456 1688236]
- [net] sched: potential NULL dereference in tcf_block_find() (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a memory leak in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a race condition in tcindex_destroy() (Ivan Vecera) [1688236 1687456]
- [net] sched: using kfree_rcu() to simplify the code (Ivan Vecera) [1688236 1687456]
- [net] sched: route: don't set arg->stop in route4_walk() when empty (Ivan Vecera) [1688236 1687456]
- [net] sched: fw: don't set arg->stop in fw_walk() when empty (Ivan Vecera) [1688236 1687456]
- [net] sched: cgroup: verify that filter is not NULL during walk (Ivan Vecera) [1688236 1687456]
- [net] sched: matchall: verify that filter is not NULL in mall_walk() (Ivan Vecera) [1688236 1687456]
- [net] sched: remove duplicated include from cls_api.c (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix two more memory leaks in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fix a memory leak in cls_tcindex (Ivan Vecera) [1688236 1687456]
- [net] sched: unlock rules update API (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tcf_block_find() into standalone functions (Ivan Vecera) [1688236 1687456]
- [net] sched: add flags to Qdisc class ops struct (Ivan Vecera) [1688236 1687456]
- [net] sched: extend proto ops to support unlocked classifiers (Ivan Vecera) [1688236 1687456]
- [net] sched: extend proto ops with 'put' callback (Ivan Vecera) [1688236 1687456]
- [net] sched: track rtnl lock status when validating extensions (Ivan Vecera) [1688236 1687456]
- [net] sched: prevent insertion of new classifiers during chain flush (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tp insert/delete for concurrent execution (Ivan Vecera) [1688236 1687456]
- [net] sched: traverse classifiers in chain with tcf_get_next_proto() (Ivan Vecera) [1688236 1687456]
- [net] sched: introduce reference counting for tcf_proto (Ivan Vecera) [1688236 1687456]
- [net] sched: protect filter_chain list with filter_chain_lock mutex (Ivan Vecera) [1688236 1687456]
- [net] sched: protect chain template accesses with block lock (Ivan Vecera) [1688236 1687456]
- [net] sched: traverse chains in block with tcf_get_next_chain() (Ivan Vecera) [1688236 1687456]
- [net] sched: protect block->chain0 with block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: refactor tc_ctl_chain() to use block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: protect chain->explicitly_created with block->lock (Ivan Vecera) [1688236 1687456]
- [net] sched: protect block state with mutex (Ivan Vecera) [1688236 1687456]
- [net] Change TCA_ACT_* to TCA_ID_* to match that of TCA_ID_POLICE (Ivan Vecera) [1688236 1687456]
- [net] Move all TC actions identifiers to one place (Ivan Vecera) [1688236 1687456]
- [net] sched: use struct_size() helper (Ivan Vecera) [1688236 1687456]
- [net] documentation: bring operstate documentation up-to-date (Ivan Vecera) [1688236 1687456]
- [net] cls_flower: Remove filter from mask before freeing it (Ivan Vecera) [1688236 1687456]
- [net] cls_flower: don't expose TC actions to drivers anymore (Ivan Vecera) [1688236 1687456]
- [net] drivers: net: use flow action infrastructure (Ivan Vecera) [1688236 1687456]
- [net] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1688236 1687456]
- [net] net_sched: add performance counters for basic filter (Ivan Vecera) [1688236 1687456]
- [net] net_sched: add hit counter for matchall (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: allocate mask dynamically in fl_change() (Ivan Vecera) [1688236 1687456]
- [net] selftests: tc-testing: fix parsing of ife type (Ivan Vecera) [1688236 1687456]
- [net] net_sched: refetch skb protocol for each filter (Ivan Vecera) [1688236 1687456]
- [net] sched: act_tunnel_key: fix memory leak in case of action replace (Ivan Vecera) [1688236 1687456]
- [net] sch_api: Change signature of qdisc_tree_reduce_backlog() to use ints (Ivan Vecera) [1688236 1687456]
- [net] sch_cake: Correctly update parent qlen when splitting GSO packets (Ivan Vecera) [1688236 1687456]
- [net] sched: Fix detection of empty queues in child qdiscs (Ivan Vecera) [1688236 1687456]
- [net] sched: Avoid dereferencing skb pointer after child enqueue (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Remove old entries from rhashtable (Ivan Vecera) [1688236 1687456]
- [net] sched: simplify the qdisc_leaf code (Ivan Vecera) [1688236 1687456]
- [net] selftests: Fix test errors related to lib.mk khdr target (Ivan Vecera) [1688236 1687456]
- [net] net_sched: fold tcf_block_cb_call() into tc_setup_cb_call() (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Reject duplicated rules also under skip_sw (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: gitignore, ignore generated test results (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Implement the TdcResults module in tdc (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Add new TdcResults module (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: Add command timeout feature to tdc (Ivan Vecera) [1688236 1687456]
- [net] netem: use a list in addition to rbtree (Ivan Vecera) [1688236 1687456]
- [net] Prevent invalid access to skb->prev in __qdisc_drop_all (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: tdc.py: Guard against lack of returncode in executed command (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: tdc.py: ignore errors when decoding stdout/stderr (Ivan Vecera) [1688236 1687456]
- [net] etf: Drop all expired packets (Ivan Vecera) [1688236 1687456]
- [net] etf: Split timersortedlist_erase() (Ivan Vecera) [1688236 1687456]
- [net] etf: Use cached rb_root (Ivan Vecera) [1688236 1687456]
- [net] etf: Cancel timer if there are no pending skbs (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_flower: Classify packets using port ranges (Ivan Vecera) [1688236 1687456]
- [net] act_mirred: clear skb->tstamp on redirect (Ivan Vecera) [1688236 1687456]
- [net] core: use __vlan_hwaccel helpers (Ivan Vecera) [1688236 1687456]
- [net] sched: Replace call_rcu_bh() and rcu_barrier_bh() (Ivan Vecera) [1688236 1687456]
- [net] sched: Remove egdev mechanism (Ivan Vecera) [1688236 1687456]
- [net] sched: avoid writing on noop_qdisc (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: simplify the hell out u32_delete() emptiness check (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: keep track of knodes count in tc_u_common (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tp_c (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: the tp_c argument of u32_set_parms() is always tp->data (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: pass tc_u_common to u32_set_parms() instead of tc_u_hnode (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: clean tc_u_common hashtable (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tc_u_common ->rcu (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of tc_u_knode ->tp (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: get rid of unused argument of u32_destroy_key() (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: make sure that divisor is a power of 2 (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: disallow linking to root hnode (Ivan Vecera) [1688236 1687456]
- [net] sched: cls_u32: mark root hnode explicitly (Ivan Vecera) [1688236 1687456]
- [net] sched: pie: fix coding style issues (Ivan Vecera) [1688236 1687456]
- [net] treewide: Replace more open-coded allocation size multiplications (Ivan Vecera) [1688236 1687456]
- [net] sched: remove unused helpers (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: use a plugin to build eBPF program (Ivan Vecera) [1688236 1687456]
- [net] tc-testing: fix build of eBPF programs (Ivan Vecera) [1688236 1687456]
- [net] tc: Add support for configuring the taprio scheduler (Ivan Vecera) [1688236 1687456]
- [documentation] KVM: arm64: Clarify access behaviour for out-of-range SVE register slice IDs (Andrew Jones) [1550499]
- [documentation] KVM: Clarify KVM_{SET,GET}_ONE_REG error code documentation (Andrew Jones) [1550499]
- [documentation] KVM: Clarify capability requirements for KVM_ARM_VCPU_FINALIZE (Andrew Jones) [1550499]
- [kvm] KVM: arm/arm64: Clean up vcpu finalization function parameter naming (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Explain validity checks in set_sve_vls() (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Simplify KVM_REG_ARM64_SVE_VLS array sizing (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: WARN when avoiding divide-by-zero in sve_reg_to_region() (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Make register ioctl access errors more consistent (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Miscellaneous tidyups in guest.c (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Clean up UAPI register ID definitions (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: sys_regs: Demote redundant vcpu_has_sve() checks to WARNs (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Demote kvm_arm_init_arch_resources() to just set up SVE (Andrew Jones) [1550499]
- [arm64] arm64/sve: Clarify vq map semantics (Andrew Jones) [1550499]
- [kvm] arm64: KVM: Fix system register enumeration (Andrew Jones) [1550499]
- [documentation] KVM: arm64/sve: Document KVM API extensions for SVE (Andrew Jones) [1550499]
- [documentation] KVM: Document errors for KVM_GET_ONE_REG and KVM_SET_ONE_REG (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add a capability to advertise SVE support (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Allow userspace to enable SVE for vcpus (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Add pseudo-register for the guest's vector lengths (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Add KVM_ARM_VCPU_FINALIZE ioctl (Andrew Jones) [1550499]
- [virt] KVM: arm/arm64: Add hook for arch-specific KVM initialisation (Andrew Jones) [1550499]
- [arm64] arm64/sve: In-kernel vector length availability query interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Enumerate SVE register indices for KVM_GET_REG_LIST (Andrew Jones) [1550499]
- [arm64] KVM: arm64/sve: Add SVE support to register access ioctl interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Reject ioctl access to FPSIMD V-regs on SVE vcpus (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Factor out core register ID enumeration (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Add missing #include of <linux/string.h> in guest.c (Andrew Jones) [1550499]
- [include] KVM: Allow 2048-bit register access via ioctl interface (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: Context switch the SVE registers (Andrew Jones) [1550499]
- [kvm] KVM: arm64/sve: System register context switch and access support (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Support runtime sysreg visibility filtering (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Propagate vcpu into read_id_reg() (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add a vcpu flag to control SVE visibility for the guest (Andrew Jones) [1550499]
- [arm64] arm64/sve: Enable SVE state tracking for non-task contexts (Andrew Jones) [1550499]
- [arm64] arm64/sve: Check SVE virtualisability (Andrew Jones) [1550499]
- [arm64] arm64/sve: Clarify role of the VQ map maintenance functions (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Add missing #includes to kvm_host.h (Andrew Jones) [1550499]
- [kvm] KVM: arm64: Refactor kvm_arm_num_regs() for easier maintenance (Andrew Jones) [1550499]
- [arm64] KVM: arm64: Delete orphaned declaration for __fpsimd_enabled() (Andrew Jones) [1550499]
- [arm64] arm64: fpsimd: Always set TIF_FOREIGN_FPSTATE on task state flush (Andrew Jones) [1550499]
- [documentation] KVM: Documentation: Document arm64 core registers in detail (Andrew Jones) [1550499]
- [arm64] arm64/sve: Disentangle <uapi/asm/ptrace.h> from <uapi/asm/sigcontext.h> (Andrew Jones) [1550499]
- [arm64] arm64/sve: ptrace: Fix SVE_PT_REGS_OFFSET definition (Andrew Jones) [1550499]

* Fri Jun 28 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-110.el8]
- [fs] xfs: fix reporting supported extra file attributes for statx() (Bill O'Donnell) [1721034]
- [scsi] scsi: hpsa: correct ioaccel2 chaining (Joseph Szczypek) [1706121]
- [powerpc] powerpc/pseries/mobility: rebuild cacheinfo hierarchy post-migration (Steve Best) [1720929]
- [powerpc] powerpc/pseries/mobility: prevent cpu hotplug during DT update (Steve Best) [1720929]
- [powerpc] powerpc/cacheinfo: add cacheinfo_teardown, cacheinfo_rebuild (Steve Best) [1720929]
- [kernel] cpuset: restore sanity to cpuset_cpus_allowed_fallback() (Joel Savitz) [1677311]

* Wed Jun 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-109.el8]
- [scripts] scripts: override locale from environment when running recordmcount.pl (Prarit Bhargava) [1721515]
- [netdrv] net: aquantia: fix wol configuration not applied sometimes (Igor Russkikh) [1662198]
- [x86] x86/resctrl: Prevent NULL pointer dereference when local MBM is disabled (Prarit Bhargava) [1721208]
- [fs] inotify: Fix fsnotify_mark refcount leak in inotify_update_existing_watch() (Miklos Szeredi) [1451863]
- [fs] inotify: Fix fd refcount leak in inotify_add_watch(). (Miklos Szeredi) [1451863]
- [fs] fanotify: Use inode_is_open_for_write (Miklos Szeredi) [1451863]
- [fs] fanotify: Make sure to check event_len when copying (Miklos Szeredi) [1451863]
- [fs] fsnotify/fdinfo: include fdinfo.h for inotify_show_fdinfo() (Miklos Szeredi) [1451863]
- [include] fanotify: introduce new event mask FAN_OPEN_EXEC_PERM (Miklos Szeredi) [1451863]
- [include] fsnotify: refactor fsnotify_parent()/fsnotify() paired calls when event is on path (Miklos Szeredi) [1451863]
- [include] fanotify: introduce new event mask FAN_OPEN_EXEC (Miklos Szeredi) [1451863]
- [fs] fanotify: return only user requested event types in event mask (Miklos Szeredi) [1451863]
- [fs] fanotify: support reporting thread id instead of process id (Miklos Szeredi) [1451863]
- [fs] fanotify: add BUILD_BUG_ON() to count the bits of fanotify constants (Miklos Szeredi) [1451863]
- [fs] fsnotify: convert runtime BUG_ON() to BUILD_BUG_ON() (Miklos Szeredi) [1451863]
- [fs] fanotify: deprecate uapi FAN_ALL_* constants (Miklos Szeredi) [1451863]
- [fs] fanotify: simplify handling of FAN_ONDIR (Miklos Szeredi) [1451863]
- [include] fanotify: fix collision of internal and uapi mark flags (Miklos Szeredi) [1451863]
- [fs] fanotify: store fanotify_init() flags in group's fanotify_data (Miklos Szeredi) [1451863]
- [fs] fanotify: clean up handling of "mark type" (Miklos Szeredi) [1451863]
- [fs] fsnotify: fix false positive warning on inode delete (Miklos Szeredi) [1451863]
- [include] inotify: Add flag IN_MASK_CREATE for inotify_add_watch() (Miklos Szeredi) [1451863]
- [fs] fanotify: factor out helpers to add/remove mark (Miklos Szeredi) [1451863]
- [fs] fsnotify: add helper to get mask from connector (Miklos Szeredi) [1451863]
- [fs] fsnotify: let connector point to an abstract object (Miklos Szeredi) [1451863]
- [fs] fsnotify: pass connp and object type to fsnotify_add_mark() (Miklos Szeredi) [1451863]
- [fs] fsnotify: use typedef fsnotify_connp_t for brevity (Miklos Szeredi) [1451863]
- [powerpc] powerpc/pseries: Fix oops in hotplug memory notifier (Steve Best) [1720932]
- [netdrv] net: aquantia: tcp checksum 0xffff being handled incorrectly (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: fix LRO with FCS error (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: check rx csum for all packets in LRO session (Igor Russkikh) [1719176]
- [netdrv] net: aquantia: tx clean budget logic error (Igor Russkikh) [1719176]
- [security] selinux: log raw contexts as untrusted strings (Ondrej Mosnacek) [1719666]
- [kernel] audit: add saddr_fam filter field (Richard Guy Briggs) [1715679]
- [kernel] audit: re-structure audit field valid checks (Richard Guy Briggs) [1715679]
- [kernel] audit: rename FILTER_TYPE to FILTER_EXCLUDE (Richard Guy Briggs) [1715679]
- [kernel] audit: allow other filter list types for AUDIT_EXE (Richard Guy Briggs) [1715679]
- [documentation] ovl: doc: add non-standard corner cases (Miklos Szeredi) [1718370]
- [fs] ovl: support the FS_IOC_FSETXATTR ioctls (Miklos Szeredi) [1718370]
- [fs] ovl: relax WARN_ON() for overlapping layers use case (Miklos Szeredi) [1718370]
- [fs] ovl: check the capability before cred overridden (Miklos Szeredi) [1718370]
- [fs] ovl: do not generate duplicate fsnotify events for "fake" path (Miklos Szeredi) [1718370]
- [fs] ovl: support stacked SEEK_HOLE/SEEK_DATA (Miklos Szeredi) [1718370]
- [fs] ovl: fix missing upper fs freeze protection on copy up for ioctl (Miklos Szeredi) [1718370]
- [fs] fuse: fallocate: fix return with locked inode (Miklos Szeredi) [1717457]
- [fs] fuse: honor RLIMIT_FSIZE in fuse_file_fallocate (Miklos Szeredi) [1717457]
- [fs] fuse: decrement NR_WRITEBACK_TEMP on the right page (Miklos Szeredi) [1717457]
- [fs] fuse: handle zero sized retrieve correctly (Miklos Szeredi) [1717457]
- [fs] fuse: continue to send FUSE_RELEASEDIR when FUSE_OPEN returns ENOSYS (Miklos Szeredi) [1717457]

* Mon Jun 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-108.el8]
- [mm] mm/mincore.c: make mincore() more conservative (Rafael Aquini) [1664203] {CVE-2019-5489}
- [x86] x86/umip: Make the UMIP activated message generic (David Arcari) [1720014]
- [x86] x86/umip: Print UMIP line only once (David Arcari) [1720014]
- [crypto] crypto: vmac - separate tfm and request context (Desnes Augusto Nunes do Rosario) [1702702]
- [crypto] crypto: ccp - Update driver messages to remove some confusion (David Arcari) [1719026]
- [block] blk-mq: fix hang caused by freeze/unfreeze sequence (Ming Lei) [1719835]
- [block] blk-mq: remove WARN_ON(!q->elevator) from blk_mq_sched_free_requests (Ming Lei) [1719835]
- [block] block: free sched's request pool in blk_cleanup_queue (Ming Lei) [1719835]
- [block] block: don't protect generic_make_request_checks with blk_queue_enter (Ming Lei) [1719835]
- [block] block: move blk_exit_queue into __blk_release_queue (Ming Lei) [1719835]
- [block] block: print offending values when cloned rq limits are exceeded (Ming Lei) [1719816]
- [block] block: fix page leak when merging to same page (Ming Lei) [1662864]
- [x86] RHEL: fix build of spec_ctrl.h for older assemblers (Jeff Moyer) [1719406]
- [drm] drm/amd/display: Initialize stream_update with memset (Jeff Moyer) [1719406]
- [mm] mm/gup: finish consolidating error handling (Jeff Moyer) [1641506]
- [mm] mm/gup: cache dev_pagemap while pinning pages (Jeff Moyer) [1641506]
- [rpmspec] kernel packaging: Fix extra namespace collision (Prarit Bhargava) [1699868]
- [rpmspec] redhat: kernel-selftests-internal: add dependencies (Jiri Benc) [1717943]
- [kernel] kernel/module.c: Only return -EEXIST for modules that have finished loading (Prarit Bhargava) [1666939]
- [input] Input: elantech - remove P52 and P72 from SMBus blacklist (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - handle physical middle button (Benjamin Tissoires) [1703157]
- [input] Input: elantech/SMBus - export all capabilities from the PS/2 node (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - do not query the info if they are provided (Benjamin Tissoires) [1703157]
- [input] Input: elantech - detect middle button based on firmware version (Benjamin Tissoires) [1703157]
- [input] Input: elantech - add helper function elantech_is_buttonpad() (Benjamin Tissoires) [1703157]
- [input] Input: elantech - query the min/max information beforehand too (Benjamin Tissoires) [1703157]
- [input] Input: elantech - enable middle button support on 2 ThinkPads (Benjamin Tissoires) [1703157]
- [input] Input: elan_i2c - increment wakeup count if wake source (Benjamin Tissoires) [1703157]
- [kernel] timekeeping: Update multiplier when NTP frequency is set directly (Prarit Bhargava) [1714164]
- [fs] xfs: fix use after free in buf log item unlock assert (Brian Foster) [1666150]
- [fs] xfs: add missing error check in xfs_prepare_shift() (Brian Foster) [1699214]
- [documentation] Documentation: Fix grammatical error in sysctl/fs.txt & clarify negative dentry (Waiman Long) [1673955]
- [fs] fs/dcache: Track & report number of negative dentries (Waiman Long) [1673955]
- [fs] fs/dcache: Fix incorrect nr_dentry_unused accounting in shrink_dcache_sb() (Waiman Long) [1673955]
- [net] tcp: tcp_fragment() should apply sane memory limits (Florian Westphal) [1719858] {CVE-2019-11478}
- [net] tcp: limit payload size of sacked skbs (Florian Westphal) [1719603] {CVE-2019-11477}

* Fri Jun 14 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-107.el8]
- [tools] kvm: selftests: make hyperv_cpuid test pass on AMD (Vitaly Kuznetsov) [1718501]
- [scsi] vmw_pvscsi: Fixed to work with SG_CHAIN (Ewan Milne) [1717278]
- [x86] mark AMD Rome processors supported (David Arcari) [1520002]
- [fs] ext4: zero out the unused memory region in the extent tree block (Lukas Czerner) [1715276] {CVE-2019-11833}
- [s390] s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU (David Hildenbrand) [1715041]
- [vfio] vfio/type1: Limit DMA mappings per container (Alex Williamson) [1695592] {CVE-2019-3882}
- [tools] selftests/powerpc: Remove Power9 paste tests (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Remove Power9 copy_unaligned test (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Fix ptrace tm failure (Diego Domingos) [1662374]
- [netdrv] mlxsw: core: Prevent reading unsupported slave address from SFP EEPROM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent QSFP module initialization for old hardware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix autoneg status in ethtool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Reincrease PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put MC TCs into DWRR mode (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add a multicast pool for Spectrum-2 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test VRF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not check VRF MAC address (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw ordered workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for EMAD workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add MDB entries in prepare phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: mlxsw: core: avoid -Wint-in-bool-context warning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Initialize base_mac (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent duplication during QSFP module initialization (Ivan Vecera) [1680241]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend initialization by querying resources data (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend input parameters list of command API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Modify input parameter name in initialization API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Fix comment misspelling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move resource query API to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Add ethtool support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Make structures and variables names shorter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move ethtool module callbacks to a common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make mlxsw_sp_acl_tcam_vregion_rehash() return void (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remember where to continue rehash migration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow to interrupt/continue rehash work (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Do rollback as another call to mlxsw_sp_acl_tcam_vchunk_migrate_all() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put vchunk migrate start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put this_is_rollback to rehash context struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Rename variables in mlxsw_sp_acl_tcam_ventry_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vchunk->chunk by the newly created chunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vregion->region by the newly created region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push code start/end from mlxsw_sp_acl_tcam_vregion_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce new rehash context struct and save hint_priv there (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't migrate already migrated entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash dw struct into rehash sub-struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: remove set but not used variable 'autoneg_status' (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add massive delta rehash test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Check migrate end trace (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add vregion migration end tracepoint (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add IPv6 variant of simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take mutex in mlxsw_sp_acl_tcam_vregion_rehash_work() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove RTNL lock assertions from ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take rtnl lock during vregion_rehash_intrvl_set() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard objagg instance manipulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable vregion rehash per-profile (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce mutex to guard Bloom Filter updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce vregion mutex (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Refactor vregion association code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard region list updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM group structure into two (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unused ops field from group structure (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC support for new port types and speeds (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add new port type-speed fields for PTYS register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: 80 columns wrapping change (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Rename p_eth_proto_adm to full name p_eth_proto_admin (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Rename port type-speed functions to ASIC specific (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Query port connector type from firmware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove unsupported eth_proto_lp_advertise field in PTYS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove duplicate port link mode entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Avoid -Wformat-truncation warnings (Ivan Vecera) [1680241]
- [netdrv] net: Remove SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS_SUPPORT (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Reject overlarge headroom size requests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Update port headroom configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add Spectrum-2 shared buffer configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_mm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_cm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_prs in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_pms in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep pool descriptors in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allocate prs & pms dynamically (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add struct mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change IP2ME CPU policer rate and burst size values (Ivan Vecera) [1680241]
- [netdrv] mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local variable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add some missing configuration symbols (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: fix spelling mistake "temprature" -> "temperature" (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend thermal module with per QSFP module thermal zones (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Allow thermal zone binding to an external cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add QSFP module temperature label attribute to hwmon (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with QSFP module temperature attributes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with fan fault attribute (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Rename cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Replace thermal temperature trips with defines (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Modify thermal zone definition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Set different thermal polling time based on bus frequency capability (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add API for QSFP module temperature thresholds reading (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Fan Out of Range Event Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Management Temperature Bulk Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move QSFP EEPROM definitions to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove unused variables (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: avoid double sourcing of lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Fix VLAN modify action support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Drop unnecessary WARN_ON_ONCE() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set LAG port collector only when active (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add couple of vregion rehash tracepoints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: add "acl_region_rehash_interval" devlink param (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement region migration according to hints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add multi field to PAGT register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass hints priv all the way to ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement basic ERP rehash hits creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split entry struct into entry and ventry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split chunk struct into chunk and vchunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split region struct into region and vregion (Ivan Vecera) [1680241]
- [netdrv] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1680241]
- [netdrv] devlink: publish params only after driver init is done (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Offload blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Implement ndo_get_port_parent_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Trace EMAD errors (Ivan Vecera) [1680241]
- [netdrv] drivers: net: use flow action infrastructure (Ivan Vecera) [1680241]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_flower: Fix test result handling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Ignore ARP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Enable forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Flush neighbors (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix roaming test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Wait for tardy mirrored packets (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix TTL test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Make ping timeout configurable (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Add delta two masks one key test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Fix multiple_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Extend and move trace helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add C-TCAM spill tracepoint (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Include delta bits into hashtable key (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Use OK instead of PASS in test output (Ivan Vecera) [1680241]
- [tools] selftests: net: forwarding: change devlink resource support checking (Ivan Vecera) [1680241]
- [documentation] Documentation: add devlink param file for mlxsw driver (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add more extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Fix rul/rule typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move mr_ruleset and mr_rule structs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unnecessary arg on action_replace call path (Ivan Vecera) [1680241]
- [netdrv] mlxfw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Enable VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add support for VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Breakout common code to a common function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose functions to create and destroy underlay RIF (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP suppression (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN symmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP decapsulation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN asymmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP tunneling lib (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add GRE tunnel support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Update tunnel decap properties (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Support RIF without device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Change mlxsw_sp_ipip_lb_ul_vr_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add underlay RIF ID support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Mark RIF index as taken before creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Adjust loopback RIF configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set RIF ops per ASIC type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Split RIF ops array for Spectrum-2 support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add underlay egress RIF field in RTDP register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add fields to RITR - Router Interface Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for externally learned FDB entries (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FDB offload indication (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not treat static FDB entries as sticky (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Update dummy FID index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Return error on PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Increase PCI SW reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Ring CQ's doorbell before RDQ's (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test veto of unsupported VXLAN FDBs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add extack messages to VXLAN FDB rejection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Add extack to mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl_bloom_filter: use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VLAN deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Set PVID correctly during VLAN deletion (Ivan Vecera) [1680241]
- [net] net: bridge: Fix VLANs memory leak (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for VLAN addition error flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Replace error code with EINVAL (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid returning errors in commit phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VXLAN dependency for spectrum (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Disable lag port TX before removing it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove ASSERT_RTNL()s in module removal flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add cleanup after C-TCAM update error condition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: drop useless LIST_HEAD (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add router test with VID 1 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Adjust test regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove limitation regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Switch to VID 4095 as default VID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add an helper function to cleanup VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Store pointer to default port VLAN in port struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Allow controlling destruction of default port VLAN (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set PVID during port initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Replace hard-coded default VID with a define (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for L3 VNI (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not force specific configuration order (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add rtnetlink tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Hold a reference on RIF's netdev (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Make RIF deletion more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate 'struct mlxsw_sp' further (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Properly cleanup LAG uppers when removing port from LAG (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove reference count from VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Handle VLAN device unlinking (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Remove unused function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not destroy RIFs based on FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Sanitize VLAN interface's uppers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Fix memory leak upon driver reload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add trap for decapsulated ARP packets (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Increase timeout during firmware flash process (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1910.622 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom delta test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter complex test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter simple test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Activate Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set master RP index on transition to eRP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Update Bloom filter on eRP transitions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set A-TCAM rules in Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter update (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter handling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 Bloom filter resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Algorithmic Bloom Filter Entries Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FID RIF MAC vetoing (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test RIF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Veto unsupported RIF MAC addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp.mac_mask (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Generalize mlxsw_sp_netdevice_router_port_event() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a port device (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a VXLAN device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on port VLAN events (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on VXLAN VLAN events (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add multicast routing test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add Multicast routing support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Limit priority value (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Support rule creation without action creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add replace rule action operation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add multicast router profile operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Spectrum-2 keys (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change stage of ACL initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Multicast Router Binding Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add PVID test case for VXLAN with VLAN-aware bridges (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: vxlan: Test FDB un/marking on VXLAN join/leave (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Un/offload FDB on nve_fid_disable/enable (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp_fid_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Publish mlxsw_sp_switchdev_notifier (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Track NVE type at FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Fix VLAN device deletion via ioctl (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Relax GRE decap matching check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid leaking FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Remove easily triggerable warnings (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a new test extack.sh (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add one-armed router test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Mirror loopbacked packets instead of trapping them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Load firmware version based on devlink parameter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Reset firmware after flash during driver initialization (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add VxLAN test with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VLAN-aware bridges as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare function for VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Unify VxLAN leave function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add API to lookup 802.1Q FIDs without creating them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Flip driver to use emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Introduce emulated VLAN RIFs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Introduce emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Make flood index calculation more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not set field when it is reserved (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VxLAN learning enabled as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Allow VxLAN learning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Allow deletion of learned FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Process learned VxLAN FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add API to resolve learned IP addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow FID lookup by its index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Store ifindex of NVE device in FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFN register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend cooling device with cooling levels (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN flooding (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose discard counters via ethtool (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Implement delta for ERP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Push code related to num_ctcam_erps inc/dec into separate helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Remove mlxsw_afk_encode() block range args and key/mask check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Don't encode the key again in mlxsw_sp_acl_atcam_12kb_lkey_id_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl: Change order of args of ops->encode_block() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Pass key pointer to master_mask_set/clear (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl_erp: Convert to use objagg for tracking ERPs (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 ctcam_two_atcam_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 two_mask_test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix IP2ME CPU policer configuration (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Add a test for UC awareness (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Tweak for min shaper (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set minimum shaper on MC TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: QEEC: Add minimum shaper fields (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix devlink unregister flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Don't ignore deletions of learned MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add support for VxLAN encapsulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Configure matching local routes for NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Clear NVE configuration when destroying 802.1D FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement VxLAN operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement common NVE core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allow querying VR ID based on table ID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Enable local routes promotion to perform NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add APIs to lookup FID without creating it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow setting and clearing NVE properties on FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix use-after-free when flashing firmware during init (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add NVE packet traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add NVE resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Monitoring Parsing State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFD register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Default Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Decapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Encapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Underlay Multicast Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunnel Port Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Seed LAG hash function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Extend FDB flush types for NVE (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add a new type of KVD linear record (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move L3 protocol and address definitions to global header file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not assume notifier information type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Check notification relevance based on upper device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare for VxLAN FDB notifications (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove misuses of private header file (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Make executable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Have lldpad_app_wait_set() wait for unknown, too (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Delete RIF when VLAN device is removed (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Derive event type from event queue number (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Make MLXSW_SP1_FWREV_MINOR a hard requirement (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Bump required firmware version (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for UC behavior under MC flood (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add mtu_set(), mtu_restore() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add ethtool_stats_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Tweak SBMM configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Configure MC pool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow configuration of static pools (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Pass SBPM min_size in cells (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow an infinite maximum for per-TC pool limit (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow pools of infinite size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep shared buffer size in mlxsw_sp_sb (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Split TC_COUNT into ingress and egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Use devlink pool indices throughout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Init shaper for TCs 8..15 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Set up a dedicated pool for BUM traffic (Ivan Vecera) [1680241]
- [netdrv] mlxsw: remove unused arrays mlxsw_i2c_driver_name and mlxsw_pci_driver_name (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: remove unnecessary function mlxsw_core_driver_put (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counter for all 16 TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Include RFC-2819 counters in stats length (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add TC flower test for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Reset FW after flash (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1702.6 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Disallow usage of vlan_id key on egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: use PTR_ERR_OR_ZERO() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Update next-hop statistics match criteria (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Configure MC-aware mode on mlxsw ports (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Switch Traffic Class Table is Multicast-Aware Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for ip_forward_update_priority (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move DSCP capture to lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move lldpad waiting to lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Handle sysctl_ip_fwd_update_priority (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extract work-scheduling into a new function (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team LACP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Introduce $ARPING (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Support team devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add require_command() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_dscp_bridge: Fix (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for trust-DSCP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Support ieee_setapp, ieee_delapp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority to DSCP Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS ReWrite Enable Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority Trust State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register (Ivan Vecera) [1680241]
- [tools] selftests: add a selftest for directed broadcast forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: add tests for TC chain get and dump operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Start using A-TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM rule insertion and deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass C-TCAM region and entry to insert function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM region initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make global TCAM resources available to regions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Encapsulate C-TCAM region in A-TCAM region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow encoding a partial key (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Extend Spectrum-2 region struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for C-TCAM eRPs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable C-TCAM only mode in eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement common eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 eRP resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 maximum large key ID resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine eRP Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine TCAM Entry Register Version 3 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Prepare PERERP register for A-TCAM usage (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Propagate extack pointer (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Drop IPv6 tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Implement chain template hinting (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extend to support Spectrum-2 ASIC (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add initial Spectrum-2 ACL implementation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add region association callback (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Prepare for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region eRP Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Association Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: acl: Introduce activity get operation for action block/set (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add support for activity information from PEFA register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Introduce flex key blocks for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 variant of flex actions ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Add Spectrum-2 stubs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add KVDL manager implementation for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Infrastructure Entry Delete Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counters for various packet sizes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Optimize processing of VRRP MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VRRP traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Direct macvlans' MACs to router (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable macvlan upper devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_nh: Unset rp_filter on host VRF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_span: Change LAG lower selection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add couple of Spectrum-2 KVD resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Prepare for multiple FW versions for Spectrum and Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement priority setting for rules inserted to TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add priority field for PTCEV2 register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move block items encoding into Spectrum op (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Convert mlxsw_afk_create args to ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add tcam init/fini ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM handling 3 ways (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Push Spectrum-specific operations into a separate file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry_count to free function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry type to alloc/free (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Push out KVD linear management into ops (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Tighten up VLAN capture (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Fix helper to get the first KVD linear index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Allow the first set to be dummy (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put pointer to flex action ops to mlxsw_sp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Change SRC_SYS_PORT flex key element size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Split MAC and IP address flex key elements (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Ignore always-zeroed bits in tp->prio (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Introduce Flex2 key type for PTAR register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change name of mlxsw_sp_afk_blocks to mlxsw_sp1_afk_blocks (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: avoid uninitialized variable access (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add mlxsw-specific test for mirror to gretap (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow importing dependent libraries (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: test for bridge port isolation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1q (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1d (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for resources (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for mirror-to-gretap test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for mirror-to-gretap (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for tc flower test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add tc flower scale test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for router test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add router test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink KVD resource test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink_lib_spectrum.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add devlink_lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Parameterize NUM_NETIFS in two functions (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add check_err_fail() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow lib.sh sourcing from other directories (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix waiting for neighbor (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Split out setup_wait_dev() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test multipath tunneling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Unset rp_filter (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test routed bridge interface (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Ban PVID change if bridge has a RIF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add mlxsw_sp_rif_fid() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Publish mlxsw_sp_rif_find_by_dev() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allocate FID according to PVID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate extack to .fid_get() (Ivan Vecera) [1680241]
- [netdrv] net: phy: realtek: Dummy IRQ calls for RTL8366RB (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add generic Realtek PHY driver (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: use new PHYID matching macros (Corinna Vinschen) [1680528]
- [include] net: phy: add macros for PHYID matching (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: load driver for all PHYs with a Realtek OUI (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: fix RTL8201F sysfs name (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: Support RTL8366RB variant (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211C to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211C (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211 to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211 (Corinna Vinschen) [1680528]
- [netdrv] r8169: change irq handler to always trigger NAPI polling (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for chip hw init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for PHY init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable ASPM again (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable tx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: use netif_receive_skb_list batching" (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_receive_skb_list batching (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable default rx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix cable re-plugging issue (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_start_queue instead of netif_wake_qeueue in rtl8169_start_xmit (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read interrupt mask register in interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: make use of xmit_more and __netdev_sent_queue" (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: remove unneeded mmiowb barriers" (Corinna Vinschen) [1680528]
- [netdrv] r8169: Avoid pointer aliasing (Corinna Vinschen) [1680528]
- [netdrv] r8169: Load MAC address from device tree if present (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_wol_pll_power_down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve WoL handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: add EEE support for RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: add general EEE support for chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out PHY init sequence adjusting 10M and ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out disabling ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve firmware handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove PCI DAC support (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rx buffer allocation (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out getting ether_clk (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace mii_bus member with phy_device member in struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: reset chip synchronously in __rtl8169_resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: add helpers for locking / unlocking the config registers (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl_pcie_state_l2l3_enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: initialize task workqueue only once (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call in pcierr (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_get_events (Corinna Vinschen) [1680528]
- [netdrv] r8169: load Realtek PHY driver module before r8169 (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't try to read counters if chip is in a PCI power-save state (Corinna Vinschen) [1680528]
- [netdrv] r8169: Add support for new Realtek Ethernet (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix WoL device wakeup enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve spurious interrupt detection (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix crash if CONFIG_DEBUG_SHIRQ is enabled (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] ethernet/realtek: Replace synchronize_sched() with synchronize_rcu() (Corinna Vinschen) [1680528]
- [netdrv] r8169: make use of xmit_more and __netdev_sent_queue (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace macro TX_FRAGS_READY_FOR with a function (Corinna Vinschen) [1680528]
- [netdrv] r8169: use napi_consume_skb where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify detecting chip versions with same XID (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove default chip versions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove ancient GCC bug workaround in a second place (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve chip version identification (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify ocp functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove workaround for ancient gcc bug (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove manual padding in struct ring_info (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove "not PCI Express" message (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove print_mac_version (Corinna Vinschen) [1680528]
- [netdrv] r8169: use PCI_VDEVICE macro (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace event_slow with irq_mask (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unused interrupt sources (Corinna Vinschen) [1680528]
- [netdrv] r8169: use dev_get_drvdata where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: merge rtl_irq_enable and rtl_irq_enable_all (Corinna Vinschen) [1680528]
- [pci] PCI: add USR vendor id and use it in r8169 and w6692 driver (Corinna Vinschen) [1680528]
- [netdrv] net: ethernet: Convert phydev advertize and supported from u32 to link mode (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix broken Wake-on-LAN from S5 (poweroff) (Corinna Vinschen) [1680528]
- [netdrv] r8169: add support for Byte Queue Limits (Corinna Vinschen) [1680528]
- [netdrv] r8169: handle all interrupt events in the hard irq handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix NAPI handling under high load (Corinna Vinschen) [1680528]
- [netdrv] r8169: re-enable MSI-X on RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call to netif_stop_queue in rtl8169_net_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify rtl8169_set_magic_reg (Corinna Vinschen) [1680528]
- [netdrv] r8169: Enable MSI-X on RTL8106e (Corinna Vinschen) [1680528]
- [netdrv] r8169: set RX_MULTI_EN bit in RxConfig for 8168F-family chips (Corinna Vinschen) [1680528]
- [netdrv] r8169: always autoneg on resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix network stalls due to missing bit TXCFG_AUTO_FIFO (Corinna Vinschen) [1680528]
- [netdrv] r8169: Disable clk during suspend / resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve a check in rtl_init_one (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl8169_irq_mask_and_ack (Corinna Vinschen) [1680528]
- [netdrv] r8169: use default watchdog timeout (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix autoneg issue on resume with RTL8168E (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove duplicated RTL8169s PHY initialization steps (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify RTL8169 PHY initialization (Corinna Vinschen) [1680528]
- [netdrv] r8169: Get and enable optional ether_clk clock (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8106E (Corinna Vinschen) [1680528]
- [netdrv] r8169: Align ASPM/CLKREQ setting function with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing RTL_FLAG_TASK_ENABLED (Corinna Vinschen) [1680528]
- [netdrv] r8169: set TxConfig register after TX / RX is enabled, just like RxConfig (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure max jumbo frame size per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure csum function per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't include asm headers directly (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove version info (Corinna Vinschen) [1680528]
- [netdrv] r8169: restore previous behavior to accept BIOS WoL settings (Corinna Vinschen) [1680528]
- [netdrv] r8169: power down chip in probe (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read chip phy status register (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove mii_if_info member from struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl8169_set_speed_xmii (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_speed_down / phy_speed_up (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_mii_ioctl (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_nway_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_(g|s)et_link_ksettings (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace open-coded PHY soft reset with genphy_soft_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_resume/phy_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: add basic phylib support (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix runtime suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove old PHY reset hack (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove TBI 1000BaseX support (Corinna Vinschen) [1680528]
- [netdrv] r8169: use standard debug output functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: reject unsupported WoL options (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't check WoL when powering down PHY and interface is down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve saved_wolopts handling (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: restore previous behavior to accept BIOS WoL settings" (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve phy initialization when resuming (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8168E-VL (Corinna Vinschen) [1680528]
- [netdrv] r8169: align ASPM entry latency setting with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Reinstate ASPM Support (Corinna Vinschen) [1680528]
- [netdrv] r8169: Don't disable ASPM in the driver (Corinna Vinschen) [1680528]
- [kernel] kernel/sched/psi.c: expose pressure metrics on root cgroup (Waiman Long) [1678388]
- [kernel] psi: introduce psi monitor (Waiman Long) [1678388]
- [spi] include/: refactor headers to allow kthread.h inclusion in psi_types.h (Waiman Long) [1678388]
- [kernel] psi: track changed states (Waiman Long) [1678388]
- [kernel] psi: split update_stats into parts (Waiman Long) [1678388]
- [kernel] psi: rename psi fields in preparation for psi trigger addition (Waiman Long) [1678388]
- [kernel] psi: make psi_enable static (Waiman Long) [1678388]
- [kernel] psi: introduce state_mask to represent stalled psi states (Waiman Long) [1678388]
- [kernel] kernel: cgroup: add poll file operation (Waiman Long) [1678388]
- [fs] fs: kernfs: add poll file operation (Waiman Long) [1678388]
- [documentation] psi: clarify the units used in pressure files (Waiman Long) [1678388]
- [kernel] psi: avoid divide-by-zero crash inside virtual machines (Waiman Long) [1678388]
- [init] psi: clarify the Kconfig text for the default-disable option (Waiman Long) [1678388]
- [kernel] psi: fix aggregation idle shut-off (Waiman Long) [1678388]
- [init] psi: fix reference to kernel commandline enable (Waiman Long) [1678388]
- [kernel] psi: make disabling/enabling easier for vendor kernels (Waiman Long) [1678388]
- [kernel] kernel/sched/psi.c: simplify cgroup_move_task() (Waiman Long) [1678388]
- [kernel] psi: cgroup support (Waiman Long) [1678388]
- [kernel] psi: pressure stall information for CPU, memory, and IO (Waiman Long) [1678388]
- [kernel] sched: introduce this_rq_lock_irq() (Waiman Long) [1678388]
- [kernel] sched: sched.h: make rq locking and clock functions available in stats.h (Waiman Long) [1678388]
- [kernel] sched: loadavg: make calc_load_n() public (Waiman Long) [1678388]
- [kernel] sched: loadavg: consolidate LOAD_INT, LOAD_FRAC, CALC_LOAD (Waiman Long) [1678388]
- [kernel] delayacct: track delays from thrashing cache pages (Waiman Long) [1678388]
- [mm] mm: workingset: tell cache transitions from workingset thrashing (Waiman Long) [1678388]
- [mm] mm: workingset: don't drop refault information prematurely (Waiman Long) [1678388]
- [scsi] scsi: ibmvfc: Add failed PRLI to cmd_status lookup array (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Byte swap status and error codes when logging (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Remove "failed" from logged errors (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Clean up transport events (Diego Domingos) [1665716]
- [scsi] scsi: ibmvscsi: Don't use rc uninitialized in ibmvscsi_do_work (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: fix tripping of blk_mq_run_hw_queue WARN_ON (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: redo driver work thread to use enum action states (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: Wire up host_reset() in the driver's scsi_host_template (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: change strncpy+truncation to strlcpy (Gustavo Duarte) [1665715]
- [fs] ext4: avoid panic during forced reboot due to aborted journal (Lukas Czerner) [1717831]
- [fs] ext4: fix use-after-free in dx_release() (Lukas Czerner) [1717831]
- [fs] ext4: fix data corruption caused by overlapping unaligned and aligned IO (Lukas Czerner) [1717831]
- [fs] ext4: avoid drop reference to iloc.bh twice (Lukas Czerner) [1717831]
- [nvme] nvme-tcp: mark NVMe/TCP as a technical preview (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix possible null deref on a timed out io queue connect (Chris Leech) [1696451]
- [nvme] nvme-tcp: rename function to have nvme_tcp prefix (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix a NULL deref when an admin connect times out (Chris Leech) [1696451]
- [nvme] nvmet-tcp: don't fail maxr2t greater than 1 (Chris Leech) [1696451]
- [nvme] nvmet-tcp: implement C2HData SUCCESS optimization (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix an endianess miss-annotation (Chris Leech) [1696451]
- [nvme] nvme-tcp: support C2HData with SUCCESS flag (Chris Leech) [1696451]
- [nvme] nvme-tcp: use older iov_iter API to fix panic (Chris Leech) [1696451]
- [nvme] nvmet: fix building bvec from sg list (Ming Lei) [1690287]
- [nvme] nvmet: set loop queue's segment boundary mask as PAGE_SIZE - 1 (Ming Lei) [1690287]
- [x86] x86/qspinlock: Fix compile error (Waiman Long) [1709451]
- [kernel] locking/rwsem: Prevent unneeded warning during locking selftest (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enable lock event counting (Waiman Long) [1709451]
- [kernel] locking/lock_events: Don't show pvqspinlock events on bare metal (Waiman Long) [1709451]
- [kernel] locking/lock_events: Make lock_events available for all archs & other locks (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Introduce generic lockevent_*() counting APIs (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enhance DEBUG_RWSEMS_WARN_ON() macro (Waiman Long) [1709451]
- [kernel] locking/rwsem: Add debug check for __down_read*() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Micro-optimize rwsem_try_read_lock_unqueued() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move rwsem internal function declarations to rwsem-xadd.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move owner setting code from rwsem.c to rwsem.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Relocate rwsem_down_read_failed() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Optimize down_read_trylock() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Remove rwsem-spinlock.c & use rwsem-xadd.c for all archs (Waiman Long) [1709451]
- [x86] locking/rwsem: Remove arch specific rwsem files (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Remove unnecessary BUG_ON() call (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Track the no MCS node available case (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Handle > 4 slowpath nesting levels (Waiman Long) [1709451]
- [kernel] locking/pvqspinlock: Extend node size when pvqspinlock is configured (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Count instances of nested lock slowpaths (Waiman Long) [1709451]
- [kernel] locking/qspinlock, x86: Provide liveness guarantee (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Rework some comments (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Re-order code (Waiman Long) [1709451]
- [x86] x86/headers: Fix -Wmissing-prototypes warning (Waiman Long) [1709451]
- [x86] Revert "x86/refcount: Work around GCC inlining bug" (Waiman Long) [1709451]
- [x86] x86/asm: 'Simplify' GEN_*_RMWcc() macros (Waiman Long) [1709451]
- [x86] x86/refcount: Work around GCC inlining bug (Waiman Long) [1709451]
- [lib] locking/refcounts: Include fewer headers in <linux/refcount.h> (Waiman Long) [1709451]
- [media] media: stk1160: Set the vb2_queue lock before calling vb2_queue_init (Torez Smith) [1697664]
- [usb] USB: typec: fsusb302: Drop empty set_current_limit implementation (Torez Smith) [1697664]
- [usb] USB: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] USB: musb: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] usb: wusbcore: security: cast sizeof to int for comparison (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: Support for Alternate Modes (Torez Smith) [1697664]
- [usb] usb: typec: pi3usb30532: Start using generic state values (Torez Smith) [1697664]
- [usb] usb: typec: Add driver for DisplayPort alternate mode (Torez Smith) [1697664]
- [usb] usb: typec: Bus type for alternate modes (Torez Smith) [1697664]
- [usb] usb: typec: Register a device for every mode (Torez Smith) [1697664]
- [usb] usb: typec: mux: Get the mux identifier from function parameter (Torez Smith) [1697664]
- [usb] usb: update for tcpci drivers moving out of staging (Torez Smith) [1697664]
- [netdrv] net: usb: Mark expected switch fall-throughs (Torez Smith) [1697664]
- [media] media: tm6000: add error handling for dvb_register_adapter (Torez Smith) [1697664]
- [usb] usb: typec: function for checking cable plug orientation (Torez Smith) [1697664]
- [include] usb: pd: include kernel.h (Torez Smith) [1697664]
- [staging] staging: typec: tcpci: move tcpci drivers out of staging (Torez Smith) [1697664]
- [usb] typec: tcpm: add starting value for drp toggling (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: support get typec and pd config from device properties (Torez Smith) [1697664]
- [usb] usb: typec: add API to get typec basic port power and data config (Torez Smith) [1697664]
- [staging] usb: typec: add fwnode to tcpc (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: add documentation for typec port controller(TCPCI) (Torez Smith) [1697664]
- [documentation] dt-bindings: connector: add properties for typec (Torez Smith) [1697664]
- [usb] usb: typec: tps6598x: Remove VLA usage (Torez Smith) [1697664]
- [usb] usb: cdc-wdm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: cdc-wdm: don't enable interrupts in USB-giveback (Torez Smith) [1697664]
- [usb] usb: legousbtower: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: ldusb: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: iowarrior: remove intr_idx_lock (Torez Smith) [1697664]
- [usb] usb: adutux: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: wusbcore: remove excessive irqsave (Torez Smith) [1697664]
- [usb] usb: usb-skeleton: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usblp: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usbfs: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: core: use irqsave() in sg_complete() complete callback (Torez Smith) [1697664]
- [usb] usb: cdc-acm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: host: ehci-npcm7xx: Fix some error codes in probe (Torez Smith) [1697664]
- [media] media: cx231xx: fix RC_CORE dependency (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: rename tty flag variable (Torez Smith) [1697664]
- [usb] USB: serial: usb_wwan: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: ti_usb_3410_5052: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: symbolserial: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: fix potential deadlock at close (Torez Smith) [1697664]
- [usb] USB: serial: quatech2: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7840: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7720: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_ti: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_edgeport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: cyberjack: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: chipidea: tegra: Use aligned DMA on Tegra114/124 (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: new ehci-npcm7xx dt (Torez Smith) [1697664]
- [usb] USB host: Add USB ehci support for nuvoton npcm7xx platform (Torez Smith) [1697664]
- [usb] usb: cdc-acm: Decrement tty port's refcount if probe() fail (Torez Smith) [1697664]
- [usb] USB: mon: use ktime_get_real_ts64 instead of getnstimeofday64 (Torez Smith) [1697664]
- [usb] USB: xhci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: ehci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: Report wakeup events on root-hub ports (Torez Smith) [1697664]
- [usb] USB: serial: cast sizeof() to int when comparing with error code (Torez Smith) [1697664]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Torez Smith) [1697664]
- [netdrv] net: usb: rtl8150: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: r8152: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: kaweth: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: hso: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: cdc-phonet: use irqsave() in USB's complete callback (Torez Smith) [1697664]

* Thu Jun 13 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-106.el8]
- [net] selftests/tls: add test for sleeping even though there is data (Sabrina Dubroca) [1711821]
- [net] tls: fix no wakeup on partial reads (Sabrina Dubroca) [1711821]
- [net] selftests/tls: test for lowat overshoot with multiple records (Sabrina Dubroca) [1711821]
- [net] tls: fix lowat calculation if some data came from previous record (Sabrina Dubroca) [1711821]
- [net] tls: don't ignore netdev notifications if no TLS features (Sabrina Dubroca) [1711821]
- [net] tls: fix state removal with feature flags off (Sabrina Dubroca) [1711821]
- [net] tls: handle errors from padding_length() (Sabrina Dubroca) [1711821]
- [net] tls: avoid NULL pointer deref on nskb->sk in fallback (Sabrina Dubroca) [1711821]
- [net] tls: byte swap device req TCP seq no upon setting (Sabrina Dubroca) [1711821]
- [net] tls: remove old exports of sk_destruct functions (Sabrina Dubroca) [1711821]
- [net] tls: don't log errors every time offload can't proceed (Sabrina Dubroca) [1711821]
- [net] tls: fix refcount adjustment in fallback (Sabrina Dubroca) [1711821]
- [net] strparser: make it explicitly non-modular (Sabrina Dubroca) [1711821]
- [net] strparser: partially revert "strparser: Call skb_unclone conditionally" (Sabrina Dubroca) [1711821]
- [net] tls: fix the IV leaks (Sabrina Dubroca) [1711821]
- [net] strparser: fix comment (Sabrina Dubroca) [1711821]
- [net] tls: prevent false connection termination with offload (Sabrina Dubroca) [1711821]
- [net] tls: Replace kfree_skb() with consume_skb() (Sabrina Dubroca) [1711821]
- [net] strparser: fix a missing check for create_singlethread_workqueue (Sabrina Dubroca) [1711821]
- [net] tls: Fix tls_device receive (Sabrina Dubroca) [1711821]
- [net] tls: Fix mixing between async capable and async (Sabrina Dubroca) [1711821]
- [net] tls: Return type of non-data records retrieved using MSG_PEEK in recvmsg (Sabrina Dubroca) [1711821]
- [net] selftest/tls: Add test to verify received 'type' of non-data record (Sabrina Dubroca) [1711821]
- [net] tls: Move protocol constants from cipher context to tls context (Sabrina Dubroca) [1711821]
- [net] tls: Do not use async crypto for non-data records (Sabrina Dubroca) [1711821]
- [net] tls: Disable async decrytion for tls1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Set async_capable for tls zerocopy only if we see EINPROGRESS (Sabrina Dubroca) [1711821]
- [net] tls: Add tests for TLS 1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Add tls 1.3 support (Sabrina Dubroca) [1711821]
- [net] tls: Refactor control message handling on recv (Sabrina Dubroca) [1711821]
- [net] tls: Refactor tls aad space size calculation (Sabrina Dubroca) [1711821]
- [net] tls: Support 256 bit keys (Sabrina Dubroca) [1711821]
- [net] tls: free ctx in sock destruct (Sabrina Dubroca) [1711821]
- [net] tls: build_protos moved to common routine (Sabrina Dubroca) [1711821]
- [net] tls: Fix recvmsg() to be able to peek across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Make function tls_sw_do_sendpage static (Sabrina Dubroca) [1711821]
- [net] tls: remove unused function tls_sw_sendpage_locked (Sabrina Dubroca) [1711821]
- [net] Optimize sk_msg_clone() by data merge to end dst sg entry (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv partial/large_buff test cases (Sabrina Dubroca) [1711821]
- [net] tls: allocate tls context using GFP_ATOMIC (Sabrina Dubroca) [1711821]
- [net] tls: Init routines in create_ctx (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv(MSG_PEEK) & splice() test cases (Sabrina Dubroca) [1711821]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add MSG_WAITALL in recv() syscall (Sabrina Dubroca) [1711821]
- [net] tls: async support causes out-of-bounds access in crypto APIs (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add test for recv(PEEK) spanning across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Add support for async decryption of tls records (Sabrina Dubroca) [1711821]
- [net] tls: Calculate nsg for zerocopy path without skb_cow_data (Sabrina Dubroca) [1711821]
- [net] strparser: remove redundant variable 'rd_desc' (Sabrina Dubroca) [1711821]
- [net] tls: Use kmemdup to simplify the code (Sabrina Dubroca) [1711821]
- [net] tls: Use socket data_ready callback on record availability (Sabrina Dubroca) [1711821]
- [net] selftests: tls: add selftests for TLS sockets (Sabrina Dubroca) [1711821]
- [net] strparser: Call skb_unclone conditionally (Sabrina Dubroca) [1711821]
- [net] tls: Remove VLA usage on nonce (Sabrina Dubroca) [1711821]
- [net] tls: Removed unused variable (Sabrina Dubroca) [1711821]
- [netdrv] veth: use generic helper to report timestamping info (Jiri Benc) [1718938]
- [netdrv] veth: Fix -Wformat-truncation (Jiri Benc) [1718938]
- [netdrv] veth: Mark expected switch fall-throughs (Jiri Benc) [1718938]
- [net] Add extack argument to rtnl_create_link (Jiri Benc) [1718938]
- [netdrv] veth: Add ethtool statistics support for XDP (Jiri Benc) [1718938]
- [netdrv] veth: Account for XDP packet statistics on rx side (Jiri Benc) [1718938]
- [netdrv] veth: Account for packet drops in ndo_xdp_xmit (Jiri Benc) [1718938]
- [netdrv] veth: rename pcpu_vstats as pcpu_lstats (Jiri Benc) [1718938]
- [netdrv] net: move definition of pcpu_lstats to header file (Jiri Benc) [1718938]
- [netdrv] veth: add software timestamping (Jiri Benc) [1718938]
- [net] tcp: tcp_grow_window() needs to respect tcp_space() (Marcelo Leitner) [1718344]
- [net] tcp: fix a potential NULL pointer dereference in tcp_sk_exit (Marcelo Leitner) [1718344]
- [net] tcp: do not use ipv6 header for ipv4 flow (Marcelo Leitner) [1718344]
- [net] tcp: Don't access TCP_SKB_CB before initializing it (Marcelo Leitner) [1718344]
- [net] tcp: do not report TCP_CM_INQ of 0 for closed connections (Marcelo Leitner) [1718344]
- [net] tcp: clear icsk_backoff in tcp_write_queue_purge() (Marcelo Leitner) [1718344]
- [net] tcp: allow MSG_ZEROCOPY transmission also in CLOSE_WAIT state (Marcelo Leitner) [1718344]
- [net] tcp: change txhash on SYN-data timeout (Marcelo Leitner) [1718344]
- [net] tcp: lack of available data can also cause TSO defer (Marcelo Leitner) [1718344]
- [net] tcp: fix NULL ref in tail loss probe (Marcelo Leitner) [1718344]
- [net] tcp: Do not underestimate rwnd_limited (Marcelo Leitner) [1718344]
- [net] tcp: defer SACK compression after DupThresh (Marcelo Leitner) [1718344]
- [net] tcp: do not release socket ownership in tcp_close() (Marcelo Leitner) [1718344]
- [net] tcp: Fix SOF_TIMESTAMPING_RX_HARDWARE to use the latest timestamp during TCP coalescing (Marcelo Leitner) [1718344]
- [net] inet: make sure to grab rcu_read_lock before using ireq->ireq_opt (Marcelo Leitner) [1718344]
- [net] tcp/dccp: fix lockdep issue when SYN is backlogged (Marcelo Leitner) [1718344]
- [net] xfrm4: Fix uninitialized memory read in _decode_session4 (Sabrina Dubroca) [1718812]
- [net] esp4: add length check for UDP encapsulation (Sabrina Dubroca) [1718812]
- [net] xfrm: clean up xfrm protocol checks (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix potential panic when unloading xfrm6_tunnel module (Sabrina Dubroca) [1718812]
- [net] xfrm: Reset secpath in xfrm failure (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: Fix out-of-bound array accesses in __xfrm_policy_unlink (Sabrina Dubroca) [1718812]
- [net] xfrm: destroy xfrm_state synchronously on net exit path (Sabrina Dubroca) [1718812]
- [net] esp: Skip TX bytes accounting when sending from a request socket (Sabrina Dubroca) [1718812]
- [net] xfrm: refine validation of template and selector families (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: increment xfrm_hash_generation on hash rebuild (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix spi check in __xfrm6_tunnel_alloc_spi (Sabrina Dubroca) [1718812]
- [net] xfrm_user: fix freeing of xfrm states on acquire (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix NULL pointer dereference in xfrm_input when skb_dst_force clears the dst_entry (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix error return code in xfrm_output_one() (Sabrina Dubroca) [1718812]
- [net] vti4: eliminated some duplicate code (Guillaume Nault) [1718443]
- [net] vti4: removed duplicate log message (Guillaume Nault) [1718443]
- [net] vti4: ipip tunnel deregistration fixes (Guillaume Nault) [1718443]
- [net] vti4: Fix a ipip packet processing bug in 'IPCOMP' virtual tunnel (Guillaume Nault) [1718443]
- [net] fou: do not use guehdr after iptunnel_pull_offloads in gue_udp_recv (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling gro_cells_receive() (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling netif_rx() (Guillaume Nault) [1718443]
- [net] devlink: turn devlink into a built-in (Petr Oros) [1717458]
- [net] ipv6: fix EFAULT on sendto with icmpv6 and hdrincl (Stefano Brivio) [1718503]
- [net] ipv6: use READ_ONCE() for inet->hdrincl as in ipv4 (Stefano Brivio) [1718503]
- [net] ipv6: Fix redirect with VRF (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a raw socket to an address (Stefano Brivio) [1718503]
- [net] ipv6: prevent possible fib6 leaks (Stefano Brivio) [1718503]
- [net] vrf: sit mtu should not be updated when vrf netdev is the link (Stefano Brivio) [1718503]
- [net] ipv6: A few fixes on dereferencing rt->from (Stefano Brivio) [1718503]
- [tools] selftests: fib_rule_tests: Fix icmp proto with ipv6 (Stefano Brivio) [1718503]
- [net] ipv6: fix races in ip6_dst_destroy() (Stefano Brivio) [1718503]
- [net] ipv6/flowlabel: wait rcu grace period before put_pid() (Stefano Brivio) [1718503]
- [net] ipv6: invert flowlabel sharing check in process and user mode (Stefano Brivio) [1718503]
- [net] route: Avoid crash from dereferencing NULL rt->from (Stefano Brivio) [1718503]
- [net] udpv6: Check address length before reading address family (Stefano Brivio) [1718503]
- [net] ip6_gre: fix possible use-after-free in ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ip6_gre: remove gre_hdr_len from ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ipv6: Fix dangling pointer when ipv6 fragment (Stefano Brivio) [1718503]
- [net] ip6_tunnel: Match to ARPHRD_TUNNEL6 for dev type (Stefano Brivio) [1718503]
- [net] inet: switch IP ID generator to siphash (Stefano Brivio) [1718503]
- [net] sit: fix UBSAN Undefined behaviour in check_6rd (Stefano Brivio) [1718503]
- [net] ip6mr: Do not call __IP6_INC_STATS() from preemptible context (Stefano Brivio) [1718503]
- [net] sit: fix memory leak in sit_init_net() (Stefano Brivio) [1718503]
- [net] ipv4: Add ICMPv6 support when parse route ipproto (Stefano Brivio) [1718503]
- [net] ipv6: Return error for RTA_VIA attribute (Stefano Brivio) [1718503]
- [net] Set rtm_table to RT_TABLE_COMPAT for ipv6 for tables > 255 (Stefano Brivio) [1718503]
- [net] ip6_gre: do not report erspan_ver for ip6gre or ip6gretap (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in rt6_update_exception_stamp_rt() (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in ip6_route_check_nh_onlink() (Stefano Brivio) [1718503]
- [net] ipv6: propagate genlmsg_reply return code (Stefano Brivio) [1718503]
- [net] fix IPv6 prefix route residue (Stefano Brivio) [1718503]
- [net] ip6mr: Fix notifiers call on mroute_clean_tables() (Stefano Brivio) [1718503]
- [net] af_packet: fix raw sockets over 6in4 tunnel (Stefano Brivio) [1718503]
- [net] ip6_gre: fix tunnel list corruption for x-netns (Stefano Brivio) [1718503]
- [net] ipv6: fix kernel-infoleak in ipv6_local_error() (Stefano Brivio) [1718503]
- [net] ip: on queued skb use skb_header_pointer instead of pskb_may_pull (Stefano Brivio) [1718503]
- [net] ipv4: fix use-after-free in ip_cmsg_recv_dstaddr() (Stefano Brivio) [1718503]
- [net] ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to a v4 mapped address (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to an address (Stefano Brivio) [1718503]
- [net] ip: validate header length on virtual device xmit (Stefano Brivio) [1718503]
- [net] ipv6: Fix a test against 'ipv6_find_idev()' return value (Stefano Brivio) [1718503]
- [net] ipv6: tunnels: fix two use-after-free (Stefano Brivio) [1718503]
- [net] ipv6: add missing tx timestamping on IPPROTO_RAW (Stefano Brivio) [1718503]
- [net] clear skb->tstamp in forwarding paths (Stefano Brivio) [1718503]
- [net] ipv6: sr: properly initialize flowi6 prior passing to ip6_route_output (Stefano Brivio) [1718503]
- [net] always initialize pagedlen (Stefano Brivio) [1718503]
- [net] ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF (Stefano Brivio) [1718503]
- [net] ipv6: gro: do not use slow memcmp() in ipv6_gro_receive() (Stefano Brivio) [1718503]
- [net] xfrm: fix out-of-bounds packet access (Stefano Brivio) [1718503]
- [net] ipv6: take rcu lock in rawv6_send_hdrinc() (Stefano Brivio) [1718503]
- [net] ip6_tunnel: be careful when accessing the inner header (Stefano Brivio) [1718503]
- [net] revert "ipv6: fix double refcount of fib6_metrics" (Stefano Brivio) [1718503]
- [net] ipv6: fix memory leak on dst->_metrics (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for ip6_mr failure (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for pingv6 registration (Stefano Brivio) [1718503]
- [net] ip6_tunnel: collect_md xmit: Use ip_tunnel_key's provided src address (Stefano Brivio) [1718503]
- [net] ipv6: fix addrconf_sysctl_addr_gen_mode (Stefano Brivio) [1718503]
- [net] ipv6: don't reinitialize ndev->cnf.addr_gen_mode on new inet6_dev (Stefano Brivio) [1718503]
- [net] ipv6: reserve room for IFLA_INET6_ADDR_GEN_MODE (Stefano Brivio) [1718503]
- [net] ipv6: propagate net.ipv6.conf.all.addr_gen_mode to devices (Stefano Brivio) [1718503]
- [net] openvswitch: check for null pointer return from nla_nest_start_noflag (Stefano Brivio) [1718408]
- [net] openvswitch: add seqadj extension when NAT is used (Stefano Brivio) [1718408]
- [net] netfilter: Replace spin_is_locked() with lockdep (Stefano Brivio) [1718392]
- [net] netfilter: ipset: do not call ipset_nest_end after nla_nest_cancel (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Fix calling ip_set() macro at dumping (Stefano Brivio) [1718392]
- [include] netfilter: ipset: Correct rcu_dereference() call in ip_set_put_comment() (Stefano Brivio) [1718392]
- [net] netfilter: ipset: fix ip_set_list allocation failure (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Make invalid MAC address checks consistent (Stefano Brivio) [1649087]
- [net] netfilter: ipset: Allow matching on destination MAC address for mac and ipmac sets (Stefano Brivio) [1649087]
- [netdrv] rocker: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [net] switchdev: Add SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [netdrv] rocker: Add missing break for PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] bridge: Stop calling switchdev_port_attr_get() (Ivan Vecera) [1717892]
- [netdrv] rocker: Check Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] mlxsw: spectrum: Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [include] net: switchdev: Add PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove port_attr_bridge_flags_get assignment (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] pktgen: do not sleep with the thread lock held (Paolo Abeni) [1715575]
- [include] ipv6: fix the check before getting the cookie in rt6_get_cookie (Xin Long) [1709166]
- [net] ipv4: not do cache for local delivery if bc_forwarding is enabled (Xin Long) [1712657]
- [net] sctp: avoid running the sctp state machine recursively (Xin Long) [1717316]
- [netdrv] netdevsim: use skb_sec_path helper (Hangbin Liu) [1711810]
- [netdrv] netdevsim: convert to DEFINE_SHOW_ATTRIBUTE (Hangbin Liu) [1711810]
- [netdrv] netdevsim: make debug dirs' dentries static (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: use internal netns switch for ip commands (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: add testcases for vxlan flag sets (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: Add a test case for multipath route get (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh: add testcase for neigh get (Hangbin Liu) [1711810]
- [tools] selftests: net: rtnetlink.sh: add fdb get test (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh explicitly requires bash (Hangbin Liu) [1711810]
- [net] udp: with udp_segment release on error path (Paolo Abeni) [1718079]
- [net] ipv6: explicitly initialize udp6_addr in udp_sock_create6() (Paolo Abeni) [1718079]
- [netdrv] geneve: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] vxlan: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] geneve: Initialize addr6 with memset (Stefano Brivio) [1652222]
- [net] ip_tunnel: don't force DF when MTU is locked (Stefano Brivio) [1652222]
- [netdrv] geneve: ICMP error lookup handler (Stefano Brivio) [1652222]
- [netdrv] vxlan: ICMP error lookup handler (Stefano Brivio) [1652222]
- [net] udp: Handle ICMP errors for tunnels with same destination port on both endpoints (Stefano Brivio) [1652222]
- [net] udp: gro behind static key (Stefano Brivio) [1652222]
- [net] bpf: in __bpf_redirect_no_mac pull mac only if present (Jiri Benc) [1687471]
- [net] lwt_bpf: remove unnecessary rcu_read_lock in run_lwt_bpf (Jiri Benc) [1687471]
- [net] bpf: add End.DT6 action to bpf_lwt_seg6_action helper (Jiri Benc) [1687471]
- [net] bpf: fix out-of-bounds read in __bpf_skc_lookup (Jiri Benc) [1687459]
- [net] bpf: Check sk_fullsock() before returning from bpf_sk_lookup() (Jiri Benc) [1687459]
- [net] flow_dissector: disable preemption around BPF calls (Jiri Benc) [1687459]
- [net] bpf: sockmap, only stop/flush strp if it was enabled at some point (Jiri Benc) [1687459]
- [net] bpf: Stop the psock parser before canceling its work (Jiri Benc) [1687459]
- [net] bpf: only test gso type on gso packets (Jiri Benc) [1687459]
- [tools] selftests: add dummy xdp test helper (Jiri Benc) [1687459]
- [net] filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [documentation] Update references to netdev-FAQ (Jiri Benc) [1687459]
- [net] bpfilter: remove trailing newline (Jiri Benc) [1687459]
- [net] core: filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [net] revert "xsk: simplify AF_XDP socket teardown" (Jiri Benc) [1687459]
- [net] bpf/test_run: fix unkillable BPF_PROG_TEST_RUN (Jiri Benc) [1687459]
- [net] xsk: share the mmap_sem for page pinning (Jiri Benc) [1687459]
- [net] xsk: add missing smp_rmb() in xsk_mmap (Jiri Benc) [1687459]
- [net] bpf: only adjust gso_size on bytestream protocols (Jiri Benc) [1687459]
- [net] sk_msg: Always cancel strp work before freeing the psock (Jiri Benc) [1687459]
- [net] bpf: sock recvbuff must be limited by rmem_max in bpf_setsockopt() (Jiri Benc) [1687459]
- [net] bpf: fix SO_MAX_PACING_RATE to support TCP internal pacing (Jiri Benc) [1687459]
- [net] bpf: bpf_setsockopt: reset sock dst on SO_MARK changes (Jiri Benc) [1687459]
- [net] bpf: correctly set initial window on active Fast Open sender (Jiri Benc) [1687459]
- [net] xsk: simplify AF_XDP socket teardown (Jiri Benc) [1687459]
- [net] bpf: fix doc of bpf_skb_adjust_room() in uapi (Jiri Benc) [1687459]
- [net] bpf: do not blindly change rlimit in reuseport net selftest (Jiri Benc) [1687459]
- [net] xsk: proper AF_XDP socket teardown ordering (Jiri Benc) [1687459]
- [net] bpf: typo fix in Documentation/networking/af_xdp.rst (Jiri Benc) [1687459]
- [net] xdp: split code for map vs non-map redirect (Jiri Benc) [1687459]
- [net] xdp: explicit inline __xdp_map_lookup_elem (Jiri Benc) [1687459]
- [net] xdp: unlikely instrumentation for xdp map redirect (Jiri Benc) [1687459]
- [net] xdp: remove redundant variable 'headroom' (Jiri Benc) [1687459]
- [net] xsk: include XDP meta data in AF_XDP frames (Jiri Benc) [1687459]
- [net] bpf: Enable BPF_PROG_TYPE_SK_REUSEPORT bpf prog in reuseport selection (Jiri Benc) [1687459]
- [net] revert "xdp: add NULL pointer check in __xdp_return()" (Jiri Benc) [1687459]
- [lib] test_rhashtable: Make test_insert_dup() allocate its hash table dynamically (Jiri Benc) [1717066]
- [lib] test_rhashtable: remove semaphore usage (Jiri Benc) [1717066]
- [lib] rhashtable: detect when object movement between tables might have invalidated a lookup (Jiri Benc) [1717066]
- [lib] rhashtable: remove duplicated include from rhashtable.c (Jiri Benc) [1717066]
- [lib] rhashtable: clean up dereference of ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: use cmpxchg() to protect ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: simplify nested_table_alloc() and rht_bucket_nested_insert() (Jiri Benc) [1717066]
- [lib] rhashtable: simplify INIT_RHT_NULLS_HEAD() (Jiri Benc) [1717066]
- [lib] rhashtable: remove nulls_base and related code (Jiri Benc) [1717066]
- [lib] rhashtable: split rhashtable.h (Jiri Benc) [1717066]
- [lib] rhashtable: silence RCU warning in rhashtable_test (Jiri Benc) [1717066]
- [net] devlink: publish params only after driver init is done (Ivan Vecera) [1715929]
- [net] iptunnel: NULL pointer deref for ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_gre: Refactor collect metatdata mode tunnel xmit to ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Fix route fl4 init in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add tnl_update_pmtu in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add ip tunnel dst_cache in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] vlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [net] vlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [netdrv] macvlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to real device (Hangbin Liu) [1664359]
- [net] ethtool: add compat for flash update (Petr Oros) [1708339]
- [net] devlink: add flash update command (Petr Oros) [1708339]
- [net] devlink: Fix list access without lock while reading region (Petr Oros) [1708339]
- [net] devlink: Return right error code in case of errors for region read (Petr Oros) [1708339]
- [net] devlink: use direct return of genlmsg_reply (Petr Oros) [1708339]
- [net] devlink: Rename devlink health attributes (Petr Oros) [1709874]
- [net] devlink: Modify reply of DEVLINK_CMD_HEALTH_REPORTER_GET (Petr Oros) [1709874]
- [net] devlink: Update reporter state to error even if recover aborted (Petr Oros) [1709874]
- [documentation] devlink: Add Documentation/networking/devlink-health.txt (Petr Oros) [1709874]
- [net] devlink: Add health dump {get, clear} commands (Petr Oros) [1709874]
- [net] devlink: Add health diagnose command (Petr Oros) [1709874]
- [net] devlink: Add health recover command (Petr Oros) [1709874]
- [net] devlink: Add health set command (Petr Oros) [1709874]
- [net] devlink: Add health get command (Petr Oros) [1709874]
- [net] devlink: Add health report functionality (Petr Oros) [1709874]
- [net] devlink: Add health reporter create/destroy functionality (Petr Oros) [1709874]
- [net] devlink: Add devlink formatted message (fmsg) API (Petr Oros) [1709874]
- [net] devlink: add hardware errors tracing facility (Petr Oros) [1709874]
- [net] cnb: devlink: report cell size of shared buffers (Petr Oros) [1708348]
- [net] devlink: skip info_get op call if it is not defined in dumpit (Petr Oros) [1708342]
- [include] devlink: add a generic board.manufacture version name (Petr Oros) [1708342]
- [net] devlink: don't allocate attrs on the stack (Petr Oros) [1708342]
- [net] devlink: fix condition for compat device info (Petr Oros) [1708342]
- [net] ethtool: add compat for devlink info (Petr Oros) [1708342]
- [include] devlink: add generic info version names (Petr Oros) [1708342]
- [net] devlink: add version reporting to devlink info API (Petr Oros) [1708342]
- [net] devlink: add device information API (Petr Oros) [1708342]
- [net] devlink: Add devlink notifications support for port params (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit set value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit get value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add port param set command (Petr Oros) [1710228]
- [net] devlink: Add port param get command (Petr Oros) [1710228]
- [net] devlink: Add devlink_param for port register and unregister (Petr Oros) [1710228]
- [net] ipv6: properly check return value in inet6_dump_all() (Petr Oros) [1714656]
- [net] Don't return invalid table id error when dumping all families (Petr Oros) [1714656]
- [net] ipmr_base: Do not reset index in mr_table_dump (Petr Oros) [1714656]
- [net] ipv6: Fix dump of specific table with strict checking (Petr Oros) [1714656]
- [net] ipv4: avoid compile error in fib_info_nh_uses_dev (Petr Oros) [1714656]
- [net] ipv4: Bail early if user only wants prefix entries (Petr Oros) [1714656]
- [net] ipv6: Bail early if user only wants cloned entries (Petr Oros) [1714656]
- [net] mpls: Handle kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Enable kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Plumb support for filtering ipv4 and ipv6 multicast route dumps (Petr Oros) [1714656]
- [net] ipmr: Refactor mr_rtm_dumproute (Petr Oros) [1714656]
- [net] mpls: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] ipv6: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] netfilter: nft_fib: Convert nft_fib4_eval to new dev helper (Petr Oros) [1714656]
- [net] netfilter: rpfilter: Convert rpfilter_lookup_reverse to new dev helper (Petr Oros) [1714656]
- [net] ipv4: Move device validation to helper (Petr Oros) [1714656]
- [net] ipv4: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] Add struct for fib dump filter (Petr Oros) [1714656]
- [lib] iov_iter: Fix build error without CONFIG_CRYPTO (Ivan Vecera) [1714213]
- [net] datagram: introduce skb_copy_and_hash_datagram_iter helper (Ivan Vecera) [1714213]
- [lib] iov_iter: introduce hash_and_copy_to_iter helper (Ivan Vecera) [1714213]
- [net] datagram: consolidate datagram copy to iter helpers (Ivan Vecera) [1714213]
- [lib] iov_iter: pass void csum pointer to csum_and_copy_to_iter (Ivan Vecera) [1714213]
- [net] datagram: open-code copy_page_to_iter (Ivan Vecera) [1714213]
- [include] net: enable mpls_ptr in net_device (Hangbin Liu) [1350011]
- [net] netfilter: ipset: actually allow allowable CIDR 0 in hash:net, port, net (Stefano Brivio) [1680512]
- [net] netfilter: ipset: fix ip_set_byindex function (Stefano Brivio) [1680512]
- [net] netfilter: ipset: Introduction of new commands and protocol version 7 (Stefano Brivio) [1680512]
- [net] ipv6: don't return positive numbers when nothing was dumped (Petr Oros) [1700306]
- [net] rtnetlink: restore handling of dumpit return value in rtnl_dump_all() (Petr Oros) [1700306]
- [net] netlink: fixup regression in RTM_GETADDR (Petr Oros) [1700306]
- [net] {ipv4, ipv6}: Do not put target net if input nsid is invalid (Petr Oros) [1700306]
- [net] rtnl_dump_all needs to propagate error from dumpit function (Petr Oros) [1700306]
- [net] rtnetlink: Move ifm in valid_fdb_dump_legacy to closer to use (Petr Oros) [1700306]
- [net] neighbor: NTF_PROXY is a valid ndm_flag for a dump request (Petr Oros) [1700306]
- [net] mpls: Implement handler for strict data checking on dumps (Petr Oros) [1700306]
- [net] rtnetlink: Update comment in rtnl_stats_dump regarding strict data checking (Petr Oros) [1700306]
- [net] ipv6: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [net] ipv4: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [tools] headers uapi: Update linux/netlink.h header copy (Petr Oros) [1700306]
- [net] neigh: fix NULL deref in pneigh_dump_table() (Petr Oros) [1700306]
- [net] ipv6: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv4: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv6: Remove ip_idx arg to in6_dump_addrs (Petr Oros) [1700306]
- [net] ipv4: Move loop over addresses on a device into in_dev_dump_addr (Petr Oros) [1700306]
- [net] netlink: Add answer_flags to netlink_callback (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_fdb_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Move input checking for rtnl_fdb_dump to helper (Petr Oros) [1700306]
- [net] bridge: Update br_mdb_dump for strict data checking (Petr Oros) [1700306]
- [net] Update netconf dump handlers for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update ip6addrlbl_dump for strict data checking (Petr Oros) [1700306]
- [net] fib_rules: Update fib_nl_dumprule for strict data checking (Petr Oros) [1700306]
- [net] namespace: Update rtnl_net_dumpid for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neightbl_dump_info for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neigh_dump_info for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update fib dumps for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update ipmr_rtm_dumplink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update inet6_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_stats_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_bridge_getlink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update inet6_dump_addr for strict data checking (Petr Oros) [1700306]
- [net] ipv4: Update inet_dump_ifaddr for strict data checking (Petr Oros) [1700306]
- [net] netlink: Add new socket option to enable strict checking on dumps (Petr Oros) [1700306]
- [net] ipv6: Refactor address dump to push inet6_fill_args to in6_dump_addrs (Petr Oros) [1700306]
- [lib] netlink: Add strict version of nlmsg_parse and nla_parse (Petr Oros) [1700306]
- [net] Add extack to nlmsg_parse (Petr Oros) [1700306]
- [include] netlink: Add extack message to nlmsg_parse for invalid header length (Petr Oros) [1700306]
- [net] netlink: Pass extack to dump handlers (Petr Oros) [1700306]
- [net] neigh: Extend dump filter to proxy neighbor dumps (Petr Oros) [1700306]
- [lib] netlink: add nested array policy validation (Petr Oros) [1700306]
- [lib] netlink: allow NLA_NESTED to specify nested policy to validate (Petr Oros) [1700306]
- [lib] netlink: move extack setting into validate_nla() (Petr Oros) [1700306]
- [lib] netlink: make validation_data const (Petr Oros) [1700306]
- [lib] netlink: remove NLA_NESTED_COMPAT (Petr Oros) [1700306]
- [lib] netlink: add ethernet address policy types (Petr Oros) [1700306]
- [net] sched: cls_u32: add res to offload information (Ivan Vecera) [1711377]
- [net] sched: gred: support reporting stats from offloads (Ivan Vecera) [1711377]
- [net] sched: gred: add basic Qdisc offload (Ivan Vecera) [1711377]
- [net] sched: gred: allow manipulating per-DP RED flags (Ivan Vecera) [1711377]
- [net] sched: gred: store red flags per virtual queue (Ivan Vecera) [1711377]
- [net] sched: gred: provide a better structured dump and expose stats (Ivan Vecera) [1711377]
- [net] sched: gred: store bytesin as a 64 bit value (Ivan Vecera) [1711377]
- [net] sched: gred: use extack to provide more details on configuration errors (Ivan Vecera) [1711377]
- [net] sched: gred: pass extack to nla_parse_nested() (Ivan Vecera) [1711377]
- [net] sched: gred: separate error and non-error path in gred_change() (Ivan Vecera) [1711377]
- [net] netlink: add NLA_REJECT policy type (Ivan Vecera) [1711377]
- [lib] netlink: Return extack message if attribute validation fails (Ivan Vecera) [1711377]
- [net] sched: red: notify drivers about RED's limit parameter (Ivan Vecera) [1711039]
- [net] sched: mq: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: red: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: provide notification for graft on root (Ivan Vecera) [1711039]
- [net] sched: prio: delay destroying child qdiscs on change (Ivan Vecera) [1711039]
- [net] sched: red: delay destroying child qdisc on replace (Ivan Vecera) [1711039]
- [net] sched: refactor grafting Qdiscs with a parent (Ivan Vecera) [1711039]
- [net] sched: add an offload graft helper (Ivan Vecera) [1711039]
- [net] sched: set TCQ_F_OFFLOADED flag for MQ (Ivan Vecera) [1711039]
- [net] sched: red: remove unnecessary red_dump_offload_stats parameter (Ivan Vecera) [1711039]
- [net] sched: add an offload dump helper (Ivan Vecera) [1711039]
- [netdrv] netdevsim: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [netdrv] rocker: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] Introduce ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] use indirect calls helpers at early demux stage (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for L3 handler hooks (Paolo Abeni) [1700747]
- [net] use indirect calls helpers at the socket layer (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for ptype hook (Paolo Abeni) [1700747]
- [net] add documentation to socket.c (Paolo Abeni) [1700747]
- [net] udp: use indirect call wrappers for GRO socket lookup (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO transport layer (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO network layer (Paolo Abeni) [1700747]
- [net] indirect call wrappers: helpers to speed-up indirect calls of builtin (Paolo Abeni) [1700747]
- [powerpc] powerpc: bpf: Fix generation of load/store DW instructions (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: propagate liveness on all frames (Yauheni Kaliuta) [1700846]
- [net] bpf: do not restore dst_reg when cur_state is freed (Yauheni Kaliuta) [1700846]
- [tools] tools lib bpf: Fix the build by adding a missing stdarg.h include (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fix version info and add it to shared object (Yauheni Kaliuta) [1700846]
- [tools] btf: fix bug with resolving STRUCT/UNION into corresponding FWD (Yauheni Kaliuta) [1700846]
- [tools] tools/libbpf: signedness bug in btf_dedup_ref_type() (Yauheni Kaliuta) [1700846]
- [tools] libbpf: fix libbpf_print (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: simplify libbpf API function libbpf_set_print() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: move set_max_rlimit() before __bpf_object__open_xattr() (Yauheni Kaliuta) [1700846]
- [include] bpf: promote bpf_perf_event.h to mandatory UAPI header (Yauheni Kaliuta) [1700846]
- [net] bpf: Avoid unnecessary instruction in convert_bpf_ld_abs() (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix check of allowed specifiers in bpf_trace_printk (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: Document Jump X addressing mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix license for a compat header file (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Capitalise document heading (Yauheni Kaliuta) [1700846]
- [documentation] docs: Add bpf/index to top level index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Add toctree to index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Rename README.rst to index.rst (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported map types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported program types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip sockmap in test_maps if kernel doesn't have support (Yauheni Kaliuta) [1700846]
- [rpmspec] rpmspec: pack bpf-helpers, bpftool-net, bpftool-feature manpages (Yauheni Kaliuta) [1700846]
- [net] bpf, tcp: correctly handle DONT_WAIT flags and timeo == 0 (Yauheni Kaliuta) [1700846]
- [kernel] bpf: mark bpf_event_notify and bpf_event_init as static (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap fix msg->sg.size account on ingress skb (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap remove duplicate queue free (Yauheni Kaliuta) [1700846]
- [net] net/tls: remove set but not used variables (Yauheni Kaliuta) [1700846]
- [media] bpf: add map helper functions push, pop, peek in more BPF programs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix infinite loop in map create (Yauheni Kaliuta) [1700846]
- [net] net/tls: fix build without CONFIG_TLS_DEVICE (Yauheni Kaliuta) [1700846]
- [net] net/tls: don't leak partially sent record in device mode (Yauheni Kaliuta) [1700846]
- [net] xdp: fix cpumap redirect SKB creation bug (Yauheni Kaliuta) [1700846]
- [net] net/core: Document reuseport_add_sock() bind_inany argument (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: clarify bump in libbpf version info (Yauheni Kaliuta) [1700846]
- [net] net/tls: Inform user space about send buffer availability (Yauheni Kaliuta) [1700846]
- [tools] libbpf: handle BTF parsing and loading properly (Yauheni Kaliuta) [1700846]
- [net] bpf: fix warning about using plain integer as NULL (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fixing leak when kernel does not support btf (Yauheni Kaliuta) [1700846]
- [net] tls: Fix write space handling (Yauheni Kaliuta) [1700846]
- [net] tls: Fix tls_device handling of partial records (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, fix documentation for attach types (Yauheni Kaliuta) [1700846]
- [tools] btf: separate btf creation and loading (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a selftest test_btf failure (Yauheni Kaliuta) [1700846]
- [tools] selftests/btf: add initial BTF dedup tests (Yauheni Kaliuta) [1700846]
- [tools] btf: add BTF types deduplication algorithm (Yauheni Kaliuta) [1700846]
- [tools] btf: extract BTF type size calculation (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: silence a libbpf unnecessary warning (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: implement libbpf btf__get_map_kv_tids() API function (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: expose functions btf_ext__* as API functions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a support for getting xdp prog id on ifindex (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a helper for retrieving a map fd for a given name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: introduce bpf_map_lookup_elem_flags() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add bash completion for bpftool probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for a network device (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add C-style "#define" output for probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF helper functions (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF map types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF program types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for kernel configuration options (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for /proc/ eBPF parameters (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add basic probe capability, probe syscall availability (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: print out btf log at LIBBPF_WARN level (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move libbpf pr_* debug print functions to headers (Yauheni Kaliuta) [1700846]
- [net] net: tls: Fix deadlock in free_resources tx (Yauheni Kaliuta) [1700846]
- [net] net: tls: Save iv in tls_rec for async crypto requests (Yauheni Kaliuta) [1700846]
- [tools] bpf: pull in pkt_sched.h header for tooling to fix bpftool build (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: change section name of bpfilter UMH blob (Yauheni Kaliuta) [1700846]
- [netdrv] tap: call skb_probe_transport_header after setting skb->dev (Yauheni Kaliuta) [1700846]
- [net] Prevent overflow of sk_msg in sk_msg_clone() (Yauheni Kaliuta) [1700846]
- [net] tls: Do not call sk_memcopy_from_iter with zero length (Yauheni Kaliuta) [1700846]
- [net] net: ipv4: Set skb->dev for output route resolution (Yauheni Kaliuta) [1700846]
- [net] bpf: refactor bpf_test_run() to separate own failures and test program result (Yauheni Kaliuta) [1700846]
- [include] bpf: fix pointer offsets in context for 32 bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: copy a few net uapi headers to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: tcp_bpf_recvmsg should return EAGAIN when nonblocking and no data (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, fix psock create on existing kcm/tls port (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove socket lock assertion on ULP cleanup (Yauheni Kaliuta) [1700846]
- [lib] bpf: test_bpf: add init_net to dev for flow_dissector (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: lookup netns by skb->sk if skb->dev is NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed uninitialised vars warning (Yauheni Kaliuta) [1700846]
- [include] cgroup: Simplify cgroup_ancestor (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Orphan skb before GRO (Yauheni Kaliuta) [1700846]
- [net] net/core/filter: fix unused-variable warning (Yauheni Kaliuta) [1700846]
- [net] bpf: fix build error with clang (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Free queues on link delete (Yauheni Kaliuta) [1700846]
- [net] bpf: fix sanitation rewrite in case of non-pointers (Yauheni Kaliuta) [1700846]
- [net] bpf: drop refcount if bpf_map_new_fd() fails in map_create() (Yauheni Kaliuta) [1700846]
- [net] bpf: decrease usercnt if bpf_map_new_fd() fails in bpf_map_get_fd_by_id() (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: fix lookup bug in map_delete_elem (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in stackmap (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix narrow load on a bpf_sock returned from sk_lookup() (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix syscall's stackmap lookup potential deadlock (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix potential deadlock in bpf_prog_register (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in percpu_freelist (Yauheni Kaliuta) [1700846]
- [net] bpf: run bpf programs with preemption disabled (Yauheni Kaliuta) [1700846]
- [tools] bpf, selftests: fix handling of sparse CPU allocations (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix test_btf for typedef func_proto case (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: allow typedef func_proto (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix crash with un-owned prog arrays (Yauheni Kaliuta) [1700846]
- [tools] bpftool: fix percpu maps updating (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: Cleanup license mess (Yauheni Kaliuta) [1700846]
- [net] bpf: Annotate implicit fall through in cgroup_dev_func_proto (Yauheni Kaliuta) [1700846]
- [net] bpf: Make function btf_name_offset_valid static (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: retry tests that expect build-id (Yauheni Kaliuta) [1700846]
- [net] bpf: zero out build_id for BPF_STACK_BUILD_ID_IP (Yauheni Kaliuta) [1700846]
- [net] bpf: don't assume build-id length is always 20 bytes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: properly account for libbfd variations (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry loading program on EAGAIN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: workaround clang asm goto compilation errors (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: install with_tunnels.sh for test_flow_dissector.sh (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: disallow to remove bpfilter module while being used (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Fix type cast and pointer warnings (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: restart bpfilter_umh when error occurred (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use cleanup callback to release umh_info (Yauheni Kaliuta) [1700846]
- [kernel] umh: add exit routine for UMH process (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Set user mode helper's command line (Yauheni Kaliuta) [1700846]
- [kernel] umh: Add command line to user mode helpers (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use get_pid_task instead of pid_task (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpftool map dump with bitfields (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test btf bitfield with >=256 struct member offset (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs bitfield pretty print (Yauheni Kaliuta) [1700846]
- [net] bpf: fix panic in stack_map_get_build_id() on i386 and arm32 (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install files tcp_(server|client)*.py (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: user proper argument index (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] bpf, doc: add note for libbpf's stand-alone build (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: update design qa to reflect kern_version requirement (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix incorrect users of create_and_get_cgroup (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases for alu op on mixed dst register types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test [::] -> [::1] rewrite in sys_sendmsg in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix [::] -> [::1] rewrite in sys_sendmsg (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to selftests (Yauheni Kaliuta) [1700846]
- [net] bpf: fix check_map_access smin_value test when pointer contains offset (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict stack pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict map value pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: enable access to ax register also from verifier rewrite (Yauheni Kaliuta) [1700846]
- [net] bpf: move tmp variable into ax register in interpreter (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix error printing in test_devmap() (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix segfault in test_verifier selftest (Yauheni Kaliuta) [1700846]
- [net] bpf: tls_sw, init TLS ULP removes BPF proto hooks (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, sock{map|hash} redirect through ULP (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, zap ingress queue on psock down (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, fix socket data_ready events (Yauheni Kaliuta) [1700846]
- [net] bpf: skb_verdict, support SK_PASS on RX BPF path (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, replace comments with BUILD bug (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, improve offset chk in _is_valid_access (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, fix sk_msg_md access past end test (Yauheni Kaliuta) [1700846]
- [net] bpf/cpumap: make sure frame_size for build_skb is aligned if headroom isn't (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: reorder stack size check with dead code sanitization (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: verifier: add tests for JSET interpretation (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: teach the verifier to reason about the BPF_JSET instruction (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add trivial JSET tests (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_LD_IMM64 to the line_info test (Yauheni Kaliuta) [1700846]
- [net] bpf: Ensure line_info.insn_off cannot point to insn with zero code (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: do not force gcc as CC (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix up uapi helper description and sync bpf header with tools (Yauheni Kaliuta) [1700846]
- [net] bpf: log struct/union attribute for forward type (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, add tests for size field (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tools lib/include support sk_msg_md size field (Yauheni Kaliuta) [1700846]
- [include] bpf: sockmap, metadata support for reporting size of msg (Yauheni Kaliuta) [1700846]
- [net] bpf: correct slot_type marking logic to allow more stack slot sharing (Yauheni Kaliuta) [1700846]
- [kernel] bpf: support raw tracepoints in modules (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add an option to prevent auto-mount of bpffs, tracefs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: attempt to mount tracefs if required for tracelog cmd (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: check precise {func, line, jited_line}_info_rec_size in test_btf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: fix memleak by freeing line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: support pretty print with kind_flag set (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: refactor btf_dumper_int_bits() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test kernel bpffs map pretty print with struct kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add test_btf unit tests for kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync btf.h header from kernel to tools (Yauheni Kaliuta) [1700846]
- [net] bpf: enable cgroup local storage map pretty print with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix struct/union/fwd types with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: refactor btf_int_bits_seq_show() (Yauheni Kaliuta) [1700846]
- [net] bpf: remove useless version check for prog load (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix -Wmissing declaration warnings (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix warning on struct bpf_prog_linfo definition (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a prog array map update example to documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix examples in documentation for bpftool prog (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add doc for -m option to bpftool-prog.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: add self-check logic to liveness analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: improve stacksafe state comparison (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: check insn processed in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: speed up stacksafe check (Yauheni Kaliuta) [1700846]
- [net] bpf: verbose log bpf_line_info in verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Create a new btf_name_by_offset() for non type name use case (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix sk lookup usage in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: remove obsolete prog->aux sanitation in bpf_insn_prepare_dump (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: make sure callees don't prune with caller differences (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: include sub program tags in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Remove !func_info and !line_info check from test_btf and bpftool (Yauheni Kaliuta) [1700846]
- [net] bpf: Remove bpf_dump_raw_ok() check for func_info and line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: dual license all files (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: replace Netronome boilerplate with SPDX license headers (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix SPDX format in headers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add btf annotations for cgroup_local_storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for cgroup local storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: pass struct btf pointer to the map_check_btf() callback (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use __bpf_constant_htons in test_prog.c (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_jit_limit knob for PAGE_SIZE >= 64K (Yauheni Kaliuta) [1700846]
- [arm64] bpf: arm64: Enable arm64 jit to provide bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use proper type when passing prog_type (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: rename *_info_cnt to nr_*_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: rename *_info_cnt to nr_*_info in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: clean up bpf_prog_get_info_by_fd() (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool: Fix newline and p_err issue (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing pointer dereference for map stacktrace fixup (Yauheni Kaliuta) [1700846]
- [net] bpf: relax verifier restriction on BPF_MOV | BPF_ALU (Yauheni Kaliuta) [1700846]
- [tools] media: bpf: add bpf function to report mouse movement (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: bpftool: Print bpf_line_info during prog dump (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Add btf_line_info support to libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Refactor and bug fix on the bpf_func_info loading logic (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add unit tests for bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor and bug fix in test_func_type in test_btf.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: Add bpf_line_info support (Yauheni Kaliuta) [1700846]
- [net] net/flow_dissector: correctly cap nhoff and thoff in case of BPF (Yauheni Kaliuta) [1700846]
- [net] selftests/bpf: use thoff instead of nhoff in BPF flow dissector (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: update testcases for BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier remove the rejection on BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: interpreter support BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [s390] s390: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [powerpc] ppc: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [tools] bpf: Expect !info.func_info and insn_off name changes in test_btf/libbpf/bpftool (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h for the name changes in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Change insn_offset to insn_off in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Improve the info.func_info and info.func_info_rec_size behavior (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a command to dump the trace pipe (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: don't allocate BPF JIT programs in module memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add __weak hook for allocating executable memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add per-insn complexity limit (Yauheni Kaliuta) [1700846]
- [net] bpf: improve verifier branch analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: check pending signals while verifying programs (Yauheni Kaliuta) [1700846]
- [tools] selftests: add a test for bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] tools: sync uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: respect size hint to BPF_PROG_TEST_RUN if present (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: seg fault with NULL pointer arg (Yauheni Kaliuta) [1700846]
- [powerpc] bpf: powerpc64: optimize JIT passes for bpf function calls (Yauheni Kaliuta) [1700846]
- [tools] bpf: allow BPF read access to qdisc pkt_len (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix license in README.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix memleak in aux->func_info and aux->btf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: get ifindex from ifname (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: improve xdp1 example (Yauheni Kaliuta) [1700846]
- [tools] bpf: Apply F_NEEDS_EFFICIENT_UNALIGNED_ACCESS to more ACCEPT test cases (Yauheni Kaliuta) [1700846]
- [tools] bpf: Make more use of 'any' alignment in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Adjust F_NEEDS_EFFICIENT_UNALIGNED_ACCESS handling in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_F_ANY_ALIGNMENT (Yauheni Kaliuta) [1700846]
- [tools] bpf: Improve socket lookup reuseport documentation (Yauheni Kaliuta) [1700846]
- [tools] bpf: Support sk lookup in netns with id 0 (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix verifier log string check for bad alignment (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add owner_prog_type and owner_jited to bpftool output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: mark offloaded programs more explicitly in plain output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for new map types (queue and stack) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for bpftool prog (attach|detach) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use "/proc/self/" i.o. crafting links with getpid() (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: use movn/movk/movk sequence to generate kernel addresses (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: make libbpf _GNU_SOURCE friendly (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix a bitfield pretty print issue (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix various lib and testsuite build failures on 32-bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add addition type tests to test_btf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix two test_btf unit test cases (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: check name validity for various types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragment CONFIG_FTRACE_SYSCALLS (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap, add options for msg_pop_data() helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: add msg_pop_data helper to tools (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Document API and ABI conventions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Verify versioned symbols (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add version script for DSO (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Name changing for btf_get_from_id (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: change selftest test_btf for both jit and non-jit (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: support proper non-jit func info (Yauheni Kaliuta) [1700846]
- [arm64] bpf, arm64: fix getting subprog addr from aux for calls (Yauheni Kaliuta) [1700846]
- [net] bpf, ppc64: generalize fetching subprog into bpf_jit_get_func_addr (Yauheni Kaliuta) [1700846]
- [tools] bpf: align map type names formatting (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix spelling mistake "Memmber" -> "Member" (Yauheni Kaliuta) [1700846]
- [net] bpf, tags: Fix DEFINE_PER_CPU expansion (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_MAP_TYPE_QUEUE and BPF_MAP_TYPE_STACK to bpftool-map (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: error handling regarding kprobe_events (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make bpf_object__open default to UNSPEC (Yauheni Kaliuta) [1700846]
- [tools] bpf: add skb->tstamp r/w access from tc clsact and cg skb progs (Yauheni Kaliuta) [1700846]
- [net] bpf: fix integer overflow in queue_stack_map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix spelling mistake "memeory" -> "memory" (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: make longest_prefix_match() faster (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding tests for map_in_map helpber in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding support for map in map in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: don't specify prog name if kernel doesn't support it (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: remove map name retry from bpf_create_map_xattr (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: introduce bpf_object__probe_caps to test BPF capabilities (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make sure bpf headers are c++ include-able (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix a libbpf loader issue (Yauheni Kaliuta) [1700846]
- [include] bpf: fix a compilation error when CONFIG_BPF_SYSCALL is not defined (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add support for func types (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: enhance test_btf file testing to test func info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: refactor to implement btf_get_from_id() in lib/bpf (Yauheni Kaliuta) [1700846]
- [samples] tools/bpf: do not use pahole if clang/llvm can generate BTF sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add support to read .BTF.ext sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: extends test_btf to test load/retrieve func_type info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add new fields for program load in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h header to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce bpf_func_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Add tests for BTF_KIND_FUNC_PROTO and BTF_KIND_FUNC (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Sync kernel btf.h header (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Add BTF_KIND_FUNC and BTF_KIND_FUNC_PROTO (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Break up btf_type_is_void() (Yauheni Kaliuta) [1700846]
- [tools] tools: add selftest for BPF_F_ZERO_SEED (Yauheni Kaliuta) [1700846]
- [tools] tools: sync linux/bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: move BPF_F_QUERY_EFFECTIVE after map flags (Yauheni Kaliuta) [1700846]
- [net] bpf: allow zero-initializing hash map seed (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry map creation without the name (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate local storage buffers using GFP_ATOMIC (Yauheni Kaliuta) [1700846]
- [net] bpf: fix off-by-one error in adjust_subprog_starts (Yauheni Kaliuta) [1700846]
- [net] bpf: fix null pointer dereference on pointer offload (Yauheni Kaliuta) [1700846]
- [tools] bpftool: make libbfd optional (Yauheni Kaliuta) [1700846]
- [net] net/bpf: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [powerpc] net/bpf_jit: PPC: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [net] net/skbuff: add macros for VLAN_PRESENT bit (Yauheni Kaliuta) [1700846]
- [tools] selftest/bpf: Use bpf_sk_lookup_{tcp, udp} in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Support socket lookup in CGROUP_SOCK_ADDR progs (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte order in bpf_sk_lookup_udp (Yauheni Kaliuta) [1700846]
- [net] bpf: Extend the sk_lookup() helper to XDP hookpoint (Yauheni Kaliuta) [1700846]
- [net] bpf: helper to pop data from messages (Yauheni Kaliuta) [1700846]
- [net] bpf: fix wrong helper enablement in cgroup local storage (Yauheni Kaliuta) [1700846]
- [include] bpf: sk_msg program helper bpf_msg_push_data (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte-order in bpf_sk_lookup (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow sk_lookup with IPv6 module (Yauheni Kaliuta) [1700846]
- [net] net: core: Fix build with CONFIG_IPV6=m (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix dev pointer dereference from sk_skb (Yauheni Kaliuta) [1700846]
- [net] bpf: fix building without CONFIG_INET (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Fix bpf_program__next() API (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix uninitialized duration warning (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 for bpf_sock_addr (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow narrow loads with offset > 0 (Yauheni Kaliuta) [1700846]
- [tools] bpftool: support loading flow dissector (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add pinmaps argument to the load/loadall (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add loadall command (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add internal pin_name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: bpf_program__pin: add special case for instances.nr == 1 (Yauheni Kaliuta) [1700846]
- [tools] libbpf: cleanup after partial failure in bpf_object__pin (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: rename flow dissector section to flow_dissector (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: do not pass netdev to translate() and prepare() offload callbacks (Yauheni Kaliuta) [1700846]
- [net] bpf: pass prog instead of env to bpf_prog_offload_verifier_prep() (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass destroy() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [include] bpf: pass translate() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: call verifier_prep from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call finalize() from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call verify_insn from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass a struct with offload callbacks to bpf_offload_dev_create() (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary when it exists (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Improve handling of ENOENT on map dumps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a test case for sock_ops perf-event notification (Yauheni Kaliuta) [1700846]
- [net] bpf: add perf event notificaton support for sock_ops (Yauheni Kaliuta) [1700846]
- [net] bpf: let verifier to calculate and record max_pkt_offset (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: update references to other man pages in documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: pass an argument to silence open_obj_pinned() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix plain output and doc for --bpffs option (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: prevent infinite loop in get_fdinfo() (Yauheni Kaliuta) [1700846]
- [samples] bpf_load: add map name to load_maps error message (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: adjust rlimit RLIMIT_MEMLOCK when loading programs, maps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: enable (uncomment) all tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_prog_get_info_by_fd to return 0 func_lens for unpriv (Yauheni Kaliuta) [1700846]
- [net] bpf: show main program address and length in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited address in bpf_prog_info->jited_ksyms (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited prog address in /proc/kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: test make sure to run unpriv test cases in test_verifier (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: don't set id on after map lookup with ptr_to_map_val return (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix compile error in libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary if it exists (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add unlimited rlimit for flow_dissector_load (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpf_jit_limit knob to restrict unpriv allocations (Yauheni Kaliuta) [1700846]
- [net] bpf: make direct packet write unclone more robust (Yauheni Kaliuta) [1700846]
- [net] bpf: fix leaking uninitialized memory on pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet write into pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix cg_skb types to hint access type in may_access_direct_pkt_data (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet access for flow dissector progs (Yauheni Kaliuta) [1700846]
- [net] bpf: disallow direct packet access for unpriv in cg_skb (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix test suite to enable all unpriv program types (Yauheni Kaliuta) [1700846]
- [net] bpf, btf: fix a missing check bug in btf_parse (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragments BPF_STREAM_PARSER and XDP_SOCKETS (Yauheni Kaliuta) [1700846]
- [net] bpf: devmap: fix wrong interface selection in notifier_call (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix completion for "bpftool map update" (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: print nb of cmds to stdout (not stderr) for batch mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: document restriction on '.' in names to pin in bpffs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix return value comparison for tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: simplify and cleanup perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: avoid retpoline for map push/pop/peek operation (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: remove unneeded flow key in check_helper_mem_access (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: reject xadd on flow key memory (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: fix register type dump in xadd and st (Yauheni Kaliuta) [1700846]
- [net] ulp: remove uid and user_visible members (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap add options to use msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf support for msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] Sync uapi/bpf.h to tools/include (Yauheni Kaliuta) [1700846]
- [net] bpf: add tests for direct packet access from CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [net] bpf: add cg_skb_is_valid_access for BPF_PROG_TYPE_CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: use correct barriers in perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [tools] tools, perf: add and use optimized ring_buffer_{read_head, write_tail} helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add test cases for queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add MAP_LOOKUP_AND_DELETE_ELEM syscall (Yauheni Kaliuta) [1700846]
- [net] bpf: add queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: add ARG_PTR_TO_UNINIT_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf/syscall: allow key to be null in map functions (Yauheni Kaliuta) [1700846]
- [net] bpf: rename stack trace map operations (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use 4 context mode for the NFP disasm (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix file resource leak in load_kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap, add msg_peek tests to test_sockmap (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, support for msg_peek in sk_msg with redirect ingress (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix skmsg recvmsg handler to track size correctly (Yauheni Kaliuta) [1700846]
- [include] bpf: skmsg, improve sk_msg_used_element to work in cork context (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Per-symbol visibility for DSO (Yauheni Kaliuta) [1700846]
- [tools] bpf, tls: add tls header to tools infrastructure (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add map create command (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add flag to allow non-compat map definitions (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add support for attaching programs to maps (Yauheni Kaliuta) [1700846]
- [maintainers] bpf, doc: add maintainers entry to related files (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tls support for testing in test_sockmap (Yauheni Kaliuta) [1700846]
- [net] tls: add bpf support to sk_msg handling (Yauheni Kaliuta) [1700846]
- [net] tls: replace poll implementation with read hook (Yauheni Kaliuta) [1700846]
- [net] tls: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove ulp bits from sockmap (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: enforce sock_owned_by_me upon ulp init and cleanup (Yauheni Kaliuta) [1700846]
- [net] net/tls: Make function get_rec() static (Yauheni Kaliuta) [1700846]
- [net] net/tls: Mark the end in scatterlist table (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed a memory leak during socket close (Yauheni Kaliuta) [1700846]
- [net] net/tls: Removed redundant checks for non-NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Add support for inplace records encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Remove redundant vars from tls record structure (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed race condition in async encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Fix socket mem accounting error under async encryption (Yauheni Kaliuta) [1700846]
- [net] net/tls: Add support for async encryption of records for performance (Yauheni Kaliuta) [1700846]
- [net] tls: Remove dead code in tls_sw_sendmsg (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed return value when tls_complete_pending_work() fails (Yauheni Kaliuta) [1700846]
- [net] bpf: wait for running BPF programs when updating map-in-map (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install script with_addr.sh (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add config fragment LWTUNNEL (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: use proper type and uapi perf_event.h header for libbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add XDP selftests for modifying and popping VLAN headers (Yauheni Kaliuta) [1700846]
- [tools] bpf: make TC vlan bpf_helpers avail to selftests (Yauheni Kaliuta) [1700846]
- [net] net: fix generic XDP to handle if eth header was mangled (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, check bpf_map_lookup_elem access in bpf prog (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, change names of fixup maps (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, print strerror when map lookup error occurs (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, split the function do_dump() (Yauheni Kaliuta) [1700846]
- [net] bpf: return EOPNOTSUPP when map lookup isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: error handling when map_lookup_elem isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix a missing check bug (Yauheni Kaliuta) [1700846]
- [net] bpf: allow offload of programs with BPF-to-BPF function calls (Yauheni Kaliuta) [1700846]
- [net] bpf: add verifier callback to get stack usage info for offloaded progs (Yauheni Kaliuta) [1700846]
- [tools] libbpf: relicense libbpf as LGPL-2.1 OR BSD-2-Clause (Yauheni Kaliuta) [1700846]
- [samples] bpf, tracex3_user: erase "ARRAY_SIZE" redefined (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Use __u32 instead of u32 in bpf_program__load (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Make include guards consistent (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in str_error.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in nlattr.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in libbpf.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Move __dump_nlmsg_t from API to implementation (Yauheni Kaliuta) [1700846]
- [documentation] Documentation: Describe bpf reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add C tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support loading individual progs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Generalize dummy program types (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add helper to retrieve socket in BPF (Yauheni Kaliuta) [1700846]
- [include] bpf: Introduce bpf_skb_ancestor_cgroup_id helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync include/uapi/linux/bpf.h to tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h uapi with tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h uapi to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add reference tracking to verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Macrofy stack state copy (Yauheni Kaliuta) [1700846]
- [include] bpf: Add PTR_TO_SOCKET verifier type (Yauheni Kaliuta) [1700846]
- [net] bpf: Generalize ptr_or_null regs check (Yauheni Kaliuta) [1700846]
- [net] bpf: Reuse canonical string formatter for ctx errs (Yauheni Kaliuta) [1700846]
- [net] bpf: Add iterator for spilled registers (Yauheni Kaliuta) [1700846]
- [net] bpf: don't accept cgroup local storage with zero value size (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: cgroup local storage-based network counters (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: extend the storage test to test per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier per-cpu cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for PERCPU_CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of per-cpu cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce per-cpu cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: rework cgroup storage pointer passing (Yauheni Kaliuta) [1700846]
- [net] bpf: extend cgroup bpf core to allow multiple cgroup storage types (Yauheni Kaliuta) [1700846]
- [net] bpf/test_run: support cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: harden flags check in cgroup_storage_update_elem() (Yauheni Kaliuta) [1700846]
- [net] bpf: permit CGROUP_DEVICE programs accessing helper bpf_get_current_cgroup_id() (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test libbpf_{prog,attach}_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Use libbpf_attach_type_by_name in test_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support sk_skb/stream_{parser, verdict} section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support cgroup_skb/{e,in}gress section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Introduce libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Fix bpftool net output (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for BPF_MAP_TYPE_REUSEPORT_SOCKARRAY maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_maps, only support ESTABLISHED socks (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix transition through disconnect without close (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap only allow ESTABLISHED sock state (Yauheni Kaliuta) [1700846]
- [net] bpf: remove redundant null pointer check before consume_skb (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix compilation failure (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: fix build failure without CONFIG_NET (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix a compilation failure (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: remove duplicated includes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: improve output format for bpftool net (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix bpf_flow.c build (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test bpf flow dissection (Yauheni Kaliuta) [1700846]
- [tools] flow_dissector: implements eBPF parser (Yauheni Kaliuta) [1700846]
- [tools] bpf: support flow dissector in libbpf and bpftool (Yauheni Kaliuta) [1700846]
- [include] flow_dissector: implements flow dissector BPF hook (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix end boundary calculation for type section (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a netlink recv issue (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: support prog array map and map of maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for program array map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add net support (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add more netlink functionalities in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move bpf/lib netlink related functions into a new file (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf/test_progs: do not check errno == 0 (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: fix verifier instability (Yauheni Kaliuta) [1700846]
- [net] bpf: avoid misuse of psock when TCP_ULP_BPF collides with another ULP (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, add xskmap in map types (Yauheni Kaliuta) [1700846]
- [tools] bpf: add selftest for bpf's (set|get)_sockopt for SAVE_SYN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: xdpsock, minor fixes (Yauheni Kaliuta) [1700846]
- [samples] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN sample program (Yauheni Kaliuta) [1700846]
- [net] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN options for bpf_(set|get)sockopt (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add btf percpu map formated dump (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs percpu map pretty print tests in test_btf (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for percpu arraymap/hash/lru_hash (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: display non-spill stack slot types in print_verifier_state (Yauheni Kaliuta) [1700846]
- [tools] bpf: use --cgroup in test_suite if supplied (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap test remove shutdown() calls (Yauheni Kaliuta) [1700846]
- [net] bpf: remove duplicated include from syscall.c (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, decrement copied count correctly in redirect error case (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix psock refcount leak in bpf_tcp_recvmsg (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix potential use after free in bpf_tcp_close (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: return from do_event_pipe() on bad arguments (Yauheni Kaliuta) [1700846]
- [net] bpf: use per htab salt for bucket hash (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: write_space events need to be passed to TCP handler (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock hash count in alloc_sock_hash_elem (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_hash_alloc and reject zero-sized keys (Yauheni Kaliuta) [1700846]
- [net] bpf: fix redirect to map under tail calls (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Support per queue XDP ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add XDP TX and REDIRECT (Yauheni Kaliuta) [1700846]
- [net] xdp: Helpers for disabling napi_direct of xdp_return_frame (Yauheni Kaliuta) [1700846]
- [net] bpf: Make redirect_info accessible from modules (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add ndo_xdp_xmit (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Handle xdp_frames in xdp napi ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Avoid drops by oversized packets when XDP is enabled (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add driver XDP (Yauheni Kaliuta) [1700846]
- [net] net: Export skb_headers_offset_update (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpf selftest test_cgroup_storage failure (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_map_ctx_update_elem race with exist/noexist (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix map elem deletion race with smap_stop_sock (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix leakage of smap_psock_map_entry (Yauheni Kaliuta) [1700846]
- [net] bpf: fix a rcu usage warning in bpf_prog_array_copy_core() (Yauheni Kaliuta) [1700846]
- [tools] bpf: test: fix spelling mistake "REUSEEPORT" -> "REUSEPORT" (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Selftest for bpf_skb_ancestor_cgroup_id (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add cgroup id helpers to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [net] bpf: decouple btf from seq bpf fs dump and enable more maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: Test BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [tools] bpf: test BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor ARRAY_SIZE macro to bpf_util.h (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [net] net: Add ID (if needed) to sock_reuseport and expose reuseport_lock (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs pretty print btf test for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: add pretty print for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs non-array map seq_show issue (Yauheni Kaliuta) [1700846]
- [powerpc] powerpc/Makefiles: Convert ifeq to ifdef where possible (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce update_effective_progs() (Yauheni Kaliuta) [1700846]
- [s390] s390: fix br_r1_trampoline for machines without exrl (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix a typo in map in map test (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix BTF code added twice to different trees (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a cgroup storage test (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce the bpf_get_local_storage() helper function (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: introduce BPF_PTR_TO_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf: extend bpf_prog_array to store pointers to the cgroup storage (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate cgroup storage entries on attaching bpf programs (Yauheni Kaliuta) [1700846]
- [net] bpf: pass a pointer to a cgroup storage using pcpu variable (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce cgroup storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add ability to charge bpf maps memory dynamically (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: MOV64 don't mark dst reg unbounded (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test for get_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add bpf_get_socket_cookie to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Support bpf_get_socket_cookie in more prog types (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdpsock_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdp_fwd_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: add bpf_object__find_program_by_title() (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: handle NULL program gracefully in bpf_program__nth_fd() (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add BTF build flags to Makefile (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: ignore build products (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add Python 3 support to selftests scripts for bpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: fix inconsistent IS_ERR and PTR_ERR (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: remove redundant pointer sg (Yauheni Kaliuta) [1700846]
- [net] bpf: bpf_prog_array_alloc() should return a generic non-rcu pointer (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: don't pass FEATURES_DUMP to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: remove libelf-getphdrnum feature detection (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: test_cgrp2_sock2: fix an off by one (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: ensure that we don't load over MAX_PROGS programs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test case for BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Better verification in test_tcpbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Switch test_tcpbpf_user to cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix const'ness in cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: print map dump and lookup with btf info (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: add btf print functionality (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: export btf types and name by offset from lib (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: build and install man page for eBPF helpers from bpftool/ (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add bash completion for cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: document cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: introduce cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test sys_connect BPF hooks with TFO (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add xdp_sample_pkts example (Yauheni Kaliuta) [1700846]
- [tools] trace_helpers.c: Add helpers to poll multiple perf FDs for events (Yauheni Kaliuta) [1700846]
- [net] bpf: deal with kABI breakage in cgroups (Yauheni Kaliuta) [1700846]
- [netdrv] nfp: bpf: fix static check error through tightening shift amount adjustment (Pablo Cascon) [1663986]
- [netdrv] nfp: disable netpoll on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: validate the return code from dev_queue_xmit() (Pablo Cascon) [1663986]
- [netdrv] nfp: fix simple vNIC mailbox length (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: set higher timeout for flash bundle (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: allow the use of DMA buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: move default buffer handling into its own function (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: use fractional size of the buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: report RJ45 connector in ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ethtool flashing fallback (Pablo Cascon) [1663986]
- [netdrv] nfp: Remove switchdev.h inclusion (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: fix code-gen bug on BPF_ALU | BPF_XOR | BPF_K (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: allow flashing the device via devlink (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: include vendor/product info in serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: use the generic manufacture identifier instead of vendor (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: cmsg: use struct_size() helper (Pablo Cascon) [1663986]
- [netdrv] nfp: Implement ndo_get_port_parent_id() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: complete ALU32 logic shift supports (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: correct the behavior for shifts by zero (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report the running and flashed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: add support for versions command (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report fixed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report driver name and serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: use struct_size() in kzalloc() (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: enable MAC address sharing for offloadable devs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure MAC cleanup on address change (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: add infastructure for non-repr priv data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure deletion of old offloaded MACs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove list infastructure from MAC offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ignore offload of VF and PF repr MAC addresses (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: tidy tunnel related private data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: support multiple memory units for filter offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase cmesg reply timeout (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: optimize codegen for JSET with a constant (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remove the trivial JSET optimization (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: fix cb_ident duplicate in indirect block register (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allow to opt-out of RED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure TCP flags can be placed in IPv6 frame (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Pablo Cascon) [1663986]
- [netdrv] nfp: convert to DEFINE_SHOW_ATTRIBUTE (Pablo Cascon) [1663986]
- [netdrv] nfp: report more info when reconfiguration fails (Pablo Cascon) [1663986]
- [netdrv] nfp: add offset to all TLV parsing errors (Pablo Cascon) [1663986]
- [netdrv] nfp: add offloads on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: add locking around representor changes (Pablo Cascon) [1663986]
- [netdrv] nfp: run don't require Qdiscs on representor netdevs (Pablo Cascon) [1663986]
- [netdrv] nfp: run representor TX locklessly (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid oversized TSO headers with metadata prepend (Pablo Cascon) [1663986]
- [netdrv] nfp: correct descriptor offsets in presence of metadata (Pablo Cascon) [1663986]
- [netdrv] nfp: move queue variable init (Pablo Cascon) [1663986]
- [netdrv] nfp: move temporary variables in nfp_net_tx_complete() (Pablo Cascon) [1663986]
- [netdrv] nfp: copy only the relevant part of the TX descriptor for frags (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: prevent offload if rhashtable insert fails (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: release metadata on offload failure (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add support for more threshold actions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add cls_u32 offload for simple band classification (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add functions to update DSCP -> virtual queue map (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: calculate PRIO map len and check mailbox size (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add GRED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: wrap RED parameters in bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add up bands for sto/non-sto stats (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: switch to extended stats for reading packet/byte counts (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: size threshold table to account for bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: pass band parameter to functions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: map per-band symbols (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: restructure Qdisc handling (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: save RED's parameters (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: reset RED's child based on limit (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: build full Qdisc hierarchy based on graft notifications (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allocate Qdisc child table (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: remember which Qdisc is root (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: track all offload-enabled qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: keep track of all RED thresholds (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: rename qdiscs -> red_qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary code in flow lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove TC egdev offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: offload tunnel decap rules via indirect TC blocks (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase scope of netdev checking functions (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow non repr netdev offload (Pablo Cascon) [1663986]
- [netdrv] nfp: use the new __netdev_tx_sent_queue() BQL optimisation (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: refuse RED offload with harddrop set (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: don't set negative threshold (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: provide more precise info about offload parameter validation (Pablo Cascon) [1663986]
- [netdrv] nfp: parse vNIC TLV capabilities at alloc time (Pablo Cascon) [1663986]
- [netdrv] nfp: pass ctrl_bar pointer to nfp_net_alloc (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: split qdisc offload code into a separate file (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: include geneve as supported offload tunnel type (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use geneve and vxlan helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use the common netdev notifier (Pablo Cascon) [1663986]
- [netdrv] nfp: register a notifier handler in a central location for the device (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: make nfp_fl_lag_changels_event() void (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: don't try to nack device unregister events (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary iteration over devices (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: protect against mis-initializing atomic counters (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink port split support for 1x100G CXP NIC (Pablo Cascon) [1663986]
- [netdrv] nfp: replace long license headers with SPDX (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support pointers to other stack frames for BPF-to-BPF calls (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: account for BPF-to-BPF calls when preparing nfp JIT (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: ignore helper-related checks for BPF calls in nfp verifier (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename nfp_prog->stack_depth as nfp_prog->stack_frame_depth (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow control message sizing for map ops (Pablo Cascon) [1663986]
- [netdrv] nfp: allow apps to request larger MTU on control vNIC (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: parse global BPF ABI version capability (Pablo Cascon) [1663986]
- [netdrv] nfp: warn on experimental TLV types (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ndo_poll_controller (Pablo Cascon) [1663986]
- [netdrv] nfp: replace spin_lock_bh with spin_lock in tasklet callback (Pablo Cascon) [1663986]
- [netdrv] nfp: separate VXLAN and GRE feature handling (Pablo Cascon) [1663986]
- [netdrv] nfp: validate rtsym accesses fall within the symbol (Pablo Cascon) [1663986]
- [netdrv] nfp: prefix rtsym error messages with symbol name (Pablo Cascon) [1663986]
- [netdrv] nfp: fix readq on absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: make RTsym users handle absolute symbols correctly (Pablo Cascon) [1663986]
- [netdrv] nfp: support access to absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: convert all RTsym users to use new read/write helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: convert existing RTsym helpers to full target decoding (Pablo Cascon) [1663986]
- [netdrv] nfp: pass cpp_id to nfp_cpp_map_area() (Pablo Cascon) [1663986]
- [netdrv] nfp: add RTsym access helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: add basic errors messages to target logic (Pablo Cascon) [1663986]
- [netdrv] nfp: save the MU locality field offset (Pablo Cascon) [1663986]
- [netdrv] nfp: refactor the per-chip PCIe config (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for NFP5000 (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: look up MAC addresses via management FW (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for indirect HWinfo lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: interpret extended FW load result codes (Pablo Cascon) [1663986]
- [netdrv] nfp: attempt FW load from flash (Pablo Cascon) [1663986]
- [netdrv] nfp: encapsulate NSP command arguments into structs (Pablo Cascon) [1663986]
- [netdrv] nfp: clean up return types in kdoc comments (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow matching on ipv4 UDP tunnel tos and ttl (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: xdp_adjust_tail support (Pablo Cascon) [1663986]
- [netdrv] nfp: fix variable dereferenced before check in nfp_app_ctrl_rx_raw() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: improve map offload info messages (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remember maps by ID (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow receiving perf events on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: pass raw data buffer to nfp_bpf_event_output() (Pablo Cascon) [1663986]
- [netdrv] nfp: allow control message reception on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: move repr handling on RX path (Pablo Cascon) [1663986]
- [netdrv] nfp: protect from theoretical size overflows on HW descriptor ring (Pablo Cascon) [1663986]
- [netdrv] nfp: restore correct ordering of fields in rx ring structure (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow program sharing within ASIC (Pablo Cascon) [1663986]
- [netdrv] nfp: add .ndo_init() and .ndo_uninit() callbacks (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for simultaneous driver and hw XDP (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid using getnstimeofday64() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: migrate to advanced reciprocal divide in reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u32 divide using reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u16 and u32 multiplications (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: copy range info for all operands of all ALU operations (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename umin/umax to umin_src/umax_src (Pablo Cascon) [1663986]
- [netdrv] nfp: make use of napi_consume_skb() (Pablo Cascon) [1663986]
- [netdrv] nfp: implement netpoll ndo (thus enabling netconsole) (Pablo Cascon) [1663986]
- [netdrv] nfp: fail probe if serial or interface id is missing (Pablo Cascon) [1663986]
- [netdrv] nfp: expose ring stats of inactive rings via ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow source ptr type be map ptr in memcpy optimization (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: aggregate offloads per-device (Pablo Cascon) [1663986]
- [tools] selftests/bpf: add test for sharing objects between netdevs (Ivan Vecera) [1708399]
- [netdrv] netdevsim: allow program sharing between devices (Ivan Vecera) [1708399]
- [net] bpf: offload: allow program and map sharing per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: aggregate offloads per-device (Ivan Vecera) [1708399]
- [net] bpf: offload: rename bpf_offload_dev_match() to bpf_offload_prog_map_match() (Ivan Vecera) [1708399]
- [netdrv] netdevsim: associate bound programs with shared dev (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add shared netdevsim devices (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add switch_id attribute (Ivan Vecera) [1708399]

* Wed Jun 12 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-105.el8]
- [infiniband] IB/mlx5: Remove set but not used variable (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: WQE dump jumps over first 16 bytes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix false compilation warning (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Remove redundant assignment (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix compilation warning in en_tc.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix compilation warning in eq.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix the max MTU check in case of XDP (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix use-after-free after xdp_return_frame (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix scatter to CQE in DCT QP creation (Alaa Hleihel) [1691238]
- [netdrv] Revert "net/mlx5e: Enable reporting checksum unnecessary also for L3 packets" (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Rx, Check ip headers sanity (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, idr remove on flow delete (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, hold rcu read lock a bit longer (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Consider tunnel type for encap contexts (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: E-Switch, Fix esw manager vport indication for more vport commands (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Correctly use the namespace type when allocating pedit action (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Allow legacy link-modes configuration via non-extended ptys (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Fix type analysis of advertised link-mode (Alaa Hleihel) [1691238]
- [netdrv] net: mlx5: Add a missing check on idr_find, free buf (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Allow IPv4 ttl & IPv6 hop_limit rewrite for all L4 protocols (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Use mlx5 core to create/destroy a DEVX DCT (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix DCT creation bad flow (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix bad flow upon DEVX mkey creation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Add support for ODP for DEVX indirection mkey (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Manage indirection mkey upon DEVX flow for ODP (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: DEVX handling for indirection MKEY (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix access to non-existing receive queue (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Properly get the PF number phys port name ndo (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Consolidate update FTE for all removal changes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add a locked flag to node removal functions (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add modify FTE helper function (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix multiple updates of steering rules in parallel (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Validate correct PD before prefetch MR (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Introduce and reuse helper to identify ODP MR (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Protect against prefetch of invalid MR (Alaa Hleihel) [1691238]
- [infiniband] net/mlx5: Make mlx5_cmd_exec_cb() a safe API (Alaa Hleihel) [1691238]
- [infiniband] RDMA: Clean structures from CONFIG_INFINIBAND_ON_DEMAND_PAGING (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Embed into the code flow the ODP config option (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Add missing static function annotation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Do not use hw_access_flags for be and CPU data (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix code style issue in mlx driver (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix the locking of SRQ objects in ODP events (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Make mlx5_ib_stage_odp_cleanup() static (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Declare local functions 'static' (Alaa Hleihel) [1691238]
- [netdrv] RDMA/mlx5: Delete declaration of already removed function (Alaa Hleihel) [1691238]
- [netdrv] mlx5-core: Mark ConnectX-6 Dx as unsupported device (Alaa Hleihel) [1691236 1687434]
- [netdrv] net/mlx5: Update the list of the PCI supported devices (Alaa Hleihel) [1691236 1687434]
- [infiniband] IB/mlx5: Fix mapping of link-mode to IB width and speed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: ethtool, Add ethtool support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Add support to ext_* fields introduced in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [include] net/mlx5: Add new fields to Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Refactor queries to speed fields in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Set peer flow needed also for multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Update check for merged eswitch device (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Use hint to resolve route when in HW multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Always query offloaded tc peer rule counter (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Re-attempt to offload flows on multipath port affinity events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Emit port affinity event for multipath offloads (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Allow one failure when offloading tc encap rules under multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't inherit flow flags on peer flow creation (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Activate HW multipath and handle port affinity based on FIB events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Add multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use own workqueue for lag netdev events processing (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Expose lag operations in header file (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use unsigned int bit instead of bool as a struct member (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't make internal use of errno to denote missing neigh (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Cleanup attach encap function (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Remove 'parse_attr' argument in mlx5e_tc_add_fdb_flow() (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Introduce mlx5e_flow_esw_attr_init() helper (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Return the allocated flow directly from __mlx5e_add_fdb_flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix GRE key by controlling port tunnel entropy calculation (Alaa Hleihel) [1691236 1663240]
- [include] net/mlx5: Introduce tunnel entropy control in PCMR register (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Use read-modify-write when changing PCMR register values (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Remove wrong and superfluous tc pedit header type check (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: use flow action infrastructure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: support for two independent packet edit actions (Alaa Hleihel) [1691236]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, fix redirect resources availability check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix a compilation warning in events.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: No command allowed when command interface is not ready (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix NULL pointer derefernce in set channels error flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Don't overwrite pedit action when multiple pedit used (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Update hw flows when encap source mac changed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the inner headers to determine tc/pedit offload limitation on decap flows (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Properly set steering match levels for offloaded TC decap rules (Alaa Hleihel) [1691236 1663207]
- [netdrv] net/mlx5e: Unblock setting vid 0 for VFs through the uplink rep (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move to use common phys port names for vport representors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow MAC invalidation while spoofchk is ON (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Take lock with IRQs disabled to avoid deadlock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong private flag usage causing checksum disable (Alaa Hleihel) [1691236]
- [netdrv] Revert "net/mlx5e: E-Switch, Initialize eswitch only if eswitch manager" (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix flow creation on representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix how advise_mr() launches async work (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix check for supported user flags when creating a QP (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix cb_ident duplicate in indirect block register (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong (zero) TX drop counter indication for representor (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong error code return on FEC query failure (Alaa Hleihel) [1691236]
- [infiniband] Revert "IB/mlx5: Fix long EEH recover time with NVMe offloads" (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC INI usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: drop useless LIST_HEAD (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: fix semicolon.cocci warnings (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Signedness bug in UVERBS_HANDLER() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allocate the per-port Q counter shared when DEVX is supported (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add user control for XDP TX MPWQE feature (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Support Enhanced Multi-Packet TX WQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add array for WQE info descriptors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Maintain a FIFO structure for xdp_info instances (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Replace boolean doorbell indication with segment pointer (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Warn upon polling an error CQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Change the XDP SQ redirect indication (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Precede XDP-related operations in RQ poll by a loaded program check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: TX, Print opcode in error CQE warning (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix wrong error unwind (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix long EEH recover time with NVMe offloads (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Simplify netdev unbinding (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the correct commands for UMEM and UCTX allocation (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix LAG requirement when CONFIG_MLX5_ESWITCH is off (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix query_nic_sys_image_guid() error during init (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support tunnel encap over tagged Ethernet (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Support VLAN encap ETH header generation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Re-order route and encap header memory allocation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Tunnel encap ETH header helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC encap flows with vlan on underlay (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Tunnel routing output devs helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC flows with egress upper devices (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow vlans on e-switch uplink reps (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Increase VF representors' SQ size to 128 (Alaa Hleihel) [1691236]
- [netdrv] mlx5: extend PTP gettime function to read system clock (Alaa Hleihel) [1691236]
- [netdrv] mlx5: update timecounter at least twice per counter overflow (Alaa Hleihel) [1691236]
- [include] IB/mlx5: Introduce uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: ethernet: mellanox: use skb_sec_path helper (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix compile issue when ODP disabled (Alaa Hleihel) [1691236]
- [include] net/mlx5: Add shared Q counter bits (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add advise_mr() support (Alaa Hleihel) [1691236 1663248]
- [infiniband] IB/uverbs: Add helper to get array size from ptr attribute (Alaa Hleihel) [1691236 1663248]
- [infiniband] RDMA/mlx5: Fix function name typo 'fileds' -> 'fields' (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Delete unreachable handle_atomic code by simplifying SW completion (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Continue driver initialization despite debugfs failure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Add some ethtool port control entries to the uplink rep netdev (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Expose ethtool pause and link functions to mlx5e callers (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Add sriov and udp tunnel ndo support for the uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Handle port mtu/link, dcb and lag for uplink reps (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Uninstantiate esw manager vport netdev on switchdev mode (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Remove leftover code from the PF netdev being uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use dedicated uplink vport netdev representor (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use single argument for the esw representor build params helper (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5: E-Switch, Remove redundant reloading of the IB interface (Alaa Hleihel) [1691236 1663256 1663207]
- [netdrv] net/mlx5: Handle LAG FW commands failure gracefully (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Make RoCE and SR-IOV LAG modes explicit (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Rename mlx5_lag_is_bonded() to __mlx5_lag_is_active() (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow co-enablement of uplink LAG and SRIOV (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow/disallow LAG according to pre-req only (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Adjustments for the activate LAG logic to run under sriov (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Duplicate offloaded TC eswitch rules under uplink LAG (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Offload TC e-switch rules with egress LAG device (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: In case of LAG, one switch parent id is used for all representors (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Enhance flow counter scheme for offloaded TC eswitch rules (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Infrastructure for duplicated offloading of TC flows (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5e: E-Switch, Add peer miss rules (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5: Introduce inter-device communication mechanism (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Fold the modify lag code into function (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Add lag affinity info to log (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Split the activate lag function into two routines (Alaa Hleihel) [1691236 1663230]
- [include] net/mlx5: E-Switch, Introduce flow counter affinity (Alaa Hleihel) [1691236 1663230]
- [infiniband] IB/mlx5: Unify e-switch representors load approach between uplink and VFs (Alaa Hleihel) [1691236]
- [include] net/mlx5: Use lowercase 'X' for hex values (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove set but not used variable 'upriv' (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove duplicated include from eswitch.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use monitor counters for update stats (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Monitor counters commands support (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Avoid query PPCNT register if not supported by the device (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use CQE padding for Ethernet CQs (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support multiple encapsulations for a TC flow (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Allow association of a flow to multiple encaps (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Change parse attr struct to accommodate multiple tunnel infos (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Support header rewrite actions with remote port mirroring (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Replace the split logic with extended destination (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Annul encap action ordering requirement (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Move flow attr reformat action bit to per dest flags (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Refactor eswitch flow attr for destination specific properties (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: E-Switch, Rename esw attr mirror count field (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: Consider encapsulation properties when comparing destinations (Alaa Hleihel) [1691236 1663239]
- [infiniband] RDMA/mlx5: Fail early if user tries to create flows on IB representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Remove duplicated include from mlx5_ib.h (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add 2X width support to query_port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add HDR speed support to query port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Report CapabilityMask2 in ib_query_port (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Add GRE protocol offloading (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Move TC tunnel offloading code to separate source file (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Branch according to classified tunnel type (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel decap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel encap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Replace egdev with indirect block notifications (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Propagate the filter's net device to mlx5e structures (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Provide the TC filter netdev as parameter to flower callbacks (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Support TC indirect block notifications for eswitch uplink reprs (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Store eswitch uplink representor state on a dedicated struct (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Remove the get protocol device interface entry (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Support extended destination format in flow steering command (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5: E-Switch, Change vhca id valid bool field to bit flag (Alaa Hleihel) [1691236 1663239 1663207]
- [include] net/mlx5: Introduce extended destination fields (Alaa Hleihel) [1691236 1663239]
- [infiniband] net/mlx5: Revise gre and nvgre key formats (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Add monitor commands layout and event data (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for plugged-disabled cable status in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for PCIe power slot exceeded error in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Rework handling of port module events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Move flow counters data structures from flow steering header (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: When fetching CQEs return CQE instead of void pointer (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Report packet based credit mode device capability (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add packet based credit mode support (Alaa Hleihel) [1691236]
- [include] net/mlx5: Expose packet based credit mode (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable TX on a DEVX flow table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Improve ethtool private-flags code structure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: ethtool, Support user configuration for RX hash fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move RSS params to a dedicated struct (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Refactor TIR configuration function (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move modify tirs hash functionality (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Cleanup unused defines (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove trailing space of tx_pause ethtool counter name (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Update the supported DEVX commands (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enforce DEVX privilege by firmware (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable modify and query verbs objects via DEVX (Alaa Hleihel) [1691236]
- [include] net/mlx5: Update mlx5_ifc with DEVX UCTX capabilities bits (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold modify RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold create RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Initialize SRQ tables on mlx5_ib (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Update SRQ functions signatures to mlx5_ib format (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use stages for callback to setup and release DEVX (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Remove SRQ signature global flag (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Move SRQ functions to RDMA part (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove references to local mlx5_core functions (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove not-used lib/eq.h header file (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove dead transobj code (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Align SRQ licenses and copyright information (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Debug print for forwarded async events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward SRQ resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward QP/WorkQueues resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove all deprecated software versions of FW events (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw delay drop general event (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow forwarding event type general event as is (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw port change event rather than the software version (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove unused events callback and logic (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward all mlx5 events to mlx5 notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow port change event to be forwarded to driver notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Driver events notifier API (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented QP's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented SRQ's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Attach a DEVX counter via raw flow creation (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Improve core device events handling (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Device events, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CQ ERR, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Resource tables, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CmdIF, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWPage, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: E-Switch, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Clock, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FPGA, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWTrace, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Introduce atomic notifier chain subscription API (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use the uapi disablement APIs instead of code (Alaa Hleihel) [1691236]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Alaa Hleihel) [1691236]
- [netdrv] mlx5: use skb_vlan_tag_get_prio() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow modify AV in DCI QP to RTR (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Make EQE access methods inline (Alaa Hleihel) [1691236]
- [netdrv] {net, IB}/mlx5: Move Page fault EQ and ODP logic to RDMA (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Generic EQ (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Different EQ types (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Privatize eq_table and friends (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, irq_info and rmap belong to eq_table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Create all EQs in one place (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Move all EQ logic to eq.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove redundant completion EQ list lock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, No need to store eq index as a field (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove unused fields and structures (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Use the right place to store/read IRQ affinity hint (Alaa Hleihel) [1691236]
- [include] net/mlx5: Fix offsets of ifc reserved fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove the false indication of software timestamping support (Alaa Hleihel) [1691234 1647734]
- [netdrv] net/mlx5: Typo fix in del_sw_hw_rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: RX, Fix wrong early return in receive queue poll (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Cancel DIM work on close SQ (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Remove unused UDP GSO remaining counter (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid encap flows deletion attempt the 1st time a neigh is resolved (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Properly initialize flow attributes for slow path eswitch rule deletion (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid overriding the user provided priority for offloaded tc rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Err if asked to mirror a goto chain tc eswitch rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix default amount of channels for VF representors (Alaa Hleihel) [1691234]
- [include] net/mlx5: E-Switch, Fix fdb cap bits swap (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Block DEVX umem from the non applicable cases (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Fix XRC QP support after introducing extended atomic (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix failing ethtool query on FEC query error (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix wrong field name in FEC related functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix a bug in turning off FEC policy in unsupported speeds (Alaa Hleihel) [1691234]
- [include] net/mlx5: Fix XRC SRQ umem valid bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Allocate enough space for the FDB sub-namespaces (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Added 'raw_errors_laneX' fields to ethtool statistics (Alaa Hleihel) [1691234]
- [include] net/mlx5: Added "per_lane_error_counters" cap bit to PCAM (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool driver callback for query/set FEC policy (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add port FEC get/set functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add FEC fields to Port Phy Link Mode (PPLM) reg (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Remove counter from idr after removing it from list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Take fs_counters dellist before addlist (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Refactor fragmented buffer struct fields and init flow (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Support offloading tc priorities and chains for eswitch flows (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Use a slow path rule instead if vxlan neighbour isn't available (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Enable setting goto slow path chain action (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid duplicated code for tc offloads add/del fdb rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: For TC offloads, always add new flow instead of appending the actions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add a no-append flow insertion mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Add chains and priorities (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Have explicit API to delete fwd rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Split FDB fast path prio to multiple namespaces (Alaa Hleihel) [1691234]
- [include] net/mlx5: Add cap bits for multi fdb encap (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Split TC add rule path for nic vs e-switch (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change return type of tc add flow functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Use flow counter IDs and not the wrapping cache object (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Get counters for offloaded flows from callers (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Add support for extended atomic operations (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Allow scatter to CQE without global signaled WRs (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify that driver supports user flags (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Support scatter to CQE for DC transport type (Alaa Hleihel) [1691234]
- [include] net/mlx5: Expose DC scatter to CQE capability bit (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Add support for flow tag to raw create flow (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify DEVX object type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add new counter for aRFS rule insertion failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add extack messages for TC offload failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: E-Switch, Add extack messages to devlink callbacks (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Allow reporting of checksum unnecessary (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable reporting checksum unnecessary also for L3 packets (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add ethtool control of ring params to VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable multi-queue and RSS for VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose ethtool rss key size / indirection table functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose function for building RSS params (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Provide explicit directive if to create inner indirect tirs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Provide flow dest when creating vport rx rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Extract creation of rep's default flow rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable stateless offloads for VF representor netdevs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change VF representors' RQ type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool steering, Support masks for l3/l4 filters (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX on IB (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Manage device uid for DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Expose RAW QP device handles to user space (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set valid umem bit on DEVX (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of XRCD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of CQ creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid upon PD allocation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIS commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIR commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of MCG commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of QP creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Use uid as part of PD commands (Alaa Hleihel) [1691234]
- [include] net/mlx5: Update mlx5_ifc with DEVX UID bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of QP commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of CQ commands (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Enable vport loopback when user context or QP mandate (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating RAW ethernet QP with loopback support (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Refactor transport domain bookkeeping logic (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Rename incorrect naming in IFC file (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Use rdma_user_mmap_io (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating a matcher for a NIC TX flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX namespace when getting a flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add flow actions support to raw create flow (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor raw flow creation (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Don't overwrite action if already set (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor flow action parsing to be more generic (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching packet reformat action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable reformat on NIC RX if supported (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching DECAP action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable decap and packet reformat on flow tables (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching modify header to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX steering support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5e: Replace PTP clock lock from RW lock to seq lock (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Move Q counters allocation and drop RQ to init_rx (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add flow counters idr (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Store flow counters in a list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add new list to store deleted flow counters (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Change flow counters addlist type to single linked list (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Extend packet reformat verbs (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add new flow action verb - packet reformat (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add a new flow action verb - modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export packet reformat alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Pass a namespace for packet reformat ID allocation (Alaa Hleihel) [1691234 1663215]
- [include] net/mlx5: Expose new packet reformat capabilities (Alaa Hleihel) [1691234 1663215]
- [netdrv] {net, RDMA}/mlx5: Rename encap to reformat packet (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Move header encap type to IFC header file (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Break encap/decap into two separated flow table creation flags (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add support for more namespaces when allocating modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export modify header alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add proper NIC TX steering flow tables support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Cleanup flow namespace getter switch logic (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Change TX affinity assignment in RoCE LAG mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add memic command opcode to command checker (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Destroy the DEVX object upon error flow (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, Read capabilities only when it is safe (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, fix udp source port value (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Improve argument name for add flow API (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, l4 proto support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, ip6 support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow parsing refactoring (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow validation refactoring (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Unexport functions that need not be exported (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Remove unused mlx5_query_vport_admin_state (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: E-Switch, Remove unused argument when creating legacy FDB (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Rename modify/query_vport state related enums (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Mark expected switch fall-throughs (Alaa Hleihel) [1691231]
- [netdrv] mellanox: fix the dport endianness in call of __inet6_lookup_established() (Alaa Hleihel) [1691231]
- [netdrv] mlx5: handle DMA mapping error case for XDP redirect (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Issue direct lookup on vxlan ports by vport representors (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Use function to access sq_dma object in fifo (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Move DB fields in TXQ-SQ struct (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add support for XDP_REDIRECT in device-out side (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Re-order fields of struct mlx5e_xdpsq (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Refactor XDP counters (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Make XDP xmit functions more generic (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add counter for XDP redirect in RX (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Enable driver uapi commands for flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for a flow table destination for driver flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support adding flow steering rule by raw description (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce driver create and destroy flow methods (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add support for flow table destination number (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add forward compatible support for the FTE match data (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Support offloading double vlan push/pop tc actions (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Refactor tc vlan push/pop actions offloading (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Support offloading tc double vlan headers match (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: FW tracer, Add debug prints (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, Enable tracing (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, parse traces and kernel tracing support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, events handling (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, register log buffer memory key (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, create trace buffer and copy strings database (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, implement tracer logic (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove set but not used variables (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add XRQ commands definitions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add core support for double vlan push/pop steering action (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: Expose MPEGC (Management PCIe General Configuration) structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, add hardware structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: fix an unused-function warning (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: IPsec, fix byte count in CQE (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add common metadata functions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, build TLS netdev from capabilities (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add software statistics (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add Innova TLS rx data path (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add innova rx support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add TLS rx offload routines (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, refactor variable names (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Check that supplied blue flame index doesn't overflow (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Melt consecutive calls to alloc_bfreg() in one call (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Use 2-factor allocator calls (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove unused port number parameter (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose dump and fill memory key (Alaa Hleihel) [1691231]
- [include] net/mlx5: Add hardware definitions for dump_fill_mkey (Alaa Hleihel) [1691231]
- [infiniband] net/mlx5: Limit scope of dump_fill_mkey function (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for drain SQ & RQ (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support RoCE ICRC encapsulated error counter (Alaa Hleihel) [1691231 1663195]
- [include] net/mlx5: Add RoCE RX ICRC encapsulated counter (Alaa Hleihel) [1691231 1663195]
- [infiniband] RDMA/mlx5: Refactor transport domain checks (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose DEVX tree (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX query EQN support (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for memory registration (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX query UAR (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for modify and query commands (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add obj create and destroy functionality (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX general command (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Introduce DEVX (Alaa Hleihel) [1691231 1663190]
- [netdrv] net/mlx5: Expose DEVX specification (Alaa Hleihel) [1691231]

* Tue Jun 11 2019 Frantisek Hrbata <fhrbata@redhat.com> [4.18.0-104.el8]
- [virt] kvm: arm/arm64: Don't emulate virtual timers on userspace ioctls (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Remove unused timer variable (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Rework the timer code to use a timer_map (Andrew Jones) [1716066]
- [powerpc] powernv: Fix compile without CONFIG_TRACEPOINTS (David Gibson) [1524674]
- [virt] kvm: ppc: book3s: Remove useless checks in 'release' method of KVM device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Clear escalation interrupt pointers on device close (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Prevent races when releasing device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Replace the 'destroy' method by a 'release' method (David Gibson) [1524674]
- [virt] kvm: Introduce a 'release' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Activate XIVE exploitation mode (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add passthrough support (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a mapping for the source ESB pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a TIMA mapping (David Gibson) [1524674]
- [virt] kvm: Introduce a 'mmap' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add get/set accessors for the VP XIVE state (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to dirty the XIVE EQ pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to sync the sources (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a global reset control (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add controls for the EQ configuration (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to configure a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: add a control to initialize a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Introduce a new capability KVM_CAP_PPC_IRQ_XIVE (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: Add a new KVM device for the XIVE native exploitation mode (David Gibson) [1524674]
- [powerpc] xive: add OPAL extensions for the XIVE native exploitation support (David Gibson) [1524674]
- [powerpc] powernv: move OPAL call wrapper tracing and interrupt handling to C (David Gibson) [1524674]
- [thermal] thermal/intel_powerclamp: fix truncated kthread name (Lihong Yang) [1716810]
- [kernel] kernel/signal.c: trace_signal_deliver when signal_group_exit (Waiman Long) [1548279]
- [kernel] signal: unconditionally leave the frozen state in ptrace_stop() (Waiman Long) [1548279]
- [kernel] cgroup: never call do_group_exit() with task->frozen bit set (Waiman Long) [1548279]
- [kernel] kernel: cgroup: fix misuse of x (Waiman Long) [1548279]
- [kernel] cgroup: get rid of cgroup_freezer_frozen_exit() (Waiman Long) [1548279]
- [kernel] cgroup: prevent spurious transition into non-frozen state (Waiman Long) [1548279]
- [kernel] cgroup: Remove unused cgrp variable (Waiman Long) [1548279]
- [documentation] cgroup: document cgroup v2 freezer interface (Waiman Long) [1548279]
- [kernel] cgroup: add tracing points for cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: make TRACE_CGROUP_PATH irq-safe (Waiman Long) [1548279]
- [tools] kselftests: cgroup: don't fail on cg_kill_all() error in cg_destroy() (Waiman Long) [1548279]
- [kernel] cgroup: cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: protect cgroup->nr_(dying_)descendants by css_set_lock (Waiman Long) [1548279]
- [kernel] cgroup: implement __cgroup_task_count() helper (Waiman Long) [1548279]
- [kernel] cgroup: rename freezer.c into legacy_freezer.c (Waiman Long) [1548279]
- [kernel] cgroup: remove extra cgroup_migrate_finish() call (Waiman Long) [1548279]
- [kernel] cgroup/cpuset: Update stale generate_sched_domains() comments (Waiman Long) [1548279]
- [kernel] cgroup: saner refcounting for cgroup_root (Waiman Long) [1548279]
- [fs] fix cgroup_do_mount() handling of failure exits (Waiman Long) [1548279]
- [kernel] cgroup: Add named hierarchy disabling to cgroup_no_v1 boot param (Waiman Long) [1548279]
- [kernel] cgroup: fix parsing empty mount option string (Waiman Long) [1548279]
- [kernel] cgroup: fix CSS_TASK_ITER_PROCS (Waiman Long) [1548279]
- [kernel] cgroup: Fix dom_cgrp propagation when enabling threaded mode (Waiman Long) [1548279]
- [lib] lib: objagg: fix handling of object with 0 users when assembling hints (Ivan Vecera) [1704850]
- [lib] test_objagg: Uninitialized variable in error handling (Ivan Vecera) [1704850]
- [lib] test_objagg: Test the correct variable (Ivan Vecera) [1704850]
- [lib] lib: objagg: Fix an error code in objagg_hints_get() (Ivan Vecera) [1704850]
- [lib] lib: objagg: add root count to stats (Ivan Vecera) [1704850]
- [lib] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1704850]
- [lib] lib: objagg: fix typo in objagg_stats_put() docstring (Ivan Vecera) [1704850]
- [lib] lib: introduce initial implementation of object aggregation manager (Ivan Vecera) [1704850]
- [netdrv] ibmvnic: Fix unchecked return codes of memory allocations (Steve Best) [1718919]
- [netdrv] ibmvnic: Refresh device multicast list after reset (Steve Best) [1718919]
- [netdrv] ibmvnic: Do not close unopened driver during reset (Steve Best) [1718919]
- [target] scsi: target: tcmu: Switch to bitmap_zalloc() (Maurizio Lombardi) [1712917]
- [target] scsi: target: tcmu: wait for nl reply only if there are listeners or during an add (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_handle_text_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_dump_data_payload() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Avoid iscsit_release_commands_from_conn() deadlock (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Rename a function and a function pointer (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Fix spelling of "unsolicited" (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Convert comments about locking into runtime checks (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Remove an incorrect comment (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Add target_send_busy() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Inline transport_lun_remove_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the LUN RESET implementation (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove several state tests from the TMF code (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the write_pending_status() callback function (Maurizio Lombardi) [1712917]
- [target] scsi: target: make the pi_prot_format ConfigFS path readable (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: fix use after free (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: avoid cmd/qfull timers updated whenever a new cmd comes (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: fix error msg typo when create lio_qr_cache failed (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kmem_cache_free() instead of kfree() (Maurizio Lombardi) [1712917]
- [target] scsi: target: perform t10_wwn ID initialisation in target_alloc_device() (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove hardcoded T10 Vendor ID in INQUIRY response (Maurizio Lombardi) [1712917]
- [target] scsi: target: add device vendor_id configfs attribute (Maurizio Lombardi) [1712917]
- [target] scsi: target: consistently null-terminate t10_wwn strings (Maurizio Lombardi) [1712917]
- [target] scsi: target: use consistent left-aligned ASCII INQUIRY data (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Reduce the amount of code executed with a spinlock held (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make ABORT and LUN RESET handling synchronous (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix TAS handling for aborted commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the code for aborting SCSI commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make it possible to wait from more than one context for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use system workqueues for TMF (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make sure that target_wait_for_sess_cmds() waits long enough (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix target_wait_for_sess_cmds breakage with active signals (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify transport_clear_lun_ref() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kvcalloc() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcmu: Fix queue_cmd_ring() declaration (Maurizio Lombardi) [1712917]
- [target] scsi: target: replace fabric_ops.name with fabric_alias (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unnecessary get_fabric_name() accessor from fabric_ops (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unused pi_prot_format attribute storage (Maurizio Lombardi) [1712917]
- [target] scsi: target: add emulate_pr backstore attr to toggle PR support (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Avoid that a kernel oops is triggered when COMPARE AND WRITE fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: Don't request modules that aren't even built (Maurizio Lombardi) [1712917]
- [target] scsi: target: Set response length for REPORT TARGET PORT GROUPS (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Always call transport_complete_callback() upon failure (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use sg_alloc_table() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use the SECTOR_SHIFT constant (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the SCF_COMPARE_AND_WRITE_POST flag (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove an unused data member from struct xcopy_pt_cmd (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix spelling in two source code comments (Maurizio Lombardi) [1712917]
- [target] scsi: target: stash sess_err_stats on Data-Out timeout (Maurizio Lombardi) [1712917]
- [target] scsi: target: split out helper for cxn timeout error stashing (Maurizio Lombardi) [1712917]
- [target] scsi: target: log NOP ping timeouts as errors (Maurizio Lombardi) [1712917]
- [target] scsi: target: log Data-Out timeouts as errors (Maurizio Lombardi) [1712917]
- [include] scsi: target: use ISCSI_IQN_LEN in iscsi_target_stat (Maurizio Lombardi) [1712917]
- [target] scsi: target: iblock: split T10 PI SGL across command bios (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: fix spelling mistake "entires" -> "entries" (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Fix conn_ops double free (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Set conn->sess to NULL when iscsi_login_set_conn_values fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: loop, usb, vhost, xen: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: tcm_fc: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: target: make transport_init_session_tags static (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi target: have iscsit_start_nopin_timer call __iscsit_start_nopin_timer (Maurizio Lombardi) [1712917]
- [target] scsi: target: fix __transport_register_session locking (Maurizio Lombardi) [1712917]
- [target] Revert "scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers" (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use u64 for dev_size (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use match_int for dev params (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: do not set max_blocks if data_bitmap has been setup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: unmap if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: check if dev is configured before block/reset (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use lio core se_device configuration helper (Maurizio Lombardi) [1712917]
- [target] scsi: target: add helper to check if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: initialize list head (Maurizio Lombardi) [1712917]
- [target] scsi: target_core_user: fix double unlock (Maurizio Lombardi) [1712917]
- [target] scsi: target: Remove se_dev_entry.ua_count (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix handling of removed LUNs (Maurizio Lombardi) [1712917]
- [target] scsi: target: Send unit attention condition even if the sense buffer is too small (Maurizio Lombardi) [1712917]
- [target] scsi: target: Do not duplicate the code that marks that a command has sense data (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcm_loop: Avoid that static checkers warn about dead code (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify the code for waiting for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (2/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (1/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fold core_tmr_handle_tas_abort() into transport_cmd_finish_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify core_tmr_handle_tas_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Document when CMD_T_STOP and CMD_T_COMPLETE are set (Maurizio Lombardi) [1712917]
- [target] scsi: target: Make the session shutdown code also wait for commands that are being aborted (Maurizio Lombardi) [1712917]
- [target] scsi: target: Introduce transport_init_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Rename transport_init_session() into transport_alloc_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Move a list_del_init() statement (Maurizio Lombardi) [1712917]
- [target] scsi: target: Avoid that EXTENDED COPY commands trigger lock inversion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Use config_item_name() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: Don't pass KERN_ERR to pr_err (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove target_find_device (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: add module wide block/reset_netlink support (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: misc nl code cleanup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: simplify nl interface (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: track nl commands (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: delete unused __wait (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: remove useless code and clean up the code style (Maurizio Lombardi) [1712917]

* Sat Jun 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-103.el8]
- [ipc] ipc: do cyclic id allocation for the ipc object. (Waiman Long) [1710480]
- [ipc] ipc: conserve sequence numbers in ipcmni_extend mode (Waiman Long) [1710480]
- [ipc] ipc: allow boot time extension of IPCMNI from 32k to 16M (Waiman Long) [1710480]
- [ipc] ipc/mqueue: optimize msg_get() (Waiman Long) [1710480]
- [ipc] ipc/mqueue: remove redundant wq task assignment (Waiman Long) [1710480]
- [ipc] ipc: prevent lockup on alloc_msg and free_msg (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for semmni (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for msgmni and shmmni (Waiman Long) [1710480]
- [ipc] ipc/shm.c: use ERR_CAST() for shm_lock() error return (Waiman Long) [1710480]
- [ipc] ipc/shm: properly return EIDRM in shm_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: update return value of ipc_getref from int to bool (Waiman Long) [1710480]
- [ipc] ipc/util.c: further variable name cleanups (Waiman Long) [1710480]
- [ipc] ipc: simplify ipc initialization (Waiman Long) [1710480]
- [ipc] ipc: get rid of ids->tables_initialized hack (Waiman Long) [1710480]
- [lib] lib/rhashtable: guarantee initial hashtable allocation (Waiman Long) [1710480]
- [lib] lib/rhashtable: simplify bucket_table_alloc() (Waiman Long) [1710480]
- [ipc] ipc: drop ipc_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: correct comment in ipc_obtain_object_check (Waiman Long) [1710480]
- [ipc] ipc: rename ipcctl_pre_down_nolock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: use ipc_rcu_putref() for failues in ipc_addid() (Waiman Long) [1710480]
- [ipc] ipc: reorganize initialization of kern_ipc_perm.seq (Waiman Long) [1710480]
- [ipc] ipc: compute kern_ipc_perm.id under the ipc lock (Waiman Long) [1710480]
- [x86] x86/speculation/mds: Improve CPU buffer clear documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Revert CPU buffer clear on double fault exit (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add 'mitigations=' support for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [s390] s390/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [powerpc] powerpc/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [mm] x86/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kernel] cpu/speculation: Add 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Fix documentation typo (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Correct the possible MDS sysfs values (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/mds: Add MDSUM variant to the MDS documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Print SMT vulnerable on MSBDS with mitigations off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Fix comment (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add SMT warning message (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Move arch_smt_update() call to after mitigation decisions (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds=full,nosmt cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Add MDS vulnerability documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] documentation: Move L1TF to separate directory (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation mode VMWERV (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [base] x86/speculation/mds: Add sysfs reporting for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation control for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Conditionally clear CPU buffers on idle entry (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm/vmx: Add MDS protection when L1D Flush is not active (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Clear CPU buffers on exit to user (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds_clear_cpu_buffers() (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add BUG_MSBDS_ONLY (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add basic bug infrastructure for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Consolidate CPU whitelists (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] x86/msr-index: Cleanup bit defines (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/l1tf: Drop the swap storage limit restriction when l1tf=off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Cast ~SPEC_CTRL_STIBP atomic value to int (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] tools power x86_energy_perf_policy: Override CFLAGS assignments and add LDFLAGS to build command (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [scsi] scsi: qla2xxx: Fix read offset in qla24xx_load_risc_flash() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplify conditional check again (Himanshu Madhani) [1665555]
- [scsi] qla2xxx: Update driver version to 10.01.00.15.08.1-k (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Secure flash update support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add 28xx flash primary/secondary status/image mechanism (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplification of register address used in qla_tmpl.c (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correction and improvement to fwdt processing (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Update flash read/write routine (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add support for multiple fwdump templates/segments (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Cleanups for NVRAM/Flash read/write path (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correctly report max/min supported speeds (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Serdes support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Device ID for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Fix routine qla27xx_dump_{mpi|ram}() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Remove FW default template (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add fw_attr and port_no SysFS node (Himanshu Madhani) [1665555]
- [netdrv] e1000e: Disable runtime PM on CNP+ (David Arcari) [1659179]
- [netdrv] intel: correct return from set features callback (David Arcari) [1659179]
- [netdrv] e1000e: Fix -Wformat-truncation warnings (David Arcari) [1659179]
- [netdrv] e1000e: fix cyclic resets at link up with active tx (David Arcari) [1659179]
- [netdrv] e1000e: fix a missing check for return value (David Arcari) [1659179]
- [netdrv] e1000e: Exclude device from suspend direct complete optimization (David Arcari) [1659179]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (David Arcari) [1659179]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1659179]
- [netdrv] e1000e: extend PTP gettime function to read system clock (David Arcari) [1659179]
- [netdrv] e1000e: allow non-monotonic SYSTIM readings (David Arcari) [1659179]
- [netdrv] intel-ethernet: use correct module license (David Arcari) [1659179]
- [kernel] sched/cpufreq: Fix kobject memleak (Phil Auld) [1714719]
- [kernel] sched/core: Check quota and period overflow at usec to nsec conversion (Phil Auld) [1714719]
- [kernel] sched/core: Handle overflow in cpu_shares_write_u64 (Phil Auld) [1714719]
- [kernel] sched/rt: Check integer overflow at usec to nsec conversion (Phil Auld) [1714719]
- [base] arch_topology: Make cpu_capacity sysfs node as read-only (Phil Auld) [1714719]
- [x86] sched/x86: Save [ER]FLAGS on context switch (Phil Auld) [1714719]
- [kernel] sched/fair: Remove setting task's se->runnable_weight during PELT update (Phil Auld) [1714719]
- [kernel] sched/fair: Disable LB_BIAS by default (Phil Auld) [1714719]
- [arm64] sched/topology, arch/arm64: Rebuild the sched_domain hierarchy when the CPU capacity changes (Phil Auld) [1714719]
- [base] sched/topology, drivers/base/arch_topology: Rebuild the sched_domain hierarchy when capacities change (Phil Auld) [1714719]
- [kernel] sched/topology: Add SD_ASYM_CPUCAPACITY flag detection (Phil Auld) [1714719]
- [kernel] sched/fair: Fix load_balance redo for !imbalance (Phil Auld) [1714719]
- [tools] cpupower : frequency-set -r option misses the last cpu in related cpu list (Steve Best) [1717841]
- [kernel] Uprobes: Fix kernel oops with delayed_uprobe_remove() (Gustavo Duarte) [1608798]
- [kernel] trace_uprobe/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes: Support SDT markers having reference count (semaphore) (Gustavo Duarte) [1608798]
- [kernel] Uprobe: Additional argument arch_uprobe to uprobe_write_opcode() (Gustavo Duarte) [1608798]
- [kernel] Uprobes: Simplify uprobe_register() body (Gustavo Duarte) [1608798]
- [pci] PCI: Rework pcie_retrain_link() wait loop (Myron Stowe) [1707902]
- [pci] PCI: Work around Pericom PCIe-to-PCI bridge Retrain Link erratum (Myron Stowe) [1707902]
- [pci] PCI: Factor out pcie_retrain_link() function (Myron Stowe) [1707902]
- [tools] selftests/powerpc: Fix strncpy usage (Diego Domingos) [1662372]
- [tools] selftests: Fix test errors related to lib.mk khdr target (Diego Domingos) [1662372]
- [nvme] nvme-fc: use separate work queue to avoid warning (Ewan Milne) [1715135]
- [scsi] scsi: scsi_transport_fc: nvme: display FC-NVMe port roles (Ewan Milne) [1715135]
- [nvme] nvme-fc: correct csn initialization and increments on error (Ewan Milne) [1715135]
- [nvme] nvme-multipath: avoid crash on invalid subsystem cntlid enumeration (Ewan Milne) [1715135]
- [nvme] nvme-multipath: don't print ANA group state by default (Ewan Milne) [1715135]
- [nvme] nvme-multipath: split bios with the ns_head bio_set before submitting (Ewan Milne) [1715135]
- [nvme] nvme-multipath: relax ANA state check (Ewan Milne) [1715135]
- [drm] drm/i915: Bump gen7+ fb size limits to 16kx16k (Lyude Paul) [1664969]
- [drm] drm/i915: Bump fb stride limit to 128KiB for gen4+ and 256KiB for gen7+ (Lyude Paul) [1664969]
- [drm] drm/i915: Align dumb buffer stride to 4k to allow for gtt remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Overcome display engine stride limits via GTT remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Shuffle stride checking code around (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add live vma selftest (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add mock selftest for remapped vmas (Lyude Paul) [1664969]
- [drm] drm/i915: Add a new "remapped" gtt_view (Lyude Paul) [1664969]
- [md] dax: Arrange for dax_supported check to span multiple devices (Jeff Moyer) [1665364]
- [mm] mm/memory_hotplug.c: drop memory device reference after find_memory_block() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Retain security state after overwrite (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/pmem: fix a possible OOB access when read and write pmem (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] libnvdimm/security, acpi/nfit: unify zero-key for all security commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: provide fix for secure-erase to use zero-key (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [mm] mm/memory.c: fix modifying of page protection by insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix a kmemdup failure check (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Fix a potential NULL pointer dereference (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Always dump _DSM output payload (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Deposit pagetable even when installing zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Clean up holder_class_store() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/of_pmem: Fix platform_no_drv_owner.cocci warnings (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Update NFIT flags error message (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix LBA masking during 'free list' population (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Remove unnecessary code in btt_freelist_init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Remove dax_label_reserve (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax: Check the end of the block-device capacity with dax_direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Avoid stale ARS results (Jeff Moyer) [1697175 1665367 1665364 1665362]
- [acpi] nfit/ars: Allow root to busy-poll the ARS state machine (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Introduce scrub_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Remove ars_start_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt short-ARS even in the no_init_ars case (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt a short-ARS whenever the ARS state is idle at boot (Jeff Moyer) [1697194 1665367 1665364 1665362]
- [fs] fs/dax: NIT fix comment regarding start/end vs range (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Convert to use vmf_error() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Require opt-in for read-only label configurations (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pmem: Honor force_raw for legacy pmem regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Account for PAGE_SIZE > info-block-size in nd_pfn_init() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Fix altmap reservation size calculation (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: Fix over-trim in trim_pfn_device() (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [nvdimm] libnvdimm/dimm: Add a no-BLK quirk based on NVDIMM family (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Add Hyper-V NVDIMM DSM command set to white list (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: acpi_nfit_ctl(): Check out_obj->type in the right place (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Fix nfit_intel_shutdown_status() command submission (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm/security: Require nvdimm_security_setup_events() to succeed (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] nfit_test: fix security state pull for nvdimm security nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: Fix nvdimm_security_state() state request selection (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/label: Clear 'updating' flag after label-set update (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Remove duplicate set nd_set in acpi_nfit_init_interleave_set() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id() (Jeff Moyer) [1665367 1665364 1665362]
- [include] libnvdimm/dimm: Fix security capability detection for non-Intel NVDIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] nfit: Mark some functions as __maybe_unused (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] ACPI/nfit: delete the function to_acpi_nfit_desc (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: delete the redundant header file (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: add MEMORY_DEVICE_PRIVATE support (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] mm, devm_memremap_pages: fix shutdown handling (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: kill mapping "System RAM" support (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: mark devm_memremap_pages() EXPORT_SYMBOL_GPL (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/security: Quiet security operations (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [documentation] libnvdimm/security: Add documentation for nvdimm security support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: add Intel DSM 1.8 support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add overwrite support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add test support for Intel nvdimm security DSMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: add Intel DSM 1.8 master passphrase support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: Add security DSM overwrite support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add support for issue secure erase DSM to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add enable/update passphrase support for Intel nvdimms (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add disable passphrase support to Intel nvdimm. (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add unlock of nvdimm support for Intel DIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add freeze security support to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Introduce nvdimm_security_ops (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys-encrypted: add nvdimm key format type to encrypted keys (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys: Export lookup_user_key to external users (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Store dimm id as a member to struct nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm, namespace: Replace kmemdup() with kstrndup() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, label: Switch to bitmap_zalloc() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: Adjust annotation for why return 0 if fail to find NFIT at start (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, bus: Check id immediately following ida_simple_get (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than "ARS-short" (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [nvdimm] libnvdimm, pfn: Pad pfn namespaces relative to other regions (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [tools] tools/testing/nvdimm: Align test resources to 128M (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [acpi] acpi/nfit: Add support for Intel DSM 1.8 commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] Revert "acpi, nfit: Further restrict userspace ARS start requests" (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix ARS overflow continuation (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix the array size for dimm devices. (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [mm] mm: Fix warning in insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Further restrict userspace ARS start requests (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix Address Range Scrub completion tracking (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [tools] tools/testing/nvdimm: Populate dirty shutdown data (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Collect shutdown status (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Introduce nfit_mem flags (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm, label: Fix sparse warning (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, namespace: Drop the repeat assignment for variable dev->parent (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, region: Fail badblocks listing for inactive regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: during init, clear errors in the metadata area (Jeff Moyer) [1665367 1665364 1665362 1641565]
- [nvdimm] libnvdimm: Set device node in nd_device_register (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Hold reference on parent while scheduling async init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: remove duplicate include (Jeff Moyer) [1665367 1665364 1665362]
- [fs] filesystem-dax: Fix use of zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: Restore page attributes when clearing errors (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] device-dax: avoid hang on error before devm_memremap_pages() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: improve emulation of smart injection (Jeff Moyer) [1685043 1665367 1665364 1665362]
- [fs] filesystem-dax: Do not request kaddr and pfn when not required (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax/super: Do not request a pointer kaddr when not required (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: queue issuing of ars when an uc error notification comes in (Jeff Moyer) [1665367 1665364 1665362 1641487]
- [kernel] mm, dev_pagemap: Do not clear ->mapping on final put (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix support for emulating controller temperature (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Make DSM failure code injection an override (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [acpi] acpi, nfit: Prefer _DSM over _LSR for namespace label reads (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [nvdimm] libnvdimm: Introduce locked DIMM capacity support (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [drm] drm/nouveau: fix duplication of nv50_head_atom struct (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/disp/dp: respect sink limits when selecting failsafe link configuration (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: initial support for boards with TU117 chipset (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: allow detected chipset to be overridden (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gf119-gp10x: push HeadSetControlOutputResource() mthd when encoders change (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/nv50-: fix bug preventing non-vsync'd page flips (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gv100-: fix spurious window immediate interlocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/nouveau: forward error generated while resuming objects tree (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/i2c: Disable i2c bus access after ->fini() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add WaDisableBankHangMode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/fbc: disable framebuffer compression on GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix setting 10 bit deep color mode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add missing combo PHY lane power setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Factor out combo PHY lane power setup helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Corrupt DSI picture fix for GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix clockgating issue when using scalers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Suppress spurious combo PHY B warning (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable read only ppgtt support for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use Engine1 instance for gen11 pm interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Disable video turbo mode for rp control (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable media sampler powergate (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: introduce REG_BIT() and REG_GENMASK() to define register contents (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1664615 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Apply a recommended rc6 threshold (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dedicated rc6 enabling sequence for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Don't warn on spurious interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Handle rps interrupts without irq lock (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure we have enough memory bandwidth on ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sandybridge_pcode_read() deal with the second data register (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix ONLY icl+ max plane width (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix MG_DP_MODE() register programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Really calculate the cursor ddb based on the highest enabled wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Inline skl_update_pipe_wm() into its only caller (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass pipe_wm around so much (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Move some variables to tighter scope (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Keep plane watermarks enabled more aggressively (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure cursor has enough ddb for the selected wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Allocate enough DDB for the cursor (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract skl_compute_wm_params() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass plane state to skl_compute_plane_wm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Accept alloc_size == blocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Introduce Comet Lake PCH (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Add CML PCI IDS (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix PSR2 selective update corruption after PSR1 setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off the CUS when turning off a HDR plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix legacy gamma mode for ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Refactor icl_is_hdr_plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] drm/i915: Add new ICL PCI ID (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix CRC mismatch error for DP link layer compliance (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Prevent incorrect DBuf enabling (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Read out memory type (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on cnl+ (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Clean up intel_get_dram_info() a bit (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i914: s/l_info/dimm_l/ etc. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Generalize intel_is_dram_symmetric() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dram_dimm_info more (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on GLK too (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix DRAM size reporting for BXT (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract BXT DIMM helpers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Polish skl_is_16gb_dimm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract functions to derive SKL+ DIMM info (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Store DIMM rank information as a number (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Default to Thread Group preemption for compute workloads (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix the state checker for ICL Y planes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: move MG pll hw_state readout (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Finalize Wa_1408961008:icl (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Call MG_DP_MODE() macro with the right parameters order (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Drop redundant gamma mode mask (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Implement new w/a for underruns with wm1+ disabled (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Include "ignore lines" in skl+ wm state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] Revert "drm/i915: W/A for underruns with WM1+ disabled on icl" (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make MG PHY macros semantically consistent (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make combo PHY DDI macro definitions consistent for ICL and CNL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add degamma and gamma lut size to gen11 caps (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable pipe output csc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable ICL Pipe CSC block (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add icl pipe degamma and gamma support (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/glk: Fix degamma lut programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Dump skl+ watermark changes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Update DSPCNTR gamma/csc bits during crtc_enable() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable pipe gamma when C8 pixel format is used (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe CSC when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe gamma when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe csc enable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe gamma enable/disable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Populate gamma_mode for all platforms (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Main backport to rebase from 4.18 to 5.1 (Lyude Paul) [1713573 1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286] {CVE-2019-11085}
- [include] list: Backport list_is_first() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] lib/scatterlist: Provide a DMA page iterator (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [acpi] ACPI / PMIC: Add support for executing PMIC MIPI sequence elements (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vfio: add edid api for display (vgpu) devices. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm: don't miss the last page because of round-off error (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] PM-runtime: Add new interface to get accounted time (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: move i915_kick_out_vgacon to vgaarb (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [scripts] tracing: Avoid calling cc-option -mrecord-mcount for every Makefile (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb_helper: Allow leaking fbdev smem_start (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb: Stop leaking physical address (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: Add FBINFO_HIDE_SMEM_START flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vt: Remove vc_panic_force_write (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] fbdev: Drop FBINFO_CAN_FORCE_OUTPUT flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: fix kerneldoc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] fbdev: add remove_conflicting_pci_framebuffers() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [media] media: cec-notifier: Get notifier by device and connector name (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] driver core: Add device_link_remove function (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] include: Move ascii85 functions from i915 to linux/ascii85.h (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm, drm/i915: mark pinned shmemfs pages as unevictable (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] list: introduce list_bulk_move_tail helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [fs] sysfs: constify sysfs create/remove files harder (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/selftests: Remove unused dmabuf->kmap routines, fix the build (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma-buf: remove kmap_atomic interface (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] include/linux/bitops.h: introduce BITS_PER_TYPE (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma_buf: remove device parameter from attach callback v2 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [pci] PCI: Export pcie_get_speed_cap and pcie_get_width_cap (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Add support for pps and compression mode command packet (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking/mutex: Fix mutex debug call and ww_mutex documentation (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: Implement an algorithm choice for Wound-Wait mutexes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: WW mutex cleanup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]

* Fri Jun 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-102.el8]
- [netdrv] igb: Fix WARN_ONCE on runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: use struct_size() helper (Corinna Vinschen) [1659168]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Corinna Vinschen) [1659168]
- [netdrv] igb: Bump version number (Corinna Vinschen) [1659168]
- [netdrv] Revert "igb: reduce CPU0 latency when updating statistics" (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix an issue that PME is not enabled during runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: Change RXPBSIZE size when setting Qav mode (Corinna Vinschen) [1659168]
- [netdrv] igb: reduce CPU0 latency when updating statistics (Corinna Vinschen) [1659168]
- [netdrv] igb: fix uninitialized variables (Corinna Vinschen) [1659168]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix format with line continuation whitespace (Corinna Vinschen) [1659168]
- [netdrv] igb: extend PTP gettime function to read system clock (Corinna Vinschen) [1659168]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Corinna Vinschen) [1659168]
- [netdrv] igb: remove ndo_poll_controller (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace mdelay() with msleep() in igb_integrated_phy_loopback() (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace GFP_ATOMIC with GFP_KERNEL in igb_sw_init() (Corinna Vinschen) [1659168]
- [netdrv] igb: Use an advanced ctx descriptor for launchtime (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_phy: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_82575: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb_main: Mark expected switch fall-throughs (Corinna Vinschen) [1659168]
- [netdrv] igb: Use dma_wmb() instead of wmb() before doorbell writes (Corinna Vinschen) [1659168]
- [netdrv] igb: Add support for ETF offload (Corinna Vinschen) [1659168]
- [netdrv] igb: Only call skb_tx_timestamp after descriptors are ready (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_offload_cbs() (Corinna Vinschen) [1659168]
- [netdrv] igb: Only change Tx arbitration when CBS is on (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_configure_cbs() (Corinna Vinschen) [1659168]
- [fs] Revert "[fs] ext4: protect journal inode's blocks using block_validity" (Lukas Czerner) [1716549]
- [fs] xfs: don't trip over uninitialized buffer on extent read of corrupted inode (Bill O'Donnell) [1715942]
- [fs] xfs: always init bma in xfs_bmapi_write (Bill O'Donnell) [1715942]
- [lib] rhashtable: Still do rehash when we get EEXIST (Vladis Dronov) [1712457]
- [fs] vmcore: Add a kernel parameter novmcoredd (Kairui Song) [1705864]
- [powerpc] powerpc/eeh: Correct retries in eeh_pe_reset_full() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Improve recovery of passed-through devices (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_clear_pe_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_pe_state_clear() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: remove sw_state from eeh_unfreeze_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_clear_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup control flow in eeh_handle_normal_event() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_ops.wait_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_state_mark() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unnecessary eeh_pe_state_mark_with_cfg() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_enabled() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup logic in eeh_rmv_from_parent_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup field names in eeh_rmv_data (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup list_head field names (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_add_virt_device() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unused field in eeh_dev (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup EEH_POSTPONED_PROBE (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Avoid misleading message "EEH: no capable adapters found" (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix use of EEH_PE_KEEP on wrong field (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix null deref for devices removed during EEH (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix possible null deref in eeh_dump_dev_log() (Sam Bobroff) [1352405]
- [edac] x86/MCE/AMD, EDAC/mce_amd: Add new error descriptions for some SMCA bank types (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new McaTypes for CS, PSP, and SMU units (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new MP5, NBIO, and PCIE SMCA bank types (Janakarajan Natarajan) [1688469]
- [scsi] megaraid_sas: remove tech preview from Aero series (Tomas Henzl) [1668409]
- [scsi] megaraid_sas: sync with mainline (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix spelling mistake "oustanding" -> "outstanding" (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Make megasas_host_device_list_query() static (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: reduce module load time (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove a bunch of set but not used variables (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: return error when create DMA pool failed (Tomas Henzl) [1668409] {CVE-2019-11810}
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update structures for HOST_DEVICE_LIST DCMD (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for DEVICE_LIST DCMD in driver (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework device add code in AEN path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework code to get PD and LD list (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: correct an info message (Tomas Henzl) [1668409]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: fix out-of-bound array accesses (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: changes to function prototypes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: NULL check before some freeing functions is not needed (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas_fusion: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: megaraid_sas_base: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: modify max supported lds related print (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: remove unused macro (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: increase timeout for IOC INIT to 180seconds (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove double endian conversion (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Re-use max_mfi_cmds to calculate queue sizes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rename scratch_pad registers (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove spin lock for dpc operation (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: optimize raid context access in IO path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fail init if heartbeat timer fails (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: For SRIOV, do not set STOP_ADP bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix combined reply queue mode detection (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix module parameter description (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix goto labels in error handling (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update copyright information (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add check for reset adapter bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix msleep granularity (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for FW snap dump (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add watchdog thread to detect Firmware fault (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: switch to generic DMA API (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix a missing-check bug (Tomas Henzl) [1668409]
- [kernel] get_maintainer.pl: Add default .get_maintainer.conf file for RHEL (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow option --mpath <directory> to read all files in <directory> (Prarit Bhargava) [1714630]
- [scripts] get_maintainer.pl: add -mpath=<path or file> for MAINTAINERS file location (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow usage outside of kernel tree (Prarit Bhargava) [1714630]
- [scripts] Revert "[scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override" (Prarit Bhargava) [1714630]
- [include] signal: Make siginmask safe when passed a signal of 0 (Waiman Long) [1714351]
- [fs] signal: Don't send signals to tasks that don't exist (Waiman Long) [1714351]
- [kernel] signal: Restore the stop PTRACE_EVENT_EXIT (Waiman Long) [1714351]
- [kernel] signal: Better detection of synchronous signals (Waiman Long) [1714351]
- [kernel] signal: Always notice exiting tasks (Waiman Long) [1714351]
- [kernel] signal: Always attempt to allocate siginfo for SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user32 (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user (Waiman Long) [1714351]
- [kernel] signal: In sigqueueinfo prefer sig not si_signo (Waiman Long) [1714351]
- [include] signal: Use a smaller struct siginfo in the kernel (Waiman Long) [1714351]
- [include] signal: Distinguish between kernel_siginfo and siginfo (Waiman Long) [1714351]
- [kernel] signal: Introduce copy_siginfo_from_user and use it's return value (Waiman Long) [1714351]
- [arm64] signal: Remove the need for __ARCH_SI_PREABLE_SIZE and SI_PAD_SIZE (Waiman Long) [1714351]
- [kernel] signal: Fail sigqueueinfo if si_signo != sig (Waiman Long) [1714351]
- [kernel] signal/sparc: Move EMT_TAGOVF into the generic siginfo.h (Waiman Long) [1714351]
- [mm] signal/arm: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Use send_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_ptrace_errno_trap (Waiman Long) [1714351]
- [arm64] signal/arm64: In ptrace_hbptriggered name the signal description string (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/arm64: Only call set_thread_esr once in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Only perform one esr_to_fault_info call in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Expand __do_user_fault and remove it (Waiman Long) [1714351]
- [mm] signal/arm64: For clarity separate the 3 signal sending cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Consolidate the two hwpoison cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Factor set_thread_esr out of __do_user_fault (Waiman Long) [1714351]
- [arm64] signal/arm64: Factor out arm64_show_signal from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove unneeded tsk parameter from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Push siginfo generation into arm64_notify_die (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Simplify _exception_pkey by using force_sig_pkuerr (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Specialize _exception_pkey for handling pkey exceptions (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Call force_sig_fault from _exception (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Factor the common exception code into exception_common (Waiman Long) [1714351]
- [powerpc] powerpc/traps: Print unhandled signals in a separate function (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/powerpc: Call _exception_pkey directly from bad_key_fault_exception (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area (Waiman Long) [1714351]
- [mm] signal/powerpc: Use force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [x86] signal/x86: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey by value (Waiman Long) [1714351]
- [mm] signal/x86: Replace force_sig_info_fault with force_sig_fault (Waiman Long) [1714351]
- [mm] signal/x86: Call force_sig_pkuerr from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey not vma into __bad_area (Waiman Long) [1714351]
- [mm] signal/x86: Don't compute pkey in __do_page_fault (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from mm_fault_error (Waiman Long) [1714351]
- [mm] signal/x86: Remove the pkey parameter from do_sigbus (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from bad_area_nosemaphore (Waiman Long) [1714351]
- [x86] signal/x86/traps: Simplify trap generation (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig instead of open coding it. (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig_bnderr (Waiman Long) [1714351]
- [x86] signal/x86/traps: Move more code into do_trap_no_signal so it can be reused (Waiman Long) [1714351]
- [x86] signal/x86/traps: Factor out show_signal (Waiman Long) [1714351]
- [x86] signal/x86: Move mpx siginfo generation into do_bounds (Waiman Long) [1714351]
- [x86] signal/x86: In trace_mpx_bounds_register_exception add __user annotations (Waiman Long) [1714351]
- [mm] signal/x86: Move MCE error reporting out of force_sig_info_fault (Waiman Long) [1714351]
- [x86] signal/x86: Inline fill_sigtrap_info in it's only caller send_sigtrap (Waiman Long) [1714351]
- [powerpc] signal: Simplify tracehook_report_syscall_exit (Waiman Long) [1714351]
- [kernel] signal: Pair exports with their functions (Waiman Long) [1714351]
- [kernel] signal: Remove specific_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Use group_send_sig_info to kill all processes in a pid namespace (Waiman Long) [1714351]
- [tty] tty_io: Use group_send_sig_info in __do_SACK to note it is a session being killed (Waiman Long) [1714351]
- [misc] signal/GenWQE: Fix sending of SIGKILL (Waiman Long) [1714351]
- [include] signal: Remove SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Use SEND_SIG_PRIV not SEND_SIG_FORCED with SIGKILL and SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Never allocate siginfo for SIGKILL or SIGSTOP (Waiman Long) [1714351]
- [usb] signal: Don't send siginfo to kthreads. (Waiman Long) [1714351]
- [usb] signal: Remove the siginfo paramater from kernel_dqueue_signal (Waiman Long) [1714351]
- [tty] signal: send_sig_all no longer needs SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Always deliver the kernel's SIGKILL and SIGSTOP to a pid namespace init (Waiman Long) [1714351]
- [x86] signal: Properly deliver SIGSEGV from x86 uprobes (Waiman Long) [1714351]
- [kernel] signal: Properly deliver SIGILL from uprobes (Waiman Long) [1714351]
- [kernel] signal: Always ignore SIGKILL and SIGSTOP sent to the global init (Waiman Long) [1714351]
- [iommu] mm: convert return type of handle_mm_fault() caller to vm_fault_t (Waiman Long) [1714351]
- [kernel] signal: make get_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make sigkill_pending() return bool (Waiman Long) [1714351]
- [kernel] signal: make legacy_queue() return bool (Waiman Long) [1714351]
- [kernel] signal: make wants_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make flush_sigqueue_mask() void (Waiman Long) [1714351]
- [kernel] signal: make unhandled_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make recalc_sigpending_tsk() return bool (Waiman Long) [1714351]
- [kernel] signal: make has_pending_signals() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_task_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_handler_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_ok_by_cred() return bool (Waiman Long) [1714351]
- [kernel] signal: simplify rt_sigaction() (Waiman Long) [1714351]
- [kernel] signal: make do_sigpending() void (Waiman Long) [1714351]
- [kernel] signal: make may_ptrace_stop() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_as_cred_perm() return bool (Waiman Long) [1714351]
- [kernel] signal: make force_sigsegv() void (Waiman Long) [1714351]
- [kernel] signal: Don't restart fork when signals come in. (Waiman Long) [1714351]
- [kernel] fork: Have new threads join on-going signal group stops (Waiman Long) [1714351]
- [include] fork: Skip setting TIF_SIGPENDING in ptrace_init_task (Waiman Long) [1714351]
- [kernel] signal: Add calculate_sigpending() (Waiman Long) [1714351]
- [kernel] fork: Unconditionally exit if a fatal signal is pending (Waiman Long) [1714351]
- [kernel] fork: Move and describe why the code examines PIDNS_ADDING (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into complete_signal. (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into __send_signal (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into send_signal (Waiman Long) [1714351]
- [tty] signal: Pass pid type into do_send_sig_info (Waiman Long) [1714351]
- [fs] signal: Pass pid type into send_sigio_to_task & send_sigurg_to_task (Waiman Long) [1714351]
- [kernel] signal: Pass pid type into group_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Pass pid and pid type into send_sigqueue (Waiman Long) [1714351]
- [kernel] posix-timers: Noralize good_sigevent (Waiman Long) [1714351]
- [fs] signal: Use PIDTYPE_TGID to clearly store where file signals will be sent (Waiman Long) [1714351]
- [kernel] pid: Implement PIDTYPE_TGID (Waiman Long) [1714351]
- [include] pids: Move the pgrp and session pid pointers from task_struct to signal_struct (Waiman Long) [1714351]
- [fs] pids: Compute task_tgid using signal->leader_pid (Waiman Long) [1714351]
- [kernel] pids: Move task_pid_type into sched/signal.h (Waiman Long) [1714351]
- [init] pids: Initialize leader_pid in init_task (Waiman Long) [1714351]

* Thu Jun 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-101.el8]
- [s390] s390: enable processes for mio instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to disable usage of MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: provide support for MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: improve bar check (Philipp Rudo) [1651734]
- [s390] s390/ism: move oddities of device IO to wrapper function (Philipp Rudo) [1651734]
- [s390] s390/pci: move io address mapping code to pci_insn.c (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to force floating irqs (Philipp Rudo) [1651735]
- [s390] s390/pci: gather statistics for floating vs directed irqs (Philipp Rudo) [1651735]
- [s390] s390: show statistics for MSI IRQs (Philipp Rudo) [1651735]
- [s390] s390/pci: provide support for CPU directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/airq: provide cacheline aligned ivs (Philipp Rudo) [1651735]
- [s390] s390/pci: clarify interrupt vector usage (Philipp Rudo) [1651735]
- [s390] s390/airq: recognize directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/sclp: detect DIRQ facility (Philipp Rudo) [1651735]
- [s390] s390/pci: move everything irq related to pci_irq.c (Philipp Rudo) [1651735]
- [s390] s390/pci: remove stale rc (Philipp Rudo) [1651735]
- [s390] s390/pci: remove unused define (Philipp Rudo) [1651735]
- [s390] s390/pci: mark command line parser data __initdata (Philipp Rudo) [1651735]
- [cpufreq] cpufreq: intel_pstate: Ignore turbo active ratio in HWP (David Arcari) [1711970]
- [scsi] mpt3sas: remove tech preview from Aero series (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix indentation issue (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update mpt3sas driver version to 28.100.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Improve the threshold value and introduce module param (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Load balance to improve performance and avoid soft lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Irq poll to avoid CPU hard lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: simplify interrupt handler (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix typo in request_desript_type (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add missing breaks in switch statements (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update driver version to 27.102.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for ATLAS PCIe switch (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for NVMe Switch Adapter (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Rename mpi endpoint device ID macro. (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: mpt3sas_scsih: Mark expected switch fall-through (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix memory ordering on 64bit writes (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix spelling mistake "manufaucturing" -> "manufacturing" (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix driver modifying persistent data in Manufacturing page11 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Don't modify EEDPTagMode field setting on SAS3.5 HBA devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix Sync cache command failure during driver unload (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Call sas_remove_host before removing the target devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Refactor mpt3sas_wait_for_ioc function (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Separate out mpt3sas_wait_for_ioc (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Added new #define variable IOC_OPERATIONAL_WAIT_COUNT (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: switch to generic DMA API (Tomas Henzl) [1684444]
- [tools] perf tools beauty ioctl: Support new ISO7816 commands (Michael Petlan) [1709243]
- [tools] perf tools: Restore proper cwd on return from mnt namespace (Michael Petlan) [1709243]
- [tools] perf tools: Fix crash on synthesizing the unit (Michael Petlan) [1709243]
- [tools] perf tools: Do not zero sample_id_all for group members (Michael Petlan) [1709243]
- [tools] perf beauty: Use SRCARCH, ARCH=x86_64 must map to "x86" to find the headers (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add MTC and CYC timestamps to debug log (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add more event information to debug log (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fix table find when table re-ordered (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add help window (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add Selected branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fall back to /usr/local/lib/libxed.so (Michael Petlan) [1709243]
- [tools] perf top: Display the LBR stats in callchain entry (Michael Petlan) [1709243]
- [tools] perf stat: Handle different PMU names with common prefix (Michael Petlan) [1709243]
- [tools] perf record: Support weak groups (Michael Petlan) [1709243]
- [tools] perf evlist: Move perf_evsel__reset_weak_group into evlist (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Start collecting pathnames in the BPF program (Michael Petlan) [1709243]
- [tools] perf trace: Fix setting of augmented payload when using eBPF + raw_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: When augmenting raw_syscalls plug raw_syscalls:sys_exit too (Michael Petlan) [1709243]
- [tools] perf examples bpf: Start augmenting raw_syscalls:sys_{start,exit} (Michael Petlan) [1709243]
- [tools] perf intel-pt/bts: Calculate cpumode for synthesized samples (Michael Petlan) [1709243]
- [tools] perf intel-pt: Insert callchain context into synthesized callchains (Michael Petlan) [1709243]
- [tools] perf top: Start display thread earlier (Michael Petlan) [1709243]
- [tools] perf trace beauty: Use the mmap flags table generated from headers (Michael Petlan) [1709243]
- [tools] perf beauty: Wire up the mmap flags table generator to the Makefile (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MAP_ mmap's flag constants (Michael Petlan) [1709243]
- [tools] perf callchain: Honour the ordering of PERF_CONTEXT_{USER,KERNEL,etc} (Michael Petlan) [1709243]
- [tools] perf cs-etm: Correct CPU mode for samples (Michael Petlan) [1709243]
- [tools] perf unwind: Take pgoff into account when reporting elf to libdwfl (Michael Petlan) [1709243]
- [tools] perf top: Do not use overwrite mode by default (Michael Petlan) [1709243]
- [tools] perf trace: Beautify mount's first pathname arg (Michael Petlan) [1709243]
- [tools] perf trace: Beautify the umount's 'name' argument (Michael Petlan) [1709243]
- [tools] perf trace: Consider syscall aliases too (Michael Petlan) [1709243]
- [tools] perf trace beauty: Beautify mount/umount's 'flags' argument (Michael Petlan) [1709243]
- [tools] perf trace beauty: Allow syscalls to mask an argument before considering it (Michael Petlan) [1709243]
- [tools] perf beauty: Introduce strarray__scnprintf_flags() (Michael Petlan) [1709243]
- [tools] perf beauty: Switch from GPL v2.0 to LGPL v2.1 (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MS_ mount/umount's flag constants (Michael Petlan) [1709243]
- [tools] tools include uapi: Grab a copy of linux/fs.h (Michael Petlan) [1709243]
- [tools] perf script: Support total cycles count (Michael Petlan) [1709243]
- [tools] perf script: Make itrace script default to all calls (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add All branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to display all the database tables (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to shrink / enlarge font (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to find symbols in the call-graph (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add support for multiple sub-windows (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Rename to exported-sql-viewer.py (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Refactor TreeItem class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add data helper functions (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Factor out CallGraphModel from TreeModel (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Remove use of setObjectName() (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add a class for global data (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Separate the database details into a class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Make a "Main" function (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Change icon (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Set a minimum window size (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Provide better default column sizes (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Use SPDX license identifier (Michael Petlan) [1709243]
- [tools] perf trace: Introduce per-event maximum number of events property (Michael Petlan) [1709243]
- [tools] perf script: Flush output stream after events in verbose mode (Michael Petlan) [1709243]
- [tools] perf script: Allow extended console debug output (Michael Petlan) [1709243]
- [tools] perf stat: Poll for monitored tasks being alive (Michael Petlan) [1709243]
- [tools] perf trace: Drop thread refcount in trace__event_handler() (Michael Petlan) [1709243]
- [tools] perf trace: Drop addr_location refcounts (Michael Petlan) [1709243]
- [tools] perf evsel: Mark a evsel as disabled when asking the kernel do disable it (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce per event max_events property (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Introduce OPTION_ULONG (Michael Petlan) [1709243]
- [tools] perf arm64: Fix generate system call table failed with /tmp mounted with noexec (Michael Petlan) [1709243]
- [tools] perf symbols: Set PLT entry/header sizes properly on Sparc (Michael Petlan) [1709243]
- [tools] perf jitdump: Add Sparc support. (Michael Petlan) [1709243]
- [tools] perf annotate: Add Sparc support (Michael Petlan) [1709243]
- [tools] perf record: Encode -k clockid frequency into Perf trace (Michael Petlan) [1709243]
- [tools] perf probe: Support SDT markers having reference counter (semaphore) (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Move struct tep_handler definition in a local header file (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Separate out tep_strerror() for strerror_r() issues (Michael Petlan) [1709243]
- [tools] perf python: More portable way to make CFLAGS work with clang (Michael Petlan) [1709243]
- [tools] perf python: Make clang_has_option() work on Python 3 (Michael Petlan) [1709243]
- [tools] perf tools: Free temporary 'sys' string in read_event_files() (Michael Petlan) [1709243]
- [tools] perf tools: Avoid double free in read_event_file() (Michael Petlan) [1709243]
- [tools] perf tools: Free 'printk' string in parse_ftrace_printk() (Michael Petlan) [1709243]
- [tools] perf tools: Cleanup trace-event-info 'tdata' leak (Michael Petlan) [1709243]
- [tools] perf strbuf: Match va_{add,copy} with va_end (Michael Petlan) [1709243]
- [tools] perf test: S390 does not support watchpoints in test 22 (Michael Petlan) [1709243]
- [tools] perf auxtrace: Include missing asm/bitsperlong.h to get BITS_PER_LONG (Michael Petlan) [1709243]
- [tools] tools include: Adopt linux/bits.h (Michael Petlan) [1709243]
- [tools] perf intel-pt: Implement decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__process() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__event() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf db-export: Add trace begin / end branch type variants (Michael Petlan) [1709243]
- [tools] perf script: Enhance sample flags for trace begin / end (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enum filter_trivial_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename data2host*() APIs (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename struct plugin_list to struct tep_plugin_list (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to structs filter_type and event_filter (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to various structs filter_arg_*. (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to struct filter_{arg,value_type} (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{exp,arg}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{boolean,op,cmp}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum print_arg_type to enum tep_print_arg_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Add prefix tep_ to all print_* structures (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix TEP_ to all EVENT_FL_* flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename enum event_{sort_}type to enum tep_event_{sort_}type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum format_flags to enum tep_format_flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct format{_field} to struct tep_format{_field} (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct event_format to struct tep_event_format (Michael Petlan) [1709243]
- [tools] perf script: Print DSO for callindent (Michael Petlan) [1709243]
- [tools] perf script: Allow sym and dso without ip, addr (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Support overwriting the pager (Michael Petlan) [1709243]
- [tools] perf tools: Report itrace options in help (Michael Petlan) [1709243]
- [tools] perf help: Add missing subcommand `version` (Michael Petlan) [1709243]
- [tools] perf tools: Initialize perf_data_file fd field (Michael Petlan) [1709243]
- [tools] perf util: Make copyfile_offset() global (Michael Petlan) [1709243]
- [tools] perf tools: Add 'struct perf_mmap' arg to record__write() (Michael Petlan) [1709243]
- [tools] perf auxtrace: Pass struct perf_mmap into mmap__read* functions (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op3 (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op2 (Michael Petlan) [1709243]
- [tools] perf bpf-loader: use PTR_ERR_OR_ZERO inetead of return code (Michael Petlan) [1709243]
- [tools] tools include: Adopt PTR_ERR_OR_ZERO from the kernel err.h header (Michael Petlan) [1709243]
- [tools] perf ordered_events: Prevent crossing max_alloc_size (Michael Petlan) [1709243]
- [tools] perf ordered_events: Add 'struct ordered_events_buffer' layer (Michael Petlan) [1709243]
- [tools] perf test: Add watchpoint test (Michael Petlan) [1709243]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh without ping's debuginfo (Michael Petlan) [1709243]
- [tools] perf map: Turn some pr_warning() to pr_debug() (Michael Petlan) [1709243]
- [tools] perf trace: Use the raw_syscalls:sys_enter for the augmented syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Setup augmented_args in the raw_syscalls:sys_enter handler (Michael Petlan) [1709243]
- [tools] perf trace: Introduce syscall__augmented_args() method (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Avoid optimization to pass older BPF validators (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Check probe_read_str() return separately (Michael Petlan) [1709243]
- [tools] perf annotate: Handle arm64 move instructions (Michael Petlan) [1709243]
- [tools] perf trace beauty: Alias 'umount' to 'umount2' (Michael Petlan) [1709243]
- [tools] perf stat: Move the display functions to stat-display.c (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_events' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'walltime_*' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Propagate 'struct target' arg to sort_aggr_thread() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_merge' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'big_num' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Do not use the global 'evsel_list' in print functions (Michael Petlan) [1709243]
- [tools] perf stat: Move *_aggr_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move ru_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_mixed_hw_group_error' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_free_counters_hint' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'null_run' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Add 'walltime_nsecs_stats' pointer to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' to aggr_update_shadow() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' to first_shadow_cpu() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only_len' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'run_count' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use 'evsel->evlist' instead of 'evsel_list' in collect_all_aliases() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' argument to print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'target' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'unit_width' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'interval_clear' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move csv_* to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass a 'struct perf_stat_config' argument to global print functions (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' argument to local print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move STAT_RECORD out of perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Introduce perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move perf_stat_synthesize_config() to stat.c (Michael Petlan) [1709243]
- [tools] perf stat: Add 'perf_event__handler_t' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_evlist' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_tool' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Rename 'is_pipe' argument to 'attrs' in perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Move create_perf_stat_counter() to stat.c (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce perf_evsel__store_ids() (Michael Petlan) [1709243]
- [tools] perf tools: Switch 'session' argument to 'evlist' in perf_event__synthesize_attrs() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'identifier' flag to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use local config arg for scale in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_inherit' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'initial_delay' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use evsel->threads in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf trace: Show comm and tid for tracepoint events (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Hook into syscalls:sys_exit_SYSCALL too (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Rename augmented_*_syscall__enter to just *_syscall (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Update the header comments (Michael Petlan) [1709243]
- [tools] perf bpf: Add syscall_exit() helper (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Split trace-seq related APIs in a separate header file (Michael Petlan) [1709243]
- [tools] perf report: Create auxiliary trace data files for s390 (Michael Petlan) [1709243]
- [tools] perf trace beauty: Reorganize 'struct sockaddr *' beautifier (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment sendto's 'addr' arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment bind's 'myaddr' sockaddr arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Add augmented_sockaddr_syscall_enter() (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment connect's 'sockaddr' arg (Michael Petlan) [1709243]
- [tools] perf bpf: Add linux/socket.h to the headers accessible to bpf proggies (Michael Petlan) [1709243]
- [tools] perf bpf: Give precedence to bpf header dir (Michael Petlan) [1709243]
- [tools] perf trace: Add a etcsnoop.c augmented syscalls eBPF utility (Michael Petlan) [1709243]
- [tools] perf trace: Augment 'newstat' (aka 'stat') filename ptr (Michael Petlan) [1709243]
- [tools] perf trace: Introduce augmented_filename_syscall_enter() declarator (Michael Petlan) [1709243]
- [tools] perf trace: Augment inotify_add_watch pathname syscall arg (Michael Petlan) [1709243]
- [tools] perf trace: Augment the 'open' syscall 'filename' arg (Michael Petlan) [1709243]
- [tools] perf trace: Use the augmented filename, expanding syscall enter pointers (Michael Petlan) [1709243]
- [tools] perf trace: Show comm/tid for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Extract the comm/tid printing for syscall enter (Michael Petlan) [1709243]
- [tools] perf trace: Print the syscall name for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Make the augmented_syscalls filter out the tracepoint event (Michael Petlan) [1709243]
- [tools] perf trace: Pass augmented args to the arg formatters when available (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Disallow precise_ip on BTS events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add generic branch tracing check to intel_pmu_has_bts() (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Move branch tracing setup to the Intel-specific source file (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Fix regression by default disabling perfmon v4 interrupt handling (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Support CoffeeLake 8th CBOX (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Add more IMC PCI IDs for KabyLake and CoffeeLake CPUs (Michael Petlan) [1709243]
- [tools] perf tools: Don't clone maps from parent when synthesizing forks (Michael Petlan) [1709243]
- [tools] perf top: Allow disabling the overwrite mode (Michael Petlan) [1709243]
- [kernel] perf/core: Clean up inconsisent indentation (Michael Petlan) [1709243]
- [tools] perf script: Implement --graph-function (Michael Petlan) [1709243]
- [tools] tools script: Add --call-trace and --call-ret-trace (Michael Petlan) [1709243]
- [tools] perf script: Add --insn-trace for instruction decoding (Michael Petlan) [1709243]
- [tools] perf trace: Introduce --max-events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add quirk for Goldmont Plus (Michael Petlan) [1709243]
- [kernel] perf: Suppress AUX/OVERWRITE records (Michael Petlan) [1709243]
- [x86] perf/x86/intel/pt: Annotate 'pt_cap_group' with __ro_after_init (Michael Petlan) [1709243]
- [x86] perf/x86: Add __ro_after_init annotations (Michael Petlan) [1709243]
- [x86] x86/mm/mem_encrypt: Disable all instrumentation for early SME setup (Janakarajan Natarajan) [1679265]
- [fs] cifs: fix copy_file_range to allow write on the same file (Leif Sahlberg) [1689100]
- [infiniband] Revert "[infiniband] IB/usnic: Remove stub functions" (Jonathan Toppins) [1713753]
- [x86] Update stepping values for Whiskey Lake U/Y (David Arcari) [1704801]
- [powerpc] powerpc/perf: Trace imc PMU functions (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Trace imc events detection and cpuhotplug (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Declare static identifier a such (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Add privileged access check for thread_imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Rearrange setting of ldbar for thread-imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/include: Add data structures and macros for IMC trace mode (Jiri Olsa) [1608796]
- [scsi] hpsa: correct-static-checker-issue-in-reset-handler (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: update driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device resets (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: do-not-complete-cmds-for-deleted-devices (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: wait longer for ptraid commands (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for tag collision (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: use local workqueues instead of system workqueues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct simple mode (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device id issues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for lv removal (Joseph Szczypek) [1713772]
- [mm] mm, slub: restore the original intention of prefetch_freepointer() (Rafael Aquini) [1714671]
- [fs] Revert "add KABI padding to dentry structure" (Waiman Long) [1714253]
- [crypto] crypto: drbg - add FIPS 140-2 CTRNG for noise source (Herbert Xu) [1687905]
- [infiniband] RDMA/qedr: Fix incorrect device rate. (Manish Chopra) [1713580]
- [scsi] scsi: bnx2fc: remove unneeded variable (Nilesh Javali) [1665308]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665308]
- [char] ipmi:ssif: compare block number correctly for multi-part return messages (Tony Camuso) [1712159]
- [kernel] kernel/sysctl.c: define minmax conv functions in terms of non-minmax versions (Alex Gladkov) [1683922]
- [kernel] kernel/sysctl.c: add missing range check in do_proc_dointvec_minmax_conv (Alex Gladkov) [1683922]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: add tests for >32-bit values written to 32-bit integers (Alex Gladkov) [1683922]
- [kernel] sched/nohz: Run NOHZ idle load balancer on HK_FLAG_MISC CPUs (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] nohz_full: Allow the boot CPU to be nohz_full (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/isolation: Require a present CPU in housekeeping mask (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] kernel/cpu: Allow non-zero CPU to be primary for suspend / kexec freeze (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] power/suspend: Add function to disable secondaries for suspend (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/core: Allow the remote scheduler tick to be started on CPU0 (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/fair: Use non-atomic cpumask_{set,clear}_cpu() (Desnes Augusto Nunes do Rosario) [1666614]
- [lib] lib: reciprocal_div: implement the improved algorithm on the paper mentioned (Petr Oros) [1706982]
- [kernel] kernel/sysctl.c: fix proc_do_large_bitmap for large input buffers (Eric Sandeen) [1667092]
- [kernel] tools/testing/selftests/sysctl/sysctl.sh: add proc_do_large_bitmap() test case (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: allow graceful use on older kernels (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: ignore diff output on verify_diff_w() (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: load module before testing for it (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: remove superfluous test_reqs() (Eric Sandeen) [1667092]
- [kernel] kernel/sysctl.c: fix out-of-bounds access when setting file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow for file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow in proc_get_long (Eric Sandeen) [1694160]
- [s390] kvm: s390: Fix potential spectre warnings (Thomas Huth) [1702344]
- [powerpc] mm: move warning from resize_hpt_for_hotplug() (Laurent Vivier) [1660737]
- [powerpc] pseries: Use pr_xxx() in lpar.c (Laurent Vivier) [1660737]
- [infiniband] RDMA/iw_cxgb4: Always disconnect when QP is transitioning to TERMINATE state (Arjun Vynipadath) [1664673]
- [infiniband] cxgb4: kfree mhp after the debug print (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxbg: Use correct sizing on buffers holding page DMA addresses (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Make function read_tcb() static (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Remove kref accounting for sync operation (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: cq/qp mask depends on bar2 pages in a host page (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: fix srqidx leak during connection abort (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: complete the cached SRQ buffers (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Remove a set-but-not-used variable (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when finding ipv6 routes (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when importing the endpoint (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use listening ep tos when accepting new connections (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb*: kzalloc the iwcm verbs struct (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Drop __GFP_NOFAIL (Arjun Vynipadath) [1664673]
- [infiniband] infiniband: cxgb4: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Fix the unchecked ep dereference (Arjun Vynipadath) [1664673]
- [infiniband] RDMA: Introduce and use rdma_device_to_ibdev() (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Check for send WR also while posting write with completion WR (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: only reconnect with MPAv1 if the peer aborts (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Use proper enumerated type in c4iw_bar2_addrs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: remove redundant null pointer check before kfree_skb (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Remove pci_unmap_addr() wrappers for DMA API (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Declare ib_post_send() and ib_post_recv() arguments const (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Simplify a structure initialization (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Fix SRQ endianness annotations (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for kernel mode SRQ's (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for srq functions & structs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Restore the dropped uninitialized_var (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Make c4iw_poll_cq_one() easier to analyze (Arjun Vynipadath) [1664673]
- [fs] gfs2: clean_journal improperly set sd_log_flush_head (Robert S Peterson) [1693660]

* Fri May 31 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-100.el8]
- [netdrv] bonding/802.3ad: fix slave link initialization transition states (Jarod Wilson) [1714387]
- [iommu] iommu/vt-d: Disable ATS support on untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [documentation] thunderbolt: Export IOMMU based DMA protection support to userspace (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Do not enable ATS for untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Force IOMMU on for platform opt in hint (Jerry Snitselaar) [1649210 1692246]
- [arm64] arm64: makefile fix build of .i file in external module case (Jerome Marchand) [1713052]
- [s390] s390/protvirt: block kernel command line alteration (Philipp Rudo) [1651711]
- [s390] s390/protvirt: add memory sharing for diag 308 set/store (Philipp Rudo) [1651711]
- [s390] s390/uv: introduce guest side ultravisor code (Philipp Rudo) [1651711]
- [netdrv] net: aquantia: fix undefined devm_hwmon_device_register_with_info reference (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make aq_ndev_driver_name static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove outdated device ids (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixups on 64bit dma counters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: get total counters from DMA block (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fetch up to date statistics on ethtool request (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: extract timer cb into work job (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: introduce fwreq mutex (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: user correct MSI irq type (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use macros for better visibility (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve ifup link detection (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link status irq handling (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: create global service workqueue (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link interrupt handling function (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add link interrupt fields (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: implement hwmon api for chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure to readout chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: enable driver build for arm64 or compile_test (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve LRO configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Increase rx ring default size from 1K to 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make RX default frame size 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Introduce rx refill threshold value (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx performance by page reuse strategy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx path using larger preallocated skb len (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload for UDP/TCP over IPv6 (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use better wrappers for state registers (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: replace AQ_HW_WAIT_FOR with readx_poll_timeout_atomic (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed instack structure overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed buffer overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: added newline at end of file (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed memcpy size (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: regression on cpus with high cores: set mode with 8 queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of RSS configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix initialization of RSS table (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: increase max number of hw queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix RSS table and key sizes (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload bits (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: return 'err' if set MPI_DEINIT state fails (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix spelling mistake "specfield" -> "specified" (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: cleanup err handing in hw_atl_utils_fw_rpc_wait (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of rx-vlan-filter offload (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add ethertype and PCP to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add vlan id to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of L3/L4 ntuple filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure for ntuple rules (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add rx-flow filter definitions (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: allow rx checksum offload configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: invalid checksumm offload implementation (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed enable unicast on 32 macvlan (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix potential IOMMU fault after driver unbind (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: synchronized flow control between mac/phy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: make function aq_fw2x_update_stats static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove some redundant variable initializations (Igor Russkikh) [1706905]
- [netdrv] bnxt_en: Add device IDs 0x1806 and 0x1752 for 57500 devices. (Selvin Xavier) [1672208]
- [scsi] scsi: fnic: Remove set but not used variable 'vdev' (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: no need to check return value of debugfs_create functions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Update fnic driver version to 1.6.0.47 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Enable fnic devcmd2 interface (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Adding devcmd2 init and posting interfaces (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add devcmd2 initialization helpers (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 controller definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 interface definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Impose upper limit on max. # of CQs processed per intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: RQ enable and then post descriptors (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: delaying vnic dev enable till after req intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Warn when calling done for IO not issued to fw (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic stats for max CQs processed and ISR time (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add port speed stat to fnic debug stats (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: use fnic_lock to guard fnic->state_flags (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: vnic_rq_clean change BUG_ON to WARN_ON (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: change fnic queue depth to 256 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: support to display 20G port speed (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Use vzalloc (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: switch to generic DMA API (Govindarajulu Varadarajan) [1656236]
- [pci] PCI/PME: Fix possible use-after-free on remove (Myron Stowe) [1701834]
- [pci] PCI/PME: Fix hotplug/sysfs remove deadlock in pcie_pme_remove() (Myron Stowe) [1701834]
- [pci] PCI: Blacklist power management of Gigabyte X299 DESIGNARE EX PCIe ports (Myron Stowe) [1701834]
- [tools] perf arm64: Fix mksyscalltbl when system kernel headers are ahead of the kernel (Michael Petlan) [1709242]
- [rpmspec] perf: remove bpf examples (Michael Petlan) [1709242]
- [tools] perf tools: Stop fallbacking to kallsyms for vdso symbols lookup (Michael Petlan) [1709242]
- [tools] perf report: Don't crash on invalid inline debug information (Michael Petlan) [1709242]
- [tools] perf cpu_map: Align cpu map synthesized events properly. (Michael Petlan) [1709242]
- [tools] perf tools: Fix tracing_path_mount proper path (Michael Petlan) [1709242]
- [tools] perf evsel: Store ids for events with their own cpus perf_event__synthesize_event_update_cpus (Michael Petlan) [1709242]
- [tools] perf vendor events intel: Fix wrong filter_band* values for uncore events (Michael Petlan) [1709242]
- [tools] Revert "perf tools: Fix PMU term format max value calculation" (Michael Petlan) [1709242]
- [tools] tools headers uapi: Sync kvm.h copy (Michael Petlan) [1709242]
- [tools] perf record: Use unmapped IP for inline callchain cursors (Michael Petlan) [1709242]
- [tools] perf python: Use -Wno-redundant-decls to build with PYTHON=python3 (Michael Petlan) [1709242]
- [tools] perf report: Don't try to map ip to invalid map (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-sqlite.py sample columns (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-postgresql.py occasional failure (Michael Petlan) [1709242]
- [tools] perf Documentation: Fix out-of-tree asciidoctor man page generation (Michael Petlan) [1709242]
- [tools] perf tools: Fix maps__find_symbol_by_name() (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/if_link.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/vhost.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copies of kvm headers (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of drm/drm.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1709242]
- [tools] perf annotate: Fix parsing aarch64 branch instructions after objdump update (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Ignore SyS symbols irrespective of endianness (Michael Petlan) [1709242]
- [tools] perf event-parse: Use fixed size string for comms (Michael Petlan) [1709242]
- [tools] perf util: Fix bad memory access in trace info. (Michael Petlan) [1709242]
- [tools] perf tools: Streamline bpf examples and headers installation (Michael Petlan) [1709242]
- [tools] perf evsel: Fix potential null pointer dereference in perf_evsel__new_idx() (Michael Petlan) [1709242]
- [tools] perf arm64: Fix include path for asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] perf tests: Add breakpoint modify tests (Michael Petlan) [1709242]
- [tools] perf annotate: Properly interpret indirect call (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add dummy task_struct state member (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add empty nmi.h (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Change to SPDX License format (Michael Petlan) [1709242]
- [tools] perf llvm: Allow passing options to llc in addition to clang (Michael Petlan) [1709242]
- [tools] perf parser: Improve error message for PMU address filters (Michael Petlan) [1709242]
- [tools] perf tools: Disable parallelism for 'make clean' (Michael Petlan) [1709242]
- [tools] perf auxtrace: Fix queue resize (Michael Petlan) [1709242]
- [tools] perf python: Remove -mcet and -fcf-protection when building with clang (Michael Petlan) [1709242]
- [tools] perf arm spe: Fix uninitialized record error variable (Michael Petlan) [1709242]
- [tools] perf tools: Move syscall_64.tbl check into check-headers.sh (Michael Petlan) [1709242]
- [tools] perf tools: Make check-headers.sh check based on kernel dir (Michael Petlan) [1709242]
- [tools] perf tools: Fix check-headers.sh AND list path of execution (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename static variables and functions in event-parse.c (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename internal parser related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent get/set/is APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_find_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent field APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_data_ APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_register / unregister APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_filter* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent,  perf tools: Rename traceevent_plugin_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_function* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, tools lib lockdep: Rename 'enum pevent_errno' to 'enum tep_errno' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'enum pevent_flag' to 'enum tep_flag' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename traceevent_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_set_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_register_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_read_number_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent print APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent parse APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent find APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent alloc / free APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent plugin related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'struct pevent_record' to 'struct tep_record' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename struct pevent to struct tep_handle (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Fix trace event post-processing (Michael Petlan) [1709242]
- [tools] perf map: Optimize maps__fixup_overlappings() (Michael Petlan) [1709242]
- [tools] perf map: Synthesize maps only for thread group leader (Michael Petlan) [1709242]
- [tools] perf trace: Wire up the augmented syscalls with the syscalls:sys_enter_FOO beautifier (Michael Petlan) [1709242]
- [tools] perf trace: Setup the augmented syscalls bpf-output event fields (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__setup_output_event() return the bpf-output event (Michael Petlan) [1709242]
- [tools] perf trace: Handle "bpf-output" events associated with "__augmented_syscalls__" BPF map (Michael Petlan) [1709242]
- [tools] perf bpf: Add wrappers to BPF_FUNC_probe_read(_str) functions (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf__setup_output_event() strerror() counterpart (Michael Petlan) [1709242]
- [tools] perf bpf: Generalize bpf__setup_stdout() (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__for_each_stdout_map() generic (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf/stdio.h wrapper to bpf_perf_event_output function (Michael Petlan) [1709242]
- [tools] perf bpf: Add struct bpf_map struct (Michael Petlan) [1709242]
- [tools] perf report: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Display percent type in stdio output (Michael Petlan) [1709242]
- [tools] perf annotate: Make local period the default percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Add support to toggle percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Pass browser percent_type in annotate_browser__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass 'struct annotation_options' to map_symbol__annotation_dump() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass struct annotation_options to symbol__calc_lines() (Michael Petlan) [1709242]
- [tools] perf annotate: Add percent_type to struct annotation_options (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_LOCAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_HITS_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Switch struct annotation_data::percent to array (Michael Petlan) [1709242]
- [tools] perf annotate: Loop group events directly in annotation__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Rename hist to sym_hist in annotation__calc_percent (Michael Petlan) [1709242]
- [tools] perf annotate: Rename local sample variables to data (Michael Petlan) [1709242]
- [tools] perf annotate: Rename struct annotation_line::samples* to data* (Michael Petlan) [1709242]
- [tools] perf annotate: Get rid of annotation__scnprintf_samples_period() (Michael Petlan) [1709242]
- [tools] perf annotate: Make annotation_line__max_percent static (Michael Petlan) [1709242]
- [tools] perf annotate: Make symbol__annotate_fprintf2() local (Michael Petlan) [1709242]
- [tools] perf bpf: Add 'syscall_enter' probe helper for syscall enter tracepoints (Michael Petlan) [1709242]
- [tools] perf tools: Drop unneeded bitmap_zero() calls (Michael Petlan) [1709242]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Michael Petlan) [1709242]
- [tools] perf report: Add GUI report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf report: Add raw report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf auxtrace: Support for perf report -D for s390 (Michael Petlan) [1709242]
- [tools] perf trace: Use perf_evsel__sc_tp_{uint,ptr} for "id"/"args" handling syscalls:* events (Michael Petlan) [1709242]
- [tools] perf trace: Setup struct syscall_tp for syscalls:sys_{enter,exit}_NAME events (Michael Petlan) [1709242]
- [tools] perf trace: Allow setting up a syscall_tp struct without a format_field (Michael Petlan) [1709242]
- [tools] perf trace: Rename some syscall_tp methods to raw_syscall (Michael Petlan) [1709242]
- [tools] perf trace: Use beautifiers on syscalls:sys_enter_ handlers (Michael Petlan) [1709242]
- [tools] perf trace: Associate vfs_getname()'ed pathname with fd returned from 'openat' (Michael Petlan) [1709242]
- [tools] perf trace: Do not require --no-syscalls to suppress strace like output (Michael Petlan) [1709242]
- [tools] perf bpf: Include uapi/linux/bpf.h from the 'perf trace' script's bpf.h (Michael Petlan) [1709242]
- [tools] perf tools: Allow overriding MAX_NR_CPUS at compile time (Michael Petlan) [1709242]
- [tools] perf bpf: Show better message when failing to load an object (Michael Petlan) [1709242]
- [tools] perf list: Unify metric group description format with PMU event description (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample when receiving a CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Support dummy address value for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Fix start tracing packet handling (Michael Petlan) [1709242]
- [tools] perf build: Fix installation directory for eBPF (Michael Petlan) [1709242]
- [tools] perf c2c report: Fix crash for empty browser (Michael Petlan) [1709242]
- [tools] perf tests: Fix indexing when invoking subtests (Michael Petlan) [1709242]
- [tools] perf trace: Beautify the AF_INET & AF_INET6 'socket' syscall 'protocol' args (Michael Petlan) [1709242]
- [tools] perf trace beauty: Add beautifiers for 'socket''s 'protocol' arg (Michael Petlan) [1709242]
- [tools] perf trace beauty: Do not print NULL strarray entries (Michael Petlan) [1709242]
- [tools] perf beauty: Add a generator for IPPROTO_ socket's protocol constants (Michael Petlan) [1709242]
- [tools] tools include uapi: Grab a copy of linux/in.h (Michael Petlan) [1709242]
- [tools] perf tests: Fix complex event name parsing (Michael Petlan) [1709242]
- [tools] perf evlist: Fix error out while applying initial delay and LBR (Michael Petlan) [1709242]
- [tools] perf trace beauty: Default header_dir to cwd to work without parms (Michael Petlan) [1709242]
- [tools] perf test: Fix subtest number when showing results (Michael Petlan) [1709242]
- [tools] perf stat: Get rid of extra clock display function (Michael Petlan) [1709242]
- [tools] perf tools: Use perf_evsel__match instead of open coded equivalent (Michael Petlan) [1709242]
- [tools] perf tools: Fix struct comm_str removal crash (Michael Petlan) [1709242]
- [tools] perf machine: Use last_match threads cache only in single thread mode (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__set_last_match function (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__get_last_match function (Michael Petlan) [1709242]
- [tools] perf tools: Synthesize GROUP_DESC feature in pipe mode (Michael Petlan) [1709242]
- [tools] perf script: Show correct offsets for DWARF-based unwinding (Michael Petlan) [1709242]
- [tools] perf trace arm64: Use generated syscall table (Michael Petlan) [1709242]
- [tools] perf arm64: Generate system call table from asm/unistd.h (Michael Petlan) [1709242]
- [tools] tools include: Grab copies of arm64 dependent unistd.h files (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh when event exists (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh to ensure cleanups (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64 (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering when return address is in a register (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering (Michael Petlan) [1709242]
- [tools] perf list: Add missing documentation for --desc and --debug options (Michael Petlan) [1709242]
- [tools] perf stat: Add transaction flag (-T) support for s390 (Michael Petlan) [1709242]
- [tools] perf json: Add s390 transaction counter definition (Michael Petlan) [1709242]
- [tools] perf list: Add s390 support for detailed PMU event description (Michael Petlan) [1709242]
- [tools] Revert "perf list: Add s390 support for detailed/verbose PMU event description" (Michael Petlan) [1709242]
- [tools] perf cs-etm: Bail out immediately for instruction sample failure (Michael Petlan) [1709242]
- [tools] perf cs-etm: Introduce invalid address macro (Michael Petlan) [1709242]
- [tools] perf hists: Clarify callchain disabling when available (Michael Petlan) [1709242]
- [tools] perf tests: Check that complex event name is parsed correctly (Michael Petlan) [1709242]
- [arm64] arm64: perf: Reject stand-alone CHAIN events for PMUv3 (Michael Petlan) [1709242]
- [x86] perf/x86/amd/uncore: Set ThreadMask and SliceMask for L3 Cache perf events (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Fix PCI BDF address of M3UPI on SKX (Michael Petlan) [1709242]
- [kernel] perf/ring_buffer: Prevent concurent ring buffer access (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Use boot_cpu_data.phys_proc_id instead of hardcorded physical package ID 0 (Michael Petlan) [1709242]
- [kernel] perf/core: Fix perf_pmu_unregister() locking (Michael Petlan) [1709242]
- [kernel] perf/core: Add sanity check to deal with pinned event failure (Michael Petlan) [1709242]
- [kernel] perf/core: Force USER_DS when recording user stack data (Michael Petlan) [1709242]
- [include] perf/UAPI: Clearly mark __PERF_SAMPLE_CALLCHAIN_EARLY as internal use (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Add support/quirk for the MISPREDICT bit on Knights Landing CPUs (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Simplify breakpoint enable in perf_event_modify_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Enable breakpoint in modify_user_hw_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove superfluous bp->attr.disabled = 0 (Michael Petlan) [1709242]
- [kernel] arm64: perf: Add cap_user_time aarch64 (Michael Petlan) [1709242]
- [include] arm_pmu: Add support for 64bit event counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support Extended PEBS for Goldmont Plus (Michael Petlan) [1709242]
- [x86] perf/x86/intel/ds: Handle PEBS overflow for fixed counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support PEBS on fixed counters (Michael Petlan) [1709242]
- [kernel] perf, tools: Use correct articles in comments (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Clean up and consolidate modify_user_hw_breakpoint_check() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Pass new breakpoint type to modify_breakpoint_slot() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove default hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/arch/arm64: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [powerpc] perf/arch/powerpc: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [x86] perf/arch/x86: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/hw_breakpoint: Pass arch breakpoint struct to arch_check_bp_in_kernelspace() (Michael Petlan) [1709242]
- [kernel] perf/core: Change perf_mmap_fault() return type to 'vm_fault_t' (Michael Petlan) [1709242]
- [x86] perf/x86/intel/lbr: Optimize context switches for the LBR call stack (Michael Petlan) [1709242]
- [netdrv] cnic: Refactor code and mark expected switch fall-through (Nilesh Javali) [1665302]
- [netdrv] cnic: remove use of VLAN_TAG_PRESENT (Nilesh Javali) [1665302]
- [netdrv] cnic: use kvzalloc to allocate memory for csk_tbl (Nilesh Javali) [1665302]
- [netdrv] cnic: remove redundant pointer req and variable func (Nilesh Javali) [1665302]
- [scsi] drivers: Remove useless trailing comments from mmiowb() invocations (Nilesh Javali) [1665307]
- [scsi] scsi: qedf: remove set but not used variables (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.20 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add return value to log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print fcport information on wait for upload timeout (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check the return value of start_xmit (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for fcoe_libfc_config failure (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add comment to display logging levels (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add port_id for fcport into initiate_cleanup debug message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add LBA to underrun debug messages (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print scsi_cmd backpointer in good completion path if the command is still being used (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add driver state to 'driver_stats' debugfs node (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Change MSI-X load error message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: remove memset/memcpy to nfunc and use func instead (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Remove set but not used variable 'fr_len' (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.19 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Fix lport may be used uninitialized warning (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correctly handle refcounting of rdata (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Cleanup rrq_work after QEDF_CMD_OUTSTANDING is cleared (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for tm_flags instead of cmd_type during cleanup (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add a flag to help debugging io_req which could not be cleaned (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't send ABTS for under run scenario (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't queue anything if upload is in progress (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check both the FCF and fabric ID before servicing clear virtual link (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fc_rport_priv reference counting fixes (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_scsi_done() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Wait for upload and link down processing during soft ctx reset (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add additional checks for io_req->sc_cmd validity (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup bit operations (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup locking in qedf_restart_rport() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: missing kref_put in qedf_xmit() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for link state before processing LL2 packets and send fipvlan retries (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing fc_disc_init call after allocating lport (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct the memory barriers in qedf_ring_doorbell (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Use a separate completion for cleanup commands (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify abort and tmf handler to handle edge condition and flush (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify flush routine to handle all I/Os and TMF (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Simplify s/g list mapping (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_post_io_req() in the fcport offload check (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct xid range overlap between offloaded requests and libfc requests (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Do not retry ELS request if qedf_alloc_cmd fails (Nilesh Javali) [1665301]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665301]
- [scsi] scsi: stop setting up request->special (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: no need to check return value of debugfs_create functions (Nilesh Javali) [1665301]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: NULL check before some freeing functions is not needed (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fully convert to the generic DMA API (Nilesh Javali) [1665301]
- [scsi] scsi: qedi: Adjust termination and offload ramrod timers (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Abort ep termination if offload not scheduled (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fix spelling mistake "oflload" -> "offload" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: remove declaration of nvm_image from stack (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Remove set but not used variable 'cls_sess' (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add ep_state for login completion on un-reachable targets (Nilesh Javali) [1665300]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Update driver version to 8.33.0.21 (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Move LL2 producer index processing in BH. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: add module param to set ping packet size (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add packet filter in light L2 Rx path. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Check for session online before getting iSCSI TLV data. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Replace PAGE_SIZE with QEDI_PAGE_SIZE (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Fix spelling mistake "OUSTANDING" -> "OUTSTANDING" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Cleanup redundant QEDI_PAGE_SIZE macro definition (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fully convert to the generic DMA API (Nilesh Javali) [1665300]
- [x86] x86/kdump: Fall back to reserve high crashkernel memory (Pingfan Liu) [1682984]
- [x86] x86/kdump: Have crashkernel=X reserve under 4G by default (Pingfan Liu) [1682984]
- [x86] Revert "[x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr" (Pingfan Liu) [1682984]
- [scsi] scsi: core: avoid pre-allocating big SGL for data (Ewan Milne) [1698297]
- [scsi] scsi: core: avoid pre-allocating big SGL for protection information (Ewan Milne) [1698297]
- [nvme] scsi: lib/sg_pool.c: improve APIs for allocating sg pool (Ewan Milne) [1698297]
- [kvm] KVM: PPC: Book3S HV: Save/restore vrsave register in kvmhv_p9_guest_entry() (Suraj Jitindar Singh) [1700272]
- [fs] ext4: avoid kernel warning when writing the superblock to a dead device (Lukas Czerner) [1695021]
- [fs] ext4: cond_resched in work-heavy group loops (Lukas Czerner) [1698815]
- [fs] ext4: ignore e_value_offs for xattrs with value-in-ea-inode (Lukas Czerner) [1698815]
- [fs] ext4: protect journal inode's blocks using block_validity (Lukas Czerner) [1698815]
- [fs] ext4: use BUG() instead of BUG_ON(1) (Lukas Czerner) [1698815]
- [fs] jbd2: check superblock mapped prior to committing (Lukas Czerner) [1698815]
- [fs] ext4: remove incorrect comment for NEXT_ORPHAN() (Lukas Czerner) [1698815]
- [fs] ext4: make sanity check in mballoc more strict (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race with debug_want_extra_isize (Lukas Czerner) [1698815]
- [fs] ext4: fix ext4_show_options for file systems w/o journal (Lukas Czerner) [1698815]
- [fs] ext4: actually request zeroing of inode table after grow (Lukas Czerner) [1698815]
- [fs] Revert "ext4: use ext4_write_inode() when fsyncing w/o a journal" (Lukas Czerner) [1698815]
- [fs] ext4: fix some error pointer dereferences (Lukas Czerner) [1698815]
- [fs] ext4: fix special inode number checks in __ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: prohibit fstrim in norecovery mode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup bh release code in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: brelse all indirect buffer in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: report real fs size after failed resize (Lukas Czerner) [1698815]
- [fs] ext4: add missing brelse() in add_new_gdb_meta_bg() (Lukas Czerner) [1698815]
- [fs] ext4: remove useless ext4_pin_inode() (Lukas Czerner) [1698815]
- [fs] ext4: avoid panic during forced reboot (Lukas Czerner) [1698815]
- [fs] ext4: fix data corruption caused by unaligned direct AIO (Lukas Czerner) [1698815]
- [fs] ext4: fix NULL pointer dereference while journal is aborted (Lukas Czerner) [1698815]
- [fs] jbd2: jbd2_get_transaction does not need to return a value (Lukas Czerner) [1698815]
- [fs] jbd2: fix invalid descriptor block checksum (Lukas Czerner) [1698815]
- [fs] ext4: fix bigalloc cluster freeing when hole punching under load (Lukas Czerner) [1698815]
- [fs] ext4: add sysfs attr /sys/fs/ext4/<disk>/journal_task (Lukas Czerner) [1698815]
- [fs] ext4: Change debugging support help prefix from EXT4 to Ext4 (Lukas Czerner) [1698815]
- [fs] ext4: fix compile error when using BUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] jbd2: fix compile warning when using JBUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] ext4: annotate more implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: annotate implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: don't update s_rev_level if not required (Lukas Czerner) [1698815]
- [fs] jbd2: fold jbd2_superblock_csum_{verify,set} into their callers (Lukas Czerner) [1698815]
- [fs] jbd2: fix race when writing superblock (Lukas Czerner) [1698815]
- [fs] ext4: fix crash during online resizing (Lukas Czerner) [1698815]
- [fs] ext4: disallow files with EXT4_JOURNAL_DATA_FL from EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: add mask of ext4 flags to swap (Lukas Czerner) [1698815]
- [fs] ext4: update quota information while swapping boot loader inode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup pagecache before swap i_data (Lukas Czerner) [1698815]
- [fs] ext4: fix check of inode in swap_inode_boot_loader (Lukas Czerner) [1698815]
- [fs] ext4: unlock unused_pages timely when doing writeback (Lukas Czerner) [1698815]
- [fs] ext4: cleanup clean_bdev_aliases() calls (Lukas Czerner) [1698815]
- [fs] jbd2: discard dirty data when forgetting an un-journalled buffer (Lukas Czerner) [1698815]
- [fs] jbd2: clear dirty flag when revoking a buffer from an older transaction (Lukas Czerner) [1698815]
- [fs] ext4: replace opencoded i_writecount usage with inode_is_open_for_write() (Lukas Czerner) [1698815]
- [fs] jbd2: fix deadlock while checkpoint thread waits commit thread to finish (Lukas Czerner) [1698815]
- [fs] ext4: use IS_ENCRYPTED() to check encryption status (Lukas Czerner) [1698815]
- [fs] ext4: track writeback errors using the generic tracking infrastructure (Lukas Czerner) [1698815]
- [fs] ext4: use ext4_write_inode() when fsyncing w/o a journal (Lukas Czerner) [1698815]
- [fs] ext4: fix a potential fiemap/page fault deadlock w/ inline_data (Lukas Czerner) [1698815]
- [fs] ext4: make sure enough credits are reserved for dioread_nolock writes (Lukas Czerner) [1698815]
- [fs] ext4: check for shutdown and r/o file system in ext4_write_inode() (Lukas Czerner) [1698815]
- [fs] ext4: force inode writes when nfsd calls commit_metadata() (Lukas Czerner) [1698815]
- [fs] ext4: avoid declaring fs inconsistent due to invalid file handles (Lukas Czerner) [1698815]
- [fs] ext4: include terminating u32 in size of xattr entries when expanding inodes (Lukas Czerner) [1698815]
- [fs] ext4: compare old and new mode before setting update_mode flag (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_GROUP_ADD ioctl (Lukas Czerner) [1698815]
- [fs] ext4: hard fail dax mount on unsupported devices (Lukas Czerner) [1698815]
- [fs] ext4: remove redundant condition check (Lukas Czerner) [1698815]
- [fs] jbd2: clean up indentation issue, replace spaces with tab (Lukas Czerner) [1698815]
- [fs] ext4: clean up indentation issues, remove extraneous tabs (Lukas Czerner) [1698815]
- [fs] ext4: missing unlock/put_page() in ext4_try_to_write_inline_data() (Lukas Czerner) [1698815]
- [fs] ext4: fix possible use after free in ext4_quota_enable (Lukas Czerner) [1698815]
- [fs] jbd2: avoid long hold times of j_state_lock while committing a transaction (Lukas Czerner) [1698815]
- [fs] ext4: add ext4_sb_bread() to disambiguate ENOMEM cases (Lukas Czerner) [1698815]
- [fs] ext4: remove unneeded brelse call in ext4_xattr_inode_update_ref() (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race in ext4_remount()'s error path (Lukas Czerner) [1698815]
- [fs] ext4: don't open-code ERR_CAST (Lukas Czerner) [1698815]
- [fs] ext4: cache NULL when both default_acl and acl are NULL (Lukas Czerner) [1698815]
- [fs] ext4: propagate error from dquot_initialize() in EXT4_IOC_FSSETXATTR (Lukas Czerner) [1698815]
- [fs] ext4: fix setattr project check in fssetxattr ioctl (Lukas Czerner) [1698815]
- [fs] ext4: convert fault handler to use vm_fault_t type (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: fix argument checking in EXT4_IOC_MOVE_EXT (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at page invalidation time (Lukas Czerner) [1698815]
- [fs] ext4: adjust reserved cluster count when removing extents (Lukas Czerner) [1698815]
- [fs] ext4: reduce reserved cluster count by number of allocated clusters (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at delayed write time (Lukas Czerner) [1698815]
- [fs] ext4: add new pending reservation mechanism (Lukas Czerner) [1698815]
- [fs] ext4: generalize extents status tree search functions (Lukas Czerner) [1698815]
- [fs] ext4: readpages() should submit IO as read-ahead (Lukas Czerner) [1698815]
- [fs] ext4: improve code readability in ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: use swap macro in mext_page_double_lock (Lukas Czerner) [1698815]
- [fs] ext4: fix warning message in ext4_enable_quotas() (Lukas Czerner) [1698815]
- [fs] ext4: super: extend timestamps to 40 bits (Lukas Czerner) [1698815]
- [fs] jbd2: replace current_kernel_time64 with ktime equivalent (Lukas Czerner) [1698815]
- [fs] ext4: use timespec64 for all inode times (Lukas Czerner) [1698815]
- [fs] ext4: use ktime_get_real_seconds for i_dtime (Lukas Czerner) [1698815]
- [fs] ext4: use 64-bit timestamps for mmp_time (Lukas Czerner) [1698815]
- [scsi] scsi: smartpqi: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add spdx (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update copyright (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add H3C controller IDs (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase LUN reset timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Reporting 'logical unit failure' (Don Brace) [1665565]
- [scsi] scsi: smartpqi_init: fix boolean expression in pqi_device_remove_start (Don Brace) [1665565]
- [scsi] scsi: smartpqi: call pqi_free_interrupts() in pqi_shutdown() (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix build warnings (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add ofa support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase fw status register read timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add smp_utils support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct lun reset issues (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct volume status (Don Brace) [1665565]
- [scsi] scsi: smartpqi: do not offline disks for transient did no connect conditions (Don Brace) [1665565]
- [scsi] scsi: smartpqi: allow for larger raid maps (Don Brace) [1665565]
- [scsi] scsi: smartpqi: check for null device pointers (Don Brace) [1665565]
- [scsi] scsi: smartpqi: enhance numa node detection (Don Brace) [1665565]
- [scsi] scsi: smartpqi: wake up drives after os resumes from suspend (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix disk name mount point (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add h3c ssid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add sysfs attributes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: refactor sending controller raid requests (Don Brace) [1665565]
- [scsi] scsi: smartpqi: turn off lun data caching for ptraid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct host serial num for ssa (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add no_write_same for logical volumes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Add retries for device reset (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add support for PQI Config Table handshake (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fully convert to the generic DMA API (Don Brace) [1665565]
- [net] rtnetlink: always put IFLA_LINK for links with a link-netnsid (Sabrina Dubroca) [1711933]
- [net] ipv6: add inet6_fill_args (Ivan Vecera) [1711956]
- [net] ipv4: add inet_fill_args (Ivan Vecera) [1711956]
- [net] rtnetlink: s/IFLA_IF_NETNSID/IFLA_TARGET_NETNSID/g (Ivan Vecera) [1711956]
- [include] if_link: add IFLA_TARGET_NETNSID alias (Ivan Vecera) [1711956]
- [net] rtnetlink: move type calculation out of loop (Ivan Vecera) [1711956]
- [net] ipv6: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [net] ipv4: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [include] if_addr: add IFA_TARGET_NETNSID (Ivan Vecera) [1711956]
- [net] rtnetlink: add rtnl_get_net_ns_capable() (Ivan Vecera) [1711956]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix untagged test (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: Tweak tc filters for mirror-to-gretap tests (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: lib: Avoid trapping soft devices (Hangbin Liu) [1710283]
- [tools] selftests: pmtu: maximum MTU for vti4 is 2^16-1-20 (Hangbin Liu) [1704659]
- [net] sched: red: inform offloads about harddrop setting (Ivan Vecera) [1710999]
- [net] tls: fix copy to fragments in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't copy negative amounts of data in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't leak IV and record seq when offload fails (Ivan Vecera) [1710366]
- [net] tls: avoid potential deadlock in tls_set_device_offload_rx() (Ivan Vecera) [1710366]
- [net] tls: prevent bad memory access in tls_is_sk_tx_device_offloaded() (Ivan Vecera) [1710366]
- [net] tls: Combined memory allocation for decryption request (Ivan Vecera) [1710366]
- [net] tls: Skip zerocopy path for ITER_KVEC (Ivan Vecera) [1710366]
- [net] tls: Fix copy-paste error in tls_device_reencrypt (Ivan Vecera) [1710366]
- [net] tls: Add rx inline crypto offload (Ivan Vecera) [1710366]
- [net] tls: Fill software context without allocation (Ivan Vecera) [1710366]
- [net] tls: Split tls_sw_release_resources_rx (Ivan Vecera) [1710366]
- [net] tls: Split decrypt_skb to two functions (Ivan Vecera) [1710366]
- [net] tcp: Don't coalesce decrypted and encrypted SKBs (Ivan Vecera) [1710366]
- [include] Add TLS rx resync NDO (Ivan Vecera) [1710366]
- [net] Add TLS RX offload feature (Ivan Vecera) [1710366]
- [net] Add decrypted field to skb (Ivan Vecera) [1710366]
- [net] tls: Use aead_request_alloc/free for request alloc/free (Ivan Vecera) [1710366]
- [net] tls: Refactor tls_offload variable names (Ivan Vecera) [1703389]

* Thu May 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-99.el8]
- [netdrv] qede: use ethtool_rx_flow_rule() to remove duplicated parser code (Manish Chopra) [1663274]
- [netdrv] qede: place ethtool_rx_flow_spec after code after TC flower codebase (Manish Chopra) [1663274]
- [netdrv] drivers: net: use flow action infrastructure (Manish Chopra) [1663274]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Manish Chopra) [1663274]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Manish Chopra) [1663274]
- [netdrv] qede: Populate mbi version in ethtool driver query data. (Manish Chopra) [1663274]
- [netdrv] qed: Define new MF bit for no_vlan config (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "faspath" -> "fastpath" (Manish Chopra) [1663274]
- [netdrv] qed: Fix the DORQ's attentions handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix missing DORQ attentions (Manish Chopra) [1663274]
- [netdrv] qed: Fix the doorbell address sanity check (Manish Chopra) [1663274]
- [netdrv] qed: Delete redundant doorbell recovery types (Manish Chopra) [1663274]
- [netdrv] qede: fix write to free'd pointer error and double free of ptp (Manish Chopra) [1663274]
- [netdrv] qede: Fix internal loopback failure with jumbo mtu configuration (Manish Chopra) [1663274]
- [netdrv] qed: Read device port count from the shmem (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP syn packet mac address validation. (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP buffer size provided for syn packet processing. (Manish Chopra) [1663274]
- [netdrv] qed: fix indentation issue with statements in an if-block (Manish Chopra) [1663274]
- [netdrv] qede: Add ethtool interface for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed: Add API for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed*: Advance drivers version to 8.37.0.20 (Manish Chopra) [1663274]
- [netdrv] qed: Change verbosity for coalescing message. (Manish Chopra) [1663274]
- [netdrv] qede: Fix system crash on configuring channels. (Manish Chopra) [1663274]
- [netdrv] qed: Consider TX tcs while deriving the max num_queues for PF. (Manish Chopra) [1663274]
- [netdrv] qed: Assign UFP TC value to vlan priority in UFP mode. (Manish Chopra) [1663274]
- [netdrv] qed: Fix EQ full firmware assert. (Manish Chopra) [1663274]
- [netdrv] qed: Fix stack out of bounds bug (Manish Chopra) [1663274]
- [netdrv] qed: Fix system crash in ll2 xmit (Manish Chopra) [1663274]
- [netdrv] qed: Fix VF probe failure while FLR (Manish Chopra) [1663274]
- [netdrv] qed: Fix LACP pdu drops for VFs (Manish Chopra) [1663274]
- [netdrv] qed: Fix bug in tx promiscuous mode settings (Manish Chopra) [1663274]
- [netdrv] qede: Error recovery process (Manish Chopra) [1663274]
- [netdrv] qed: Add infrastructure for error detection and recovery (Manish Chopra) [1663274]
- [netdrv] qed: Revise load sequence to avoid PCI errors (Manish Chopra) [1663274]
- [netdrv] qed: Mark expected switch fall-through (Manish Chopra) [1663274]
- [include] qed: remove duplicated include from qed_if.h (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Fix out of bounds index check in query pkey (Manish Chopra) [1663274]
- [netdrv] qed: Fix qed_ll2_post_rx_buffer_notify_fw() by adding a write memory barrier (Manish Chopra) [1663274]
- [include] qed: Fix qed_chain_set_prod() for PBL chains with non power of 2 page count (Manish Chopra) [1663274]
- [infiniband] infiniband/qedr: Potential null ptr dereference of qp (Manish Chopra) [1663274]
- [netdrv] qed: Fix an error code qed_ll2_start_xmit() (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Dispalying" -> "Displaying" (Manish Chopra) [1663274]
- [netdrv] qede: Register l2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Expose the doorbell overflow recovery mechanism to the protocol drivers (Manish Chopra) [1663274]
- [netdrv] qed: Register light L2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Register slowpath queue doorbell with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Use the doorbell overflow recovery mechanism in case of doorbell overflow (Manish Chopra) [1663274]
- [netdrv] qed: Add doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qede - Add a statistic for a case where driver drops tx packet due to memory allocation failure. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "attnetion" -> "attention" (Manish Chopra) [1663274]
- [netdrv] qed: Add support for MBI upgrade over MFW. (Manish Chopra) [1663274]
- [netdrv] qede: Update link status only when interface is ready. (Manish Chopra) [1663274]
- [netdrv] qede: Simplify the usage of qede-flags. (Manish Chopra) [1663274]
- [netdrv] qed: Display port_id in the UFP debug messages. (Manish Chopra) [1663274]
- [netdrv] qed: Fix QM getters to always return a valid pq (Manish Chopra) [1663274]
- [netdrv] qed: Fix bitmap_weight() check (Manish Chopra) [1663274]
- [netdrv] drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo (Manish Chopra) [1663274]
- [netdrv] qed: Fix reading wrong value in loop condition (Manish Chopra) [1663274]
- [netdrv] qed: Fix rdma_info structure allocation (Manish Chopra) [1663274]
- [netdrv] qed: Fix overriding offload_tc by protocols without APP TLV (Manish Chopra) [1663274]
- [netdrv] qed: Fix PTT leak in qed_drain() (Manish Chopra) [1663274]
- [netdrv] qed: Fix potential memory corruption (Manish Chopra) [1663274]
- [netdrv] qed: Fix SPQ entries not returned to pool in error flows (Manish Chopra) [1663274]
- [netdrv] qed: Fix blocking/unlimited SPQ entries leak (Manish Chopra) [1663274]
- [netdrv] qed: Fix memory/entry leak in qed_init_sp_request() (Manish Chopra) [1663274]
- [netdrv] qed: fix link config error handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix static checker warning (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "transcevier" -> "transceiver" (Manish Chopra) [1663274]
- [netdrv] qed: Prevent link getting down in case of autoneg-off. (Manish Chopra) [1663274]
- [netdrv] qede: Check available link modes before link set from ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Add supported link and advertise link to display in ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Added supported transceiver modes, speed capability and board config to HSI. (Manish Chopra) [1663274]
- [netdrv] qed: Align local and global PTT to propagate through the APIs. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Ireelevant" -> "Irrelevant" (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_ooo_submit_tx_buffers (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Remove enumerated type qed_roce_ll2_tx_dest (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "b_cb_registred" -> "b_cb_registered" (Manish Chopra) [1663274]
- [netdrv] qed: Remove set but not used variable 'p_archipelago' (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_iwarp_parse_rx_pkt (Manish Chopra) [1663274]
- [netdrv] qed: Avoid constant logical operation warning in qed_vf_pf_acquire (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_roce_mode_to_flavor (Manish Chopra) [1663274]
- [netdrv] qed: Fix mask parameter in qed_vf_prep_tunn_req_tlv (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_set_tunn_cls_info (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "toogle" -> "toggle" (Manish Chopra) [1663274]
- [netdrv] net: qed: list usage cleanup (Manish Chopra) [1663274]
- [netdrv] net: qede: Use FIELD_SIZEOF directly instead of reimplementing its function (Manish Chopra) [1663274]
- [netdrv] qed: remove duplicated include from qed_cxt.c (Manish Chopra) [1663274]
- [netdrv] qed*: Utilize FW 8.37.7.0 (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: remove set but not used variable 'ctx' (Manish Chopra) [1663274]
- [netdrv] qed: Lower the severity of a dcbx log message. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "comparsion" -> "comparison" (Manish Chopra) [1663274]
- [netdrv] net_sched: remove list_head from tc_action (Manish Chopra) [1663274]
- [infiniband] qedr: Add user space support for SRQ (Manish Chopra) [1663274]
- [infiniband] qedr: Add support for kernel mode SRQ's (Manish Chopra) [1663274]
- [infiniband] qedr: Add wrapping generic structure for qpidr and adjust idr routines. (Manish Chopra) [1663274]
- [netdrv] qed/qede: qede_setup_tc() can be static (Manish Chopra) [1663274]
- [netdrv] qede: Ingress tc flower offload (drop action) support. (Manish Chopra) [1663274]
- [netdrv] qede: Add destination ip based flow profile. (Manish Chopra) [1663274]
- [netdrv] qed/qede: Multi CoS support. (Manish Chopra) [1663274]
- [netdrv] qede: qede_fp: Mark expected switch fall-through (Manish Chopra) [1663274]
- [netdrv] qed: qed_dev: Mark expected switch fall-throughs (Manish Chopra) [1663274]
- [netdrv] qed: Add Multi-TC RoCE support (Manish Chopra) [1663274]
- [netdrv] qed: Add DCBX API - qed_dcbx_get_priority_tc() (Manish Chopra) [1663274]
- [netdrv] qed: Make some functions static (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_get_cm_pq_idx_rl (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_set_gft_event_id_cm_hdr (Manish Chopra) [1663274]
- [netdrv] qede: Add driver callbacks for eeprom module query. (Manish Chopra) [1663274]
- [netdrv] qed: Add qed APIs for PHY module query. (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant pointer 'name' (Manish Chopra) [1663274]
- [iommu] iommu: Don't print warning when IOMMU driver only supports unmanaged domains (Jerry Snitselaar) [1707616 1694210 1689183]
- [iommu] iommu/vt-d: Check capability before disabling protected memory (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: fix sg->dma_address for sg->offset bigger than PAGE_SIZE (Jerry Snitselaar) [1694210 1694029]
- [iommu] iommu/amd: Fix NULL dereference bug in match_hid_uid (Jerry Snitselaar) [1677737 1694210]
- [iommu] iommu/vt-d: Fix NULL pointer reference in intel_svm_bind_mm() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Remove unnecessary WARN_ON() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Check identity map for hot-added devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/dmar: Fix buffer overflow during PCI bus notification (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Fix amd_iommu=force_isolation (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Handle domain agaw being less than iommu agaw (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Use memunmap to free memremap (Jerry Snitselaar) [1694210]
- [iommu] amd/iommu: Fix Guest Virtual APIC Log Tail Address Register (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix NULL pointer dereference in prq_event_thread() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Return devid as alias for ACPI HID devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Free irqs in shutdown handler (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Move irq request past pm_runtime_enable (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Handle errors returned from PM framework (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: make sure TLB to be flushed before IOVA freed (Jerry Snitselaar) [1694210]
- [idle] intel_idle: Get rid of custom ICPU() macro (Alexander Beregalov) [1710976]
- [security] selinux: do not report error on connect(AF_UNSPEC) (Ondrej Mosnacek) [1707828]
- [security] selinux: Check address length before reading address family (Ondrej Mosnacek) [1707828]
- [scsi] scsi: core: add new RDAC LENOVO/DE_Series device (Maurizio Lombardi) [1700912]
- [infiniband] i40iw: Avoid panic when handling the inetdev event (Stefan Assmann) [1659180]
- [infiniband] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659180]
- [infiniband] infiniband: prefix header search paths with $(srctree)/ (Stefan Assmann) [1659180]
- [infiniband] i40iw: remove use of VLAN_TAG_PRESENT (Stefan Assmann) [1659180]
- [infiniband] RDMA/i40iw: Fix incorrect iterator type (Stefan Assmann) [1659180]
- [infiniband] infiniband: i40iw, nes: don't use wall time for TCP sequence numbers (Stefan Assmann) [1659180]
- [infiniband] i40iw: Reorganize acquire/release of locks in i40iw_manage_apbvt (Stefan Assmann) [1659180]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659174]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659174]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659174]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659174]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659174]
- [netdrv] i40e: Memory leak in i40e_config_iwarp_qvlist (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix of memory leak and integer truncation in i40e_virtchnl.c (Stefan Assmann) [1659162]
- [netdrv] i40e: Use struct_size() in kzalloc() (Stefan Assmann) [1659162]
- [netdrv] i40e: Revert ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: missing input validation on VF message handling by the PF (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support for X710 B/P & SFP+ cards (Stefan Assmann) [1659162]
- [netdrv] i40e: Wrong truncation from u16 to u8 (Stefan Assmann) [1659162]
- [netdrv] i40e: add num_vectors checker in iwarp handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix the typo in adding 40GE KR4 mode (Stefan Assmann) [1659162]
- [netdrv] i40e: Setting VF to VLAN 0 requires restart (Stefan Assmann) [1659162]
- [netdrv] i40e: add new pci id for X710/XXV710 N3000 cards (Stefan Assmann) [1659162]
- [netdrv] i40e: VF's promiscuous attribute is not kept (Stefan Assmann) [1659162]
- [netdrv] i40e: Introduce recovery mode support (Stefan Assmann) [1659162]
- [netdrv] i40e: print PCI vendor and device ID during probe (Stefan Assmann) [1659162]
- [netdrv] i40e: fix misleading message about promisc setting on un-trusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove out-of-range comparisons in i40e_validate_cloud_filter (Stefan Assmann) [1659162]
- [netdrv] i40e: Further implementation of LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBase_LR4, CR4 and fibre (Stefan Assmann) [1659162]
- [netdrv] i40e: ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: remove error msg when vf with port vlan tries to remove vlan 0 (Stefan Assmann) [1659162]
- [netdrv] i40e: change behavior on PF in response to MDD event (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for allowing too many MDD events on VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix misleading error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Able to add up to 16 MAC filters on an untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBASE_SR4 (Stefan Assmann) [1659162]
- [netdrv] i40e: The driver now prints the API version in error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove misleading messages for untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Update i40e_init_dcb to return correct error (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for 10G ports LED not blinking (Stefan Assmann) [1659162]
- [netdrv] i40e: save PTP time before a device reset (Stefan Assmann) [1659162]
- [netdrv] i40e: don't allow changes to HW VLAN stripping on active port VLANs (Stefan Assmann) [1659162]
- [netdrv] i40e: Implement DDP support in i40e driver (Stefan Assmann) [1659162]
- [netdrv] i40e: Queues are reserved despite "Invalid argument" error (Stefan Assmann) [1659162]
- [netdrv] i40e: add tracking of AF_XDP ZC state for each queue pair (Stefan Assmann) [1659162]
- [netdrv] i40e: move i40e_xsk_umem function (Stefan Assmann) [1659162]
- [netdrv] i40e: fix WoL support check (Stefan Assmann) [1659162]
- [netdrv] i40e: fix i40e_ptp_adjtime when given a negative delta (Stefan Assmann) [1659162]
- [netdrv] i40e: fix XDP_REDIRECT/XDP xmit ring cleanup race (Stefan Assmann) [1659162]
- [netdrv] i40e: fix potential RX buffer starvation for AF_XDP (Stefan Assmann) [1659162]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Stefan Assmann) [1659162]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659162]
- [netdrv] i40e: clean up several indentation issues (Stefan Assmann) [1659162]
- [netdrv] i40e: increase indentation (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove debugfs tx_timeout support (Stefan Assmann) [1659162]
- [netdrv] i40e: check queue pairs num in config queues handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Change unmatched function types (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support FEC configuration for Fortville 25G (Stefan Assmann) [1659162]
- [netdrv] i40e: Limiting RSS queues to CPUs (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove umem from VSI (Stefan Assmann) [1659162]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659162]
- [netdrv] i40e: extend PTP gettime function to read system clock (Stefan Assmann) [1659162]
- [netdrv] i40e: DRY rx_ptype handling code (Stefan Assmann) [1659162]
- [netdrv] i40e: fix kerneldoc for xsk methods (Stefan Assmann) [1659162]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659162]
- [netdrv] i40e: suppress bogus error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Allow disabling FW LLDP on X722 devices (Stefan Assmann) [1659162]
- [netdrv] i40e: update driver version (Stefan Assmann) [1659162]
- [netdrv] i40e: Protect access to VF control methods (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace strncpy with strlcpy to ensure null termination (Stefan Assmann) [1659162]
- [netdrv] i40e: Add capability flag for stopping FW LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Use a local variable for readability (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace spin_is_locked() with lockdep (Stefan Assmann) [1659162]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Stefan Assmann) [1659162]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659162]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove unnecessary print statement (Stefan Assmann) [1659162]
- [netdrv] i40e: Use proper enum in i40e_ndo_set_vf_link_state (Stefan Assmann) [1659162]
- [nvme] nvmet: ignore EOPNOTSUPP for discard (Ewan Milne) [1696369]
- [tools] tools: bpftool: fix potential NULL pointer dereference in do_load (Ivan Vecera) [1708560]
- [tools] tools lib bpf: Provide wrapper for strerror_r to build in !_GNU_SOURCE systems (Ivan Vecera) [1708560]
- [tools] libbpf: Remove the duplicate checking of function storage (Ivan Vecera) [1708560]
- [tools] bpf: fix build error in libbpf with EXTRA_CFLAGS="-Wp, -D_FORTIFY_SOURCE=2 -O2" (Ivan Vecera) [1708560]
- [tools] tools: include reallocarray feature test in FEATURE_TESTS_BASIC (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow reuse of maps with bpftool prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow map reuse (Ivan Vecera) [1708560]
- [tools] tools: bpf: make use of reallocarray (Ivan Vecera) [1708560]
- [tools] tools: libbpf: move library error code into a separate file (Ivan Vecera) [1708560]
- [tools] tools: bpftool: reimplement bpf_prog_load() for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add extended attributes version of bpf_object__open() (Ivan Vecera) [1708560]
- [tools] tools: libbpf: recognize offload neutral maps (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow users to specify program type for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: expose the prog type guessing from section name logic (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add support for loading programs for offload (Ivan Vecera) [1708560]
- [tools] tools: bpftool: refactor argument parsing for prog load (Ivan Vecera) [1708560]
- [tools] selftests/bpf: add Error: prefix in check_extack helper (Ivan Vecera) [1708560]
- [tools] selftests/bpf: remove duplicated word from test offloads (Ivan Vecera) [1708560]
- [tools] tools: bpftool: deal with options upfront (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add missing --bpffs to completions (Ivan Vecera) [1708560]
- [tools] tools: bpftool: drop unnecessary Author comments (Ivan Vecera) [1708560]
- [tools] tools: libbpf: don't return '.text' as a program for multi-function programs (Ivan Vecera) [1708560]
- [tools] tools: libbpf: restore the ability to load programs from .text section (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow setting ifindex for programs and maps (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add section names for missing program types (Ivan Vecera) [1708560]
- [tools] tools: bpftool: use correct make variable type to improve compilation time (Ivan Vecera) [1708560]
- [scsi] scsi: lpfc: nvme: avoid hang / use-after-free when destroying localport (Dick Kennedy) [1588024]

* Thu May 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-98.el8]
- [xen] ALSA: xen: Introduce shared buffer helpers for page directory... (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Initialize completion for defer messages (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Remove duplicate assignment (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Fix uninitialized adev deref (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Add pre/post bank switch ops (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: keep track of Masters in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support for multi link bank switch (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: Handle multiple master instances in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support to lock across bus instances (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix acquiring bus lock twice during master release (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix incorrect exit after configuring stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix duplicate stream state assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix for Lenovo B50-70 inverted internal microphone bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix race between creating and refreshing sysfs entries (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: uapi: fix sound/skl-tplg-interface.h userspace compilation errors (Jaroslav Kysela) [1683051]
- [include] ALSA: uapi: #include <time.h> in asound.h (Jaroslav Kysela) [1683051]
- [include] ALSA: timer: fix wrong comment to refer to 'SNDRV_TIMER_PSFLG_*' (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86/cpu: Sanitize FAM6_ATOM naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: don't select DPCM via simple-audio-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: don't select DPCM via audio-graph-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Corrected fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Avoid superfluous COEF EAPD setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixup headphone noise via runtime suspend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix unused variable warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: toneport: Fix broken usage of timer for delayed execution (Jaroslav Kysela) [1683051]
- [sound] ALSA: aica: Fix a long-time build breakage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi: no checking monitor in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save PGA for mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save output volume for mixer controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: initialize setting when ramping volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: core: fix undefined nocodec reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: xtensa: fix undefined references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Propagate sof_get_ctrl_copy_params() error properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdea/realtek - Headset fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: add CometLake PCI IDs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC295 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: Fix an uninitialized variable compile warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix a compile warning with CONFIG_PCI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Fix a compile warning at CONFIG_COMMON_CLK=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sound/soc/sof/: fix kconfig dependency warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: change trace level on iec control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: Fix restore of DAPM Muxes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: RT5677-SPI: Disable 16Bit SPI Transfers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Consider eld_valid when reporting jack event (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Read the pin sense from register when repolling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add reserved DMA memory support (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: emux: soundfont.c: divide by zero in calc_gus_envelope_time() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: Map BTN_0 to KEY_PLAYPAUSE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: add sof-rt5682 machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic:refine code style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic: add DMIC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: APL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: IPC: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: intel: hda: add hw_params_upon_resume flag for hda stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: handle real stream interrupts only (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: store stream capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: simplify handling of IPC IRQ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: ipc: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: PCM: add period_elapsed work to fix race condition in interrupt context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-pcm: remove useless dependency on hdac_ext (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set bus->idx as 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set I2S slave before enabling DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add SSP info to the chip info struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add the SSP Host Device memory space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: cnl: add pointer ops to use DPIB position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: topology: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASOC: SOF: ipc: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: add Kconfig option for strict ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: avoid Oops if DMA setup fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: stream is already locked in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: remove redundant null checks of dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skip hw_free on codec dai for which the stream is invalid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix valid stream condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: unlock the device on startup errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update the support rate list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Use clk_round_rate to handle enabled bclk/wclk case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: Headphone Jack sense inverts on the LattePanda board (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Fix missing break in switch statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct region base typo in wm_halo_setup_algs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: fix spelling mistake "incompatble" -> "incompatible" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Use DSP ops pointers to stop watchdog in error handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix to use list_for_each_entry_safe() when delete items (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix return value check in sprd_mcdt_probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: fix DAI_CLK_EN register bit overwrite (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix kcontrols for effect widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: cache pdev->dev pointer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix potential uninitialized variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: add I2S2 control path from UL2 and UL3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: change supported formats of DL2 and UL1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: remove "model" attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmix: fix object reference leaks in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs43130: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add Geminilake Realtek+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make boards more available for compile test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: Make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx: fix fiq dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: acp3x: Make acp3x_dai_i2s_ops static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove set but not used variable 'mclk_rate' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_micfil: Remove set but not used variable 'osr' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Enable TDM support for DSP_A/B modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure wclk and bclk of master codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build err while CONFIG_I2C set to module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix spelling mistake "plalform" -> "platform" (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply the fixup for ASUS Q325UAR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Register irq handler after the chip initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: fix a double free bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: overwrite hdev type to HDA_DEV_ASOC (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unregister device twice on ASoC driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: use dynamic buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix a memory leak bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix misuse of x (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - EAPD turn on later (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Dell AIO speaker noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: select relevant machine drivers for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make sure BDW based machine drivers build for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Build support for SOF core and Intel drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Kconfig: expose common option between SST and SOF drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add platform differentiation for APL and CNL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: add SKL+ platform DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add support for HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA trace operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA stream operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add hda-bus support and initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA PCM operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA firmware loader (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add ACPI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA IPC mechanisms. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA DSP HW operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add HDA controller for Intel DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add APL/CNL HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add legacy IPC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BDW HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BYT, CHT and BSW DSP HW support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add utils (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add xtensa support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Nocodec machine driver support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PM support (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: SOF: Add userspace ABI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add firmware loader support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP HW abstraction operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP firmware logger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for loading topologies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCM operations support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for IPC IO between DSP and Host (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add driver debug support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware KControl support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware driver core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: simplify dai driver initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Read pin switches conf from devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add missing return 0 in remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_parse_pin_switches() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix irq mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: fix compilation warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add support for runtime pm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Update is_slave_mode with correct value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum multi-channel data transfer support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: rt5682: initialize mutex before using (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: return the get_irq error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup 6ch settings to 8ch (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Handle the error from snd_usb_mixer_apply_create_quirk() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add new Dell platform for headset mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi add device_link to card device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: Remove set but not used variable 'stage_type' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: save fixed-up hw_params of BE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tobermory: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: speyside: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: snow: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8994*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8580: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smartq_wm8987: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_uda134x: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c2412-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: rx1950_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c-i2s-v2: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: pcm: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: lowland: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: littlemill: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: jive_wm8750: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: idma: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: h1940_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: bells: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: arndale: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ps3: Remove set but not used variables 'start_vaddr' and 'pcm_index' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - add two more pin configuration sets to quirk table (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't refer to snd_cards array directly (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Drop superfluous id-uniquification behavior (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Fix card races between register and disconnect (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Fix racy addition/deletion of nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Correct unlock sequence at snd_seq_client_ioctl_unlock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for Focusrite Scarlett Solo (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize ext-bus-specific fields in snd_hdac_bus_init(), too (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize power_state field properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect racy pool manipulation from OSS sequencer (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Simplify snd_seq_kernel_client_enqueue() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Cover unsubscribe_port() in list_mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: seq: Protect in-kernel ioctl calls with mutex" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing regmap requirement (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix racy display power access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: fix error handling when try_module_get() fails. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl: fix wrong number of channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Coding style fixes (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Simplify error path in snd_timer_open() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix race of get-subscription call vs port-delete ioctls (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect in-kernel ioctl calls with mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove superfluous irqsave flags (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Align temporary re-locking with irqsave version (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use kvmalloc() for cell pools (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Revert active callback sync check at close (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add two more machines to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix spacing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: remove headset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: update module refcount if module_get_upon_open is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: conditionally increase module refcount on component open (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for the Teclast X98+ II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm1133-ev1: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: phycore-ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm030-audio-fabric: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_rdk: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_ds: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mx27vis-aic32x4: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc8610_hpcd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-ssi: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm-fiq: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-mc13783: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-es8328: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: fix sai driver name initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the correct dobj to free enum control values and texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix OOB-reads from strlcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: change mic bias DAPM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Support synchronous mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix big-endian check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdmout: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: rework quirks settings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-frddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove link components before cleaning up card resources (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: add remove() callback for component driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l35: Disable regulators on driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add adc volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add support of master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add reset management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add regulator management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Avoid calling snd_compr_stop_error from WDT expiry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98357a: add missing supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Playback PowerTune Controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Switch for Setting Common Mode Voltage (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Do not use stream buffer size before it is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Mark RXFIFO_DATA as volatile and precious (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix spelling mistake "faied" -> "failed" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Correct PDM_CTRL0 reg value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: adjust waterlevel in frame unit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add compatible for rk1808 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fixup pdm fractional div (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: optimize clear logic (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add default regs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: using left justified store mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: change dma burst to 8 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fix regmap_ops hang issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Update copyright and use SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix the smatch warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Change author's name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk for Tuxedo XC 1509 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Move to ACT_INIT state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix modular build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: Enable codec clock once and keep it enabled (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build error in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: TS3A227: fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make use of local variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Remove redundant NULL check in wm_adsp_buffer_free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: aic31xx_set_jack() can be static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Check for buffer in trigger stop (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate B114-21 with ALC233 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Align tplg pointer increment across all kcontrols (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: support driver alias names for FE topology overrides (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio compress offload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix SND_SOC_LOCHNAGAR_SC kconfig warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: set power_check callback for widgets that shouldnt be always on (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add button press detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add headphone/headset detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: skip missing substream while applying symmetry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [acpi] ALSA: ACPI / utils: Introduce acpi_dev_get_first_match_dev() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove set but not used variable 'dai_name' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add support for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix typo in comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: fix spelling mistake: "missign" -> "missing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with DA7219 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with TS3A227 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Add ACPI ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add multi endpoint support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix Common Pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: us122l: Use alloc_pages_exact() (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers, take#2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make snd_timer_close() really kill pending actions (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Check ack_list emptiness instead of bit flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make sure to clear pending ack list (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Unify timer callback process code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: Fix kbuild failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Add support of loading GUS-patch (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speakers on Acer Predator Helios 500 Ryzen laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer CPU DAI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: enable S24_LE format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Only enable with common clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Allow 192000 Sample Rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove mclk references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Restructure set_dai_sysclk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Dynamically Determine Clocking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Move aosr and dosr setting to separate functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Control clock gating with CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model BDIV divider in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model DAC/ADC dividers in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model CODEC_CLKIN in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model PLL in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Initialize private_value in snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: aloop: Support S24 sample formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Don't suspend stream in unrecoverable PCM state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer dereference in snd_soc_dapm_free_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf-audio: Remove redundant of_match_node call (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix incorrect extern (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of 64 bits division (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix crash at suspend/resume after failed codec registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Simplify alt firmware loading code (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix possible OOB access in PCM oss plugins (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of ASUS X430UN and X512DK with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset mic of ASUS P5440FF with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable ASUS X441MB and X705FD headset MIC with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: test memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: lochnagar: Add driver to support Lochnagar 2 sound card (Jaroslav Kysela) [1683051]
- [mfd] ALSA: mfd: lochnagar: Add support for the Cirrus Logic Lochnagar (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Properly Set Processing Blocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mchp-i2s-mcc: add driver for I2SC Multi-Channel Controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: rename asoc_simple_card_xxx() to asoc_simple_() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: separate asoc_simple_card_parse_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_card_init_priv() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_be_hw_params_fixup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_dai_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_hw_param() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_shutdown() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_startup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: share common priv for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_debug_info() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Update DA7219 DAI clock name to align with codec updates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Expose BCLK and WCLK control through CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix channel swap issue when stream starts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: add constraint for the asrc of older version (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: Set auto-increment bit for register writes (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire E5-523G/ES1-432 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer Aspire Z24-890 with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Fix Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer AIO with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: add mmap support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: fix debugfs warnings on entry creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: manage multiple prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct some minor issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Don't use register read to determine slave/master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Break out clock setting into separate function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: jz4740: Depend on MIPS instead of MACH_JZ4740 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add WDT expiry IRQ handling support for Halo core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add HALO MPU fault logging (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for new Halo core DSPs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Reduce repititive code on mtk_regmap_update_bits. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Fix UBSAN warning. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out DSP specific operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out parsing of firmware ID header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor firmware status reading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Move wm_adsp2_set_dspclk to CODEC drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Don't export wm_adsp2_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Shutdown any compressed streams on DSP watchdog timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add locking to wm_adsp2_bus_error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct handling of compressed streams that restart (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free link string in error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free stream_name of dai_drv (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enforces runtime_resume after S3 and S4 for each codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Don't trigger jackpoll_work in azx_resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: add graph_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: rename graph_get_conversion() to graph_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add simple_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename simple_get_conversion() to simple_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: recording has no sound after booting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: fix jack type detection issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Check JD status when system resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: skip for i2s5 in mck_disable (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use 8 byte header for IR context to get isochronous cycle (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support MOTU 8pre FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: fix mismatch between snd_opl3_drum_switch definition and declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add Lenovo IdeaCentre B550 to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_JD_NOT_INV quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for active-high jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: Make gpio property optional (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: dt-bindings: add regulator property to simple amplifier (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: simple-amplifier: remame dio2125 documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: use 'version' field of unit directory to identify model (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: add a check for request_region (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: add a check for ioremap_nocache (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: create tlv before soc_tplg_init_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for New DELL WYSE NB (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for DELL WYSE AIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: merge alc_fixup_headset_jack to alc295_fixup_chromebook (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: hdmi - add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: automatic selecting BCLK in I2S master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the typo of function name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix clock configuration for 44100 sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of widget with prefixed name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add more quirks for HP Z2 G4 and HP Z240 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Headset Mic JD not stable (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate X514-51T with ALC255 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: avoid build error without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Avoid NULL pointer dereference at snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: axi-i2s: let both capture and playback be optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: Avoid a potential deadlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix registers declaration in regmap (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix the issue of the widget with prefix name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: prevent snd_soc_dpcm use after free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:intel:skl:fix a simultaneous playback & capture issue on hda platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:hdac_hda:use correct format to setup hda codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:soc-pcm:fix a codec fixup issue in TDM case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: fix davinci_mcasp_probe dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ams-delta: remove duplicate 'const' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: remove compat dma probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: use default dai name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: improve channel capabilities handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: change trigger traces (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add i2c dependency for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Fix clang warning without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: fix compiler warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix DAPM routes for capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Fix probe deferral following prelink failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: avoid limiting params->msbits in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix set_sync service (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix oversampling mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix exposed capabilities in spdif mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix iec958 controls indexation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ab8500: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix S/PDIF DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for MOTU MicroBook II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd add loopback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: fix reset gpio reference counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: skip useless write in slave mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: remove useless callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix dma configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix stream count management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix 16 bit format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix IRQ clearing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: fix dependency for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add Maxim98373 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: fix SSI9 4/5/6/7 busif related register address (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: fix construction of PCM frame for capture direction (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use more identical mod_alias for Saffire Pro 10 I/O against Liquid Saffire 56 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Extend i915 component bind timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Improve logging messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for multiple compressed buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor compress stream initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Reorder some functions for improved clarity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out stripping padding from ADSP data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Fix an IS_ERR() vs NULL checking bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: sound card name from device tree (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Prevent uninitialized variable use (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in qcom_snd_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in apq8016_sbc_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix of_node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Reduce click noise on Dell Precision 5820 headphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix of-node refcount unbalance in DAI-link parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix of-node refcount unbalance in fsl_ssi_probe_from_dt() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow compressed buffers in any memory region (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Update cached error state on trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: Fix energysense SLEEP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: fix wrong usage of DECLARE_TLV_DB_SCALE() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix multiple "IIS multi" devices initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix secondary platform device unregistration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk: Add DAI links for Multi-Playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add Geminilake Dialog Maxim machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Headset button support in broxton machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Rename hpvcc regulator supply to cpvdd (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1977: Add support for setting MICBIAS via DT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Potential small memory leak in dapm_cnew_widget() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add missing DAPM routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Make function 'wm8741_mute' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix register setting issue in RIGHT_J mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: imx-sgtl5000: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix missing of_node_put() at simple_dai_link_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix refcount underflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Ensure proper sample rate on pri/sec PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: remove set but not used variables 'mask, cr1' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free created components in tplg load error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Make some symbols static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select dmic for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix sysclk_df type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix TXCLK_DF mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add support to disable on-chip PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add runtime support for DSP_A and I2S modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Fix frame polarity for DSP_A format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Set constraint to always have 32 sample bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Remove capture support for codecs without ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: fix spelling mistake "doens't" -> "doesn't" (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Expose sample resolution through proc interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Prevent potential NULL platform data dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Remove unused SND_DMAENGINE_PCM_FLAG_CUSTOM_CHANNEL_NAME flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update TDM usage to be more flexible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add support for master mode BCLK rate adjustment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Comments clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Change indentation in SAMSUNG_I2S_FMTS definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Simplify pri_dai, sec_dai pointers usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Specify DMA channel names through custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add support for secondary CPU DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Get rid of a static spinlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move quirks data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move IP variant data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Drop spinlock pointer from i2s_dai data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move SFR pointer to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: Remove set but not used variable 'hw' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Disable PC beep in passthrough on alc285 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone and internal speaker support for System76 oryp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Make symbol 'cros_ec_dai' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Remove unused including <linux/version.h> (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move registers cache to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move opclk data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move core clk to the driver common data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Add widgets and routes for DPCM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move clk supplier data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Restore support for the secondary PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Comment why read blocks when PCM is not running (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove new_mach_data field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cnl-match.c: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: icl-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: hsw-bdw-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: glk-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cht-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: byt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: bxt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: icl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hsw-bdw-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hda-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cnl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: byt-match.c: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to single component with multiple DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Allow to specify custom DMA device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Extend use of chan_names provided in custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Improve of_node test in dmaengine_pcm_request_chan_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix prescaler setting for the secondary DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use __printf markup to silence compiler (Jaroslav Kysela) [1683051]
- [sound] ALSA: tlv320aic32x4: delay i2c access by 1 ms after hardware reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix rx stream assign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Set OSR mode in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Add digital mute callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: PCM: check if ops are defined before suspending PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: use devm_kzalloc for all structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: use pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add clock select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add soft reset on probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: set .ignore_module_refcount field in component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: don't increase component module refcount unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: gpiolib: acpi: Introduce ACPI_GPIO_QUIRK_ONLY_GPIOIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: convert license header to SPDX (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-analog: add missing license information (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: regulator notifier registration should be managed (Jaroslav Kysela) [1683051]
- [sound] ALSA: i915/snd_hdac: I915 subcomponent for the snd_hdac (Jaroslav Kysela) [1683051]
- [base] ALSA: components: multiple components for a device (Jaroslav Kysela) [1683051]
- [documentation] ALSA: component: Add documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Revert capture stream behavior change in blocking mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix function name in kernel-doc comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Define snd_pcm_lib_preallocate_*() as returning void (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix up for snd_pcm_lib_preallocate_pages_for_all() API change (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: stm32: i2s: manage clock power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Remove unnecessary const qualifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Add support for Cirrus CS35L36 Amplifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix implicit fb endpoint setup by quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for HP EliteBook 840 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Use C++ style comments in header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Kconfig: Show knob, and depend on MIPS || COMPILE_TEST (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Add support for devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Use SPDX license notifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Prevent clk_get_rate() calls in atomic context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Line Playback Volume, Line Boost Volume, Line Right, Line Left, Line Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add FM Playback Volume, FM Left, FM Right, FM Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Playback Switch, Mic2 Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Merge sun4i_codec_left_mixer_controls and sun4i_codec_right_mixer_controls into sun4i_codec_mixer_controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Boost Volume, Mic2 Boost Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add sun7i_codec_controls, sun7i_codec_codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic Playback Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add MIC2 Pre-Amplifier, Mic2 input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: fix spelling mistake "Deemphatize" -> "Deemphasize" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix semicolon.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: correct shift bit for ssiu9 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Add jz4725b-codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup rsnd_ssi_master_clk_start() user count check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: harden use of lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xtensa: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dwc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix out-of-bounds accesses to DAPM lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Clean up proc file creations (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Move card id proc creation into info.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Minor optimization (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Drop unused snd_info_entry.card field (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Add standard helpers for card proc file entries (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl4: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Add helper functions for component trigger/set_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Clarify the intent of current compressed ops handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: remove some unnecessary NULL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: Fix ADC powerup sequencing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Check for NULL widget in dapm_update_dai_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: spi: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: parisc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: atmel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix build error without CONFIG_PCI (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Fix stop handling on compressed capture streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for new T+A USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Always register entries recursively (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't allow NULL device for memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: fix missing header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd: fix spelling mistake "offest" -> "offset" (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: unload physical dai link in remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: add SND_SOC_DOBJ_GRAPH type for dapm routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: clear platform pointers on error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: fix object reference leaks in fsl_asoc_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add warnings for widget overwrite when adding route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Only power up active channels from a DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix oops/use-after-free case with dai driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix use-after-free issue with dailink sname (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: add btcvsd driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Add channel numbers to AIFs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup TDM Split mode check for CTU (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: synchronize connection check for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup MIX kctrl registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hal2: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Serialize codec registrations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use a common helper for hp pin reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix lose hp_pins for disable auto mute (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone support for System76 darp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: remove a superfluous function declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio DMA platfrom driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: modify dapm route loading routine and add dapm route unloading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix memory leak in soc_tplg_dapm_widget_create (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Fix memory leak from soc_tplg_denum_create_texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Remove widgets from dobj list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Reduce number of dereferences when accessing dobj (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use standard device registration for beep (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply ALC294 hp init also for S4 resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Record the current power state before suspend/resume calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: remove useless test (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed hp_pin no value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Add codec driver for Cros EC (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: Documentation: Add google, cros-ec-codec (Jaroslav Kysela) [1683051]
- [maintainers] ALSA: MAINTAINERS: add maintainers for ChromeOS EC sub-drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing slimbus dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Cleanup DSD whitelist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: add slim support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add audio routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add capture dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add playback dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add basic controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_rt298: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broadwell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: haswell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add helper to change platform name for all dailinks (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: add support for Solid State Logic Duende Classic/Mini (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Variable "ret" in function rt5651_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: add static inline fallbacks when CONFIG_ACPI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix clocking calculations when not using the PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the set_bclk_ratio interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs V2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fixup build error for mt6358 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix tight loop of OSS capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add Opus #3 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: add platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow soc_find_component lookups to match parent of_node (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use the common error path in __snd_pcm_lib_xfer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: Off by one in latter_handle_midi_msg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: make const arrays static, reduces object code size (Jaroslav Kysela) [1683051]
- [sound] ALSA: proc: Avoid possible leaks of snd_info_entry objects (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Simplify proc file destruction (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Drop unused snd_pcm_substream.file field (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: comment cleanup about destination address of async transactions for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Cleanup snd_pcm_stream_lock() & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove down_write() hack for snd_pcm_link_rwsem (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: More fine-grained PCM link locking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Fix multi-CODEC setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support rx MIDI functionality for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-specific operation to fill transaction buffer with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address to receive async transaction for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support tx MIDI functionality of Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address range to receive async transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: change prototype of handler for async transaction with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Correct the setting while select ASRC clk for AD/DA filter (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add driver flag for runtime PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: implement runtime suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: remove redundant clock enable API (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add runtime PM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: get clock handles early in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: runtime power management support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename to asoc_simple_card_canonicalize_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add soc_cleanup_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: reduce if/else nest on soc_probe_link_dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: merge card resources cleanup method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add new snd_soc_flush_all_delayed_work() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add .num_platform for dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Avoid confusing loop in snd_pcm_unlink() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make PCM linked list consistent while re-grouping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Unify snd_pcm_group initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_card_unref() inside in_pcm_file() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mute LED support for HP ProBook 470 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to parse of clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring for dump of sync status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to get clock status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to switch mode to fetch PCM frame (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to dump status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: obsolete proc node to leave one node (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: unify protocol layer for FF400/FF800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: rename protocol layer for former models (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: add explanation of legacy/modern style of dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Remove expensive print in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove error due to probe deferral (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: lower log level for potential probe deferral cases (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: put of nodes if finding codec fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix oops on re-probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add default pdata for i2s mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Set DAI format for dmic codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select max98927 for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix PLL source register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't defer probe on optional, NULL components (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make snd_pcm_suspend() local static (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Move PCM suspend/resume code into trigger callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Suspend streams globally via device type PM ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Make snd_soc_find_component() more robust (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix init platform memory handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: parse AES audio parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Select REGMAP_MMIO to fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: remove few unused variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: fix waring unused-function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe control for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe bits for controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add verbs for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add register offset for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add api to program stripe control bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skl: Fix display power regression (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix typo for ALC225 model (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Hold client_mutex around soc_init_dai_link() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: use correct drvdata in snd_byt_cht_es8316_mc_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: move the codec PLL configuration to _init (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: SND_SOC_DAPM_MICBIAS is deprecated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add recalc_rate function to return DAI clock rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: MCLK should be enabled before DAI clocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: defer card probe until all component is added to list (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Remove set but not used variable 'first_ch_bits' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix a mask wrong issue in snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatches for register mask and value in hdac controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Disable headset Mic VREF for headset mode of ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add unplug function into unplug state of Headset Mode for ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix CM6206 register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Variable "buf" in function rt274_jack_detect() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ADAU7002: Add optional delay before start of capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Potential NULL dereference in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk for PoV TAB-P1006W-232 (v1.0) tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for jack-detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirks module parameter (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Revert "Fix DMIC map headsetmic mapping" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for jack detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add ACPI ID 10EC5640 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for PoV P1006W tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: update BSDSR/BSDISR handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: Allow SCLK pad drive strength to be changed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable SPDIF driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add SPDIF audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Kernel OOPS while entering DAPM standby mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add MICFIL SoC Digital Audio Interface driver. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eliminate left-over from Raumfeld machine driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt298: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rl6437a: use __be32 for a __be32 buf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: store eq kcontrol byte in __be (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use logical AND (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6351: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs42xx.c: fix boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix boolean assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98927: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rt286: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4271: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98383: fix boolean assignments to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: remove unused mux/mixer define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: remove unused mux define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: fix kernel doc descriptions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: declare trigger function as static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: Add support for AK4497 (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: fix a missing check of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: fix check on snd_card_register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1712: fix a missing check of snd_i2c_sendbytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: add a check of the status of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxygen: initialize spdif_playback_enable to 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: virtuoso: add de-emphasis control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support Dell headset mode for New AIO platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix an out-of-bound read in create_composite_quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Always check descriptor sizes in parser code (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Check mixer unit descriptors more strictly (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Avoid access before bLength check in build_audio_procunit() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for GPIO mode of the pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Move context save/restore to runtime_pm callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: No need for IS_MODULE/BUILTIN check for pcm driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for ASUS MeMO Pad 7 (ME176C) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Fallback to BYT-CR if IRQ 5 is missing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Simplify is_byt_cr() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add ACPI match table entry for ES8316 codec on BYTCR platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Set card long_name based on quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add input-map support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add external speaker mux support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add support for SSP0 (BYTCR) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Minor refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Sort includes alphabetically (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Let core handle GPIO descriptor (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator/gpio: Allow nonexclusive GPIO access (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Default enable high on DT regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add DAC mono mix switch mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Variable "val" in function rt274_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix error handling in xlnx_formatter_pcm_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add workaround for silence of rk3288 ACODEC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: support ACODEC for rk3328 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add asoc_simple_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable audio formatter driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add pcm formatter platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: remove simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add asoc_graph_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: check "reg" property on asoc_simple_card_get_dai_id() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: use snd_mask_set_format in all machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: simplify boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: assign booleans to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: remove unneeded semicolon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: enable MCLK in STANDBY (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: save model id directly in of_device_id.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: make the driver visible in Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: Add driver for CS4341 DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix recording no sound issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: atom: Make PCI dependency explicit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: prevent potential divide by zero bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a small memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a NULL vs IS_ERR() bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Off by one in of_q6asm_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix a double unlock in pcm512x_digital_mute() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: change license header format style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell/Broadwell: fix setting for .dynamic field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Grammar s/the the/the/ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: cleanup a debug printk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: set jack only for a specific backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Revert DSP detection on legacy HD-audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: clear pending irq handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable the headset mic auto detection for ASUS laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: force HDaudio legacy or SKL+ driver selection (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: abort probe if DSP is present and Skylake driver selected (Jaroslav Kysela) [1683051]
- [sound] ALSA: HDA: export process_unsol_events() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix model-id of unit for Apogee Ensemble (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Use Xen common shared buffer implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Kconfig: Remove the deprecated options (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Merge davinci and omap directories (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add mute LED support for HP EliteBook 840 G4 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle model-specific registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for packet streaming on Fireface 800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: allocate isochronous resources in mode-specific implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle multiplier mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to switch fetching mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix for state to fetch PCM frames (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use the same print format for 'without_header' tracepoints (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong assignment for 'out_packet_without_header' tracepoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong handling payload_length as payload_quadlet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add display_port_rx port routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to Display port RX dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: add support for display_port_rx (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Add support to compress offload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: add support to MP3 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: soc-compress: add support to snd_compr_set_runtime_buffer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: make use of runtime buffer for copy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add more platform granularity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: merge simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: merge audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() ID method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Invoke pcm_new() for all DAI-link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the digital_mute interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: fix do_div warning in spdifin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add error logs on probe, remove dependency on NHLT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless tests on HDaudio capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: stop probe if HDaudio capabilities don't exist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Harden DSP detection with PCI class/subclass info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add CFL-S support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add powersaving widgets for DAC and ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable i2s driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Add i2s driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: Add a new machine driver for kbl with rt5660 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add support for spdifin backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Dereference pointer for memcpy sizeof in asoc_simple_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add support for Huawei WMI micmute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix front speakers on Huawei MBXP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove RSND_REG_ from rsnd_reg (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface 800 with MIDI functionality only (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: localize a handler for MIDI messages on tx transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add driver data for register for MIDI high address (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share register for async transaction of MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for second optical interface for ADAT stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to get current sampling rate and clock source (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share status and configuration dump (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share some registers for status of clock synchronization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: add dai-link support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - make pci_iounmap() call conditional (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Always set display_power_control for Intel HSW+ codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add missing display power-off at driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make snd_hdac_display_power() void function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Properly free the display power at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Drop superfluous AZX_DCAPS_I915_POWERWELL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Refactor display power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: use cpu/codec pointer on simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fix build warning without CONFIG_OF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: add rt5663 codec select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: fix the audio jack button remapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Point of View Mobii TAB-P1005W-232 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Prowise PT301 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS X542UN (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Refactoring PM code (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix reference to wrong register for clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1 Carbon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Add copyright and module author (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add configuration for headset codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add TDM configuration for speaker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix signal paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Calculate LRCLK divider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Remove useless assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Enable headset button support for new codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack button support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack pointer and unsolicited event bits to callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed headphone issue for ALC700 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5660: Add a new ACPI match ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ak4104: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: cs4270: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use dma_ops of parent device for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use DMA addr rather than CPU pa for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Gnawty (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove direct OF name and type accesses (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4860G/Z6860G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer Aspire U27-880 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added max98373_reset for stable amp reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add missing TDM Split mode support for simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup mod ID for CTU regmap read/write (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: indicates Channel and Mode for debug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Add Tegra186 and Tegra194 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra - Probe up to 8 codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Clapper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove raumfeld machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix UAF decrement if card has no live interfaces in card.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for ICL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speaker output regression on Thinkpad T570 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: au8540: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add support for AMD Stoney Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix starvation on down_write_nonblock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_pcm_unlink() conditionally at closing (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: compatible string as shortname (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: thinkpad_acpi: Add audio mute LED classdev support (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: dell-laptop: Add micmute LED trigger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Support led audio trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Don't disable pcm3168a when CONFIG_PM defined (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce module_param wakeup_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce mode switch delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Create and setup jack in init callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Add board specific dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Implement configurable dismod handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Update PDIR (pin direction) register handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Clear TXSTAT register before activating serializers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add FW reply for MCLK/SCLK IPC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Make DSP replies more human readable (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: trigger: Introduce audio mute LED trigger (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: core: Introduce LED pattern trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup registering method for rsnd_kctrl_new() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support ALC300 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix whitespace (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: makes snd_soc_of_parse_audio_prefix() inline (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix a NULL vs IS_ERR() check in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix the pop noise on headphone for lenovo laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix spelling mistake "Frequence" -> "Frequency" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Consolidate helpers for adding and replacing ctl elements (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Fix race between adding and removing a user element (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix headset mic detection for MSI MS-B171 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: notify events of change of state for userspace applications (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: apply small refactoring to handle several type of event for hwdep interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: queue events for change of control surface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: add new hwdep ioctl command to get state image (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: pick up data of state from tx isochronous pakcets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Add pm_qos handling to avoid overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Fix latency value calculation for pm_qos (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup define position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup typo SND_AUDIO_GRAPH_CARD (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_of_parse_node_prefix() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: add VCC regulator widget (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Add support for cpvdd regulator supply (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: remove "option" from asoc_simple_card_of_parse_routing() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: tidyup asoc_simple_card_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: accept NULL parameter on asoc_simple_card_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove asoc_simple_card_clk_register() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: makes rsnd_ssi_is_dma_mode() static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup rsnd_parse_connect_ssiu_compatible() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add support for Secondary MI2S interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Update slot_width for Quaternary TDM port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use platform_data for machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: fix interface for Chromebook machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: define common interface for machine driver configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: fix: continue searching when machine is ignored (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix Kconfigs, make HDaudio codec optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: Add support for CBM_CFS and CBS_CFM clocking modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use device_type helpers to access the node type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - fix AE-5 pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add new ZxR quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: clean up indentation, replace spaces with tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Fix error handling of regulator_set_load (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix spelling mistake "Inavlid" -> "Invalid" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: fix indentation issue with return statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320dac33: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: asihpi: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert a few more users to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Add regulator support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: Add support for AK4118 S/PDIF transceiver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Fix device reset-registers trigger value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: remove set but not used variable 'dma_buffer' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fixed build errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Recalculate audio map forcely when card instantiated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-abe-twl6040: Fix missing audio card caused by deferred probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix memory leak of i2s_data on error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add DT property for single-ended output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Rename output widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Set dai_link id to each dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: add missing route for ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: enable acp3x drivers build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x system resume pm op (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x runtime pm ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x tdm mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x i2s ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x pcm driver dma ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Interrupt handler changes for ACP3x DMA driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add ACP3x PCM platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: create ACP3x PCM platform device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP3.0 PCI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP 3.x IP register header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Power down links before turning off display audio power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out common init code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix dma-unsafe read of scratch registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing slave_config setting for I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: No need to initialize max_xx_thres when it is not used (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Remove redundant check for mcbsp->pdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Re-arrange files for core McBSP and Sidetone function split (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Move out the FIFO check from set_threshold and get_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Simplify the mcbsp_start/_stop function parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up the interrupt handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Skip dma_data.maxburst initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up dma_data addr initialization code (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: add support for APOGEE duet FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk entry for HP Pavilion 15 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Optimize for non-PCI configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use ring buffer for rsnd_mod_name() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: fix crash on module removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: oss: Use kvzalloc() for local buffer allocations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_ssi: Change to use DEFINE_SHOW_ATTRIBUTE macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add TDM Split mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add SSIU BUSIF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: handle DPCM converted rate/chan under core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move HDMI information from ssi.c to core.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use defined io_playback/io_capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rename rsnd_runtime_is_ssi_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove error check which never happen (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add quirk for APL RVP boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add SOF information for APL RVP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: remove GFP_ATOMIC, use GFP_KERNEL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: fix Skylake typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Atom machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Hdaudio machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: change ac97 dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: Remove unused machine driver for AM3517-evm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: remove read-only status register from snd_kcontrol_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: Remove redundant snd_soc_component_read32 calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Fix the dai widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Only add routing once. (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Define registers for CM6206 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix incorrect clearance of thinkpad_acpi hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Fix wrong MI2S SD line mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using pmc_plt_clk_0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rsnd_mod_name() handles both name and ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add .get_id/.get_id_sub (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move .get_status under rsnd_mod_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: cleanup hw_constraint for LEFT_J/I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: On OMAP1 and OMAP2420 only 16bit format is supported (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: constify regulator_desc structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: remove unnecessary unlikely() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: mrfld: fix uninitialized variable access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm97xx: fix uninitialized regmap pointer problem (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: constify snd_soc_ops structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix less than zero comparison on unsigned int (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: rename SND_SUNXI_ADDA_PR_REGMAP to SND_SUN8I_ADDA_PR_REGMAP (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Rip out the lpe audio runtime suspend/resume hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Fix runtime PM for hdmi-lpe-audio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup clock start checker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix oops w/ for_each_rtd_codec_dai_rollback() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix insufficient PCM rule for period/buffer size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix to wait for releases of all ALSA character devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix noderef.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: add clock dependency for sai (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Actually fix microphone issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: move code from startup/shutdown hooks into pm_runtime hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm2000: Remove wm2000_read helper function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: fix mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Log addresses as 8 digits in wm_adsp_buffer_populate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Rename memory fields in wm_adsp_buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: set sai as mclk clock provider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix trivial checkpatch issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for hw_free on CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: minor white space clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c/cs8427: Fix int to char conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup SSICR::SWSP for TDM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: enable TDM settings for SSI parent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for capture channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: Add support for XTI clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: new codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_sgtl5000: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: allow the sun8i-codec driver to be built on ARM64 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: Add new driver for Allwinner A64 codec's analog path controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec-analog: split regmap code into separate driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: Don't hardcode BCLK / LRCK ratio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: Add compatibility with A64 codec I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add 2 more models to the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Kabylake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add KBL Dialog Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add SND_JACK_LINEOUT jack type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add I2S/Left_J TDM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add HW constraint for non RIGHT_J (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: set ->component pointer in private struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88xx: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92xx-ad1848: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: caiaq: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add missing entries to Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: isight: fix leak of reference to firewire unit in error path of .probe callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort DHT Rot Pnt Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort max98373_bde_gain_tlv in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort BDE Limiter Thresh Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort Digital Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: enable mclk-fs on codec node (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use 32bit TDM width as default (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: add I2C dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: simplify cleanup process when failing to register sound card (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob/fireworks: simplify handling of local device entry table (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: release reference count of firewire unit in .remove callback of bus driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: block .remove callback of bus driver till all of ALSA character devices are released (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the problem of the front MIC on the Lenovo M715 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix headphone pin config for ASUS G751 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix input effect controls for desktop cards (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add error checking in ca0132_build_controls() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up patch_ca0132() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix microphone inconsistency issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: make it selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: Add master clock handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8782: add support for regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add ASUS G751 quirk model entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for ASUS G751 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the standard fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1761: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add custom mixer status quirks for RME CC devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: update quirk for B&W PX to remove microphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Disable automute for Elo VuPoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: A lightweight function to discard pending bytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add fault detect recovery property to DT bindings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: enable and disable extclk if given (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: checking NULL vs IS_ERR() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add missing break in skl_tplg_get_token() (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain cache of stream formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain model-specific data (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: use managed-resource to maintain response buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use managed-resource to maintain data specific to M-Audio FW-1814/ProjectMix I/O (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: use managed-resource of fw unit device for private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Cannot adjust speaker's volume on Dell XPS 27 7760 (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: add PCM rules to obsolete PCM constraints based on LCM of SYT_INTERVAL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR exit commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR 600 ohm gain control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Remove input select enum for ZxR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR input/output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR DSP post-download commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR init commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DBpro hda_codec_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR quirks + new quirk check function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix surround sound with output effects (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix AE-5 control type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatch for register mask and value in ext controller. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: add SND_SOC_I2C_AND_SPI dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: avoid AC97_BUS build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Rename dummy_dma_ops to snd_dummy_dma_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: add OF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a MIC pre. route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component_dais() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup SSI clock during suspend/resume modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include from q6adm.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tidyup for_each_card_prelinks() dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Remove the boost volume in the beginning of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_be() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_fe() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_comp_order() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_components() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_rtds() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_links() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_prelinks() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rename for_each_rtd_codec_dai_reverse to rollback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: convert for_each_rtd_codec_dai() for missing part (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 exit function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 specific controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add input selection commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add output set commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_alt_out_select (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup functions for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Merge post-dsp functions + cleanup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change firmware name and usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 regular init setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 pre-init and ca0113 functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change ca0132_mmio_init for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Set AE-5 bools and select mixer (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add pincfg for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk for Sound BlasterX AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Define new verbs and control params (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Refine indentations and constify snd_pcm_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix the audio-component completion timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Drop unused GPIO include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Minor code modification (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix capture unstable in beginning for some runs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix the boost volume at the begining of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Remove HP volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Improve HP performance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove redundant include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Get the period_bytes in the copy work to make sure the value correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_is_matching_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: manage platform name under snd_soc_init_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove duplicated include from q6asm-dai.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hisilicon: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8328: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: fix memory leak of response buffer at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of discovered stream formats at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak for model-dependent data at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix I/O at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enable runtime PM only for discrete GPU (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-digi00x: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Register irq handler after register initializations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit definition of pci_iomap() on SH (Jaroslav Kysela) [1683051]
- [sound] ALSA: don't call skl_init_chip() to reset intel skl soc (Jaroslav Kysela) [1683051]
- [sound] ALSA: enable interrupt after dma buffer initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ASoC: Intel: Skylake: Acquire irq after RIRB allocation" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove dai->driver NULL check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card rebind (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove unneeded static set .owner field in platform_driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing INTERLEAVED PCM attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove unused num_dai_links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: avoid nested code on soc_remove_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: remove empty rt5668_i2c_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fix UBSAN warning at snd_soc_get/put_volsw_sx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: switch to new ac97 bus support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix simultaneous playback and capture on different channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: fix possible info leak to userspace on SNDRV_EMU10K1_IOCTL_INFO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add missing return value check for snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skl-topology: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6core: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nuc900: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs454: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: bcm: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel_ssc_dai: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Ensure reset bit is cleared before configuring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: clean up a return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix a couple uninitialized ret variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix memory leak in ff400_switch_fetching_mode() (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use address returned by kmalloc() instead of kernel stack for streaming DMA mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Update hardware pointer before start capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: usleep_range() needs include/delay.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: regmap: split up regmap_config.use_single_rw (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: Limit sampling rates at dai creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Avoid uninitialised variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: avoid division by zero if lo_vag is zero (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't use p for dev_dbg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: adg: care clock-frequency size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: use tab instead of white-space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: remove redundant check for !port condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move CODEC to CODEC params from the widget to the runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for multi-CODEC CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move connection of CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Cosmetic tidy up of snd_soc_dapm_new_control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move error handling to snd_soc_dapm_new_control_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_link_codecs() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add overflow detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Cleanup indirect PCM helper usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: rme32: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix several mismatch for register mask and value (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't schedule DAPM work if already in target state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add driver for PROTO Audio CODEC (with a WM8731) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: merge .nolock_start and .prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support to init different BUSIF instance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support BUSIF other than BUSIF0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate PDMACHCRE with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate dma address with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Check runtime channel number rather than hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Fix issue in dma data address assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove is_play parameter from hw_rule function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 8 bit S8 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for the DSP_A/DSP_B formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 16/24 bit slot widths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add warning message to rsnd_kctrl_accept_runtime() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup not to call clk_get/set under non-atomic (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Initialize allocated buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add short circuit detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix soc-core.c kernel-doc warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6routing: initialize data correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Add channel fault reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Save last fault register even when clear (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Print full register name in error message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use snd_soc_dai_link_component for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a S/PDIF enable switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add native 32bit I2S transport (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: SOC_SINGLE register value error fix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 TDM slot width setting support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 specific volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Add support for FIFO usage caused delay reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix cancel_work_sync() stall from jackpoll work (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Clean up jackpoll_ms option handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg pdm input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add DT module alias (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add Kconfig prompt for the generic dmic codec. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Unused exported functions changed to internal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve legibility of if-statements (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve stylistics of file comments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: switch to SPDX license identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change MCLK to 48Mhz (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set constraints for DMIC and MAX98357a codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-bsw-rt5672: Add key-mappings for the headset buttons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Implemented safeload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sigmadsp: safeload should not have lower byte limit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: add asoc extension for legacy HDA codec drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use hda_bus instead of hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add HDA BE DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use HDAudio if ACPI enumeration fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Machine driver for SKL+ w/ HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add table for HDA-based platforms (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: move hda_codec.h to include/sound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8804: Add ACPI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Change DAC/ADC volume scale (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added 10ms sleep after amp software reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm: restrict formats depending on slot width (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: report interrupt request failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: imply clock and reset controllers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: Properly initialise hw->rate_max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Don't fail creating new DAPM control on NULL pinctrl (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Remove clock framework ifdefs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: Use the new non-cached allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Use the new non-cached allocation for 440MX workaround (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Remove substream allocation/free ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Use new non-cached allocation for non-snoop mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Check the non-cached stream buffers more explicitly (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add non-cached buffer type (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Simplify snd_malloc_dev_pages() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't align the size to power-of-two (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Do error checks at creating system ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: add error check in snd_seq_system_client_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: signedness bug in snd_pcm_plug_alloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdspm: fix spelling mistake "Initializeing" -> "Initializing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Return 0 when size < start_threshold in capture (Jaroslav Kysela) [1683051]
- [kvm] ALSA: treewide: correct "differenciate" and "instanciate" typos (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix HP Headset Mic can't record (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix unbalanced pm_runtime_enable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix check of pm_runtime_get_sync failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix device initialization in the compat layer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added speaker FS gain cotnrol register to volatile. (Jaroslav Kysela) [1683051]
- [sound] ALSA: update dell-wmi mic-mute registration to new world order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer deference on CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Fix discarding the unsubscribed output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Acquire irq after RIRB allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix replace codec to component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for 2 more devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adav80x: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add delays to capture path to remove DC offset noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add exit commands for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change mixer controls for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D input and output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup defaults for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D startup functions and setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add bool variable to enable/disable pci region2 mmio (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk ID and enum for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add alt_functions unsolicited response (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_init function. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Create mmio gpio function to make code clearer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make DSP name configurable by codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Declare firmware controls from codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added software reset register to readable registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct DSP pointer for preloader control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Fix initialization of rt5677_of_match.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: make BE and FE order inline with dpcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: remove redundant variable cfg_val (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set delay value for the capture case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Modified DMA pointer for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Make ACP->SYSMEM DMA non circular (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Fix missing break in switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add SLIM tx AIF_IN dapm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: remove unused header files from common.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: make common.c as proper module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8903: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da9055: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm5100-tables: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8990: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tda7419: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9850: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix wrong copy to rx parameters for Alesis iO26 (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add mute LED quirk for HP Spectre x360 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq_oss: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-i2s: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: fix memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix spelling mistake "acumulator" -> "accumulator" (Jaroslav Kysela) [1683051]
- [sound] ALSA: es18xx: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti9xx: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92x: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: galaxy: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt: Use refcap device for mono recording (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove support for card rebind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix unmet dependency warning for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9081: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8995: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8962: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8960: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8955: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8961: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix a typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix invalid use of sizeof in parse_uac_endpoint_attributes() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Drop unused 64bit division macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use no intrruptible mutex_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix leftovers at probe error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove dead codes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Minor cleanup of MIDI event parser helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: Use delay set in component pointer function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build due to CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: remove redundant pointer 'urb' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sonicvibes: remove redundant pointer 'dir' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ens137x: remove redundant array pcm_devs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: remove redundant variable attn (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: remove redundant pointer 'dma' (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: remove redundant variable max_streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: remove redundant pointers 'priv' and 'rtd' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8540: remove redundant variable osrate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add sdm845 sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Add support to parse common audio device nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Operate UAC3 Power Domains in PCM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add UAC3 Power Domains to suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: AudioStreaming Power Domain parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Initial Power Domain support (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Use READ_ONCE/WRITE_ONCE() macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Offload the output event processing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: change functions to static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: add support for multichannel output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_alc5632: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Kconfig: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4613: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7210: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4554: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4642: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8988: fix typo in rate constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: i2s: Fix typo/broken macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Use single mutex unlock in error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Turn CX8200 into D3 as well upon reboot (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: cthw20k2: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ALSA:: ctxfi: cthw20k1: Replace mdelay() with msleep() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: quirks: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp_modem: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: bt87x: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: maestro3: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: lola: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Properly endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Proper endian notations for BDL pointers (Jaroslav Kysela) [1683051]
- [sound] ALSA: trident: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ymfpci: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen: Use standard pcm_format_to_bits() for ALSA format bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix PCM format bit calculation (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: Fix PCM format notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88x0: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ad1816a: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Fix PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: virmidi: Fix too long output trigger loop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Use standard pcm_format_to_bits() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Declare PCM format with snd_pcm_format_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Use snd_mask_set_format() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix interval evaluation with openmin/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add snd_mask_set_format() helper for standard usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix snd_pcm_format_t handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Use int for format bit position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Fix missing __user prefix in copy_user callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: zte: Fix incorrect PCM format bit usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: align axg card driver with DT bindings documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: use IRQ_RETVAL in the fifo irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add a fix voltage regulator for DA7219 and ADAU7002 (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Fix missing PAGE_SIZE definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: declare snd_sgbuf_aligned_pages() unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Fix missing __force annotation for user/kernel pointer cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: korg1212: Add __force annotation to cast in user-copy callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use standard lower_32_bits() and upper_32_bits() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Declare the common variable in header file (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Declare common variables properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix a sparse warning about snd_ctl_elem_iface_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Fix the default sample sizes (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Add missing __iomem annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Encore mDSD USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: Fix invalid endian conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: vxpocket: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: vx222: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix poll() error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix widget handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: fix inversion between __iowrite32 and __ioread32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify iomem address and casts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: make sst_dma functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: BDL definitions should be __le32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: fix endianness handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: add Volume to the name of volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to snd_soc_dai_get_channel_map() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-spdifout: select SND_PCM_IEC958 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Allow delayed i915 audio component binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Generic DSD detection for Thesycon-based implementations (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't exceed over the requested size (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: catch invalid timer object creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove clock divider and pll setup from zylonite and magician (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: export snd_soc_of_get_slot_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm input driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm output driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm interface driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm formatter base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: improve goto error label (Jaroslav Kysela) [1683051]
- [usb] ALSA: powerpc/ps3: Set driver coherent_dma_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the "Connect Tablet 9" tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk table entries for various devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add mono speaker quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add IN2 input mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Set OVCD limit for VIOS LTH17 to 2000uA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix using the wrong GPIO for the ext-amp on some boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add IN3 Boost volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Parse HOST_BUFFER controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow up to 8 channels for voice control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Take prefix into account in control name length (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct algorithm list allocation size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Ensure DSP boot work complete before preloader_put return (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Allow changing from a bad sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg toddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg frddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg fifo base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add documentation for power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: remove component fw related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card re-bind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add __force to cast in snd_pcm_lib_read/write() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Nuke snd_pcm_lib_mmap_vmalloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Use kvmalloc() for buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Minor code refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Simplify error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Tidy up coding styles (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make audio component support more generic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Associate audio component with devres (Jaroslav Kysela) [1683051]
- [sound] ALSA: drm/i915: Split audio component to a generic type (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu8000: Use swap macro in snd_emu8000_sample_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1_patch: Use swap macro in snd_emu10k1_sample_new (Jaroslav Kysela) [1683051]
- [gpu] ALSA: vga_switcheroo: set audio client id according to bound GPU id (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: use PCI_BASE_CLASS_DISPLAY to replace PCI_CLASS_DISPLAY_VGA (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Tidy up logic for Processing Unit min/max values (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Unify virtual type units type to UAC3 values (Jaroslav Kysela) [1683051]
- [include] ALSA: usb-audio: Add support for Processing Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Processing Unit controls parsing in UAC2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Selector Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: For capture have interrupts on I2S->ACP channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Send correct channel for configuring DMA descriptors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add GLK Realtek Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: remove redundant pointer 'ins' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ali5451: remove redundant pointer 'codec' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: remove redundant pointer runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: remove redundant pointer private_data (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: remove redundant pointer chip (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: remove redundant pointer opl3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: off by one in routing_hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: fix a range check in of_q6afe_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: allow soc-core to pick up name prefixes from component nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: add rate merge to the BE stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: rework runtime stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix snd_interval_refine first/last with open min/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Reporting button presses (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Disable jack-detect over suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add button press support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Allow disabling jack-detect by calling set_jack(NULL) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Fix workqueue cancel vs irq free race on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for externar amplifier enable GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Move getting of codec_dev into probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove is_valleyview helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix2 8 tablet (Jaroslav Kysela) [1683051]
- [dma] ALSA: dmaengine: add support for reporting pause and resume separately (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau171x1: Connect playback DAI to the DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA_SOC_SSP depend on PLAT_PXA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: replace "p" with "pK" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Allow drivers to set R/W wait time. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: add support for an external clock in devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: cmd: Add missing newline to debug message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: Use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Do not overwrite slim dai num_channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add slim rx routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to slim tx dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Add missing slimbus capture ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sti: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use snd_pcm_stop_xrun() for xrun injection (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: trace XRUN event at injection, too (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow topology to override machine driver FE DAI link config. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel-i2s: Remove unnecessary audio PLL clock (aclk) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: add support for the es7154 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: correct required power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Simplify trigger handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Reset bytescount when starting transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Do not generate interrups for every captured sample (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix Capture DMA channel names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always subtract bytescount (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always stop ch2 first (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7241: add es7241 codec support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add button detection mode control (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-midi: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: caiaq: audio: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: Add VDD and AVDD power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: check if mclk rate is valid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: remove 64kHz rate from the supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: remove .set_pll() and .set_clkdiv() callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: select SND_PXA2XX_LIB for drivers that depend on it (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-compress: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-topology: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dapm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-devres.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-jack.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dpcm.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-ops.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dai.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-io.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: snd-aoa: add of_node_put() in error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6797: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA2XX_SOC_I2S selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove bindings from pxa2xx-pcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: provide PCM ops for ssp, i2s and ac97 components (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa2xx-pcm-lib: fix indenting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: move some functions to pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: clean up function names in pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fold pxa2xx-pcm into its only user, pxa2xx-ac97 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove the dmaengine compat need (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Don't fall back to generic when i915 binding fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: don't merge format from invalid codec dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: extend channel merging to the backend cpu dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: fix some off by one bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: improve runtime update predictability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: add extended ops in the hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: remove memory allocation from snd_hdac_ext_bus_device_init (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: split snd_hda_codec_new function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: ext: add wait for codec to respond after link reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_driver, use hdac_driver instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_bus and use hdac_bus instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_device and use hdac_device instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move in_pm accessors to HDA core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas517x: add tas5707 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifer: add simple-amplifier compatible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: rename dio2125 to simple-amplifer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Sort DMI table entries alphabetically (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_HP_LR_SWAPPED quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Simplify card long-name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix DMIC map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1 map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove IN2 input mappings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1_IN2_MAP quirk not being logged (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Change default input map from in2 to in1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_DEFAULT_QUIRKS define (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Kill snd_hda_codec_update_cache() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC882 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC262 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC268 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC259 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC662 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: Fix references to Documentation/.*/MultiSound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: remove unused struct q6asm member (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add proper error check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove redundant owner assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6adm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Fix unregistration order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cx20442: Don't ignore regulator_get() errors. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply PRE_PROBE fixup after ALC269 codec variant setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Use standard verb containers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Simplify control management (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Rewrite with error goto (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/cirrus - Simplify creation of new controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Clean up beep code (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating ALC268 beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common GPIO mask for ALC660VD ASUS fixup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify Dell XPS13 GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Convert some manual GPIO setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify mute LED GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc885_fixup_macpro_gpio() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Consolidate gpio_data and gpio_led (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add GPIO data update helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Manage GPIO bits commonly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Allow skipping spec->init_amp detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: add codecs devicetree binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: DPCM cares BE channel constraint (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure channel 1 or channel 0 for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change codec to channel link as per hardware redesign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: remove redundant check of PLL ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix missing rename from 'reef' to 'sof' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc269_fixup_hp_line1_mic1_led() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sanity check of unexpected cap_sync_hook override (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Use common helper for mic mute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Allow multiple ADCs for mic mute LED controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Use the mic-mute LED helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use the mic-mute LED helper for HP and others (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use the common helper for thinkpad_acpi mic mute LED handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move mic mute LED helper to the generic parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: rename 'reef' to 'sof' in ACPI matching table (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Set compressed IRQ to a wake source (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Simplify handling of alg offset and length (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support for Motu Traveler (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: cancel chunk alignment for protocol version 2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for AES/EBU on XLR interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for chunks for main 1/2 out (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: suppless consumption for unused element of array in stack (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: Tidy up open/hw_params handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix copy/paste issue with SOF/broadwell topology file (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add entries for SOF-based machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add firmware/topology information for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Geminilake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: move SKL+ codec ACPI tables to common directory (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: cleanup before moving ACPI tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broxton: reduce machine name for bxt_da7219_max98357a (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: add fe_ops for kbl Audio Capture Port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ARM: pxa: change SSP DMA channels allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: stop using get_seconds() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: use enum type CT_SUM_CTL where appropriate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1724: remove unused array (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Fix Acer Iconia 8 over-current detect threshold (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Nuvison/TMax TM800W560 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: add devicetree support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: PCM1789: unconditionally flush work (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add rt5682 codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add headphone auto switching (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Remove Playback/Capture in names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add mic bias boost control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: make structure soc_codec_dev_ak4458 static const (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: make two structures static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: make pointer dmic_codec_dev static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: set card as device drvdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add rsnd_daidrv_get() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add hp and mic detect gpios same as simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: move hp and mic detection to soc_card probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: move hp and mic detect gpios from simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Vi10 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: Use ULL suffixes for 64-bit constants (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add config for rockchip dmaengine pcm register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: put device_node on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add iec958 controls support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add NULL pointer check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: SSI parent cares SWSP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: has .symmetric_rates if SSIs are sharing WS pin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh7760-ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: migor: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: siu: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hac: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Add callback for DAPM route load/unload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Give more data to clients via callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix potential DAI widget pointer deref when linking DAIs (Jaroslav Kysela) [1683051]
- [fs] gfs2: Fix loop in gfs2_rbm_find (v2) (Andreas Grunbacher) [1690483]
- [fs] gfs2: Rename bitmap.bi_{len => bytes} (Andreas Grunbacher) [1690483]

* Wed May 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-97.el8]
- [vfio] vfio/pci: Mask buggy SR-IOV VF INTx support (Myron Stowe) [1678076]
- [netdrv] net/ibmvnic: Update carrier state after link state change (Steve Best) [1711282]
- [netdrv] net/ibmvnic: Update MAC address settings after adapter reset (Steve Best) [1711282]
- [scsi] scsi: storvsc: Reduce default ring buffer size to 128 Kbytes (Cathy Avery) [1691370]
- [scsi] scsi: storvsc: Fix calculation of sub-channel count (Cathy Avery) [1691370]
- [powercap] powercap: RAPL: Get rid of custom RAPL_CPU() macro (Alexander Beregalov) [1706827]
- [tools] tools/power turbostat: Increase default buffer size (Prarit Bhargava) [1711260]
- [char] virtio_console: initialize vtermno value for ports (Pankaj Gupta) [1460636]
- [rpmspec] redhat: exclude kvm_stat from pathfix.py's tenure (Vitaly Kuznetsov) [1692804]
- [virt] kvm: arm: Skip stage2 huge mappings for unaligned ipa backed by THP (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Ensure vcpu target is unset on reset failure (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-v3: Retire pending interrupts on disabling LPIs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Fix CNTP_TVAL calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move RSB stuffing to before the first RET after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix size checks in vmx_set_nested_state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Check for in-kernel LAPIC before deferencing apic pointer (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix KVM_CLEAR_DIRTY_LOG for memory slots of unaligned size (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: reset MMU context when 32-bit guest switches PAE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Whitelist port 0x7e for pre-incrementing rip (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Convert guest TSC to host time domain if necessary (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Allow user to disable adaptive tuning of timer advancement (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Track lapic timer advance per vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Disable timer advancement if adaptive tuning goes haywire (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyper-v: deal with buggy TLB flush requests from WS2012 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Consider LAPIC TSC-Deadline timer expired if deadline too short (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: avoid misreporting level-triggered irqs as edge-triggered in tracing (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix spectrev1 gadgets (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix warning Using plain integer as NULL pointer (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add a selftest for SMM (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: fix for compilers that do not support -no-pie (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm/evmcs_test: complete I/O before migrating guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Always use 32-bit SMRAM save state for 32-bit kernels (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Don't clear EFER during SMM transitions for 32-bit vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: clear SMM flags before loading state while leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Open code kvm_set_hflags (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Load SMRAM in a single shot when leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Expose RDPMC-exiting only when guest supports PMU (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm: move kvm_load/put_guest_xcr0 into atomic context (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: svm: make sure NMI is injected after nmi_singlestep (Vitaly Kuznetsov) [1692804]
- [kvm] svm/avic: Fix invalidate logical APIC id entry (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "svm: Fix AVIC incomplete IPI emulation" (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Fix overflow on kvm mmu page limit calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: always use early vmcs check when EPT is disabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: allow tests to use bad virtual-APIC page address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Fix an inverted list_empty() check when zapping sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: fix x2APIC VTPR read intercept (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: close leak of L0's x2APIC MSRs (CVE-2019-3887) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: prevent DBG_DECRYPT and DBG_ENCRYPT overflow (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: fix potential get_num_contig_pages overflow (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation: kvm: clarify KVM_SET_USER_MEMORY_REGION (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: complete IO before migrating guest state (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: disable stack protector for all KVM tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: explicitly disable PIE for tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: assert on exit reason in CR4/cpuid sync test (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: update rip after emulating IO (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid spurious pending stimer on vCPU init (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: Move MSR_IA32_ARCH_CAPABILITIES to array emulated_msrs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Emulate MSR_IA32_ARCH_CAPABILITIES on AMD hosts (Vitaly Kuznetsov) [1692804]
- [virt] kvm: don't redefine flags as something else (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Used range based flushing in slot_handle_level_range (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Fix definition of HV_MAX_FLUSH_REP_COUNT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: remove check on nr_mmu_pages in kvm_arch_commit_memory_region() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: Add a vmentry check for HOST_SYSENTER_ESP and HOST_SYSENTER_EIP fields (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: Workaround errata#1096 (insn_len maybe zero on SMAP violation) (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Reject device ioctls from processes other than the VM's creator (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Fix incorrect word ordering regarding supported use of APIs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix handling of role.cr4_pae and rename it to 'gpte_size' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not inherit quadrant and invalid for the root shadow EPT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Comments cleanup in mmu.c (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Make attribute accessors static (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix handling of stage2 huge mappings (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Enforce PTE mappings at stage2 when needed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when parsing the memslots (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when writing to guest memory (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Always set ICH_HCR_EL2.EN if GICv4 is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reset the PMU in preemptible context (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix formatting of a comment (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Document the life cycle of a VM and its resources (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range()" (Vitaly Kuznetsov) [1692804]
- [documentation] virtio-ccw: diag 500 may return a negative cookie (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Add count cache flush parameters to kvmppc_get_cpu_char() (Vitaly Kuznetsov) [1692804]
- [virt] kvm: properly check debugfs dentry before using it (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Fix compilation when KVM is not enabled (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc: Avoid circular header inclusion in mmu-hash.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: MMU: record maximum physical address width in kvm_mmu_extended_role (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Return LA57 feature based on hardware capability (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: fix switch between root and guest MMUs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Minor cleanups for kvm_main.c (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Fix architecturally invalid reset value for FPEXC32_EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Improve KVM reference counting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Fix build failure without IOMMU support (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc/64s: Better printing of machine check info for guest MCEs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Simplify machine check handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Context switch AMR on Power9 (Vitaly Kuznetsov) [1692804]
- [virt] Revert "KVM: Eliminate extra function calls in kvm_get_dirty_log_protect()" (Vitaly Kuznetsov) [1692804]
- [x86] x86: kvmguest: use TSC clocksource if invariant TSC is exposed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Never start grow vCPU halt_poll_ns from value below halt_poll_ns_grow_start (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Expose the initial start value in grow_halt_poll_ns() as a module parameter (Vitaly Kuznetsov) [1692804]
- [virt] KVM: grow_halt_poll_ns() should never shrink vCPU halt_poll_ns (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Consolidate kvm_mmu_zap_all() and kvm_mmu_zap_mmio_sptes() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: WARN if zapping a MMIO spte results in zapping children (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Differentiate between nr zapped and list unstable (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: skip over invalid root pages when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: x86: use the fast way to invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: show mmu_valid_gen in shadow page related tracepoints" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: add tracepoint for kvm_mmu_invalidate_all_pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: zap pages in batch" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: collapse TLB flushes when zap all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: reclaim the zapped-obsolete page first" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Remove is_obsolete() call (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping MMIO sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: drop kvm_mmu_zap_mmio_sptes" (Vitaly Kuznetsov) [1692804]
- [x86] Revert "KVM: MMU: document fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Zap only the relevant pages when removing a memslot (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Split remote_flush+zap case out of kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Move slot_level_*() helper functions up a few lines (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Move the memslot update in-progress flag to bit 63 (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Remove the hack to trigger memslot generation wraparound (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Refactor the MMIO SPTE generation handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Use a u64 when passing the MMIO gen around (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Explicitly define the "memslot update in-progress" bit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Do not cache MMIO accesses while memslots are in flux (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Detect MMIO generation wrap in any address space (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Call kvm_arch_memslots_updated() before updating memslots (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not start the preemption timer hrtimer unnecessarily (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix typos in vmentry/vmexit control setting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cleanup freeing of nested state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Sync the pending Posted-Interrupts (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIR64B CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIRI CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] kvm, x86, mmu: Use kernel generic dynamic physical address mask (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: remove useless is_protmode check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Ignore limit checks on VMX instructions using flat segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Apply addr size mask to effective address for VMX instructions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Sign extend displacements of VMX instr's mem operands (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix improper check when deactivate AVIC (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cull apicv code when userspace irqchip is requested (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC DFR and LDR handling (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Use struct_size() in kmalloc() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: set offset for kvm unstable clock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Reorder clearing of registers in the vCPU-run assembly flow (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Call vCPU-run asm sub-routine from C and remove clobbering (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Preserve callee-save registers in vCPU-run asm sub-routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Return VM-Fail from vCPU-run assembly via standard ABI reg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass @launched to the vCPU-run asm via standard ABI regs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use RAX as the scratch register during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Rename ____vmx_vcpu_run() to __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Fold __vmx_vcpu_run() back into vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vCPU-run code to a proper assembly routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Create a stack frame in vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use #defines in place of immediates in VM-Enter inline asm (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: Explicitly #define the VCPU_REGS_* indices (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove unused gpa_end variable (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Fix comment for KVM_PHYS_SHIFT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: fix spelling mistake: "auxilary" -> "auxiliary" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Prefix header search paths with $(srctree)/ (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix TRACE_INCLUDE_PATH (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Mark physical interrupt active when a virtual interrupt is pending (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Describe data or unified caches as having 1 set and 1 way (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Expose sanitised cache type register to guest (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Move kvm_is_write_fault to header file (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Assign the phys timer on VHE systems (Vitaly Kuznetsov) [1692804]
- [include] clocksource/arm_arch_timer: Store physical timer IRQ number for KVM on VHE (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: timer: Rework data structures for multiple timers (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: consolidate arch timer trap handlers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reuse sys_reg() macro when searching the trap table (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Fix ICH_ELRSR_EL2 sysreg naming (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Simplify bg_timer programming (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Factor out VMID into struct kvm_vmid (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Statically configure the host's view of MPIDR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Drop VHE-specific HYP call stub (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Allow for direct call of HYP functions when using VHE (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Introduce kvm_call_hyp_ret() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Release all hardware TCE tables attached to a group (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Optimise mmio emulation for devices on FAST_MMIO_BUS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Allow XICS emulation to work in nested hosts using XIVE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Replace kmalloc_node+memset with kzalloc_node (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Add emulation for slbfee. instruction (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix entry number check for add_atomic_switch_msr() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Recompute PID.ON when clearing PID.SN (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Restore a preemption timer consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: read from MSR_IA32_VMX_PROCBASED_CTLS2 only when it is available (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use vcpu->arch.regs directly when saving/loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Don't save guest registers after VM-Fail (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Invert the ordering of saving guest/host scratch reg at VM-Enter (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass "launched" directly to the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Update VMCS.HOST_RSP via helper C function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Load/save guest CR2 via C code in __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Cache host_rsp on a per-VMCS basis (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Let the compiler select the reg for holding HOST_RSP (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Reference vmx->loaded_vmcs->launched directly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail via CC_{SET, OUT} in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail to a local var in nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Explicitly reference the scratch reg in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Drop STACK_FRAME_NON_STANDARD from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove a rogue "rax" clobber from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Let the compiler save/load RDX during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Manually load RDX in vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Save RSI to an unused output in the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Modify only RSP when creating a placeholder for guest's RCX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Zero out *all* general purpose registers after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Check a single byte for VMCS "launched" in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Compare only a single byte for VMCS' "launched" in vCPU-run (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add selftest for releasing VM file descriptor while in L2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Add kvm_ras.h to collect kvm specific RAS plumbing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: work around leak of uninitialized stack contents (CVE-2019-7222) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Forbid kprobing of the VHE world-switch code (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Relax the restriction on using stage2 PUD huge mapping (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Always initialize the group of private IRQs (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Don't panic on failure to properly reset system registers (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Allow a VCPU to fully reset itself (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Reset the VCPU without preemption and vcpu state loaded (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: fix possible null pointer dereference in pending_irqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: start using the GIB (Vitaly Kuznetsov) [1692804]
- [s390] KVM: s390: add gib_alert_irq_handler() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: kvm_s390_gisa_clear() now clears the IPM only (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add functions to (un)register GISC with GISA (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add kvm reference to struct sie_page2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add the GIB and its related life-cyle functions (Vitaly Kuznetsov) [1692804]
- [s390] s390/cio: add function chsc_sgib() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: introduce struct kvm_s390_gisa_interrupt (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: remove kvm_s390_ from gisa static inline functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: use pending_irqs_no_gisa() where appropriate (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: coding style kvm_s390_gisa_init/clear() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: move bitmap idle_mask into arch struct top level (Vitaly Kuznetsov) [1692804]
- [virt] virt/kvm: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Mark expected switch fall-throughs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix TRACE_INCLUDE_PATH and remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: check returned evmcs version range (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: nested_enable_evmcs() sets vmcs_version incorrectly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vmx_vcpu_run()'s VM-Enter asm blob to a helper function (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: Fix region overlap check in kvm_util (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix some -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: clear events pending from svm_complete_interrupts() when exiting to L1 (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC incomplete IPI emulation (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Add warning message for AVIC IPI invalid target (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: WARN_ONCE if sending a PV IPI returns a fatal error (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix PV IPIs for 32-bit KVM host (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: recommend using eVMCS only when it is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't recommend doing reset via synthetic MSR (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86/vmx: Use kzalloc for cached_vmcs12 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use the correct field var when clearing VM_ENTRY_LOAD_IA32_PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix single-step debugging (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't announce GUEST IDLE MSR support (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Don't generate UNDEF when LORegion feature is present (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_cpu->ap_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_dist->lpi_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_irq->irq_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: powerpc: remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation/virtual/kvm: Update URL for AMD SEV API specification (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Avoid return error when flush tlb successfully in the hv_remote_flush_tlb_with_range() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: sev: Fail KVM_SEV_INIT if already initialized (Vitaly Kuznetsov) [1692804]
- [virt] KVM: validate userspace input in kvm_clear_dirty_log_protect() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix bit shifting in update_intel_pt_cfg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: radix: Fix uninitialized var build error (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: fix exit mmio address guessing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VM-Enter + VM-Exit handling to non-inline sub-routines (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Explicitly reference RCX as the vmx_vcpu pointer in asm blobs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use SVM assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in kvm_set_pte_rmapp() (Vitaly Kuznetsov) [1692804]
- [virt] KVM/MMU: Move tlb flush in kvm_set_pte_rmapp() to kvm_mmu_notifier_change_pte() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Make kvm_set_spte_hva() return int (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Replace old tlb flush function with new one to flush a specified range. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Add tlb flush with range helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Add hv tlb range flush support (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Add HvFlushGuestAddressList hypercall support (Vitaly Kuznetsov) [1692804]
- [x86] KVM: Add tlb_remote_flush_with_range callback in kvm_x86_ops (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Disable Intel PT when VMXON in L1 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Set intercept for Intel PT MSRs read/write (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Implement Intel PT MSRs read/write emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Introduce a function to initialize the PT configuration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT context switch for each vcpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel Processor Trace cpuid emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT virtualization work mode (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: add new capability for Intel PT (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Add new bit definitions for PT MSRs (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Introduce intel_pt_validate_cap() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Export pt_cap_get() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Move Intel PT MSRs bit defines to global header (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: aarch64: dirty_log_test: support greater than 40-bit IPAs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add pa-48/va-48 VM modes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: improve mode param management (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: reset guest test phys offset (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: always use -t (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: don't identity map the test mem (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: x86_64: dirty_log_test: fix -t (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix some typos (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: convert to SPDX identifiers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Remove KF() macro placeholder (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Allow guest read access to IA32_TSC (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: NMI-window and interrupt-window exiting should wake L2 from HLT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: Fix nested guest support for PAUSE filtering. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Remove duplicated include from vmx.c (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: report failed stage when exit reason is unexpected (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix size of x86_fpu_cache objects (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Flush branch predictor when entering KVM (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Emulate SPRN_BUCSR register (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nSVM: fix switch to guest mmu (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add trapped system register access tracepoint (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Make vcpu const in vcpu_read_sys_reg (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Simplify kvm_timer_vcpu_terminate (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove arch timer workqueue (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix unregistering coalesced mmio zone from wrong bus (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Add support for creating PUD hugepages at stage 2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Update age handlers to support PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support handling access faults for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support PUD hugepage in stage2_is_exec() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Support dirty page tracking for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Introduce helpers to manipulate page table entries (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Re-factor setting the Stage 2 entry to exec on fault (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Share common code in user_mem_abort() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Log PSTATE for unhandled sysregs (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Consistently advance singlestep when emulating instructions (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Skip MMIO insn after emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L3 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Introduce new hcall H_COPY_TOFROM_GUEST to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L2 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Update kvmppc_st and kvmppc_ld to use quadrants (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Add load_from_eaddr and store_to_eaddr to the kvmppc_ops struct (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Book3S HV: Implement functions to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Add function kvmhv_vcpu_is_radix() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Only report KVM_CAP_SPAPR_TCE_VFIO on powernv machines (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: improve ucall placement in memory, fix unsigned comparison (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Dynamically allocate guest_fpu (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Use task structs fpu field for user (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Guest Non-Register States to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Host Control Registers and MSRs to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Entry Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Exit Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove param indirection from nested_vmx_check_msr_switch() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Execution Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Prepend "nested_vmx_" to check_vmentry_{pre, post}reqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Check ept_pointer before flushing ept tlb (Vitaly Kuznetsov) [1692804]
- [kvm] KVM nVMX: MSRs should not be stored if VM-entry fails during or after loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Don't modify MSR_PLATFORM_INFO on vCPU reset (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: add cpu into VMX preemption timer bug list (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Stop caring about EOI for direct stimers (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid open-coding stimer_mark_pending() in kvm_hv_notify_acked_sint() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: direct mode for synthetic timers (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm/hyper-v: use stimer config definition from hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: Add hyperv_cpuid test (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: implement an unchecked version of vcpu_ioctl() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce KVM_GET_SUPPORTED_HV_CPUID (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Do some housekeeping in hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Mark TLFS structures packed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce nested_get_evmcs_version() helper (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: don't retry message delivery for periodic timers (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: simplify SynIC message delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: remove unnecessary recalculate_apic_map (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: remove unused struct definition (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Skip all SYSCALL MSRs in setup_msrs() when !EFER.SCE (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Don't set hardware IA32_CSTAR MSR on VM-entry (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Document the need for MSR_STAR in i386 builds (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Set IA32_TSC_AUX for legacy mode guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move nested code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose nested_vmx_allowed() to nested VMX as a non-inline (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various getters and setters to nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose misc variables needed for nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move "vmcs12 to shadow/evmcs sync" to helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Call nested_vmx_setup_ctls_msrs() iff @nested is true (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Set callbacks for nested functions during hardware setup (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move the hardware {un}setup functions to the bottom (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: Allow nested_enable_evmcs to be NULL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move nested hardware/vcpu {un}setup to helper functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX instruction wrappers to a dedicated header file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move eVMCS code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Add vmx.h to hold VMX definitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move vmcs12 code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMCS definitions to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various module param vars via capabilities.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move capabilities structs and helpers to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass vmx_capability struct to setup_vmcs_config() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Properly handle dynamic VM Entry/Exit controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move caching of MSR_IA32_XSS to hardware_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Drop the "vmx" prefix from vmx_evmcs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: rename vmx_shadow_fields.h to vmcs_shadow_fields.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX specific files to a "vmx" subdirectory (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to hyperv.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to kvm_cache_regs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Alphabetize the includes in vmx.c (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Allocate and configure VM{READ, WRITE} bitmaps iff enable_shadow_vmcs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: introduce manual dirty log reprotect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: rename last argument to kvm_get_dirty_log_protect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: make KVM_CAP_ENABLE_CAP_VM architecture agnostic (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Set hflag to indicate that POWER9 supports 1T segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Change to use DEFINE_SHOW_ATTRIBUTE macro (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Don't trap host pointer auth use to EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64/kvm: hide ptrauth from guests (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add pointer authentication register bits (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add comments about EC exception levels (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/kvm: consistently handle host HCR_EL2 flags (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add configuration/documentation for Cortex-A76 erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle ARM erratum 1165522 in TLB invalidation (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add synchronization on translation regime change for erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Force VHE for systems affected by erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add TCR_EPD{0,1} definitions (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Rework detection of SVE, !VHE systems (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Check VMX-preemption timer controls on vmentry of L2 guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/nVMX: Remove unneeded forward jump in nested_vmx_check_vmentry_hw asm (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Unrestricted guest mode requires EPT (Vitaly Kuznetsov) [1692804]
- [tools] tools/kvm_stat: switch to python3 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Trace changes to active TSC offset regardless if vCPU in guest-mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: vmcs12 revision_id is always VMCS12_REVISION even when copied from eVMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Verify eVMCS revision id match supported eVMCS version on eVMCS VMPTRLD (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/vmx: fix old-style function declaration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix empty-body warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix kernel info-leak when enabling KVM_CAP_HYPERV_ENLIGHTENED_VMCS more than once (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Move and undef TRACE_INCLUDE_PATH/FILE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Use exported tb_to_ns() function in decrementer emulation (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: Fix -Wformat warnings (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: fix spelling mistake "Insufficent" -> "Insufficient" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "kvm: x86: optimize dr6 restore" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Optimize clearing TCEs for sparse tables (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: tweak shadow fields (Vitaly Kuznetsov) [1692804]
- [tools] selftests/kvm: add missing executables to .gitignore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Don't use streamlined entry path on early POWER9 chips (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Enable 32 bits kvm vcpu events support (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Rename function kvm_arch_dev_ioctl_check_extension() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: enable nested virtualization by default (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear registers in svm.c (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Introduce KVM_CAP_EXCEPTION_PAYLOAD (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Defer setting of DR6 until #DB delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Defer setting of CR2 until #PF delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add payload operands to kvm_multiple_exception (Vitaly Kuznetsov) [1692804]
- [x86] kvm: x86: Add exception payload fields to kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add has_payload and payload to kvm_queued_exception (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: Fix omission in struct kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: add Enlightened VMCS test (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: nested state migration for Enlightened VMCS (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: state_test: test bare VMXON migration (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyperv: don't clear VP assist pages on init (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: optimize prepare_vmcs02{, _full} for Enlightened VMCS case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: implement enlightened VMPTRLD and VMCLEAR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add enlightened VMCS state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add KVM_CAP_HYPERV_ENLIGHTENED_VMCS capability (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: refactor evmcs_sanitize_exec_ctrls() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: refine the comment of function gfn_to_hva_memslot_prot() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: reintroduce pte_list_remove, but including mmu_spte_clear_track_bits (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: rename pte_list_remove to __pte_list_remove (Vitaly Kuznetsov) [1692804]
- [virt] kvm/x86 : add coalesced pio support (Vitaly Kuznetsov) [1692804]
- [documentation] kvm/x86 : add document for coalesced mmio (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86 : fix some typo (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Change hv flush logic when ept tables are mismatched. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear register (Vitaly Kuznetsov) [1692804]
- [x86] KVM/x86: Use assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Fix invvpid and invept register operand size in 64-bit mode (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if MMU reconfiguration is needed in init_kvm_nested_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if tdp/shadow MMU reconfiguration is needed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: introduce source data cache for kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make space for source data caching in struct kvm_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: get rid of redundant kvm_mmu_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: introduce guest_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: add kvm_mmu parameter to kvm_mmu_free_roots() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: set get_pdptr hook in kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make vcpu->mmu a pointer to the current MMU (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: optimize dr6 restore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize sparse VP set processing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: fix 'tlb_lush' typo (Vitaly Kuznetsov) [1692804]
- [virt] vgic: Add support for 52bit guest physical address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: WARN if nested run hits VMFail with early consistency checks enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add option to perform early consistency checks via H/W (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: write HOST_IA32_EFER in vmx_set_constant_host_state() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: call kvm_skip_emulated_instruction in nested_vmx_{fail, succeed} (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not call nested_vmx_succeed() for consistency check VMExit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not skip VMEnter instruction that succeeds (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do early preparation of vmcs02 before check_vmentry_postreqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: initialize vmcs02 constant exactly once (per VMCS) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: split pieces of prepare_vmcs02() to prepare_vmcs02_early() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: remove ASSERT() on vmx->pml_pg validity (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vVMX: rename label for post-enter_guest_mode consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: assimilate nested_vmx_entry_failure() into nested_vmx_enter_non_root_mode() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: rename enter_vmx_non_root_mode to nested_vmx_enter_non_root_mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: try to set EFER bits correctly when initializing controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: do not unconditionally clear EFER switching (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: reset cache/shadows when switching loaded VMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: use vm_exit_controls_init() to write exit controls for vmcs02 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move vmcs12 EPTP consistency check to check_vmentry_prereqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move host EFER consistency checks to VMFail path (Vitaly Kuznetsov) [1692804]
- [virt] KVM: leverage change to adjust slots->used_slots in update_memslots() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: implement PV IPI send hypercalls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize kvm_hv_flush_tlb() for vp_index == vcpu_idx case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: valid_bank_mask should be 'u64' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: keep track of mismatched VP indexes (Vitaly Kuznetsov) [1692804]
- [virt] KVM: x86: hyperv: optimize 'all cpus' case in kvm_hv_flush_tlb() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: return meaningful value from KVM_SIGNAL_MSI (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: move definition PT_MAX_HUGEPAGE_LEVEL and KVM_NR_PAGE_SIZES together (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Remve unused function is_external_interrupt(). (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: return 0 in case kvm_mmu_memory_cache has min number of objects (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Make nested_vmx_check_pml_controls() concise (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: adjust kvm_mmu_page member to save 8 bytes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: support high GPAs in dirty_log_test (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: stop lying to aarch64 tests about PA-bits (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: also test 64K pages on aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: port dirty_log_test to aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce new VM mode for 64K pages (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vcpu support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add virt mem support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vm_phy_pages_alloc (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: tidy up kvm_util (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add cscope make target (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: move arch-specific files to arch-specific locations (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce ucall (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: vcpu_setup: set cr4.osfxsr (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: LAPIC: Tune lapic_timer_advance_ns automatically (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not flush TLB on L1<->L2 transitions if L1 uses VPID and EPT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush linear and combined mappings on VPID02 related flushes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Use correct VPID02 when emulating L1 INVVPID (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush TLB entries tagged by dest EPTP on L1<->L2 transitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: rename KVM_GUEST_CR0_MASK tp KVM_VM_CR0_ALWAYS_OFF (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Remove redundand permission bits removal (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Propagate errors to the guest when failed instead of ignoring (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Provide mode where all vCPUs on a core must be the same VM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Exiting split hack mode needs to fixup both PC and LR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Remove some extra semicolon in kvm_target_cpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Validate all tces before updating tables (Vitaly Kuznetsov) [1692804]
- [documentation] arm64: Add silicon-errata.txt entry for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: arch_timer: Add workaround for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [virt] signal/arm/kvm: Use send_sig_mceerr (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/cpufeatures: Introduce ESR_ELx_SYS64_ISS_RT() (Vitaly Kuznetsov) [1692804]
- [kvm] signal/x86: Use send_sig_mceerr as apropriate (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm: Use __bss_decrypted attribute in shared variables (Vitaly Kuznetsov) [1692804]
- [x86] x86/mm: Add .bss..decrypted section to hold shared variables (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: Inject #UD for SGX ENCLS instruction in guest (Vitaly Kuznetsov) [1692804]
- [x86] KVM: vmx: Add defines for SGX ENCLS exiting (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: rename the capability of KVM_CAP_ARM_SET_SERROR_ESR (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark kvm_get_preset_lpj() as __init (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Don't open code task_pid in kvm_vcpu_ioctl (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Share the parts of get/set events useful to 32bit (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: export the capability to set guest SError syndrome (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Add KVM_GET/SET_VCPU_EVENTS (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Switch kvmclock data to a PER_CPU variable (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Move kvmclock vsyscall param and init to kvmclock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark variables __initdata and __ro_after_init (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Cleanup the code (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Decrapify kvm_register_clock() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove page size requirement from wall_clock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove memblock dependency (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/arm: use PSR_AA32 definitions (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle Set/Way CMOs as NOPs if FWB is present (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Add support for Stage-2 control of memory types and cacheability (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Handle mismatched cache type (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Fix mismatched cache line size detection (Vitaly Kuznetsov) [1692804]

* Mon May 27 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-96.el8]
- [lib] rhel-kabi: Add RH_KABI_FORCE_CHANGE() to radix-tree and idr functions (Don Dutile) [1692079]
- [lib] XArray: Fix xa_reserve for 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Fix xa_erase of 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Use xa_cmpxchg to implement xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Fix xa_release in allocating arrays (Don Dutile) [1692079]
- [lib] XArray: Mark xa_insert and xa_reserve as must_check (Don Dutile) [1692079]
- [lib] XArray: Add cyclic allocation (Don Dutile) [1692079]
- [lib] XArray: Redesign xa_alloc API (Don Dutile) [1692079]
- [lib] XArray: Add support for 1s-based allocation (Don Dutile) [1692079]
- [lib] XArray: Change xa_insert to return -EBUSY (Don Dutile) [1692079]
- [lib] XArray: Update xa_erase family descriptions (Don Dutile) [1692079]
- [lib] XArray tests: RCU lock prohibits GFP_KERNEL (Don Dutile) [1692079]
- [include] XArray: Fix an arithmetic error in xa_is_err (Don Dutile) [1692079]
- [lib] XArray tests: Check mark 2 gets squashed (Don Dutile) [1692079]
- [include] XArray: Fix typo in comment (Don Dutile) [1692079]
- [lib] XArray: Honour reserved entries in xa_insert (Don Dutile) [1692079]
- [lib] XArray: Permit storing 2-byte-aligned pointers (Don Dutile) [1692079]
- [lib] XArray: Change xa_for_each iterator (Don Dutile) [1692079]
- [lib] XArray: Turn xa_init_flags into a static inline (Don Dutile) [1692079]
- [lib] XArray tests: Add RCU locking (Don Dutile) [1692079]
- [lib] XArray: Fix xa_alloc when id exceeds max (Don Dutile) [1692079]
- [lib] XArray tests: Check iterating over multiorder entries (Don Dutile) [1692079]
- [lib] XArray tests: Handle larger indices more elegantly (Don Dutile) [1692079]
- [include] XArray: Add xa_cmpxchg_irq and xa_cmpxchg_bh (Don Dutile) [1692079]
- [tools] radix tree: Don't return retry entries from lookup (Don Dutile) [1692079]
- [lib] XArray tests: Add missing locking (Don Dutile) [1692079]
- [lib] XArray tests: Correct some 64-bit assumptions (Don Dutile) [1692079]
- [lib] XArray: Correct xa_store_range (Don Dutile) [1692079]
- [lib] XArray: Fix Documentation (Don Dutile) [1692079]
- [lib] XArray: Handle NULL pointers differently for allocation (Don Dutile) [1692079]
- [lib] XArray: Unify xa_store and __xa_store (Don Dutile) [1692079]
- [include] XArray: Add xa_store_bh() and xa_store_irq() (Don Dutile) [1692079]
- [lib] XArray: Turn xa_erase into an exported function (Don Dutile) [1692079]
- [lib] XArray: Unify xa_cmpxchg and __xa_cmpxchg (Don Dutile) [1692079]
- [lib] XArray: Regularise xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Export __xa_foo to non-GPL modules (Don Dutile) [1692079]
- [lib] XArray: Fix xa_for_each with a single element at 0 (Don Dutile) [1692079]
- [lib] xarray: Add range store functionality (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_check to in-kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_shrink to kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder account test in-kernel (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert iteration test to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert tag_tagged_items to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert regression1 to XArray (Don Dutile) [1692079]
- [lib] ida: Convert to XArray (Don Dutile) [1692079]
- [lib] xarray: Track free entries in an XArray (Don Dutile) [1692079]
- [lib] xarray: Add xa_reserve and xa_release (Don Dutile) [1692079]
- [lib] xarray: Add xas_create_range (Don Dutile) [1692079]
- [lib] xarray: Add xas_for_each_conflict (Don Dutile) [1692079]
- [lib] xarray: Step through an XArray (Don Dutile) [1692079]
- [lib] xarray: Destroy an XArray (Don Dutile) [1692079]
- [lib] xarray: Extract entries from an XArray (Don Dutile) [1692079]
- [lib] xarray: Add XArray iterators (Don Dutile) [1692079]
- [lib] xarray: Add XArray conditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray unconditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray marks (Don Dutile) [1692079]
- [tools] xarray: Add XArray load operation (Don Dutile) [1692079]
- [documentation] xarray: Add documentation (Don Dutile) [1692079]
- [include] xarray: Define struct xa_node (Don Dutile) [1692079]
- [tools] xarray: Add definition of struct xarray (Don Dutile) [1692079]
- [lib] test_ida: Fix lockdep warning (Don Dutile) [1692079]
- [lib] xarray: Change definition of sibling entries (Don Dutile) [1692079]
- [mm] xarray: Replace exceptional entries (Don Dutile) [1692079]
- [lib] idr: Permit any valid kernel pointer to be stored (Don Dutile) [1692079]
- [pci] Update email address (Don Dutile) [1692079]
- [lib] ida: Change ida_get_new_above to return the id (Don Dutile) [1692079]
- [lib] ida: Remove old API (Don Dutile) [1692079]
- [target] target/iscsi: Allocate session IDs from an IDA (Don Dutile) [1692079]
- [target] iscsi target: fix session creation failure handling (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Return 0 when gmrid::get_node runs out of ID's (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Convert to new IDA API (Don Dutile) [1692079]
- [dma] dmaengine: Convert to new IDA API (Don Dutile) [1692079]
- [powerpc] ppc: Convert vas ID allocation to new IDA API (Don Dutile) [1692079]
- [media] media: Convert entity ID allocation to new IDA API (Don Dutile) [1692079]
- [mm] ppc: Convert mmu context allocation to new IDA API (Don Dutile) [1692079]
- [net] Convert net_namespace to new IDA API (Don Dutile) [1692079]
- [misc] cb710: Convert to new IDA API (Don Dutile) [1692079]
- [block] rsxx: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] osd: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] sd: Convert to new IDA API (Don Dutile) [1692079]
- [fs] devpts: Convert to new IDA API (Don Dutile) [1692079]
- [fs] fs: Convert namespace IDAs to new API (Don Dutile) [1692079]
- [fs] fs: Convert unnamed_dev_ida to new API (Don Dutile) [1692079]
- [lib] test_ida: check_ida_destroy and check_ida_alloc (Don Dutile) [1692079]
- [lib] test_ida: Convert check_ida_conv to new API (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_max (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_leaf (Don Dutile) [1692079]
- [tools] idr-test: Convert ida_check_nomem to new API (Don Dutile) [1692079]
- [tools] ida: Start new test_ida module (Don Dutile) [1692079]
- [lib] ida: Lock the IDA in ida_destroy (Don Dutile) [1692079]
- [lib] radix-tree: Fix UBSAN warning (Don Dutile) [1692079]
- [include] rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile) [1692079]
- [s390] s390/pkey: add one more argument space for debug feature entry (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix possible deadlock situation on ap queue remove (Philipp Rudo) [1710033]
- [s390] zcrypt: handle AP Info notification from CHSC SEI command (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: revisit ap device remove procedure (Philipp Rudo) [1710033]
- [s390] pkey: Indicate old mkvp only if old and current mkvp are different (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: use new state UNBOUND during queue driver rebind (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix specification exception on z196 during ap probe (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: rework ap scan bus code (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: make sysfs reset attribute trigger queue reset (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: improve special ap message cmd handling (Philipp Rudo) [1710033]
- [s390] s390: vfio-ap: include <asm/facility> for test_facility() (Philipp Rudo) [1710033]
- [fs] flexfiles: enforce per-mirror stateid only for v4 DSes (Scott Mayhew) [1709556]
- [fs] flexfiles: use per-mirror specified stateid for IO (Scott Mayhew) [1709556]
- [powerpc] powerpc/pseries: Fix build break due to pnv_npu2_init() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/sriov: Register IOMMU groups for VFs (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Allocate enough memory in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Fix oops in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [mm] mm: defer ZONE_DEVICE page initialization to the point where we init pgmap (Waiman Long) [1666538 1634343]
- [mm] mm: create non-atomic version of SetPageReserved for init use (Waiman Long) [1666538 1634343]
- [mm] mm: provide kernel parameter to allow disabling page init poisoning (Waiman Long) [1666538 1634343]
- [x86] x86/resctrl: Initialize a new resource group with default MBA values (David Arcari) [1688127]
- [x86] x86/resctrl: Move per RDT domain initialization to a separate function (David Arcari) [1688127]
- [x86] x86/resctrl: Do not repeat rdtgroup mode initialization (David Arcari) [1688127]
- [x86] x86/resctrl: Fix rdt_find_domain() return value and checks (David Arcari) [1688127]
- [x86] x86/resctrl: Use rdt_last_cmd_puts() where possible (David Arcari) [1688127]

* Fri May 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-95.el8]
- [s390] s390/pci: map IOV resources (Philipp Rudo) [1659411]
- [powerpc] powerpc/book3s/64: check for NULL pointer in pgd_alloc() (Steve Best) [1710310]
- [md] dm thin metadata: do not write metadata if no changes occurred (Mike Snitzer) [1710030]
- [md] dm thin metadata: add wrappers for managing write locking of metadata (Mike Snitzer) [1710030]
- [md] dm thin metadata: check __commit_transaction()'s return (Mike Snitzer) [1710030]
- [md] dm space map common: zero entire ll_disk (Mike Snitzer) [1710030]
- [powerpc] powerpc/tm: Fix stack pointer corruption (Desnes Augusto Nunes do Rosario) [1707635]
- [pci] PCI/MSI: Remove obsolete sanity checks for multiple interrupt sets (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove the leftovers of the original set support (Prarit Bhargava) [1686678]
- [nvme] nvme-pci: Simplify interrupt allocation (Prarit Bhargava) [1686678]
- [include] genirq/affinity: Add new callback for (re)calculating interrupt sets (Prarit Bhargava) [1686678]
- [nvme] genirq/affinity: Store interrupt sets size in struct irq_affinity (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Code consolidation (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Move allocation of 'node_to_cpumask' to irq_build_affinity_masks() (Prarit Bhargava) [1686678]
- [kernel] genirq/irqdesc: Fix double increment in alloc_descs() (Prarit Bhargava) [1686678]
- [include] genirq: Fix the kerneldoc comment for struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Add is_managed to struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/core: Introduce struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove excess indentation (Prarit Bhargava) [1686678]

* Thu May 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-94.el8]
- [md] dm: make sure to obey max_io_len_target_boundary (Mike Snitzer) [1712607]

* Wed May 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-93.el8]
- [mm] x86/dump_pagetables: Fix LDT remap address marker (Baoquan He) [1639560]
- [x86] x86/mm: Fix guard hole handling (Baoquan He) [1639560]
- [x86] x86/mm: Move LDT remap out of KASLR region on 5-level paging (Baoquan He) [1639560]
- [x86] x86/ldt: Define LDT_END_ADDR (Baoquan He) [1639560]
- [mm] x86/ldt: Reserve address-space range on 32 bit for the LDT (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Enhance the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Clean up the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [fs] cifs: fix page reference leak with readv/writev (Leif Sahlberg) [1708033]
- [fs] cifs: do not attempt cifs operation on smb2+ rename error (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak in SMB2_read (Leif Sahlberg) [1708033]
- [fs] CIFS: keep FileInfo handle live during oplock break (Leif Sahlberg) [1708033]
- [fs] cifs: fix handle leak in smb2_query_symlink() (Leif Sahlberg) [1708033]
- [fs] cifs: Fix lease buffer length error (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_read (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_write (Leif Sahlberg) [1708033]
- [fs] cifs: a smb2_validate_and_copy_iov failure does not mean the handle is invalid. (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow persistent handle timeout to be configurable on mount (Leif Sahlberg) [1708033]
- [fs] smb3: Fix enumerating snapshots to Azure (Leif Sahlberg) [1708033]
- [fs] cifs: fix kref underflow in close_shroot() (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] SMB3: Fix SMB3.1.1 guest mounts to Samba (Leif Sahlberg) [1708033]
- [fs] cifs: Fix slab-out-of-bounds when tracing SMB tcon (Leif Sahlberg) [1708033]
- [fs] cifs: allow guest mounts to work for smb3.11 (Leif Sahlberg) [1708033]
- [fs] fix incorrect error code mapping for OBJECTID_NOT_FOUND (Leif Sahlberg) [1708033]
- [fs] cifs: fix that return -EINVAL when do dedupe operation (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending rdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending wdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: fix POSIX lock leak and invalid ptr deref (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow SMB3 FSCTL queries to be sent to server from tools (Leif Sahlberg) [1708033]
- [fs] cifs: fix incorrect handling of smb2_set_sparse() return in smb3_simple_falloc (Leif Sahlberg) [1708033]
- [fs] smb2: fix typo in definition of a few error flags (Leif Sahlberg) [1708033]
- [fs] CIFS: make mknod() an smb_version_op (Leif Sahlberg) [1708033]
- [documentation] cifs: minor documentation updates (Leif Sahlberg) [1708033]
- [documentation] cifs: minor updates to documentation (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused value pointed out by Coverity (Leif Sahlberg) [1708033]
- [fs] SMB3: passthru query info doesn't check for SMB3 FSCTL passthru (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoints for simple fallocate and zero range (Leif Sahlberg) [1708033]
- [fs] cifs: fix smb3_zero_range so it can expand the file-size when required (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_ioctl_init/free helpers to be used with compounding (Leif Sahlberg) [1708033]
- [fs] smb3: Add dynamic trace points for various compounded smb3 ops (Leif Sahlberg) [1708033]
- [fs] cifs: cache FILE_ALL_INFO for the shared root handle (Leif Sahlberg) [1708033]
- [fs] smb3: display volume serial number for shares in /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] cifs: simplify how we handle credits in compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoint for timeout waiting for credits (Leif Sahlberg) [1708033]
- [fs] smb3: display security information in /proc/fs/cifs/DebugData more accurately (Leif Sahlberg) [1708033]
- [fs] cifs: add a timeout argument to wait_for_free_credits (Leif Sahlberg) [1708033]
- [fs] cifs: prevent starvation in wait_for_free_credits for multi-credit requests (Leif Sahlberg) [1708033]
- [fs] cifs: wait_for_free_credits() make it possible to wait for >=1 credits (Leif Sahlberg) [1708033]
- [fs] cifs: pass flags down into wait_for_free_credits() (Leif Sahlberg) [1708033]
- [fs] cifs: change wait_for_free_request() to take flags as argument (Leif Sahlberg) [1708033]
- [fs] fs: cifs: Kconfig: pedantic formatting (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on normal (non-large read/write) ops (Leif Sahlberg) [1708033]
- [fs] CIFS: Return -EAGAIN instead of -ENOTSOCK (Leif Sahlberg) [1708033]
- [fs] CIFS: Only send SMB2_NEGOTIATE command on new TCP connections (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix read after write for files with read caching (Leif Sahlberg) [1708033]
- [fs] smb3: for kerberos mounts display the credential uid used (Leif Sahlberg) [1708033]
- [fs] cifs: use correct format characters (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for query_info_enter/done (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for smb3_cmd_enter (Leif Sahlberg) [1708033]
- [fs] smb3: improve dynamic tracing of open and posix mkdir (Leif Sahlberg) [1708033]
- [fs] smb3: add missing read completion trace point (Leif Sahlberg) [1708033]
- [fs] smb3: Add tracepoints for read, write and query_dir enter (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoints for query dir (Leif Sahlberg) [1708033]
- [fs] smb3: Update POSIX negotiate context with POSIX ctxt GUID (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Try to acquire credits at once for compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Return error code when getting file handle for writeback (Leif Sahlberg) [1708033]
- [fs] CIFS: Move open file handling to writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Move unlocking pages from wdata_send_pages() (Leif Sahlberg) [1708033]
- [fs] CIFS: Find and reopen a file before get MTU credits in writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Reopen file before get SMB2 MTU credits for async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Remove custom credit adjustments for SMB2 async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Adjust MTU credits before reopening a file (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending async requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in non-MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Set reconnect instance to one initially (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect SMB2 hdr preamble size in read responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Count SMB3 credits for malformed pending responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not log credits when unmounting a share (Leif Sahlberg) [1708033]
- [fs] CIFS: Always reset read error to -EIO if no response (Leif Sahlberg) [1708033]
- [fs] cifs: Accept validate negotiate if server return NT_STATUS_NOT_SUPPORTED (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not skip SMB2 message IDs on send failures (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on tree connect (Leif Sahlberg) [1708033]
- [fs] smb3: make default i/o size for smb3 mounts larger (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reset lease state to NONE on lease break (Leif Sahlberg) [1708033]
- [fs] smb3: fix bytes_read statistics (Leif Sahlberg) [1708033]
- [fs] cifs: return -ENODATA when deleting an xattr that does not exist (Leif Sahlberg) [1708033]
- [fs] cifs: add credits from unmatched responses/messages (Leif Sahlberg) [1708033]
- [fs] cifs: replace snprintf with scnprintf (Leif Sahlberg) [1708033]
- [fs] cifs: Fix NULL pointer dereference of devname (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix leaking locked VFS cache pages in writeback retry (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: fix use-after-free of the lease keys (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not consider -ENODATA as stat failure for reads (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not count -ENODATA as failure for query directory (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix trace command logging for SMB2 reads and writes (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible oops and memory leaks in async IO (Leif Sahlberg) [1708033]
- [fs] cifs: limit amount of data we request for xattrs to CIFSMaxBufSize (Leif Sahlberg) [1708033]
- [fs] cifs: fix computation for MAX_SMB2_HDR_SIZE (Leif Sahlberg) [1708033]
- [fs] cifs: print CIFSMaxBufSize as part of /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] smb3: add credits we receive from oplock/break PDUs (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix mounts if the client is low on credits (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not assume one credit for async responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculations in compound mid callback (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculation for encrypted reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculations for reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reconnect TCP session in add_credits() (Leif Sahlberg) [1708033]
- [fs] smb3: Cleanup license mess (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible hang during async MTU reads and writes (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak of an allocated cifs_ntsd structure (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error paths in writeback code (Leif Sahlberg) [1708033]
- [fs] CIFS: Move credit processing to mid callbacks for SMB3 (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculation for cancelled requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix potential OOB access of lock element array (Leif Sahlberg) [1708033]
- [fs] cifs: Limit memory used by lock request calls to a page (Leif Sahlberg) [1708033]
- [fs] cifs: move large array from stack to heap (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not hide EINTR after sending network packets (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit computation for compounded requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not set credits to 1 if the server didn't grant anything (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix adjustment of credits for MTU requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a tiny potential memory leak (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a debug message (Leif Sahlberg) [1708033]
- [fs] smb3: add smb3.1.1 to default dialect list (Leif Sahlberg) [1708033]
- [fs] cifs: fix confusing warning message on reconnect (Leif Sahlberg) [1708033]
- [fs] smb3: fix large reads on encrypted connections (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] cifs: we can not use small padding iovs together with encryption (Leif Sahlberg) [1708033]
- [fs] cifs: Minor Kconfig clarification (Leif Sahlberg) [1708033]
- [fs] cifs: Always resolve hostname before reconnecting (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect_tcon() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in smb2_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Only free DFS target list if we actually got one (Leif Sahlberg) [1708033]
- [fs] cifs: start DFS cache refresher in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Use GFP_ATOMIC when a lock is held in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'sep' (Leif Sahlberg) [1708033]
- [fs] cifs: Make use of DFS cache to get new DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: check kzalloc return (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'server' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kzfree() to free password (Leif Sahlberg) [1708033]
- [fs] cifs: Fix to use kmem_cache_free() instead of kfree() (Leif Sahlberg) [1708033]
- [fs] cifs: update for current_kernel_time64() removal (Leif Sahlberg) [1708033]
- [fs] cifs: Add DFS cache routines (Leif Sahlberg) [1708033]
- [fs] cifs: Save TTL value when parsing DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: auto disable 'serverino' in dfs mounts (Leif Sahlberg) [1708033]
- [fs] cifs: Make devname param optional in cifs_compose_mount_options() (Leif Sahlberg) [1708033]
- [fs] cifs: Skip any trailing backslashes from UNC (Leif Sahlberg) [1708033]
- [fs] cifs: Refactor out cifs_mount() (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error mapping for SMB2_LOCK command which caused OFD lock problem (Leif Sahlberg) [1708033]
- [fs] CIFS: return correct errors when pinning memory failed for direct I/O (Leif Sahlberg) [1708033]
- [fs] CIFS: use the correct length when pinning memory for direct I/O for write (Leif Sahlberg) [1708033]
- [fs] cifs: check ntwrk_buf_start for NULL before dereferencing it (Leif Sahlberg) [1708033]
- [fs] cifs: remove coverity warning in calc_lanman_hash (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'smb_buf' (Leif Sahlberg) [1708033]
- [fs] cifs: suppress some implicit-fallthrough warnings (Leif Sahlberg) [1708033]
- [fs] cifs: change smb2_query_eas to use the compound query-info helper (Leif Sahlberg) [1708033]
- [fs] Add vers=3.0.2 as a valid option for SMBv3.0.2 (Leif Sahlberg) [1708033]
- [fs] cifs: create a helper function for compound query_info (Leif Sahlberg) [1708033]
- [fs] cifs: address trivial coverity warning (Leif Sahlberg) [1708033]
- [fs] cifs: smb2 commands can not be negative, remove confusing check (Leif Sahlberg) [1708033]
- [fs] cifs: use a compound for setting an xattr (Leif Sahlberg) [1708033]
- [fs] cifs: clean up indentation, replace spaces with tab (Leif Sahlberg) [1708033]
- [fs] smb3: Fix rmdir compounding regression to strict servers (Leif Sahlberg) [1708033]
- [fs] CIFS: Avoid returning EBUSY to upper layer VFS (Leif Sahlberg) [1708033]
- [fs] cifs: Fix separator when building path from dentry (Leif Sahlberg) [1708033]
- [fs] cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy (insecure cifs) (Leif Sahlberg) [1708033]
- [fs] cifs: fix signed/unsigned mismatch on aio_read patch (Leif Sahlberg) [1708033]
- [fs] cifs: don't dereference smb_file_target before null check (Leif Sahlberg) [1708033]
- [fs] CIFS: Add direct I/O functions to file_operations (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O write (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O read (Leif Sahlberg) [1708033]
- [fs] smb3: missing defines and structs for reparse point handling (Leif Sahlberg) [1708033]
- [fs] smb3: allow more detailed protocol info on open files for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: on kerberos mount if server doesn't specify auth type use krb5 (Leif Sahlberg) [1708033]
- [fs] smb3: add trace point for tree connection (Leif Sahlberg) [1708033]
- [fs] cifs: fix spelling mistake, EACCESS -> EACCES (Leif Sahlberg) [1708033]
- [fs] cifs: fix return value for cifs_listxattr (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.14 (Leif Sahlberg) [1708033]
- [fs] smb3: add debug for unexpected mid cancellation (Leif Sahlberg) [1708033]
- [fs] cifs: allow calling SMB2_xxx_free(NULL) (Leif Sahlberg) [1708033]
- [fs] smb3 - clean up debug output displaying network interfaces (Leif Sahlberg) [1708033]
- [fs] smb3: show number of current open files in /proc/fs/cifs/Stats (Leif Sahlberg) [1708033]
- [fs] cifs: add support for ioctl on directories (Leif Sahlberg) [1708033]
- [fs] cifs: fallback to older infolevels on findfirst queryinfo retry (Leif Sahlberg) [1708033]
- [fs] smb3: do not attempt cifs operation in smb3 query info error path (Leif Sahlberg) [1708033]
- [fs] smb3: send backup intent on compounded query info (Leif Sahlberg) [1708033]
- [fs] cifs: track writepages in vfs operation counters (Leif Sahlberg) [1708033]
- [fs] smb2: fix uninitialized variable bug in smb2_ioctl_query_info (Leif Sahlberg) [1708033]
- [fs] cifs: add IOCTL for QUERY_INFO passthrough to userspace (Leif Sahlberg) [1708033]
- [fs] cifs: minor clarification in comments (Leif Sahlberg) [1708033]
- [fs] CIFS: Print message when attempting a mount (Leif Sahlberg) [1708033]
- [fs] CIFS: Adds information-level logging function (Leif Sahlberg) [1708033]
- [fs] cifs: OFD locks do not conflict with eachothers (Leif Sahlberg) [1708033]
- [fs] CIFS: SMBD: Do not call ib_dereg_mr on invalidated memory registration (Leif Sahlberg) [1708033]
- [fs] CIFS: pass page offsets on SMB1 read/write (Leif Sahlberg) [1708033]
- [fs] fs/cifs: fix uninitialised variable warnings (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for sending lease break responses to server (Leif Sahlberg) [1708033]
- [fs] cifs: do not return atime less than mtime (Leif Sahlberg) [1708033]
- [fs] smb3: update default requested iosize to 4MB from 1MB for recent dialects (Leif Sahlberg) [1708033]
- [fs] smb3: Add debug message later in smb2/smb3 reconnect path (Leif Sahlberg) [1708033]
- [fs] CIFS: make 'nodfs' mount opt a superblock flag (Leif Sahlberg) [1708033]
- [fs] smb3: track the instance of each session for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: minor missing defines relating to reparse points (Leif Sahlberg) [1708033]
- [fs] smb3: add way to control slow response threshold for logging and stats (Leif Sahlberg) [1708033]
- [fs] cifs: minor updates to module description for cifs.ko (Leif Sahlberg) [1708033]
- [fs] cifs: protect against server returning invalid file system block size (Leif Sahlberg) [1708033]
- [fs] smb3: allow stats which track session and share reconnects to be reset (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing from compounded ops (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for the max number of iov we need for a SMB2 set_info (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_RENAME and SMB2_OP_HARDLINK to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: remove the is_falloc argument to SMB2_set_eof (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_INFO to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_EOF to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: make rmdir() use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: create helpers for SMB2_set_info_init/free() (Leif Sahlberg) [1708033]
- [fs] cifs: change unlink to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: change mkdir to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a smb2_compound_op and change QUERY_INFO to use it (Leif Sahlberg) [1708033]
- [fs] cifs: fix a credits leak for compund commands (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint to catch cases where credit refund of failed op overlaps reconnect (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'cifs_sb' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kmemdup rather than duplicating its implementation in smb311_posix_mkdir() (Leif Sahlberg) [1708033]
- [fs] smb3: do not display confusing message on mount to Azure servers (Leif Sahlberg) [1708033]
- [fs] smb3: fix lease break problem introduced by compounding (Leif Sahlberg) [1708033]
- [fs] cifs: only wake the thread for the very last PDU in a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a warning if we try to to dequeue a deleted mid (Leif Sahlberg) [1708033]
- [fs] smb2: fix missing files in root share directory listing (Leif Sahlberg) [1708033]
- [fs] cifs: read overflow in is_valid_oplock_break() (Leif Sahlberg) [1708033]
- [fs] cifs: integer overflow in in SMB2_ioctl() (Leif Sahlberg) [1708033]
- [fs] CIFS: fix wrapping bugs in num_entries() (Leif Sahlberg) [1708033]
- [fs] cifs: prevent integer overflow in nxt_dir_entry() (Leif Sahlberg) [1708033]
- [fs] fs/cifs: suppress a string overflow warning (Leif Sahlberg) [1708033]
- [fs] cifs: connect to servername instead of IP for IPC$ share (Leif Sahlberg) [1708033]
- [fs] smb3: check for and properly advertise directory lease support (Leif Sahlberg) [1708033]
- [fs] smb3: minor debugging clarifications in rfc1001 len processing (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing for directory opens with backupuid mounts (Leif Sahlberg) [1708033]
- [fs] fs/cifs: don't translate SFM_SLASH (U+F026) to backslash (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.12 (Leif Sahlberg) [1708033]
- [fs] cifs: check kmalloc before use (Leif Sahlberg) [1708033]
- [fs] cifs: check if SMB2 PDU size has been padded and suppress the warning (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for how many iovs we need for an SMB2_open() (Leif Sahlberg) [1708033]
- [fs] smb3: create smb3 equivalent alias for cifs pseudo-xattrs (Leif Sahlberg) [1708033]
- [fs] smb3: allow previous versions to be mounted with snapshot= mount parm (Leif Sahlberg) [1708033]
- [fs] cifs: don't show domain= in mount output when domain is empty (Leif Sahlberg) [1708033]
- [fs] cifs: add missing support for ACLs in SMB 3.11 (Leif Sahlberg) [1708033]
- [fs] smb3: enumerating snapshots was leaving part of the data off end (Leif Sahlberg) [1708033]
- [fs] cifs: update smb2_queryfs() to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: update receive_encrypted_standard to handle compounded responses (Leif Sahlberg) [1708033]
- [fs] cifs: create SMB2_open_init()/SMB2_open_free() helpers. (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_query_info_[init|free]() (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_close_init()/SMB2_close_free() (Leif Sahlberg) [1708033]
- [fs] smb3: display stats counters for number of slow commands (Leif Sahlberg) [1708033]
- [fs] CIFS: fix uninitialized ptr deref in smb2 signing (Leif Sahlberg) [1708033]
- [fs] smb3: Do not send SMB3 SET_INFO if nothing changed (Leif Sahlberg) [1708033]
- [fs] smb3: fix minor debug output for CONFIG_CIFS_STATS (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for slow responses (Leif Sahlberg) [1708033]
- [fs] cifs: add compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] cifs: make smb_send_rqst take an array of requests (Leif Sahlberg) [1708033]
- [fs] cifs: update init_sg, crypt_message to take an array of rqst (Leif Sahlberg) [1708033]
- [fs] smb3: fix reset of bytes read and written stats (Leif Sahlberg) [1708033]
- [fs] smb3: display bytes_read and bytes_written in smb3 stats (Leif Sahlberg) [1708033]
- [fs] cifs: simple stats should always be enabled (Leif Sahlberg) [1708033]
- [fs] cifs: use a refcount to protect open/closing the cached file handle (Leif Sahlberg) [1708033]
- [fs] smb3: add reconnect tracepoints (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for session expired or deleted (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused stats (Leif Sahlberg) [1708033]
- [fs] smb3: don't request leases in symlink creation and query (Leif Sahlberg) [1708033]
- [fs] smb3: remove per-session operations from per-tree connection stats (Leif Sahlberg) [1708033]
- [fs] SMB3: Number of requests sent should be displayed for SMB3 not just CIFS (Leif Sahlberg) [1708033]
- [fs] smb3: snapshot mounts are read-only and make sure info is displayable about the mount (Leif Sahlberg) [1708033]
- [fs] smb3: remove noisy warning message on mount (Leif Sahlberg) [1708033]
- [fs] cifs: add missing debug entries for kconfig options (Leif Sahlberg) [1708033]
- [fs] smb3: fill in statfs fsid and correct namelen (Leif Sahlberg) [1708033]
- [fs] cifs: Make sure all data pages are signed correctly (Leif Sahlberg) [1708033]
- [fs] CIFS: fix memory leak and remove dead code (Leif Sahlberg) [1708033]
- [fs] cifs: use 64-bit timestamps for fscache (Leif Sahlberg) [1708033]
- [fs] cifs: use timespec64 internally (Leif Sahlberg) [1708033]
- [fs] cifs: Silence uninitialized variable warning (Leif Sahlberg) [1708033]
- [fs] fs/cifs: Simplify ib_post_(send|recv|srq_recv)() calls (Leif Sahlberg) [1708033]

* Mon May 20 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-92.el8]
- [edac] EDAC/amd64: Set maximum channel layer size depending on family (Gary Hook) [1690984]
- [edac] EDAC/amd64: Adjust printed chip select sizes when interleaved (Gary Hook) [1690984]
- [edac] EDAC/amd64: Recognize x16 symbol size (Gary Hook) [1690984]
- [edac] EDAC/amd64: Support more than two Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC/amd64: Use a macro for iterating over Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC, amd64: Add Family 17h, models 10h-2fh support (Gary Hook) [1670609 1690984]
- [md] dm mpath: fix missing call of path selector type->end_io (Mike Snitzer) [1686227]
- [rpmspec] redhat: do not generate debuginfo for self-tests and samples (Ivan Vecera) [1708375]
- [netdrv] broadcom: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Kamal Heib) [1684380]
- [netdrv] broadcom: tg3: fix use of SPEED_UNKNOWN ethtool constant (Kamal Heib) [1684380]
- [netdrv] tg3: allow ethtool -p to work for NICs in down state (Kamal Heib) [1684380]
- [netdrv] tg3: optionally use eth_platform_get_mac_address() to get mac address (Kamal Heib) [1684380]
- [netdrv] tg3: extend PTP gettime function to read system clock (Kamal Heib) [1684380]
- [netdrv] tg3: Fix fall-through annotations (Kamal Heib) [1684380]
- [netdrv] tg3: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [mm] x86/mm/KASLR: Fix the size of the direct mapping section (Baoquan He) [1669075]
- [netdrv] net/mlx4_en: fix spelling mistake: "quiting" -> "quitting" (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix error handling when initializing CQ bufs in the driver (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Add masking for a few queries on HCA caps (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Fix using wrong function to destroy sqp AHs under SRIOV (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: replace pci_{,un}map_sg with dma_{,un}map_sg (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: Get rid of page operation after dma_alloc_coherent (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: drop useless LIST_HEAD (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove set but not used variable 'pd' (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Utilize macro to calculate SQ spare size (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: remove fallback after kzalloc_node() (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove unneeded NULL check (Alaa Hleihel) [1691235 1691228]
- [infiniband] mlx4: Use snprintf instead of complicated strcpy (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix several coding style errors (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix return codes of unsupported operations (Alaa Hleihel) [1691235 1691228]
- [netdrv] {net, IB}/mlx4: Initialize CQ buffers in the driver when possible (Alaa Hleihel) [1691235 1691228]
- [netdrv] mlx4: use __vlan_hwaccel helpers (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: Fix build break when CONFIG_INET is off (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: use __netdev_tx_sent_queue() (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: add a missing <net/ip.h> include (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Add port and TID to MAD debug print (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Enable debug print of SMPs (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA: Fix dependencies for rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Remove unnecessary parentheses (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA/mlx4: Use rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_core: Fix warnings during boot on driverinit param set failures (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Use devlink region_snapshot parameter (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add Crdump FW snapshot support (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add health buffer address capability (Alaa Hleihel) [1691228]
- [netdrv] mlx4: Add support for devlink reload and load driverinit values (Alaa Hleihel) [1691228 1663198]
- [netdrv] mlx4: Add mlx4 initial parameters table and register it (Alaa Hleihel) [1691228 1663198]
- [infiniband] IB/mlx4: Create slave AH's directly (Alaa Hleihel) [1691228]
- [infiniband] IB/mlx4: Add support for drain SQ & RQ (Alaa Hleihel) [1691228]
- [net] openvswitch: return an error instead of doing BUG_ON() (Eelco Chaudron) [1700468]
- [include] net: add netif_is_geneve() (Petr Oros) [1707002]
- [netdrv] team: fix possible recursive locking when add slaves (Hangbin Liu) [1700679]
- [netdrv] phy: Fix ioctl handler when modifing MII_ADVERTISE (Petr Oros) [1691676]
- [netdrv] mii: Add mii_lpa_mod_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] phy: marvell: Rename mii_lpa_to_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] mii: Rename mii_stat1000_to_linkmode_lpa_t (Petr Oros) [1691676]
- [include] mii: Fix autoneg in mii_lpa_to_linkmode_lpa_t() (Petr Oros) [1691676]
- [netdrv] phy: remove unused code in phy_probe (Petr Oros) [1691676]
- [netdrv] phy: check if advertising is zero using linkmode_empty (Petr Oros) [1691676]
- [netdrv] phy: marvell: remove set but not used variable 'pause' (Petr Oros) [1691676]
- [netdrv] phy: Add support for resolving 5G and 2.5G autoneg (Petr Oros) [1691676]
- [netdrv] phy: Add more link modes to the settings table (Petr Oros) [1691676]
- [netdrv] phy: Fixup kerneldoc markup. (Petr Oros) [1691676]
- [netdrv] phy: Convert u32 phydev->lp_advertising to linkmode (Petr Oros) [1691676]
- [netdrv] ethernet: Convert phydev advertize and supported from u32 to link mode (Petr Oros) [1691676]
- [netdrv] bonding: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [netdrv] bonding: Give bond_set_dev_addr() a return value (Ivan Vecera) [1705509]
- [netdrv] ipvlan: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] bridge: Handle NETDEV_PRE_CHANGEADDR from ports (Ivan Vecera) [1705509]
- [net] bridge: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add extack argument to dev_set_mac_address() (Ivan Vecera) [1705509]
- [netdrv] phy: phy driver features are mandatory (Petr Oros) [1691720]
- [netdrv] phy: add missing phy driver features (Petr Oros) [1691720]
- [netdrv] phy: Add missing features to PHY drivers (Petr Oros) [1691720]
- [netdrv] phy: genphy_10g_driver: Avoid NULL pointer dereference (Petr Oros) [1691720]
- [netdrv] phy: phy_support_sym_pause: Clear Asym Pause (Petr Oros) [1691720]
- [netdrv] phy: Replace phy driver features u32 with link_mode bitmap (Petr Oros) [1691720]
- [netdrv] ethernet: xgbe: expand PHY_GBIT_FEAUTRES (Petr Oros) [1691720]
- [net] net: phy: Add limkmode equivalents to some of the MII ethtool helpers (Petr Oros) [1691720]
- [netdrv] phy: Add helper for advertise to lcl value (Petr Oros) [1691720]
- [net] phy: Add helper to convert MII ADV register to a linkmode (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_info() (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_warn() (Petr Oros) [1691720]
- [netdrv] phy: Move linkmode helpers to somewhere public (Petr Oros) [1691720]
- [netdrv] ethernet: dpaa: remove unused variables (Petr Oros) [1691720]
- [netdrv] ravb: Disable Pause Advertisement (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to determine if pause configuration is supported (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Asym Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support asym pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to remove a supported link mode (Petr Oros) [1691720]
- [netdrv] ethernet: Fix up drivers masking pause support (Petr Oros) [1691720]
- [netdrv] bcmgenet: Fix speed selection for reverse MII (Petr Oros) [1691720]
- [netdrv] ethernet: Use phy_set_max_speed() to limit advertised speed (Petr Oros) [1691720]
- [netdrv] phy: bcm63xx: Allow to be built with COMPILE_TEST (Petr Oros) [1691720]
- [netdrv] phy: et1011c: Remove incorrect missing 1000 Half (Petr Oros) [1691720]
- [netdrv] phy: ste10Xp: Remove wrong SUPPORTED_Pause (Petr Oros) [1691720]
- [tools] selftests: net: ip_defrag: cover new IPv6 defrag behavior (Guillaume Nault) [1660282]
- [tools] selftests: net: fix/improve ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests: use posix-style redirection in ip_defrag.sh (Guillaume Nault) [1660282]
- [tools] selftests: net: Clean up an unused variable (Guillaume Nault) [1660282]
- [tools] selftests/net: add ipv6 tests to ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests/net: add ip_defrag selftest (Guillaume Nault) [1660282]
- [net] ip6: fix skb leak in ip6frag_expire_frag_queue() (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees in nf_conntrack_reasm.c (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees for IPv6 defrag (Guillaume Nault) [1660282]
- [net] IP defrag: encapsulate rbtree defrag code into callable functions (Guillaume Nault) [1660282]
- [net] ipv4: do not handle duplicate fragments as overlapping (Guillaume Nault) [1660282]
- [net] ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize changes (Guillaume Nault) [1660282]
- [net] ipv6: remove dependency of nf_defrag_ipv6 on ipv6 module (Guillaume Nault) [1660282]
- [net] ipv6: fix typo in net/ipv6/reassembly.c (Guillaume Nault) [1660282]
- [net] core: dev: Attach extack to NETDEV_PRE_UP (Ivan Vecera) [1705501]
- [net] core: dev: Add call_netdevice_notifiers_extack() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to __dev_change_flags() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to dev_change_flags() (Ivan Vecera) [1705501]
- [netdrv] ipvlan: ipvlan_set_port_mode(): Add an extack argument (Ivan Vecera) [1705501]
- [netdrv] vrf: cycle_netdev(): Add an extack argument (Ivan Vecera) [1705501]
- [net] net: core: dev: Add extack argument to dev_open() (Ivan Vecera) [1705501]
- [net] vlan: conditional inclusion of FCoE hooks to match netdevice.h and bnx2x (Chris Leech) [1685894]
- [net] Do not route unicast IP packets twice (Ivan Vecera) [1704923]
- [net] skbuff: Rename 'offload_mr_fwd_mark' to 'offload_l3_fwd_mark' (Ivan Vecera) [1704923]
- [net] devlink: Add 'fw_load_policy' generic parameter (Ivan Vecera) [1704902]
- [net] bridge: Extend br_vlan_get_pvid() for bridge ports (Ivan Vecera) [1704863]
- [net] ipv4: Notify about changes to ip_forward_update_priority (Ivan Vecera) [1704697]
- [net] ipv4: Control SKB reprioritization after forwarding (Ivan Vecera) [1704697]
- [net] dcb: Add priority-to-DSCP map getters (Ivan Vecera) [1704639]
- [net] xsk: export xdp_get_umem_from_qid (Ivan Vecera) [1704606]
- [net] net: Add lag.h, net_lag_port_dev_txable() (Ivan Vecera) [1704297]
- [netdrv] team: Publish team_port_get_rcu() (Ivan Vecera) [1704297]
- [net] sched: sch_api: set an error msg when qdisc_alloc_handle() fails (Ivan Vecera) [1677094]
- [net] ethtool: Remove unnecessary null check in ethtool_rx_flow_rule_create (Ivan Vecera) [1691738]
- [net] flow_offload: fix block stats (Ivan Vecera) [1691738]
- [net] sched: flower: only return error from hw offload if skip_sw (Ivan Vecera) [1691738]
- [net] flow_offload: Fix flow action infrastructure (Ivan Vecera) [1691738]
- [net] ethtool: add ethtool_rx_flow_spec to flow_rule structure translator (Ivan Vecera) [1691738]
- [net] flow_offload: add wake-up-on-lan and queue to flow_action (Ivan Vecera) [1691738]
- [net] flow_offload: add statistics retrieval infrastructure and use it (Ivan Vecera) [1691738]
- [net] cls_api: add translator to flow_action representation (Ivan Vecera) [1691738]
- [net] flow_offload: add flow action infrastructure (Ivan Vecera) [1691738]
- [net] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1691738]
- [net] netfilter: ipv6: Don't preserve original oif for loopback address (Florian Westphal) [1702813]
- [net] netfilter: ipv6: Preserve link scope traffic original oif (Florian Westphal) [1702813]
- [net] sctp: implement memory accounting on rx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] sctp: implement memory accounting on tx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] openvswitch: fix flow actions reallocation (Eelco Chaudron) [1700468]
- [net] openvswitch: fix missing checks for nla_nest_start (Eelco Chaudron) [1700468]
- [net] openvswitch: fix a NULL pointer dereference (Eelco Chaudron) [1700468]
- [net] openvswitch: meter: Use struct_size() in kzalloc() (Eelco Chaudron) [1700468]
- [net] openvswitch: Fix IPv6 later frags parsing (Eelco Chaudron) [1700468]
- [net] openvswitch: fix spelling mistake "execeeds" -> "exceeds" (Eelco Chaudron) [1700468]
- [net] openvswitch: remove BUG_ON from get_dpdev (Eelco Chaudron) [1700468]
- [net] openvswitch: fix linking without CONFIG_NF_CONNTRACK_LABELS (Eelco Chaudron) [1700468]
- [net] revert "openvswitch: Fix template leak in error cases." (Eelco Chaudron) [1700468]
- [net] openvswitch: Use correct reply values in datapath and vport ops (Eelco Chaudron) [1700468]
- [net] ovs: fix return type of ndo_start_xmit function (Eelco Chaudron) [1700468]
- [net] openvswitch: Derive IP protocol number for IPv6 later frags (Eelco Chaudron) [1700468]
- [net] openvswitch: kernel datapath clone action (Eelco Chaudron) [1700468]
- [net] openvswitch: Avoid OOB read when parsing flow nlattrs (Eelco Chaudron) [1700468]
- [net] net/vlan: remove unused #define HAVE_VLAN_GET_TAG (Ivan Vecera) [1700369]
- [net] vlan: include the shift in skb_vlan_tag_get_prio() (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_copy_tag() helper (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_clear_tag() helper (Ivan Vecera) [1700369]
- [net] sctp: initialize _pad of sockaddr_in before copying to user memory (Xin Long) [1699076]
- [net] sctp: use memdup_user instead of vmemdup_user (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: not copy sctp_sock pd_lobby in sctp_copy_descendant (Xin Long) [1699076]
- [net] sctp: get sctphdr by offset in sctp_compute_cksum (Xin Long) [1699076]
- [net] sctp: call sctp_auth_init_hmacs() in sctp_sock_migrate() (Xin Long) [1699076]
- [net] sctp: move up sctp_auth_init_hmacs() in sctp_endpoint_init() (Xin Long) [1699076]
- [net] sctp: sctp_sock_migrate() returns error if sctp_bind_addr_dup() fails (Xin Long) [1699076]
- [net] sctp: remove sched init from sctp_stream_init (Xin Long) [1699076]
- [net] sctp: call iov_iter_revert() after sending ABORT (Xin Long) [1699076]
- [net] ipvs: get sctphdr by sctphoff in sctp_csum_check (Xin Long) [1699076]
- [net] sctp: chunk.c: correct format string for size_t in printk (Xin Long) [1699076]
- [net] sctp: don't compare hb_timer expire date before starting it (Xin Long) [1699076]
- [net] doc: sctp: Merge and clean up rst files (Xin Long) [1699076]
- [net] sctp: set stream ext to NULL after freeing it in sctp_stream_outq_migrate (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASOC and SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER_VALUE sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_INTERLEAVING_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RECONFIG_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PR_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_THLDS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_LOCAL_AUTH_CHUNKS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_MAXSEG sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_ASSOCINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RTOINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_PARAMS sockopt (Xin Long) [1699076]
- [net] sctp: introduce SCTP_FUTURE/CURRENT/ALL_ASSOC (Xin Long) [1699076]
- [net] sctp: set flow sport from saddr only when it's 0 (Xin Long) [1699076]
- [net] sctp: set chunk transport correctly when it's a new asoc (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream adding (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream reset (Xin Long) [1699076]
- [net] sctp: allocate sctp_sockaddr_entry with kzalloc (Xin Long) [1699076]
- [net] sctp: initialize sin6_flowinfo for ipv6 addrs in sctp_inet6addr_event (Xin Long) [1699076]
- [net] sctp: frag_point sanity check (Xin Long) [1699076]
- [net] sctp: kfree_rcu asoc (Xin Long) [1699076]
- [net] sctp: update frag_point when stream_interleave is set (Xin Long) [1699076]
- [net] sctp: add sockopt SCTP_EVENT (Xin Long) [1699076]
- [net] sctp: rename enum sctp_event to sctp_event_type (Xin Long) [1699076]
- [net] sctp: add subscribe per asoc (Xin Long) [1699076]
- [net] sctp: define subscribe in sctp_sock as __u16 (Xin Long) [1699076]
- [net] sctp: process sk_reuseport in sctp_get_port_local (Xin Long) [1699076]
- [net] sctp: add sock_reuseport for the sock in __sctp_hash_endpoint (Xin Long) [1699076]
- [net] sctp: do reuseport_select_sock in __sctp_rcv_lookup_endpoint (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_ordered(). (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_reasm(). (Xin Long) [1699076]
- [net] sctp: define SCTP_SS_DEFAULT for Stream schedulers (Xin Long) [1699076]
- [net] sctp: clear the transport of some out_chunk_list chunks in sctp_assoc_rm_peer (Xin Long) [1699076]
- [net] sctp: use sk_wmem_queued to check for writable space (Xin Long) [1699076]
- [net] sctp: count both sk and asoc sndbuf with skb truesize and sctp_chunk size (Xin Long) [1699076]
- [net] sctp: use the pmtu from the icmp packet to update transport pathmtu (Xin Long) [1699076]
- [net] sctp: fix fall-through annotation (Xin Long) [1699076]
- [net] sctp: Use skb_queue_is_first(). (Xin Long) [1699076]
- [net] sctp: not traverse asoc trans list if non-ipv6 trans exists for ipv6_flowlabel (Xin Long) [1699076]
- [net] sctp: fix invalid reference to the index variable of the iterator (Xin Long) [1699076]
- [net] sctp: remove useless start_fail from sctp_ht_iter in proc (Xin Long) [1699076]
- [net] sctp: Make wrappers for accessing in/out streams (Xin Long) [1699076]
- [net] sctp: whitespace fixes (Xin Long) [1699076]
- [net] sctp: check for ipv6_pinfo legal sndflow with flowlabel in sctp_v6_get_dst (Xin Long) [1699076]
- [net] sctp: add support for setting flowlabel when adding a transport (Xin Long) [1699076]
- [net] sctp: add spp_ipv6_flowlabel and spp_dscp for sctp_paddrparams (Xin Long) [1699076]
- [net] sctp: add support for dscp and flowlabel per transport (Xin Long) [1699076]
- [net] ipv4: add __ip_queue_xmit() that supports tos param (Xin Long) [1699076]
- [net] sctp: add support for SCTP_REUSE_PORT sockopt (Xin Long) [1699076]
- [netdrv] pptp: dst_release sk_dst_cache in pptp_sock_destruct (Xin Long) [1671606]
- [net] datagram: fix unbounded loop in __skb_try_recv_datagram() (Paolo Abeni) [1692379]
- [net] ipv6: route: purge exception on removal (Paolo Abeni) [1669049]
- [net] vsock: cope with memory allocation failure at socket creation time (Paolo Abeni) [1671619]
- [net] ptp: fix Spectre v1 vulnerability (Hangbin Liu) [1664624]

* Fri May 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-91.el8]
- [infiniband] RDMA/bnxt_re: fix or'ing of data into an uninitialized struct member (Selvin Xavier) [1664798]
- [netdrv] RDMA/bnxt_en: Enable RDMA driver support for 57500 chip (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Update kernel user abi to pass chip context (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add extended psn structure for 57500 adapters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Enable GSI QP support for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Skip backing store allocation for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add 64bit doorbells for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add chip context to identify 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: fix a size calculation (Selvin Xavier) [1664798]
- [infiniband] infiniband: bnxt_re: qplib: Check the return value of send_message (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Increase depth of control path command queue (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Query HWRM Interface version from FW (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of destroy AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of create AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing the device structure after it is freed (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix system hang when registration with L2 driver fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid resource leak in case the NQ registration fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Wait for delayed work to finish before device removal (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Limit max_pkey to 16 bit value (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix qp async event reporting (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Report out of sequence hw counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Expose rx discards and drop counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Prevent driver crash due to NULL pointer in error message print (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Drop L2 async events silently (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing nq->bar_reg_iomem in failure case (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid NULL check after accessing the pointer (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Remove the unnecessary version macro definition (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix recursive lock warning in debug kernel (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add missing spin lock initialization (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: QPLIB: Add and use #define dev_fmt(fmt) "QPLIB: " fmt (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Modify a fall-through annotation (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a couple off by one bugs (Selvin Xavier) [1664798]
- [powerpc] powerpc/fadump: Do not allow hot-remove memory from fadump reserved area. (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Throw proper error message on fadump registration failure (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Reservationless firmware assisted dump (Gustavo Duarte) [1524686]
- [infiniband] IB/hfi1: Fix WQ_MEM_RECLAIM warning (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Implement CCA for TID RDMA protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove WARN_ON when freeing expected receive groups (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unify the software PSN check for TID RDMA READ/WRITE (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to read next expected psn from hardware flow (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Delay the release of destination mr for TID RDMA WRITE DATA (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Do not flush send queue in the TID RDMA second leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix the allocation of RSM table (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Eliminate opcode tests on mr deref (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Clear the IOWAIT pending bits when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Failed to drain send queue when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add missing break in switch statement (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a build warning for TID RDMA READ (Alex Estrin) [1660618]
- [infiniband] RDMA/rdmavt: Adapt to handle non-uniform sizes on umem SGEs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prioritize the sending of ACK packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between TID RDMA WRITE and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA WRITE functionality into RDMA verbs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the dual leg code (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg ACK packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg send packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Resend the TID RDMA WRITE DATA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA retry timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID resource timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add an s_acked_ack_queue pointer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow for extra entries in QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Build TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between a TID RDMA request and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate TID RDMA READ protocol into RC protocol (Alex Estrin) [1660618]
- [include] IB/hfi1: Increment the retry timeout value for TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions for restarting TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA handlers (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set PbcInsertHcrc for TID RDMA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to build TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for flow and TID management functions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the counter n_tidwait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA RcvArray programming and TID allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA flow allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi: Move RC functions into a header file (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for OPFN (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate OPFN into RC transactions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1, IB/rdmavt: Allow for extending of QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN interface (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN helper functions for TID RDMA feature (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN support discovery (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib, rvt} Cleanup open coded sge usage (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1,qib}: Cleanup open coded sge sizing (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Use GUP longterm for PSM page pining (Alex Estrin) [1660618]
- [infiniband] infiniband: qib: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: drop crazy DEBUGFS_SEQ_FILE_CREATE() macro (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib}: Fix WC.byte_len calculation for UD_SEND_WITH_IMM (Alex Estrin) [1660618]
- [infiniband] IB/qib: Fix an error code in qib_sdma_verbs_send() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reduce lock contention on iowait_lock for sdma and pio (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Close VNIC sdma_progress sleep window (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow the driver to initialize QP priv struct (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN and TID RDMA capability bits (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unreserve a reserved request when it is completed (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Consider LMC in 16B/bypass ingress packet check (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Limit VNIC use of SDMA engines to the available count (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Correctly process FECN and BECN in packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Ignore LNI errors before DC8051 transitions to Polling state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Dump pio info for non-user send contexts (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a latency issue for small messages (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Remove all occurrences of BUG_ON() (Alex Estrin) [1660618]
- [infiniband] IB/qib: fix spelling mistake "colescing" -> "coalescing" (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Use VL15 for SM packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add mtu check for operational data VLs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for iowait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare resource waits for dual leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Error path MAD response size is incorrect (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move UnsupportedVL bits definitions to the correct header (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: set_intr_bits uses incorrect source for register modification (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Missing return value in error path for user sdma (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Right size user_sdma sequence numbers and related variables (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move URGENT IRQ enable to hfi1_rcvctrl() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework the IRQ API to be more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: PCIe bus width retry (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Make the MSIx resource allocation a bit more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare for new HFI1 MSIx API (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Get the hfi1_devdata structure as early as possible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: tune_pcie_caps is arbitrarily placed, poorly (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove duplicated defines (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework file list in Makefile (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove incorrect call to do_interrupt callback (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set in_use_ctxts bits for user ctxts only (Alex Estrin) [1660618]
- [include] include/rdma/opa_addr.h: Fix an endianness issue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove INTx support and simplify MSIx usage (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reorg ctxtdata and rightsize fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove caches of chip CSRs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove unused/writeonly devdata fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rightsize ctxt_eager_bufs fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvctrl from ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrq_size (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrsize (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move rhf_offset from devdata to ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move normal functions from hfi1_devdata to const array (Alex Estrin) [1660618]
- [infiniband] scsi: RDMA/srpt: Fix handling of TMF submission failure (Jonathan Toppins) [1685313]
- [infiniband] scsi: RDMA/srpt: Fix a credit leak for aborted commands (Jonathan Toppins) [1685313]
- [net] xprtrdma: Reduce the doorbell rate (Receive) (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix sparse warnings (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix helper that drains the transport (Jonathan Toppins) [1685313]
- [netdrv] enic: fix build warning without CONFIG_CPUMASK_OFFSTACK (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Fix out of bounds index check in query pkey (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Remove stub functions (Jonathan Toppins) [1685313]
- [infiniband] rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use (Jonathan Toppins) [1685313]
- [infiniband] RDMA/ucontext: Fix regression with disassociate (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Fix dma_nents type definition (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Pass the correct number of entries for dma mapped SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/rxe: Use for_each_sg_page iterator on umem SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Fix memory leak on pvrdma_pci_remove (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Support upto 64-bit PFNs (Jonathan Toppins) [1683475]
- [include] IB/mlx5: Remove dead code (Jonathan Toppins) [1685313]
- [infiniband] IB/mlx5: Ranges in implicit ODP MR inherit its write access (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix frwr memory registration (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Add wc_flags and wc_immdata to cq entry trace (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix concurrency panics in QP post_send and modify to error (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix loopback send with invalidate ordering (Jonathan Toppins) [1685313]
- [infiniband] IB/hfi1: Add limit test for RC/UC send via loopback (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: Fix string truncation error (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: add tos_set bool to iw_cm struct (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: listening device cm_ids should inherit tos (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: Rollback source IP address if failing to acquire device (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Call ib_cache_release_one() only from ib_device_release() (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Ensure that security memory is always freed (Jonathan Toppins) [1685313]
- [infiniband] RDMA/uverbs: Fix an error flow in ib_uverbs_poll_cq (Jonathan Toppins) [1685313]
- [infiniband] IB/ipoib: Make ipoib_intercept_dev_id_attr() static (Jonathan Toppins) [1685313]
- [infiniband] RDMA: Provide safe ib_alloc_device() function (Jonathan Toppins) [1685313]
- [infiniband] IB/core, ipoib: Do not overreact to SM LID change event (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Abort page fault handler silently during owning process exit (Jonathan Toppins) [1685313]
- [infiniband] RDMA/core: Verify that memory window type is legal (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Don't register each MAD agent for LSM notifier (Jonathan Toppins) [1711086 1685313]
- [include] IB/core: Eliminate a hole in MAD agent struct (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Fix potential memory leak while creating MAD agents (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Unregister notifier before freeing MAD security (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Destroy QP if XRC QP fails (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Declare local functions 'static' (Jonathan Toppins) [1685313]
- [infiniband] RDMA/i40iw: Make sure to initialize ib_device_ops (Jonathan Toppins) [1685313]
- [rpmspec] Update the kernel rpm package description to mention backports/bug fixes ("Herton R. Krzesinski") [1701064]
- [netdrv] bonding: fix arp_validate toggling in active-backup mode (Jarod Wilson) [1654214]
- [scsi] scsi: bnx2i: fix indentation issue, remove a tab (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: remove set but not used variable 'cid_num' (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: add error handling for ioremap_nocache (Maurizio Lombardi) [1665626]
- [wireless] iwlwifi: mvm: Send LQ command as async when necessary (Stanislaw Gruszka) [1687265]
- [scsi] scsi: bnx2fc: Fix error handling in probe() (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Fix NULL dereference in error handling (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Remove set but not used variable 'oxid' (Maurizio Lombardi) [1665625]
- [scsi] bnx2fc_fcoe: Use skb_queue_walk_safe(). (Maurizio Lombardi) [1665625]
- [netdrv] hv_netvsc: Fix rndis_per_packet_info internal field initialization (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add handler for LRO setting change (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add support for LRO/RSC in the vSwitch (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix unwanted wakeup after tx_disable (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix IP header checksum for coalesced packets (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: fix typos in code comments (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix hash key value reset after other ops (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Refactor assignments of struct netvsc_device_info (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix ethtool change hash key error (Mohammed Gamal) [1691375]
- [netdrv] ice: Disable sniffing VF traffic on PF (Kamal Heib) [1659176]
- [netdrv] ice: Use more efficient structures (Kamal Heib) [1659176]
- [netdrv] ice: Use bitfields where possible (Kamal Heib) [1659176]
- [netdrv] ice: Add function to program ethertype based filter rule on VSIs (Kamal Heib) [1659176]
- [netdrv] ice: Separate if conditions for ice_set_features() (Kamal Heib) [1659176]
- [netdrv] ice: Remove __always_unused attribute (Kamal Heib) [1659176]
- [netdrv] ice: Suppress false-positive style issues reported by static analyzer (Kamal Heib) [1659176]
- [netdrv] ice: Refactor getting/setting coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Always free/allocate q_vectors (Kamal Heib) [1659176]
- [netdrv] ice: Do not unnecessarily initialize local variable (Kamal Heib) [1659176]
- [netdrv] ice: Add more validation in ice_vc_cfg_irq_map_msg (Kamal Heib) [1659176]
- [netdrv] ice: Don't remove VLAN filters that were never programmed (Kamal Heib) [1659176]
- [netdrv] ice: Preserve VLAN Rx stripping settings (Kamal Heib) [1659176]
- [netdrv] ice: Fix for allowing too many MDD events on VF (Kamal Heib) [1659176]
- [netdrv] ice: Use pf instead of vsi-back (Kamal Heib) [1659176]
- [netdrv] ice: Use dev_err when ice_cfg_vsi_lan fails (Kamal Heib) [1659176]
- [netdrv] ice: Refactor link event flow (Kamal Heib) [1659176]
- [netdrv] ice: Add missing PHY type to link settings (Kamal Heib) [1659176]
- [netdrv] ice: Add reg_idx variable in ice_q_vector structure (Kamal Heib) [1659176]
- [netdrv] ice: Remove runtime change of PFINT_OICR_ENA register (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue when adding more than allowed VLANs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary wait when disabling/enabling Rx queues (Kamal Heib) [1659176]
- [netdrv] ice: Add ability to update rx-usecs-high (Kamal Heib) [1659176]
- [netdrv] ice: Add 52 byte RSS hash key support (Kamal Heib) [1659176]
- [netdrv] ice: Use ice_for_each_q_vector macro where possible (Kamal Heib) [1659176]
- [netdrv] ice: Validate ring existence and its q_vector per VSI (Kamal Heib) [1659176]
- [netdrv] ice: Reduce scope of variable in ice_vsi_cfg_rxqs (Kamal Heib) [1659176]
- [netdrv] ice: Resolve static analysis reported issue (Kamal Heib) [1659176]
- [netdrv] ice: Return configuration error without queue to disable (Kamal Heib) [1659176]
- [netdrv] ice: Create framework for VSI queue context (Kamal Heib) [1659176]
- [netdrv] ice: Calculate ITR increment based on direct calculation (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump driver version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to control FW LLDP and DCBX (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB rebuild (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to get DCB related statistics (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add priority information into VLAN header (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Update rings based on TC information (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to process LLDP MIB change events (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 4/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 3/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 2/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 1/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix incorrect use of abbreviations (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix typos in code comments (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Remove "2 BITS" comment (Kamal Heib) [1659176]
- [netdrv] ice: Update comment regarding the ITR_GRAN_S (Kamal Heib) [1659176]
- [netdrv] ice: Update function header for __ice_vsi_get_qs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary braces (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: Add missing case in print_link_msg for printing flow control (Kamal Heib) [1659176]
- [netdrv] ice: Audit hotpath structures with pahole (Kamal Heib) [1659176]
- [netdrv] ice: Do not bail out when filter already exists (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF attempt to delete default MAC address (Kamal Heib) [1659176]
- [netdrv] ice: enable VF admin queue interrupts (Kamal Heib) [1659176]
- [netdrv] ice: Fix for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Implement pci_error_handler ops (Kamal Heib) [1659176]
- [netdrv] ice: Put __ICE_PREPARED_FOR_RESET check in ice_prepare_for_reset (Kamal Heib) [1659176]
- [netdrv] ice: use virt channel status codes (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary newlines from log messages (Kamal Heib) [1659176]
- [netdrv] ice: Create a generic name for the ice_rx_flg64_bits structure (Kamal Heib) [1659176]
- [netdrv] ice: add and use new ice_for_each_traffic_class() macro (Kamal Heib) [1659176]
- [netdrv] ice: change VF VSI tc info along with num_queues (Kamal Heib) [1659176]
- [netdrv] ice: Prevent unintended multiple chain resets (Kamal Heib) [1659176]
- [netdrv] ice: map Rx buffer pages with DMA attributes (Kamal Heib) [1659176]
- [netdrv] ice: Limit the ice_add_rx_frag to frag addition (Kamal Heib) [1659176]
- [netdrv] ice: Gather the rx buf clean-up logic for better reuse (Kamal Heib) [1659176]
- [netdrv] ice: Introduce bulk update for page count (Kamal Heib) [1659176]
- [netdrv] ice: Get rid of ice_pull_tail (Kamal Heib) [1659176]
- [netdrv] ice: Pull out page reuse checks onto separate function (Kamal Heib) [1659176]
- [netdrv] ice: Retrieve rx_buf in separate function (Kamal Heib) [1659176]
- [netdrv] ice: Enable link events over the ARQ (Kamal Heib) [1659176]
- [netdrv] ice: use irq_num var in ice_vsi_req_irq_msix (Kamal Heib) [1659176]
- [netdrv] ice: Restore VLAN switch rule if port VLAN existed before (Kamal Heib) [1659176]
- [netdrv] ice: update VSI config dynamically (Kamal Heib) [1659176]
- [netdrv] ice: Get VF VSI instances directly via PF (Kamal Heib) [1659176]
- [netdrv] ice: Don't let VF know that it is untrusted (Kamal Heib) [1659176]
- [netdrv] ice: Set LAN_EN for all directional rules (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LB_EN for prune switch rules (Kamal Heib) [1659176]
- [netdrv] ice: Enable LAN_EN for the right recipes (Kamal Heib) [1659176]
- [netdrv] ice: Add support for PF/VF promiscuous mode (Kamal Heib) [1659176]
- [netdrv] ice: code cleanup in ice_sched.c (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused vsi_id field (Kamal Heib) [1659176]
- [netdrv] ice: fix some function prototype and signature style issues (Kamal Heib) [1659176]
- [netdrv] ice: fix the divide by zero issue (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reconfiguring VF queues (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: fix static analysis warnings (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reclaiming resources back to the pool after reset (Kamal Heib) [1659176]
- [netdrv] ice: Enable MAC anti-spoof by default (Kamal Heib) [1659176]
- [netdrv] ice: Determine descriptor count and ring size based on PAGE_SIZE (Kamal Heib) [1659176]
- [netdrv] ice: Reset all VFs with VFLR during SR-IOV init flow (Kamal Heib) [1659176]
- [netdrv] ice: Get resources per function (Kamal Heib) [1659176]
- [netdrv] ice: Implement flow to reset VFs with PFR and other resets (Kamal Heib) [1659176]
- [netdrv] ice: configure GLINT_ITR to always have an ITR gran of 2 (Kamal Heib) [1659176]
- [netdrv] ice: use ice_for_each_vsi macro when possible (Kamal Heib) [1659176]
- [netdrv] ice : Ensure only valid bits are set in ice_aq_set_phy_cfg (Kamal Heib) [1659176]
- [netdrv] ice: remove redundant variable and if condition (Kamal Heib) [1659176]
- [netdrv] ice: avoid multiple unnecessary de-references in probe (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF reset and multiple VFs support on PFs (Kamal Heib) [1659176]
- [netdrv] ice: Fix broadcast traffic in port VLAN mode (Kamal Heib) [1659176]
- [netdrv] ice: fix overlong string, update stats output (Kamal Heib) [1659176]
- [netdrv] ice: Fix for FC get rx/tx pause params (Kamal Heib) [1659176]
- [netdrv] ice: use absolute vector ID for VFs (Kamal Heib) [1659176]
- [netdrv] ice: check for a leaf node presence (Kamal Heib) [1659176]
- [netdrv] ice: flush Tx pipe on disable queue timeout (Kamal Heib) [1659176]
- [netdrv] ice: clear VF ARQLEN register on reset (Kamal Heib) [1659176]
- [netdrv] ice: don't spam VFs with link messages (Kamal Heib) [1659176]
- [netdrv] ice: only use the VF for ICE_VSI_VF in ice_vsi_release (Kamal Heib) [1659176]
- [netdrv] ice: fix numeric overflow warning (Kamal Heib) [1659176]
- [netdrv] ice: fix issue where host reboots on unload when iommu=on (Kamal Heib) [1659176]
- [netdrv] ice: fix ice_remove_rule_internal vsi_list handling (Kamal Heib) [1659176]
- [netdrv] ice: fix stack hogs from struct ice_vsi_ctx structures (Kamal Heib) [1659176]
- [netdrv] ice: sizeof(<type>) should be avoided (Kamal Heib) [1659176]
- [netdrv] ice: Fix added in VSI supported nodes calc (Kamal Heib) [1659176]
- [netdrv] ice: Fix the calculation of ICE_MAX_MTU (Kamal Heib) [1659176]
- [netdrv] ice: Mark extack argument as __always_unused (Kamal Heib) [1659176]
- [netdrv] ice: add const qualifier to mac_addr parameter (Kamal Heib) [1659176]
- [netdrv] ice: Add support for new PHY types (Kamal Heib) [1659176]
- [netdrv] ice: Offload SCTP checksum (Kamal Heib) [1659176]
- [netdrv] ice: Allow for software timestamping (Kamal Heib) [1659176]
- [netdrv] ice: Implement getting and setting ethtool coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Add support for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Move aggregator list into ice_hw instance (Kamal Heib) [1659176]
- [netdrv] ice: Rework queue management code for reuse (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool private flag to make forcing link down optional (Kamal Heib) [1659176]
- [netdrv] ice: Set physical link up/down when an interface is set up/down (Kamal Heib) [1659176]
- [netdrv] ice: Implement support for normal get_eeprom[_len] ethtool ops (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool set_phys_id handler (Kamal Heib) [1659176]
- [netdrv] ice: Configure RSS LUT and HASH KEY in rebuild path (Kamal Heib) [1659176]
- [netdrv] ice: Refactor a few Tx scheduler functions (Kamal Heib) [1659176]
- [netdrv] ice: Fix unused variable build warning (Kamal Heib) [1659176]
- [netdrv] ice: Do not enable NAPI on q_vectors that have no rings (Kamal Heib) [1659176]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Kamal Heib) [1659176]
- [netdrv] ice: Fix possible NULL pointer de-reference (Kamal Heib) [1659176]
- [netdrv] ice: Use Tx|Rx in comments (Kamal Heib) [1659176]
- [netdrv] ice: Cosmetic formatting changes (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup short function signatures (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup ice_tx_timeout() (Kamal Heib) [1659176]
- [netdrv] ice: Fix return value from NAPI poll (Kamal Heib) [1659176]
- [netdrv] ice: Constify global structures that can/should be (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LAN_EN for MAC-VLAN filters (Kamal Heib) [1659176]
- [netdrv] ice: Pass the return value of ice_init_def_sw_recp() (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup duplicate control queue code (Kamal Heib) [1659176]
- [netdrv] ice: Remove ICE_MAX_TXQ_PER_TXQG check when configuring Tx queue (Kamal Heib) [1659176]
- [netdrv] ice: Destroy scheduler tree in reset path (Kamal Heib) [1659176]
- [netdrv] ice: Fix to make VLAN priority tagged traffic to appear on all TCs (Kamal Heib) [1659176]
- [netdrv] ice: Call pci_disable_sriov before stopping queues for VF (Kamal Heib) [1659176]
- [netdrv] ice: Increase Rx queue disable timeout (Kamal Heib) [1659176]
- [netdrv] ice: Fix NVM mask defines (Kamal Heib) [1659176]
- [netdrv] ice: Avoid nested RTNL locking in ice_dis_vsi (Kamal Heib) [1659176]
- [netdrv] ice: Calculate guaranteed VSIs per function and use it (Kamal Heib) [1659176]
- [netdrv] ice: Remove node before releasing VSI (Kamal Heib) [1659176]
- [netdrv] ice: Check for q_vector when stopping rings (Kamal Heib) [1659176]
- [netdrv] ice: Fix debug print in ice_tx_timeout (Kamal Heib) [1659176]
- [netdrv] intel-ethernet: use correct module license (Kamal Heib) [1659176]
- [netdrv] bnx2x: Add support for detection of P2P event packets. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: Replace magic numbers with macro definitions. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: fix spelling mistake "dicline" -> "decline" (Manish Chopra) [1663271]
- [netdrv] bnx2x: Utilize FW 7.13.11.0. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove set but not used variable 'mfw_vn' (Manish Chopra) [1663271]
- [netdrv] bnx2x: Use struct_size() in kzalloc() (Manish Chopra) [1663271]
- [netdrv] broadcom: Mark expected switch fall-throughs (Manish Chopra) [1663271]
- [netdrv] bnx2x: Bump up driver version to 1.713.36 (Manish Chopra) [1663271]
- [netdrv] bnx2x: fix various indentation issues (Manish Chopra) [1663271]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() on headers (Manish Chopra) [1663271]
- [netdrv] bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans() on some hw (Manish Chopra) [1663271]
- [netdrv] bnx2x: Send update-svid ramrod with retry/poll flags enabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Enable PTP only on the PF that initializes the port (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove configured vlans as part of unload sequence. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Clear fip MAC when fcoe offload support is disabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add storm FW version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add MBI version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Manish Chopra) [1663271]
- [netdrv] bnx2x: remove ndo_poll_controller (Manish Chopra) [1663271]
- [netdrv] bnx2x: Provide VF link status in ndo_get_vf_config (Manish Chopra) [1663271]
- [netdrv] bnx2x: Ignore bandwidth attention in single function mode (Manish Chopra) [1663271]
- [block] block: remove CONFIG_LBDAF (Ming Lei) [1708452]
- [kernel] sched/pelt: Fix warning and clean up IRQ PELT config (Phil Auld) [1637824]
- [kernel] sched/pelt: Fix update_blocked_averages() for RT and DL classes (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove remaining traces of NUMA rate-limiting (Phil Auld) [1637824]
- [kernel] sched/fair: Fix cpu_util_wake() for 'execl' type workloads (Phil Auld) [1637824]
- [kernel] sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Phil Auld) [1637824]
- [kernel] sched/numa: Migrate pages to local nodes quicker early in the lifetime of a task (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove rate-limiting of automatic NUMA balancing migration (Phil Auld) [1637824]
- [kernel] sched/numa: Avoid task migration for small NUMA improvement (Phil Auld) [1637824]
- [mm] mm/migrate: Use spin_trylock() while resetting rate limit (Phil Auld) [1637824]
- [kernel] sched/numa: Limit the conditions where scan period is reset (Phil Auld) [1637824]
- [kernel] sched/numa: Reset scan rate whenever task moves across nodes (Phil Auld) [1637824]
- [kernel] sched/numa: Pass destination CPU as a parameter to migrate_task_rq (Phil Auld) [1637824]
- [kernel] sched/numa: Stop multiple tasks from moving to the CPU at the same time (Phil Auld) [1637824]
- [kernel] sched/fair: Fix scale_rt_capacity() for SMT (Phil Auld) [1637824]
- [kernel] sched/numa: Move task_numa_placement() closer to numa_migrate_preferred() (Phil Auld) [1637824]
- [kernel] sched/numa: Use group_weights to identify if migration degrades locality (Phil Auld) [1637824]
- [kernel] sched/numa: Update the scan period without holding the numa_group lock (Phil Auld) [1637824]
- [kernel] sched/numa: Remove numa_has_capacity() (Phil Auld) [1637824]
- [kernel] sched/numa: Modify migrate_swap() to accept additional parameters (Phil Auld) [1637824]
- [kernel] sched/numa: Remove unused task_capacity from 'struct numa_stats' (Phil Auld) [1637824]
- [kernel] sched/numa: Skip nodes that are at 'hoplimit' (Phil Auld) [1637824]
- [kernel] sched/debug: Reverse the order of printing faults (Phil Auld) [1637824]
- [kernel] sched/numa: Use task faults only if numa_group is not yet set up (Phil Auld) [1637824]
- [kernel] sched/numa: Set preferred_node based on best_cpu (Phil Auld) [1637824]
- [kernel] sched/numa: Simplify load_too_imbalanced() (Phil Auld) [1637824]
- [kernel] sched/numa: Evaluate move once per node (Phil Auld) [1637824]
- [kernel] sched/fair: Remove #ifdefs from scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Clarify sugov_get_util() (Phil Auld) [1637824]
- [kernel] sched/sysctl: Remove unused sched_time_avg_ms sysctl (Phil Auld) [1637824]
- [kernel] sched/core: Remove the rt_avg code (Phil Auld) [1637824]
- [kernel] sched/core: Use PELT for scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Remove sugov_aggregate_util() (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Take time spent in interrupts into account (Phil Auld) [1637824]
- [kernel] sched/irq: Add IRQ utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use DL utilization tracking (Phil Auld) [1637824]
- [kernel] sched/dl: Add dl_rq utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use RT utilization tracking (Phil Auld) [1637824]
- [kernel] sched/rt: Add rt_rq utilization tracking (Phil Auld) [1637824]
- [kernel] sched/pelt: Move PELT related code in a dedicated file (Phil Auld) [1637824]
- [char] ipmi_si: Potential array underflow in hotmod_handler() (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hacks for adding a dummy platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Consolidate scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hotmod devices on removal and exit (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hardcode IPMI devices by scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Switch hotmod to use a platform device (Tony Camuso) [1665131]
- [char] ipmi: Fix failure on SMBIOS specified devices (Tony Camuso) [1665131]
- [char] ipmi: Consolidate the adding of platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Rename addr_type to addr_space to match what it does (Tony Camuso) [1665131]
- [char] ipmi_si: Convert some types into unsigned (Tony Camuso) [1665131]
- [char] ipmi: ipmi_si_hardcode.c: init si_type array to fix a crash (Tony Camuso) [1665131]
- [char] ipmi_si: Fix crash when using hard-coded device (Tony Camuso) [1665131]
- [char] ipmi: Use dedicated API for copying a UUID (Tony Camuso) [1665131]
- [char] ipmi: Use defined constant for UUID representation (Tony Camuso) [1665131]
- [char] ipmi:ssif: Change some pr_xxx to dev_xxx calls (Tony Camuso) [1665131]
- [char] ipmi: kcs_bmc: handle devm_kasprintf() failure case (Tony Camuso) [1665131]
- [char] ipmi: Fix return value when a message is truncated (Tony Camuso) [1665131]
- [char] ipmi: clean an indentation issue, remove extraneous space (Tony Camuso) [1665131]
- [char] ipmi: Make the smi watcher be disabled immediately when not needed (Tony Camuso) [1665131]
- [char] ipmi: Fix how the lower layers are told to watch for messages (Tony Camuso) [1665131]
- [char] ipmi: Fix SSIF flag requests (Tony Camuso) [1665131]
- [char] ipmi_si: fix use-after-free of resource->name (Tony Camuso) [1665131]
- [char] ipmi: Don't initialize anything in the core until something uses it (Tony Camuso) [1665131]
- [char] ipmi:ssif: Fix handling of multi-part return messages (Tony Camuso) [1665131]
- [char] ipmi:dmi: Use pr_fmt in the IPMI DMI code (Tony Camuso) [1665131]
- [char] ipmi: Remove platform driver overrides and use the id_table (Tony Camuso) [1665131]
- [char] ipmi: msghandler: Add and use pr_fmt and dev_fmt, remove PFX (Tony Camuso) [1665131]
- [char] ipmi: Use more common logging styles (Tony Camuso) [1665131]
- [acpi] ACPI / glue: Split dev_is_platform() out of module for wide use (Tony Camuso) [1665131]

* Thu May 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-90.el8]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: remove timeout from TURs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: clean up two indentation issues (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: mark expected switch fall-throughs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: switch to generic DMA API (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: Use vmemdup_user to replace the open code (Joseph Szczypek) [1672669]
- [netdrv] ibmvnic: Add device identification to requested IRQs (Steve Best) [1665717]
- [crypto] crypto: authenc - fix parsing key with misaligned rta_len (Herbert Xu) [1707546]
- [block] block: don't drain in-progress dispatch in blk_cleanup_queue() (Ming Lei) [1694879]
- [block] blk-mq: move cancel of hctx->run_work into blk_mq_hw_sysfs_release (Ming Lei) [1694879]
- [include] blk-mq: always free hctx after request queue is freed (Ming Lei) [1694879]
- [block] blk-mq: split blk_mq_alloc_and_init_hctx into two parts (Ming Lei) [1694879]
- [block] blk-mq: free hw queue's resource in hctx's release handler (Ming Lei) [1694879]
- [block] blk-mq: move cancel of requeue_work into blk_mq_release (Ming Lei) [1694879]
- [block] blk-mq: grab .q_usage_counter when queuing request from plug code path (Ming Lei) [1694879]
- [block] block: fix use-after-free on gendisk (Ming Lei) [1694879]
- [netdrv] bonding: fix event handling for stacked bonds (Jarod Wilson) [1708390]
- [netdrv] bonding: show full hw address in sysfs for slave entries (Jarod Wilson) [1708390]
- [netdrv] bonding: fix PACKET_ORIGDEV regression (Jarod Wilson) [1708390]
- [netdrv] bonding: check slave set command firstly (Jarod Wilson) [1708390]
- [netdrv] bonding: count master 3ad stats separately (Jarod Wilson) [1708390]
- [netdrv] bonding: add support for xstats and export 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: add 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: 3ad: remove bond_3ad_rx_indication's length argument (Jarod Wilson) [1708390]
- [netdrv] bonding: adjust style of bond_3ad_rx_indication (Jarod Wilson) [1708390]
- [netdrv] bonding: update nest level on unlink (Jarod Wilson) [1708390]
- [netdrv] bonding: fix indentation issues, remove extra spaces (Jarod Wilson) [1708390]
- [netdrv] bonding: convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1708390]
- [netdrv] bonding: fix 802.3ad state sent to partner when unbinding slave (Jarod Wilson) [1708390]
- [netdrv] bonding: use netpoll_poll_dev() helper (Jarod Wilson) [1708390]
- [net] netpoll: do not test NAPI_STATE_SCHED in poll_one_napi() (Jarod Wilson) [1708390]
- [net] netpoll: make ndo_poll_controller() optional (Jarod Wilson) [1708390]
- [netdrv] bonding: don't cast const buf in sysfs store (Jarod Wilson) [1708390]
- [netdrv] netdevsim: fix sa_idx out of bounds check (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: add ipsec offload API test (Ivan Vecera) [1708373]
- [netdrv] netdevsim: add ipsec offload testing (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use dummydev as a test device (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: clear the return code at start of ipsec test (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use a local IP address for IPsec tests (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: hide complaint from terminated monitor (Ivan Vecera) [1708373]
- [powerpc] powerpc/watchdog: Use hrtimers for per-CPU heartbeat (Steve Best) [1708327]
- [netdrv] ixgbevf: Update driver version for RHEL-8.1.0 (Ken Cox) [1659166]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659166]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Ken Cox) [1659166]
- [netdrv] ixgbevf: add support for software timestamps (Ken Cox) [1659166]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659166]
- [netdrv] ixgbevf: off by one in ixgbevf_ipsec_tx() (Ken Cox) [1659166]
- [netdrv] ixgbevf: fix msglen for ipsec mbx messages (Ken Cox) [1659166]
- [netdrv] ixgbevf: remove ndo_poll_controller (Ken Cox) [1659166]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659166]
- [netdrv] ixgbevf: enable VF IPsec offload operations (Ken Cox) [1659166]
- [netdrv] ixgbevf: add VF IPsec offload code (Ken Cox) [1659166]
- [netdrv] ixgbevf: add defines for IPsec offload request (Ken Cox) [1659166]
- [netdrv] ixgbevf: VF2VF TCP RSS (Ken Cox) [1659166]
- [netdrv] ixgbe: Update driver version for RHEL-8.1.0 (Ken Cox) [1659164]
- [netdrv] intel: correct return from set features callback (Ken Cox) [1659164]
- [netdrv] ixgbe: don't do any AF_XDP zero-copy transmit if netif is not OK (Ken Cox) [1659164]
- [netdrv] ixgbe: fix potential RX buffer starvation for AF_XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: fix older devices that do not support IXGBE_MRQC_L3L4TXSWEN (Ken Cox) [1659164]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Ken Cox) [1659164]
- [netdrv] ixgbe: Use struct_size() helper (Ken Cox) [1659164]
- [netdrv] ixgbe: remove magic constant in ixgbe_reset_hw_82599() (Ken Cox) [1659164]
- [netdrv] ixgbe: use mii_bus to handle MII related ioctls (Ken Cox) [1659164]
- [netdrv] ixgbe: register a mdiobus (Ken Cox) [1659164]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix race when the VF driver does a reset (Ken Cox) [1659164]
- [netdrv] ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (Ken Cox) [1659164]
- [netdrv] ixgbe: Replace synchronize_sched() with synchronize_rcu() (Ken Cox) [1659164]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Ken Cox) [1659164]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Ken Cox) [1659164]
- [netdrv] ixgbe: allow IPsec Tx offload in VEPA mode (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear_bit on xdp_ring->state if xdp_ring is null (Ken Cox) [1659164]
- [netdrv] ixgbe: fix MAC anti-spoofing filter after VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659164]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Ken Cox) [1659164]
- [netdrv] ixgbe: check return value of napi_complete_done() (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Tx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Tx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Rx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Rx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: added Rx/Tx ring disable/enable functions (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix crash with VFs and flow director on interface flap (Ken Cox) [1659164]
- [netdrv] ixgbe: remove redundant function ixgbe_fw_recovery_mode() (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix ixgbe TX hangs with XDP_TX beyond queue limit (Ken Cox) [1659164]
- [netdrv] ixgbe: remove ndo_poll_controller (Ken Cox) [1659164]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659164]
- [netdrv] ixgbe: fix the return value for unsupported VF offload (Ken Cox) [1659164]
- [netdrv] ixgbe: disallow IPsec Tx offload when in SR-IOV mode (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload request message handling (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload enable flag (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec management (Ken Cox) [1659164]
- [netdrv] ixgbe: prep IPsec constants for later use (Ken Cox) [1659164]
- [netdrv] ixgbe: reload IPsec IP table after sa tables (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear IPsec sa counters on HW clearing (Ken Cox) [1659164]
- [netdrv] ixgbe: firmware recovery mode (Ken Cox) [1659164]
- [netdrv] ixgbe: fix driver behaviour after issuing VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe: Prevent unsupported configurations with XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: Refactor queue disable logic to take completion time into account (Ken Cox) [1659164]
- [netdrv] ixgbe: Reorder Tx/Rx shutdown to reduce time needed to stop device (Ken Cox) [1659164]
- [netdrv] ixgbe: add ipsec security registers into ethtool register dump (Ken Cox) [1659164]
- [netdrv] ixgbe: Do not allow LRO or MTU change with XDP (Ken Cox) [1659164]
- [wireless] brcmfmac: add subtype check for event handling in data path (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [wireless] brcmfmac: assure SSID length from firmware is limited (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [base] driver core: Postpone DMA tear-down until after devres release (Maurizio Lombardi) [1698053]

* Wed May 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-89.el8]
- [of] of: Add missing exports of node name compare functions (Neil Horman) [1665660]
- [of] of: add node name compare helper functions (Neil Horman) [1665660]
- [include] gpio: Add API to explicitly name a consumer (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: fix SPI_CS_HIGH capability (Neil Horman) [1665660]
- [drivers] spi: use gpio[d]_set_value_cansleep for setting chipselect GPIO (Neil Horman) [1665660]
- [drivers] spi: gpio: Advertise support for SPI_CS_HIGH (Neil Horman) [1665660]
- [include] spi: support inter-word delay requirement for devices (Neil Horman) [1665660]
- [drivers] spi: dw: Fix default polarity of native chipselect (Neil Horman) [1665660]
- [drivers] spi: Support high CS when using descriptors (Neil Horman) [1665660]
- [include] spi: Go back to immediate teardown (Neil Horman) [1665660]
- [drivers] spi: dw: change snprintf to scnprintf for possible overflow (Neil Horman) [1665660]
- [drivers] spi: dw: fix warning unused variable 'ret' (Neil Horman) [1665660]
- [include] spi: core: avoid waking pump thread from spi_sync instead run teardown delayed (Neil Horman) [1665660]
- [drivers] spi: dw: Convert to use CS GPIO descriptors (Neil Horman) [1665660]
- [include] spi: Optionally use GPIO descriptors for CS GPIOs (Neil Horman) [1665660]
- [drivers] spi: dw: fix potential variable assignment error (Neil Horman) [1665660]
- [drivers] spi: Use of_node_name_eq for node name comparisons (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add ACPI support (Neil Horman) [1665660]
- [include] spi: add support for octal mode I/O data transfer (Neil Horman) [1665660]
- [drivers] spi: Fix formatting of header block (Neil Horman) [1665660]
- [drivers] spi: Fix core transfer waits after slave support (Neil Horman) [1665660]
- [drivers] spi: Deal with slaves that return from transfer_one() unfinished (Neil Horman) [1665660]
- [include] spi: gpio: Support 3WIRE high-impedance turn-around (Neil Horman) [1665660]
- [drivers] spi: Make GPIO CSs honour the SPI_NO_CS flag (Neil Horman) [1665660]
- [drivers] dw: spi: add support for Amazon's Alpine spi controller (Neil Horman) [1665660]
- [include] spi: Add driver_override SPI device attribute (Neil Horman) [1665660]
- [include] spi: make OF helper available for others (Neil Horman) [1665660]
- [include] spi: switch to SPDX license identifier (Neil Horman) [1665660]
- [drivers] spi: always use software fallback for SPI_CS_WORD when using cs_gio (Neil Horman) [1665660]
- [drivers] spi: add software implementation for SPI_CS_WORD (Neil Horman) [1665660]
- [include] spi: add new SPI_CS_WORD flag (Neil Horman) [1665660]
- [drivers] spi: gpio: No MISO does not imply no RX (Neil Horman) [1665660]
- [drivers] spi: dw: support 4-16 bits per word (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: Remove set but not used variable 'pdata' (Neil Horman) [1665660]
- [drivers] spi: Do not print a message if spi_controller_{suspend,resume}() fails (Neil Horman) [1665660]
- [drivers] spi: gpio: Fix copy-and-paste error (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: avoid hardcoded field mask (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Jaguar2 support (Neil Horman) [1665660]
- [include] spi: Introduce one new field to set word delay (Neil Horman) [1665660]
- [drivers] spi: Fix double IDR allocation with DT aliases (Neil Horman) [1665660]
- [drivers] spi: fix IDR collision on systems with both fixed and dynamic SPI bus numbers (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: add SPI_3WIRE support (Neil Horman) [1665660]
- [drivers] spi: add flags parameter to txrx_word function pointers (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Ocelot support (Neil Horman) [1665660]
- [drivers] spi: dw: export dw_spi_set_cs (Neil Horman) [1665660]
- [drivers] spi: dw: allow providing own set_cs callback (Neil Horman) [1665660]
- [drivers] spi: dw: fix possible race condition (Neil Horman) [1665660]
- [acpi] ACPI / APD: Add clock frequency for Hisilicon Hip08 SPI controller (Neil Horman) [1665660]
- [md] md/raid: raid5 preserve the writeback action after the parity check (Nigel Croxon) [1702309]
- [md] Revert "Don't jump to compute_result state from check_result state" (Nigel Croxon) [1702309]
- [md] md: return -ENODEV if rdev has no mddev assigned (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to handle_active_stripes (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to (un)lock_two_stripes (Nigel Croxon) [1702309]
- [md] md: mark md_cluster_mod static (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_sync (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_load (Nigel Croxon) [1702309]
- [md] md: use correct types in md_bitmap_print_sb (Nigel Croxon) [1702309]
- [md] md: add a missing endianness conversion in check_sb_changes (Nigel Croxon) [1702309]
- [md] md: add mddev->pers to avoid potential NULL pointer dereference (Nigel Croxon) [1702309]
- [md] md: batch flush requests. (Nigel Croxon) [1702309]
- [md] Revert "MD: fix lock contention for flush bios" (Nigel Croxon) [1702309]
- [md] Don't jump to compute_result state from check_result state (Nigel Croxon) [1702309]
- [netdrv] bnxt_en: Reset device on RX buffer errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Improve RX consumer index validity check. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Drop oversize TX packets to prevent errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Wait longer for the firmware message response to complete. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix typo in firmware message timeout logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return relevant error code when offload fails (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for mdio read/write to external PHY (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Propagate trusted VF attribute to firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for BCM957504 (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.47. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable interrupts when allocating CP rings or NQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix context memory allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ring checking logic on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust default RX coalescing ticks to 10 us. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Support for 64-bit flow handle. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase context memory allocations on 57500 chips for RDMA. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add Level 2 context memory paging support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Enhance bnxt_alloc_ring()/bnxt_free_ring(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for 2nd firmware message channel. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Introduce bnxt_get_hwrm_resp_addr & bnxt_get_hwrm_seq_id routines. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Avoid arithmetic on void * pointer. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use macros for firmware message doorbell offsets. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Set hwrm_intr_seq_id value to its inverted value. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.33. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ethtool self-test loopback. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: query force speeds before disabling autoneg mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not free port statistics buffer when device is down. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Save ring statistics before reset. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return linux standard errors in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Don't set ETS on unused TCs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add ethtool -S priority counters. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add SR-IOV support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable MSIX before re-reserving NQs/CMPL rings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Reserve 1 stat_ctx for RDMA driver. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not modify max_stat_ctxs after RDMA driver requests/frees stat_ctxs (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get rid of num_stat_ctxs variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_get_avail_cp_rings_for_en() helper function. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Store the maximum NQs available on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove printing of hwrm message (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix _bnxt_get_max_rings() for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix NQ/CP rings accounting on the new 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Keep track of reserved IRQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix CNP CoS queue regression. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix filling time in bnxt_fill_coredump_record() (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add software "missed_irqs" counter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Workaround occasional TX timeout on 57500 A0. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable RDMA support on the 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix rx_l4_csum_errors counter on 57500 devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix RSS context allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Copy and paste bug in extended tx_stats (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PCI ID for BCM57508 device. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new NAPI poll function for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_poll_work(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add coalescing setup for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use bnxt_cp_ring_info struct pointer as parameter for RX path. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add RSS support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase RSS context array count and skip ring groups on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate/Free CP rings for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify bnxt_ring_alloc_send_msg() to support 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add helper functions to get firmware CP ring ID. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate completion ring structures for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify the ring reservation functions for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust MSIX and ring groups for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Re-structure doorbells. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add 57500 new chip ID and basic structures. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Configure context memory on new devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Check context memory requirements from firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new flags to setup new page table PTE bits on newer devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_ring_struct. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update interrupt coalescing logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add maximum extended request length fw message support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add additional extended port statistics. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.3. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Remove unnecessary unsigned integer comparison and initialize variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get the reduced max_irqs by the ones used by RDMA (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: free hwrm resources, if driver probe fails. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix VNIC reservations on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add a driver specific gre_ver_check devlink parameter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use msix_vec_per_pf_max and msix_vec_per_pf_min devlink params. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: return proper error when FW returns HWRM_ERR_CODE_RESOURCE_ACCESS_DENIED (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use ignore_ari devlink parameter (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix TX timeout during netpoll. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove ndo_poll_controller (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: don't try to offload VLAN 'modify' action (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'addr_type' (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'rx_stats' (Selvin Xavier) [1664477]
- [netdrv] net: bnxt: Fix a uninitialized variable warning. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: take coredump_record structure off stack (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: avoid string overflow for record->system_name (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix strcpy() warnings in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not use the CNP CoS queue for networking traffic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add DCBNL DSCP application protocol support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add hwmon sysfs support to read temperature (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Notify firmware about IF state changes. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Move firmware related flags to a new fw_cap field in struct bnxt. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add BNXT_NEW_RM() macro. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for ethtool get dump. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update RSS setup and GRO-HW logic according to the latest spec. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new VF resource allocation strategy mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PHY retry logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add external loopback test to ethtool selftest. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust timer based on ethtool stats-block-usecs settings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface version to 1.9.2.25. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: combine 'else if' and 'else' into single branch (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove redundant debug register dma mem allocation (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_en initial params table and register it. (Selvin Xavier) [1664477]
- [netdrv] sfc: mcdi_port: Mark expected switch fall-through (Jarod Wilson) [1685478]
- [netdrv] sfc: ensure recovery after allocation failures (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace dev_kfree_skb_any by dev_consume_skb_any (Jarod Wilson) [1685478]
- [netdrv] sfc: add bundle partition definitions to mtd (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace spin_is_locked() with lockdep (Jarod Wilson) [1685478]
- [netdrv] sfc: remove ndo_poll_controller (Jarod Wilson) [1685478]
- [iommu] iommu/amd: Set exclusion range correctly (Jerry Snitselaar) [1702766]
- [iommu] iommu/amd: Reserve exclusion range in iova-domain (Jerry Snitselaar) [1694835]
- [scsi] scsi: mpt3sas: Fix kernel panic during expander reset (Tomas Henzl) [1677693]
- [mm] mm/vmstat.c: fix /proc/vmstat format for CONFIG_DEBUG_TLBFLUSH=y CONFIG_SMP=n (Waiman Long) [1705607]
- [mm] x86/mm: Drop usage of __flush_tlb_all() in kernel_physical_mapping_init() (Waiman Long) [1705607]
- [include] x86/mm: Validate kernel_physical_mapping_init() PTE population (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce set_pte_safe() (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce {p4d,pgd}_same() (Waiman Long) [1705607]
- [include] generic/pgtable: Make {pmd, pud}_same() unconditionally available (Waiman Long) [1705607]
- [mm] percpu: stop printing kernel addresses (Waiman Long) [1705607]
- [x86] x86/speculation: Prevent deadlock on ssb_state::lock (Waiman Long) [1705607]
- [fs] debugfs: fix use-after-free on symlink traversal (Waiman Long) [1705607]
- [lib] debugobjects: avoid recursive calls with kmemleak (Waiman Long) [1705607]
- [mm] mm/swapfile.c: use kvzalloc for swap_info_struct allocation (Waiman Long) [1705607]
- [mm] hugetlbfs: fix kernel BUG at fs/hugetlbfs/inode.c:444! (Waiman Long) [1705607]
- [include] watchdog/core: Add missing prototypes for weak functions (Waiman Long) [1705607]
- [mm] memory_hotplug: cond_resched in __remove_pages (Waiman Long) [1705607]
- [kernel] genirq: Fix race on spurious interrupt detection (Waiman Long) [1705607]
- [kernel] printk: Fix panic caused by passing log_buf_len to command line (Waiman Long) [1705607]
- [mm] mm/hmm: fix race between hmm_mirror_unregister() and mmu_notifier callback (Waiman Long) [1705607]
- [mm] mm/rmap: map_pte() was not handling private ZONE_DEVICE page properly (Waiman Long) [1705607]
- [mm] hugetlbfs: dirty pages as they are added to pagecache (Waiman Long) [1705607]
- [fs] mm: /proc/pid/smaps_rollup: fix NULL pointer deref in smaps_pte_range() (Waiman Long) [1705607]
- [kernel] sched/fair: Fix the min_vruntime update logic in dequeue_entity() (Waiman Long) [1705607]
- [mm] x86/mm/pat: Disable preemption around __flush_tlb_all() (Waiman Long) [1705607]
- [x86] x86/corruption-check: Fix panic in memory_corruption_check() when boot option without value is provided (Waiman Long) [1705607]
- [x86] x86/time: Correct the attribute on jiffies' definition (Waiman Long) [1705607]
- [x86] x86/percpu: Fix this_cpu_read() (Waiman Long) [1705607]
- [x86] x86/tsc: Force inlining of cyc2ns bits (Waiman Long) [1705607]
- [mm] mm/migrate.c: split only transparent huge pages when allocation fails (Waiman Long) [1705607]
- [mm] mm/thp: fix call to mmu_notifier in set_pmd_migration_entry() v2 (Waiman Long) [1705607]
- [mm] mm/mmap.c: don't clobber partially overlapping VMA with MAP_FIXED_NOREPLACE (Waiman Long) [1705607]
- [mm] percpu: stop leaking bitmap metadata blocks (Waiman Long) [1705607]
- [lib] vsprintf: Fix off-by-one bug in bstr_printf() processing dereferenced pointers (Waiman Long) [1705607]
- [mm] mm/vmstat.c: fix outdated vmstat_text (Waiman Long) [1705607]
- [base] PM / core: Clear the direct_complete flag on errors (Waiman Long) [1705607]
- [tools] x86/vdso: Fix vDSO syscall fallback asm constraint regression (Waiman Long) [1705607]
- [x86] x86/vdso: Only enable vDSO retpolines when enabled and supported (Waiman Long) [1705607]
- [tools] selftests/x86: Add clock_gettime() tests to test_vdso (Waiman Long) [1705607]
- [x86] x86/vdso: Fix asm constraints on vDSO syscall fallbacks (Waiman Long) [1705607]
- [drivers] clocksource/drivers/timer-atmel-pit: Properly handle error cases (Waiman Long) [1705607]
- [mm] mm/vmstat.c: skip NR_TLB_REMOTE_FLUSH* properly (Waiman Long) [1705607]
- [mm] mm, thp: fix mlocking THP page with migration enabled (Waiman Long) [1705607]
- [mm] mm: migration: fix migration of huge PMD shared pages (Waiman Long) [1705607]
- [net] net/smc: improve smc_conn_create reason codes (Philipp Rudo) [1703471]
- [net] net/smc: improve smc_listen_work reason codes (Philipp Rudo) [1703471]
- [net] net/smc: code cleanup smc_listen_work (Philipp Rudo) [1703471]
- [net] net/smc: cleanup of get vlan id (Philipp Rudo) [1703471]
- [net] net/smc: consolidate function parameters (Philipp Rudo) [1703471]
- [net] net/smc: check for ip prefix and subnet (Philipp Rudo) [1703471]
- [net] net/smc: fallback to TCP after connect problems (Philipp Rudo) [1703471]
- [net] net/smc: nonblocking connect rework (Philipp Rudo) [1703471]
- [net] net/smc: move unhash before release of clcsock (Philipp Rudo) [1703471]
- [net] net/smc: fix return code from FLUSH command (Philipp Rudo) [1703471]
- [net] net/smc: propagate file from SMC to TCP socket (Philipp Rudo) [1703471]
- [net] net/smc: fix a NULL pointer dereference (Philipp Rudo) [1703471]
- [net] net/smc: wait for pending work before clcsock release_sock (Philipp Rudo) [1703471]
- [net] net/smc: allow pnetid-less configuration (Philipp Rudo) [1700797]
- [net] net/smc: allow PCI IDs as ib device names in the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: add pnet table namespace support (Philipp Rudo) [1700797]
- [net] net/smc: add smcd support to the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: rework pnet table (Philipp Rudo) [1700797]
- [net] net/smc: cleanup for smcr_tx_sndbuf_nonempty (Philipp Rudo) [1700797]

* Tue May 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-88.el8]
- [tools] tools power turbostat: Override CFLAGS assignments and add LDFLAGS to build command (Steve Best) [1705959]
- [tools] tools/power turbostat: update version number (Steve Best) [1705959]
- [tools] tools/power turbostat: Add checks for failure of fgets() and fscanf() (Steve Best) [1705959]
- [tools] tools/power turbostat: Warn on bad ACPI LPIT data (Steve Best) [1705959]
- [tools] tools/power turbostat: Also read package power on AMD F17h (Zen) (Steve Best) [1705959]
- [tools] tools/power turbostat: Add support for AMD Fam 17h (Zen) RAPL (Steve Best) [1705959]
- [tools] tools/power turbostat: Do not display an error on systems without a cpufreq driver (Steve Best) [1705959]
- [tools] tools/power turbostat: Add Die column (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CNL-specific code (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CC3-skip code (Steve Best) [1705959]
- [tools] tools/power turbostat: Restore ability to execute in topology-order (Steve Best) [1705959]
- [tools] tools/power turbostat: fix goldmont C-state limit decoding (Steve Best) [1705959]
- [tools] tools/power turbostat: reduce debug output (Steve Best) [1705959]
- [tools] tools/power turbosat: fix AMD APIC-id output (Steve Best) [1705959]
- [mmc] mmc: sdhci-iproc: Add ACPI support (Mark Langsdorf) [1576966]
- [mmc] mmc: sdhci-pltfm: Convert DT properties to generic device properties (Mark Langsdorf) [1576966]
- [tty] serial: 8250_dw: Add ACPI support for uart on Broadcom SoC (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: Add clock-frequency property (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: set WDOG_HW_RUNNING when appropriate (Mark Langsdorf) [1576966]
- [thermal] thermal: broadcom: Add Stingray thermal driver (Mark Langsdorf) [1576966]
- [hv] hv: vmbus: Change server monitor_pages index to 0 (Mohammed Gamal) [1691383]
- [kernel] hv: vmbus: Expose counters for interrupts and full conditions (Mohammed Gamal) [1691383]
- [kernel] vmbus: Switch to use new generic UUID API (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Check for ring when getting debug info (Mohammed Gamal) [1691383]
- [x86] hyper-v: move synic/stimer control structures definitions to hyperv-tlfs.h (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Return -EINVAL for the sys files for unopened channels (Mohammed Gamal) [1691383]
- [hv] x86, hyperv: remove PCI dependency (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Offload the handling of channels to two workqueues (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: check the creation_status in vmbus_establish_gpadl() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove the useless API vmbus_get_outgoing_channel() (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Use u to print U32 (Mohammed Gamal) [1691383]
- [hv] hv_utils: update name in struct hv_driver util_drv (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Get rid of unnecessary state in hv_context (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the recent regression caused by incorrect clean-up (Mohammed Gamal) [1691383]
- [hv] hv_balloon: Replace spin_is_locked() with lockdep (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use cpumask_var_t for on-stack cpu mask (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix two "this statement may fall through" warnings (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the indentation of some "break" statements (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the descriptions of some function parameters (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use get/put_cpu() in vmbus_connect() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix synic per-cpu context initialization (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Cleanup synic memory free path (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove use of slow_virt_to_phys() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: add numa_node to sysfs (Mohammed Gamal) [1691383]
- [x86] hv: vmbus: Get rid of MSR access from vmbus_drv.c (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the issue with freeing up hv_ctl_table_hdr (Mohammed Gamal) [1691383]
- [hv] hv: vmus: Fix the check for return value from kmsg get dump buffer (Mohammed Gamal) [1691383]
- [hv] hv: Send one page worth of kmsg dump over Hyper-V during panic (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove x86 MSR refs in arch independent code (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the offer_in_progress in vmbus_process_offer() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Add comments on ring buffer signaling (Mohammed Gamal) [1691383]
- [video] use the new async probing feature for the hyperv drivers (Mohammed Gamal) [1691383]
- [rpmspec] kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava) [1705216]
- [fs] xfs: don't ever put nlink > 0 inodes on the unlinked list (Brian Foster) [1693063]
- [fs] xfs: reserve blocks for ifree transaction during log recovery (Brian Foster) [1693063]
- [fs] xfs: rename m_inotbt_nores to m_finobt_nores (Brian Foster) [1693063]
- [net] xfrm: Honor original L3 slave device in xfrmi policy lookup (Herbert Xu) [1702198]
- [net] xfrm: Fix inbound traffic via XFRM interfaces across network namespaces (Herbert Xu) [1702198]
- [net] xfrm: Make set-mark default behavior backward compatible (Herbert Xu) [1702198]
- [net] xfrm: remove unnecessary check in xfrmi_get_stats64 (Herbert Xu) [1702198]
- [net] xfrm: fix gro_cells leak when remove virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Make function xfrmi_get_link_net() static (Herbert Xu) [1702198]
- [net] xfrm: fix ptr_ret.cocci warnings (Herbert Xu) [1702198]
- [net] xfrm: Return detailed errors from xfrmi_newlink (Herbert Xu) [1702198]
- [net] xfrm: Allow xfrmi if_id to be updated by UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Remove xfrmi interface ID from flowi (Herbert Xu) [1702198]
- [net] xfrm: Allow Set Mark to be Updated Using UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Add virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Add a new lookup key to match xfrm interfaces. (Herbert Xu) [1702198]
- [net] flow: Extend flow informations with xfrm interface id. (Herbert Xu) [1702198]
- [net] xfrm: Extend the output_mark to support input direction and masking. (Herbert Xu) [1702198]
- [fs] xfs: don't account extra agfl blocks as available (Brian Foster) [1656687]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't fail IT nexus reset for Open Reject timeout (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't hard reset disk during controller reset (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Support all RAS events with MSI interrupts (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: allocate different SAS address for directly attached situation (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Adjust the printk format of functions hisi_sas_init_device() (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Fix for setting the PHY linkrate when disconnected (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Remedy inconsistent PHY down state in software (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: add host reset interface for test (Xiaojun Tan) [1702614]
- [hid] HID: Increase maximum report size allowed by hid_field_extract() (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove data[128] usage on stack when sending HBM request (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: move doorbell writing before flush (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Optimize writing ipc message from queue (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: avoid binding wrong ishtp_cl_device (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Ice Lake mobile (Tony Camuso) [1688112]
- [hid] HID: increase maximum global item tag report size to 256 (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Sunrise Point-H ish driver (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove redundant variable num_frags (Tony Camuso) [1688112]

* Mon May 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-87.el8]
- [s390] Disable kexec_load via kernel_lockdown for s390 (Philipp Rudo) [1659399]
- [s390] s390/ipl: Provide has_secure sysfs attribute (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Create ipl report and pass to next kernel (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Signature verification prototype (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Load new kernel to absolute 0 (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Unify loader code (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Simplify parmarea access (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Omit use of bin2c (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Reduce purgatory size (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix detection of text segment in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix potential segment overlap in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/zcore: Rename ipl_block to mitigate name collision (Philipp Rudo) [1659399]
- [s390] s390/boot: pad bzImage to 4K (Philipp Rudo) [1659399]
- [s390] s390/ipl: add helper functions to create an IPL report (Philipp Rudo) [1659399]
- [s390] s390/ipl: read IPL report at early boot (Philipp Rudo) [1659399]
- [s390] s390/ipl: add definitions for the IPL report block (Philipp Rudo) [1659399]
- [s390] s390/ipl: provide uapi header for list directed IPL (Philipp Rudo) [1659399]
- [s390] s390/ipl: make ipl_info less confusing (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section compile time validation (Philipp Rudo) [1659399]
- [s390] s390: move ipl block to .boot.preserved.data section (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section (Philipp Rudo) [1659399]
- [mm] s390: clean up redundant facilities list setup (Philipp Rudo) [1659399]
- [s390] s390/als: remove duplicated in-place implementation of stfle (Philipp Rudo) [1659399]
- [netdrv] fm10k: Fix a potential NULL pointer dereference (Neil Horman) [1659172]
- [netdrv] fm10k: use struct_size() in kzalloc() (Neil Horman) [1659172]
- [netdrv] fm10k: TRIVIAL cleanup of extra spacing in function comment (Neil Horman) [1659172]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Neil Horman) [1659172]
- [netdrv] fm10k: bump driver version to match out-of-tree release (Neil Horman) [1659172]
- [netdrv] fm10k: add missing device IDs to the upstream driver (Neil Horman) [1659172]
- [netdrv] fm10k: ensure completer aborts are marked as non-fatal after a resume (Neil Horman) [1659172]
- [netdrv] fm10k: fix SM mailbox full condition (Neil Horman) [1659172]
- [netdrv] fm10k: remove ndo_poll_controller (Neil Horman) [1659172]
- [netdrv] intel-ethernet: use correct module license (Neil Horman) [1659172]
- [scsi] Revert "scsi: fcoe: clear FC_RP_STARTED flags when receiving a LOGO" (Nilesh Javali) [1701545]
- [tools] tools: introduce test_and_clear_bit (Peter Xu) [1694926]
- [net] bridge: fix netlink export of vlan_stats_per_port option (Ivan Vecera) [1703551]
- [net] bridge: fix vlan stats use-after-free on destruction (Ivan Vecera) [1703551]
- [tools] headers uapi: Update linux/if_link.h header copy (Ivan Vecera) [1703551]
- [net] bridge: fix a possible memory leak in __vlan_add (Ivan Vecera) [1703551]
- [net] bridge: add support for per-port vlan stats (Ivan Vecera) [1703551]
- [net] bridge: mcast: Default back to multicast enabled state (Ivan Vecera) [1703551]
- [net] bridge: pack net_bridge better (Ivan Vecera) [1703551]
- [net] bridge: convert mtu_set_by_user to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert neigh_suppress_enabled option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert mcast options to bits (Ivan Vecera) [1703551]
- [net] bridge: convert and rename mcast disabled (Ivan Vecera) [1703551]
- [net] bridge: convert group_addr_set option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert nf call options to bits (Ivan Vecera) [1703551]
- [net] bridge: add bitfield for options and convert vlan opts (Ivan Vecera) [1703551]
- [net] bridge: make struct opening bracket consistent (Ivan Vecera) [1703551]
- [net] Add netif_is_gretap()/netif_is_ip6gretap() (Ivan Vecera) [1701208]
- [net] sched: register callbacks for indirect tc block binds (Ivan Vecera) [1701214]
- [tools] selftests: tc-testing: fix tunnel_key failure if dst_port is unspecified (Ivan Vecera) [1701210]
- [tools] selftests: tc-testing: drop test on missing tunnel key id (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Don't dump dst port if it wasn't set (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Allow key-less tunnels (Ivan Vecera) [1701210]
- [net] ethtool: Added support for 50Gbps per lane link modes (Ivan Vecera) [1701215]
- [net] ip_gre: fix parsing gre header in ipgre_err (Hangbin Liu) [1702212]
- [net] vxlan: Free a leaked vetoed multicast rdst (Ivan Vecera) [1691695]
- [net] switchdev: Add extack argument to call_switchdev_notifiers() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add extack to switchdev operations (Ivan Vecera) [1691695]
- [net] net: Add extack argument to ndo_fdb_add() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Delete remote after update (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Postpone vxlan_config_apply() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Inline vxlan_dev_configure() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Allow vetoing of FDB notifications (Ivan Vecera) [1691695]
- [netdrv] vxlan: Have vxlan_fdb_replace() save original rdst value (Ivan Vecera) [1691695]
- [netdrv] vxlan: Split vxlan_fdb_update() in two (Ivan Vecera) [1691695]
- [netdrv] vxlan: Move up vxlan_fdb_free(), vxlan_fdb_destroy() (Ivan Vecera) [1691695]
- [net] bridge: Add br_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_replay() (Ivan Vecera) [1691695]
- [net] route: add support for directed broadcast forwarding (Xin Long) [1562384]
- [net] erspan: build the header with the right proto according to erspan_ver (Xin Long) [1663862]
- [net] ipv6: make ip6_create_rt_rcu return ip6_null_entry instead of NULL (Xin Long) [1688617]
- [net] tipc: handle the err returned from cmd header function (Jon Maloy) [1693452]
- [net] tipc: check link name with right length in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: check bearer name with right length in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: change to check tipc_own_id to return in tipc_net_stop (Jon Maloy) [1693452]
- [net] tipc: tipc clang warning (Jon Maloy) [1693452]
- [net] tipc: fix cancellation of topology subscriptions (Jon Maloy) [1693452]
- [net] tipc: allow service ranges to be connect()'ed on RDM/DGRAM (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check for nla_nest_start (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check of nla_nest_start (Jon Maloy) [1693452]
- [net] tipc: fix RDM/DGRAM connect() regression (Jon Maloy) [1693452]
- [net] tipc: fix race condition causing hung sendto (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_rcvmsg() (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: fix link session and re-establish issues (Jon Maloy) [1693452]
- [net] tipc: fix skb may be leaky in tipc_link_input (Jon Maloy) [1693452]
- [net] tipc: remove dead code in struct tipc_topsrv (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: remove unneeded semicolon in trace.c (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_doit (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_name_table_dump (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_reset_stats (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in in tipc_conn_rcv_sub (Jon Maloy) [1693452]
- [net] tipc: fix memory leak in tipc_nl_compat_publ_dump (Jon Maloy) [1693452]
- [net] tipc: fix a missing check of genlmsg_put (Jon Maloy) [1693452]
- [net] tipc: fix a double free in tipc_enable_bearer() (Jon Maloy) [1693452]
- [net] net/netlink_compat: Fix a missing check of nla_parse_nested (Jon Maloy) [1693452]
- [net] tipc: fix uninitialized value for broadcast retransmission (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc bearer (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc node (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc socket (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc link (Jon Maloy) [1693452]
- [net] tipc: enable tracepoints in tipc (Jon Maloy) [1693452]
- [net] tipc: handle broadcast NAME_DISTRIBUTOR packet when receiving it (Jon Maloy) [1693452]
- [net] tipc: check group dests after tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: check tsk->group in tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: compare remote and local protocols in tipc_udp_enable() (Jon Maloy) [1693452]
- [net] tipc: use lock_sock() in tipc_sk_reinit() (Jon Maloy) [1693452]
- [net] tipc: fix node keep alive interval calculation (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning during node delete (Jon Maloy) [1693452]
- [net] tipc: don't assume linear buffer when reading ancillary data (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning when reinitilaizing sockets (Jon Maloy) [1693452]
- [net] tipc: fix link re-establish failure (Jon Maloy) [1693452]
- [net] tipc: improve broadcast retransmission algorithm (Jon Maloy) [1693452]
- [net] tipc: use destination length for copy string (Jon Maloy) [1693452]
- [net] tipc: support binding to specific ip address when activating UDP bearer (Jon Maloy) [1677371 1693452]
- [net] tipc: remainder of commit ignore STATE_MSG on wrong link session (Jon Maloy) [1693452]
- [net] tipc: buffer overflow handling in listener socket (Jon Maloy) [1693452]
- [net] tipc: add SYN bit to connection setup messages (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_filter_connect() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_timeout() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_msg_reverse() (Jon Maloy) [1693452]
- [net] tipc: Add and use skb_mark_not_on_list(). (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for tipc_topsrv_queue_evt() comments (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for struct tipc_bc_base's comment (Jon Maloy) [1693452]
- [net] tipc: correct structure parameter comments for topsrv (Jon Maloy) [1693452]
- [net] net/tipc: remove redundant variables 'tn' and 'oport' (Jon Maloy) [1693452]
- [net] net: tipc: bcast: Replace GFP_ATOMIC with GFP_KERNEL in tipc_bcast_init() (Jon Maloy) [1693452]
- [net] net: tipc: name_table: Replace GFP_ATOMIC with GFP_KERNEL in tipc_nametbl_init() (Jon Maloy) [1693452]
- [net] tipc: make some functions static (Jon Maloy) [1693452]
- [net] tipc: make link capability update thread safe (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_group_size (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_link_is_active (Jon Maloy) [1693452]
- [net] tipc: check session number before accepting link protocol messages (Jon Maloy) [1693452]
- [net] tipc: add sequence number check for link STATE messages (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: extend sock diag for group communication (Jon Maloy) [1693452]
- [net] tipc: Auto removal of peer down node instance (Jon Maloy) [1693452]
- [net] tipc: optimize function tipc_node_timeout() (Jon Maloy) [1693452]
- [net] tipc: eliminate buffer cloning in function tipc_msg_extract() (Jon Maloy) [1693452]
- [net] netfilter: nf_conncount: fix argument order to find_next_bit (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: speculative garbage collection on empty lists (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: move all list iterations under spinlock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: merge lookup and add functions (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: restart search when nodes have been erased (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: split gc in two phases (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: don't skip eviction when age is negative (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: replace CONNCOUNT_LOCK_SLOTS with CONNCOUNT_SLOTS (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use rb_link_node_rcu() instead of rb_link_node() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: remove wrong condition check routine (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix unexpected permanent node of list. (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix list_del corruption in conn_free (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use spin_lock_bh instead of spin_lock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Add list lock and gc worker, and RCU for init tree search (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Split insert and traversal (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Move locking into count_tree() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit in nf_conncount_lookup() and cleanup (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Switch to plain list (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit for garbage collection (Florian Westphal) [1531074]
- [net] ptp: uapi: change _IOW to IOWR in PTP_SYS_OFFSET_EXTENDED definition (Hangbin Liu) [1677215]
- [net] ptp: check that rsv field is zero in struct ptp_sys_offset_extended (Hangbin Liu) [1677215]
- [net] ptp: deprecate gettime64() in favor of gettimex64() (Hangbin Liu) [1677215]
- [net] ptp: add PTP_SYS_OFFSET_EXTENDED ioctl (Hangbin Liu) [1677215]
- [net] ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl (Hangbin Liu) [1677215]
- [net] ptp: reorder declarations in ptp_ioctl() (Hangbin Liu) [1677215]
- [net] tuntap: fix multiqueue rx (Guillaume Nault) [1686563]

* Fri May 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-86.el8]
- [edac] EDAC/amd64: Add Family 17h Model 30h PCI IDs (Aristeu Rozanski) [1696603]
- [x86] Update stepping values for coffee lake desktop (David Arcari) [1704800]
- [security] KEYS: trusted: allow trusted.ko to initialize w/o a TPM (Jerry Snitselaar) [1694208]
- [security] tpm: pass an array of tpm_extend_digest structures to tpm_pcr_extend() (Jerry Snitselaar) [1665130 1665129]
- [security] KEYS: trusted: explicitly use tpm_chip structure from tpm_default_chip() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm/ppi: Enable submission of optional command parameter for PPI 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Possibly show command parameter if TPM PPI 1.3 is used (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Display up to 101 operations as define for version 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: rename TPM_PPI_REVISION_ID to TPM_PPI_REVISION_ID_1 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: pass function revision ID to tpm_eval_dsm() (Jerry Snitselaar) [1665130]
- [char] tpm: Fix the type of the return value in calc_tpm2_event_size() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: fix an invalid condition in tpm_common_poll (Jerry Snitselaar) [1694208]
- [char] tpm: turn on TPM on suspend for TPM 1.x (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: move tpm_chip definition to include/linux/tpm.h (Jerry Snitselaar) [1665129]
- [char] tpm: retrieve digest size of unknown algorithms with PCR read (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: rename and export tpm2_digest and tpm2_algorithms (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: dynamically allocate the allocated_banks array (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove @flags from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: take TPM chip power gating out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: introduce tpm_chip_start() and tpm_chip_stop() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove TPM_TRANSMIT_UNLOCKED flag (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: use tpm_try_get_ops() in tpm-sysfs.c. (Jerry Snitselaar) [1665130]
- [char] tpm: remove @space from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move TPM space code out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move tpm_validate_commmand() to tpm2-space.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: clean up tpm_try_transmit() error handling flow (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: encapsulate tpm_dev_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: access command header through struct in tpm_try_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: declare struct tpm_header (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: print tpm2_commit_space() error inside tpm2_commit_space() (Jerry Snitselaar) [1665129]
- [char] tpm: return 0 from pcrs_show() when tpm1_pcr_read() fails (Jerry Snitselaar) [1665130]
- [char] tpm: fix invalid return value in pubek_show() (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: use tpm_buf in tpm_transmit_cmd() as the IO parameter (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: don't return bool from update_timeouts (Jerry Snitselaar) [1665130]
- [char] tpm: don't print error message in tpm_transmit_cmd when tpm still testing (Jerry Snitselaar) [1665129]
- [char] tpm: add _head suffix to tcg_efi_specid_event and tcg_pcr_event2 (Jerry Snitselaar) [1665129]
- [char] tpm: Fix off-by-one when reading binary_bios_measurements (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: Simplify the measurements loop (Jerry Snitselaar) [1665130]
- [char] tpm/tpm_i2c_atmel: Return -E2BIG when the transfer is incomplete (Jerry Snitselaar) [1694208]
- [char] tpm: Unify the send callback behaviour (Jerry Snitselaar) [1665129]
- [char] tpm: Fix some name collisions with drivers/char/tpm.h (Jerry Snitselaar) [1694208]
- [char] tpm/tpm_crb: Avoid unaligned reads in crb_recv() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: add support for partial reads (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_ibmvtpm: fix kdoc warnings (Jerry Snitselaar) [1665129]
- [char] tpm: fix kdoc for tpm2_flush_context_cmd() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: tpm_try_transmit() refactor error flow. (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: use u32 instead of int for PCR index (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Get rid of ima_used_chip and use ima_tpm_chip != NULL instead (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Use tpm_default_chip() and call TPM functions with a tpm_chip (Jerry Snitselaar) [1665129]
- [char] tpm1: reimplement tpm1_continue_selftest() using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: reimplement SAVESTATE using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: rename tpm1_pcr_read_dev to tpm1_pcr_read() (Jerry Snitselaar) [1665130]
- [char] tpm1: implement tpm1_pcr_read_dev() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm1: rewrite tpm1_get_random() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm-space.c remove unneeded semicolon (Jerry Snitselaar) [1665129]
- [char] tpm: tpm-interface.c drop unused macros (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: add tpm_auto_startup() into tpm-interface.c (Jerry Snitselaar) [1665129]
- [char] tpm: factor out tpm_startup function (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x pm suspend flow into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm 1.x selftest code from tpm-interface.c tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm1_get_random into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm_getcap to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm1_pcr_extend to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm_get_timeouts() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: add tpm_calc_ordinal_duration() wrapper (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x duration calculation to tpm1-cmd.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: sort objects in the Makefile (Jerry Snitselaar) [1665129]
- [char] tpm2: add new tpm2 commands according to TCG 1.36 (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x (Jerry Snitselaar) [1665129]
- [char] tpm: add support for nonblocking operation (Jerry Snitselaar) [1665129]
- [char] tpm: add ptr to the tpm_space struct to file_priv (Jerry Snitselaar) [1665129]
- [char] tpm: Make SECURITYFS a weak dependency (Jerry Snitselaar) [1665129]
- [char] tpm: suppress transmit cmd error logs when TPM 1.2 is disabled/deactivated (Jerry Snitselaar) [1665130]
- [char] tpm: fix response size validation in tpm_get_random() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: replace TPM_TRANSMIT_RAW with TPM_TRANSMIT_NESTED (Jerry Snitselaar) [1665129]
- [char] tpm: Convert tpm_find_get_ops() to use tpm_default_chip() (Jerry Snitselaar) [1665129]
- [char] tpm: Implement tpm_default_chip() to find a TPM chip (Jerry Snitselaar) [1665129]
- [char] tpm: rename tpm_chip_find_get() to tpm_find_get_ops() (Jerry Snitselaar) [1665129]
- [char] tpm: Allow tpm_tis drivers to set hwrng quality. (Jerry Snitselaar) [1665129]
- [char] tpm: Return the actual size when receiving an unsupported command (Jerry Snitselaar) [1694208 1665129]
- [char] tpm/tpm_i2c_infineon: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (Jerry Snitselaar) [1665129]
- [char] tpm_tis_spi: Pass the SPI IRQ down to the driver (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_random() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_tpm_pt() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_probe() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_shutdown() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [pci] PCI: Fix __initdata issue with "pci=disable_acs_redir" parameter (Myron Stowe) [1704979]
- [s390] s390/pci: skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Add flag so platforms can skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Factor out sriov_add_vfs() (Myron Stowe) [1704979]
- [pci] switchtec: Add MRPC DMA mode support (Myron Stowe) [1704979]
- [pci] switchtec: Improve MRPC efficiency by enabling write combining (Myron Stowe) [1704979]
- [pci] switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite (Myron Stowe) [1704979]
- [pci] switchtec: Set DMA coherent mask (Myron Stowe) [1704979]
- [pci] switchtec: Remove immediate status check after submitting MRPC command (Myron Stowe) [1704979]
- [pci] PCI / PM: Allow runtime PM without callback functions (Myron Stowe) [1704979]
- [pci] PCI/P2PDMA: Clean up documentation and kernel-doc (Myron Stowe) [1704979]
- [pci] PCI: Remove unnecessary space before function pointer arguments (Myron Stowe) [1704979]
- [maintainers] MAINTAINERS: Add x86 early-quirks.c file pattern to PCI subsystem (Myron Stowe) [1704979]
- [pci] PCI: Expand the "PF" acronym in Kconfig help text (Myron Stowe) [1704979]
- [x86] x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux) (Myron Stowe) [1704979]
- [pci] PCI/ASPM: Remove unused lists from struct pcie_link_state (Myron Stowe) [1704979]
- [pci] PCI / ACPI: Identify untrusted PCI devices (Myron Stowe) [1704979]

* Thu May 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-85.el8]
- [documentation] x86/resctrl: Update Documentation/x86/resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Remove unnecessary check for cbm_validate() (Prarit Bhargava) [1504489]
- [maintainers] MAINTAINERS: Update resctrl filename patterns (Prarit Bhargava) [1504489]
- [documentation] Documentation: Rename and update intel_rdt_ui.txt to resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Introduce AMD QOS feature (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Fixup the user-visible strings (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add AMD's X86_FEATURE_MBA to the scattered CPUID features (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the config option INTEL_RDT to RESCTRL (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add vendor check for the MBA software controller (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Bring cbm_validate() into the resource structure (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Initialize the vendor-specific resource functions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Move all the macros to resctrl/internal.h (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Re-arrange the RDT init code (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the RDT functions and definitions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename and move rdt files to a separate directory (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Prevent pseudo-locking from using stale pointers (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix initial allocation to consider CDP (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: CBM overlap should also check for overlap with CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce utility to obtain CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix out-of-bounds memory access in CBM tests (Prarit Bhargava) [1504489]
- [x86] perf/x86: Add helper to obtain performance counter index (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Switch to bitmap_zalloc() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Re-enable pseudo-lock measurements (Prarit Bhargava) [1504489]
- [x86] x86/cpu: Sanitize FAM6_ATOM naming (David Arcari) [1504489]
- [x86] x86/intel_rdt: Use perf infrastructure for measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create required perf event attributes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Remove local register variables (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix exclusive mode handling of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Do not allow pseudo-locking of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix unchecked MSR access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix invalid mode warning when multiple resources are managed (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Global closid helper to support future fixes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix size reporting of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix data type in parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Disable PMU access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix possible circular lock dependency (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make CPU information accessible for pseudo-locked regions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support restoration of subset of permissions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix cleanup of plr structure on error (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Move pseudo_lock_region_clear() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Limit C-states dynamically when pseudo-locking active (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support L3 cache performance event of Broadwell (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: More precise L2 hit/miss measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create character device exposing pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create debugfs files for pseudo-locking testing (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create resctrl debug area (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure RDT cleanup on exit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Resctrl files reflect pseudo-locked information (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support creation/removal of pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Pseudo-lock region creation/removal core (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Discover supported platforms via prefetch disable bits (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utilities to test pseudo-locked region possibility (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Split resource group removal in two (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable entering of pseudo-locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support enter/exit of locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add check to determine if monitoring in progress (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Utilities to restrict/restore access to specific files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Protect against resource group changes during locking (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to restrict/restore access to resctrl files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to test if tasks assigned to resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Respect read and write access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce the Cache Pseudo-Locking modes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Display resource groups' allocations' size in bytes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce "bit_usage" to display cache allocations details (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure requested schemata respects mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support flexible data to parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Making CBM name and type more explicit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable setting of exclusive mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce new "exclusive" mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Initialize new resource group with sane defaults (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make useful functions available internally (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce test to determine if closid is in use (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce resource group's mode resctrl file (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Associate mode with each RDT resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce RDT resource group mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Provide pseudo-locking hooks within rdt_mount (Prarit Bhargava) [1504489]
- [x86] perf/x86: Make perf callchains work without CONFIG_FRAME_POINTER (Jiri Olsa) [1699780]

* Wed May 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-84.el8]
- [kernel] sched/fair: Do not re-read ->h_load_next during hierarchical load calculation (Phil Auld) [1701762]
- [s390] kvm: s390: enable MSA9 keywrapping functions depending on cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add deflate conversion facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add enhanced sort facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: provide query function for instructions returning 32 byte (Thomas Huth) [1660913]
- [s390] kvm: s390: add MSA9 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector BCD enhancements facility to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector enhancements facility 2 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add debug logging for cpu model subfunctions (Thomas Huth) [1660913]
- [s390] kvm: s390: implement subfunction processor calls (Thomas Huth) [1660913]
- [powercap] powercap: intel_rapl: add support for Jacobsville (Steve Best) [1482401]
- [x86] x86/cpu: Add Atom Tremont (Jacobsville) (Steve Best) [1482401]

* Tue May 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-83.el8]
- [crypto] crypto: qat - Remove unused goto label (Neil Horman) [1660313]
- [crypto] crypto: prefix header search paths with $(srctree)/ (Neil Horman) [1660313]
- [crypto] crypto: qat - no need to check return value of debugfs_create functions (Neil Horman) [1660313]
- [crypto] cross-tree: phase out dma_zalloc_coherent() (Neil Horman) [1660313]
- [crypto] crypto: qat - move temp buffers off the stack (Neil Horman) [1660313]
- [crypto] crypto: qat - Remove VLA usage (Neil Horman) [1660313]
- [include] block: kill all_q_node in request_queue (Ming Lei) [1702865]
- [block] bfq: update internal depth state when queue depth changes (Ming Lei) [1702865]
- [fs] block: fix the return errno for direct IO (Ming Lei) [1702865]
- [block] block: do not leak memory in bio_copy_user_iov() (Ming Lei) [1702865]
- [nvme] nvme: cancel request synchronously (Ming Lei) [1702865]
- [block] blk-mq: introduce blk_mq_complete_request_sync() (Ming Lei) [1702865]
- [scsi] scsi: virtio_scsi: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] virtio-blk: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] block, bfq: fix use after free in bfq_bfqq_expire (Ming Lei) [1702865]
- [block] paride/pcd: Fix potential NULL pointer dereference and mem leak (Ming Lei) [1702865]
- [block] blk-mq: do not reset plug->rq_count before the list is sorted (Ming Lei) [1702865]
- [block] paride/pf: Fix potential NULL pointer dereference (Ming Lei) [1702865]
- [block] blk-mq: add trace block plug and unplug for multiple queues (Ming Lei) [1702865]
- [block] block: use blk_free_flush_queue() to free hctx->fq in blk_mq_init_hctx (Ming Lei) [1702865]
- [block] paride/pcd: cleanup queues when detection fails (Ming Lei) [1702865]
- [block] paride/pf: cleanup queues when detection fails (Ming Lei) [1702865]
- [crypto] crypto: chelsio - Fixed Traffic Stall (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix passing zero to 'PTR_ERR' warning in chcr_aead_op (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Inline single pdu only (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - avoid using sa_entry imm (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variables 'adap' (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - check set_msg_len overflow in generate_b0 (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix wrong error counter increments (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Reset counters on cxgb4 Detach (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Handle PCI shutdown event (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - cleanup:send addr as value in function argument (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Use same value for both channel in single WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Swap location of AAD and IV sent in WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variable 'kctx_len' (Arjun Vynipadath) [1664679]
- [crypto] drivers: chelsio: use skb_sec_path helper (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - ESN for Inline IPSec Tx (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - small packet Tx stalls the queue (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - clean up various indentation issues (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Update ntx queue received from cxgb4 (Arjun Vynipadath) [1664679]

* Fri May 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-82.el8]
- [platform] platform/x86: intel_pmc_core: Convert to INTEL_CPU_FAM6 macro (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Avoid a u32 overflow (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Include Reserved IP for LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix file permissions for ltr_show (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP name (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP sts reading (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Handle CFL regmap properly (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: convert to DEFINE_SHOW_ATTRIBUTE (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Decode Snoop / Non Snoop LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix LTR IGNORE Max offset (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Show Latency Tolerance info (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc: Convert to use SPDX identifier (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Add CNP SLPS0 debug registers (David Arcari) [1658080]
- [x86] x86/cpu: Introduce INTEL_CPU_FAM*() helper macros (David Arcari) [1658080]
- [include] locking/atomics, asm-generic: Move some macros from <linux/bitops.h> to a new <linux/bits.h> file (David Arcari) [1658080]
- [s390] s390/kasan: fix strncpy_from_user kasan checks (Philipp Rudo) [1665182]
- [s390] s390: correct some inline assembly constraints (Philipp Rudo) [1665182]
- [s390] s390/kasan: improve string/memory functions checks (Philipp Rudo) [1665182]
- [include] compiler: remove __no_sanitize_address_or_inline again (Philipp Rudo) [1665182]
- [s390] s390/kasan: increase instrumented stack size to 64k (Philipp Rudo) [1665182]
- [mm] s390/kasan: support preemptible kernel build (Philipp Rudo) [1665182]
- [mm] s390/kasan: add support for mem= kernel parameter (Philipp Rudo) [1665182]
- [mm] s390/kasan: optimize kasan vmemmap allocation (Philipp Rudo) [1665182]
- [mm] s390/kasan: avoid kasan crash with standby memory defined (Philipp Rudo) [1665182]
- [s390] s390/head: avoid doubling early boot stack size under KASAN (Philipp Rudo) [1665182]
- [mm] s390/mm: improve debugfs ptdump markers walking (Philipp Rudo) [1665182]
- [mm] s390/mm: optimize debugfs ptdump kasan zero page walking (Philipp Rudo) [1665182]
- [s390] s390/kasan: add option for 4-level paging support (Philipp Rudo) [1665182]
- [mm] s390/kasan: free early identity mapping structures (Philipp Rudo) [1665182]
- [s390] s390/kasan: enable stack and global variables access checks (Philipp Rudo) [1665182]
- [s390] s390/dumpstack: disable __dump_trace kasan instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: reipl and kexec support (Philipp Rudo) [1665182]
- [s390] s390/smp: kasan stack instrumentation support (Philipp Rudo) [1665182]
- [include] compiler: introduce __no_sanitize_address_or_inline (Philipp Rudo) [1665182]
- [s390] s390/kasan: use noexec and large pages (Philipp Rudo) [1665182]
- [mm] s390/kasan: dynamic shadow mem allocation for modules (Philipp Rudo) [1665182]
- [mm] s390/mm: add kasan shadow to the debugfs pgtable dump (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid user access code instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: double the stack size (Philipp Rudo) [1665182]
- [s390] s390/kasan: add initialization code and enable it (Philipp Rudo) [1665182]
- [s390] s390: add pgd_page primitive (Philipp Rudo) [1665182]
- [s390] s390: introduce MAX_PTRS_PER_P4D (Philipp Rudo) [1665182]
- [s390] s390/kasan: replace some memory functions (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid instrumentation of early C code (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid vdso instrumentation (Philipp Rudo) [1665182]
- [s390] s390/mm: add missing pfn_to_kaddr helper (Philipp Rudo) [1665182]
- [s390] s390/cpum_cf: Add support for CPU-MF SVN 6 (Philipp Rudo) [1683278]
- [s390] s390: report new CPU capabilities (Philipp Rudo) [1685086]
- [net] net/smc: fix smc_poll in SMC_INIT state (Philipp Rudo) [1700812]
- [net] net/smc: fix byte_order for rx_curs_confirmed (Philipp Rudo) [1700812]
- [net] net/smc: check port_idx of ib event (Philipp Rudo) [1700799]
- [net] net/smc: check connections in smc_lgr_free_work (Philipp Rudo) [1700799]
- [net] net/smc: reduce amount of status updates to peer (Philipp Rudo) [1700799]
- [net] net/smc: no delay for free tx buffer wait (Philipp Rudo) [1700799]
- [net] net/smc: move wake up of close waiter (Philipp Rudo) [1700799]
- [net] net/smc: reset cursor update required flag (Philipp Rudo) [1700799]
- [net] net/smc: correct state change for peer closing (Philipp Rudo) [1700799]
- [net] net/smc: delete rkey first before switching to unused (Philipp Rudo) [1700799]
- [net] net/smc: fix sender_free computation (Philipp Rudo) [1700799]
- [net] net/smc: preallocated memory for rdma work requests (Philipp Rudo) [1700799]
- [net] net/smc: fix use of variable in cleared area (Philipp Rudo) [1700799]
- [net] net/smc: use device link provided in qp_context (Philipp Rudo) [1700799]
- [net] net/smc: call smc_cdc_msg_send() under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: do not wait under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: recvmsg and splice_read should return 0 after shutdown (Philipp Rudo) [1700799]
- [net] net/smc: don't wait for send buffer space when data was already sent (Philipp Rudo) [1700799]
- [net] net/smc: prevent races between smc_lgr_terminate() and smc_conn_free() (Philipp Rudo) [1700799]
- [net] net/smc: allow 16 byte pnetids in netlink policy (Philipp Rudo) [1700799]
- [net] net/smc: fix another sizeof to int comparison (Philipp Rudo) [1700799]
- [net] net/smc: move code to clear the conn->lgr field (Philipp Rudo) [1700799]
- [net] net/smc: use client and server LGR pending locks for SMC-R (Philipp Rudo) [1700799]
- [net] net/smc: unlock LGR pending lock earlier for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: use smc_curs_copy() for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: postpone release of clcsock (Philipp Rudo) [1700799]
- [net] smc: move unhash as early as possible in smc_release() (Philipp Rudo) [1700799]
- [net] net/smc: fix TCP fallback socket release (Philipp Rudo) [1700799]
- [s390] s390/ism: ignore some errors during deregistration (Philipp Rudo) [1700799]
- [infiniband] mlx4: trigger IB events needed by SMC (Philipp Rudo) [1700799]
- [s390] s390/smp: fix CPU hotplug deadlock with CPU rescan (Philipp Rudo) [1700836]
- [block] s390/dasd: fix panic for failed online processing (Philipp Rudo) [1700811]
- [netdrv] s390/qeth: fix use-after-free in error path (Philipp Rudo) [1700803]
- [netdrv] s390/qeth: cancel close_dev work before removing a card (Philipp Rudo) [1700802]
- [netdrv] s390/qeth: conclude all event processing before offlining a card (Philipp Rudo) [1700800]
- [scsi] scsi: zfcp: fix posting too many status read buffers leading to adapter shutdown (Philipp Rudo) [1700775]
- [fs] xfs: prohibit fstrim in norecovery mode (Bill O'Donnell) [1697749]
- [x86] perf/x86: Fixup typo in stub functions (Waiman Long) [1688789]
- [x86] perf/x86/intel: Fix memory corruption (Waiman Long) [1688789]
- [x86] perf/x86/intel: Implement support for TSX Force Abort (Waiman Long) [1688789]
- [x86] x86: Add TSX Force Abort CPUID/MSR (Waiman Long) [1688789]
- [x86] perf/x86/intel: Generalize dynamic constraint creation (Waiman Long) [1688789]
- [x86] perf/x86/intel: Make cpuc allocations consistent (Waiman Long) [1688789]
- [x86] perf/x86/intel: Delay memory deallocation until x86_pmu_dead_cpu() (Waiman Long) [1688789]
- [x86] perf/x86/intel: Export mem events only if there's PEBS support (Waiman Long) [1688789]
- [x86] perf/x86/intel: Add a separate Arch Perfmon v4 PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Factor out common code of PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Introduce PMU flag for Extended PEBS (Waiman Long) [1688789]
- [x86] x86/speculation: Add PR_SPEC_DISABLE_NOEXEC (Waiman Long) [1671512]

* Tue Apr 30 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-81.el8]
- [kernel] exit from RHEL 8.1 early ystream mode ("Herton R. Krzesinski")
- [net] Bluetooth: Verify that l2cap_get_conf_opt provides large enough buffer (Gopal Tiwari) [1700507] {CVE-2019-3459}
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1664683]
- [target] scsi: target: iscsi: cxgbit: add missing spin_lock_init() (Arjun Vynipadath) [1664683]
- [scsi] scsi: cxgb4i: fix incorrect spelling "reveive" -> "receive" (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: update route finding logic (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: find cxgbi device by MAC address (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgbi: remove redundant __kfree_skb call on skb and free cst->atid (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: remove uninitialized variable len (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: validate tcp sequence number only if chip version <= T5 (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: get pf number from lldi->pf (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add wait_for_completion() (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: fix thermal configuration dependencies (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add DCB support for iSCSI connections (Arjun Vynipadath) [1664685]
- [netdrv] cxgb4: Don't return EAGAIN when TCAM is full. (Arjun Vynipadath) [1664670]
- [netdrv] chelsio: use BUG() instead of BUG_ON(1) (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/chtls: Prefix adapter flags with CXGB4 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Call netif_carrier_off properly in pci_probe (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Revert force link up behaviour (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Add VF Link state support (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Prefix adapter flags with CXGB4VF (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: Enter debugging mode if FW is inaccessible (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Enable outer UDP checksum offload for T6 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix up netdev->hw_features (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: Mask out interrupts that are not enabled. (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Export sge_host_page_size to ulds (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add capability to get/set SGE Doorbell Queue Timer Tick (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Add support for SGE doorbell queue timer (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Few more link management changes. (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: add tcb flags and tcb rpl struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608b (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Program hash region for {t4/t4vf}_change_mac() (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: smt: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: sched: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: cxgb4_tc_u32: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Update port information in cxgb4vf_open() (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4/cxgb4vf: Link management changes (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: TLS record offload enable (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: clip_tbl: Use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] net: cxgb4: fix various indentation issues (Arjun Vynipadath) [1664670]
- [netdrv] net: chelsio: Add a missing check on cudg_get_buffer (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove DEFINE_SIMPLE_DEBUGFS_FILE() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: number of VFs supported is not always 16 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variables 'multitrc, speed' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use new fw interface to get the VIN and smt index (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix mac_hlist initialization and free (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: fix memleak in mac_hlist initialization (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: free mac_hlist properly (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: free mac_hlist properly (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal zone build error (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal configuration dependencies (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add thermal zone support (Arjun Vynipadath) [1664670]
- [infiniband] cxgb4: use __vlan_hwaccel helpers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608a (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix the error path of cxgb4_uld_register() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use FW_PORT_ACTION_L1_CFG32 for 32 bit capability (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove the unneeded locks (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in IEEE_FAUX_SYNC (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in cxgb4_dcb_handle_fw_update (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove duplicated include from cxgb4_main.c (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add per rx-queue counter for packet errors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Fix endianness issue in t4_fwcache() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix abort_req_rss6 struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove redundant assignment to vlan_cmd.dropnovlan_fm (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect hardware queue descriptors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device ids 0x50af and 0x50b0 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variable 'spd' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add support to display DCB info (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/t4_hw: mark expected switch fall-throughs (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/l2t: Mark expected switch fall-through (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix endian to test F_FW_PORT_CMD_DCBXDIS32 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: print ULD queue information managed by LLD (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: move Tx/Rx free pages collection to common code (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add support to read actual provisioned resources (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device id 0x50ae (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect number of free PSTRUCT page pointers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: display number of rx and tx pages free (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect ASIC LA dumps from ULP TX (Arjun Vynipadath) [1664670]
- [netdrv] libcxgb: replace vmalloc and memset with vzalloc (Arjun Vynipadath) [1664670]
- [netdrv] enic: fix checksum validation for IPv6 (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Return the correct opcode when creating WR (Jonathan Toppins) [1688010 1685309]
- [infiniband] RDMA/vmw_pvrdma: Use atomic memory allocation in create AH (Jonathan Toppins) [1685309]
- [infiniband] IB/usnic: fix spelling mistake "miniumum" -> "minimum" (Jonathan Toppins) [1685309]
- [infiniband] RDMA/drivers: Fix spelling mistake "initalize" -> "initialize" (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Reuse code which sets port state (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make counters thread safe (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Jonathan Toppins) [1685309]
- [infiniband] IB/{mlx5, ocrdma, qedr, rxe}: Omit port validation from IB verbs (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Fix incorrect cache cleanup in error flow (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Utilize generic function to validate port number (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make function rxe_pool_cleanup return void (Jonathan Toppins) [1685309]
- [infiniband] rxe: IB_WR_REG_MR does not capture MR's iova field (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: make rxe_unregister_device void (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: move the variable into the function that uses it (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Add link_down, rdma_sends, rdma_recvs stats counters (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Distinguish between down links and disabled links (Jonathan Toppins) [1685309]
- [infiniband] rxe: fix error completion wr_id and qp_num (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: clean skb queue directly (Jonathan Toppins) [1685309]
- [net] xprtrdma: Make sure Send CQ is allocated on an existing compvec (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework SCSI device reset handling (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: Fix for use-after-free in ipoib_cm_tx_start (Jonathan Toppins) [1685309]
- [net] xprtrdma: Double free in rpcrdma_sendctxs_create() (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix error code in rpcrdma_buffer_create() (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: drop useless LIST_HEAD (Jonathan Toppins) [1685309]
- [net] xprtrdma: Prevent leak of rpcrdma_rep objects (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't leak freed MRs (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add documenting comment for rpcrdma_buffer_destroy (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace outdated comment for rpcrdma_ep_post (Jonathan Toppins) [1685309]
- [net] xprtrdma: Update comments in frwr_op_send (Jonathan Toppins) [1685309]
- [net] xprtrdma: Trace mapping, alloc, and dereg failures (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add trace points for calls to transport switch methods (Jonathan Toppins) [1685309]
- [net] xprtrdma: Relocate the xprtrdma_mr_map trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Clean up of xprtrdma chunk trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove unused fields from rpcrdma_ia (Jonathan Toppins) [1685309]
- [net] xprtrdma: Cull dprintk() call sites (Jonathan Toppins) [1685309]
- [net] xprtrdma: Simplify locking that protects the rl_allreqs list (Jonathan Toppins) [1685309]
- [net] xprtrdma: Expose transport header errors (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove request_module from backchannel (Jonathan Toppins) [1685309]
- [net] xprtrdma: Plant XID in on-the-wire RDMA offset (FRWR) (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove rpcrdma_memreg_ops (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove support for FMR memory registration (Jonathan Toppins) [1685309]
- [net] xprtrdma: Reduce max_frwr_depth (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix ri_max_segs and the result of ro_maxpages (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't wake pending tasks until disconnect is done (Jonathan Toppins) [1685309]
- [net] xprtrdma: No qp_event disconnect (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace rpcrdma_receive_wq with a per-xprt workqueue (Jonathan Toppins) [1685309]
- [net] xprtrdma: Refactor Receive accounting (Jonathan Toppins) [1685309]
- [net] xprtrdma: Ensure MRs are DMA-unmapped when posting LOCAL_INV fails (Jonathan Toppins) [1685309]
- [net] xprtrdma: Yet another double DMA-unmap (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Use kmem_cache_free() instead of kfree() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Rework the srpt_alloc_srq() error path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Remove driver version and release date (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Make kernel-doc headers complete (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Join split strings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Improve coding style conformance (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Fix a use-after-free in the channel release code (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework handling of the maximum information unit length (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Move srp_rdma_ch.max_ti_iu_len declaration (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Propagate ib_post_send() failures to the SCSI mid-layer (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Handle large SCSI CDBs correctly (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Document srp_parse_in() arguments (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Move response flag definitions into this file (Jonathan Toppins) [1685309]
- [net] svcrdma: Optimize the logic that selects the R_key to invalidate (Jonathan Toppins) [1685309]
- [infiniband] IB/srpt: Drop pointless static qualifier in srpt_make_tpg() (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs in uverbs_user_mmap_disassociate (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix ioctl query port to consider device disassociation (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs upon device disassociation (Jonathan Toppins) [1685309]
- [infiniband] RDMA/umem: Add missing initialization of owning_mm (Jonathan Toppins) [1685309]
- [infiniband] RDMA/device: Expose ib_device_try_get(() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Mark ioctl responses with UVERBS_ATTR_F_VALID_OUTPUT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Add cm_id restrack resource based on kernel or user cm_id type (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Don't expose unsafe global rkey to regular user (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fix post send success return value in case of error (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add advise_mr to the list of known ops (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Signedness bug in UVERBS_HANDLER() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Start using dev_groups of class (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Use class_groups and let core create class file (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Refactor code to use cdev_device_add() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Avoid destroying device while it is accessed (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Simplify and avoid dynamic allocation of class (Jonathan Toppins) [1685309]
- [infiniband] RDMA/iwcm: Don't copy past the end of dev_name() string (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Move query port to ioctl (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Expose port_cap_flags2 (Jonathan Toppins) [1685309]
- [infiniband] IB/core: uverbs copy to struct or zero helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if destroy address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if create address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/restrack: Resource-tracker should not use uobject pointers (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add support to advise_mr (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add helper to get array size from ptr attribute (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add an ioctl method to destroy an object (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a method to introspect handles in a context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Delete RoCE GID in hw when corresponding IP is deleted (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Implement an ioctl that can call write and write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Start use ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rdmavt: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/usnic: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qib: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qedr: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/ocrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nes: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mthca: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx5: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/i40iw: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hns: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hfi1: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb3: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/bnxt_re: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Introduce ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Optimize clearing of extra bytes in response (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add new IB rates (Jonathan Toppins) [1685309]
- [include] IB/core: Add 2X port width (Jonathan Toppins) [1685309]
- [include] IB/core: Add CapabilityMask2 to port attributes (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Validate port number in query_pkey verb (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Fix typo in string concatenation macro (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Enable getting an object type from a given uobject (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Introduce UVERBS_IDR_ANY_OBJECT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Export to user space number of contexts (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Annotate alloc/deallloc paths with context tracking (Jonathan Toppins) [1685309]
- [include] RDMA/restrack: Track ucontext (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use only attrs for the write() handler signature (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not check the input length on create_cq/qp paths (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use the iterator for ib_uverbs_unmarshall_recv() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a simple iterator interface for reading the command (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Simplify ib_uverbs_ex_query_device (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fill in the response for IB_USER_VERBS_EX_CMD_MODIFY_QP (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() and core for write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() for request copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_response() for remaining response copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Get rid of the 'callback' scheme in the compat path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass ucore for write/write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Remove out_len checks that are now done by the core (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: fix ptr_ret.cocci warnings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for ioctl() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Prohibit write() calls with too small buffers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add structure size info to write commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not pass ib_uverbs_file to ioctl methods (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make write() handlers return 0 on success (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Replace ib_uverbs_file with uverbs_attr_bundle for write (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Add missing driver_data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Sync unregistration with netlink commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Move cma module specific functions to cma_priv.h (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Check for NULL driver methods for every write call (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make all the method functions in uverbs_cmd static (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Convert the write interface to use uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/verbs: Store the write/write_ex uapi entry points in the uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Require all objects to have a driver destroy function (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add helpers to mark uapi functions as unsupported (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Factor out the add/get pattern into a helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Make function ib_fmr_pool_unmap return void (Jonathan Toppins) [1685309]
- [include] RDMA/core: Remove unused header files mm.h, socket.h, scatterlist.h (Jonathan Toppins) [1685309]
- [include] IB/uverbs: fix a typo (Jonathan Toppins) [1685309]
- [fs] coredump: fix race condition between mmget_not_zero()/get_task_mm() and core dumping (Andrea Arcangeli) [1696081] {CVE-2019-3892}
- [scsi] scsi: csiostor: fix missing data copy in csio_scsi_err_handler() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: drop serial_number usage (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix calls to dma_set_mask_and_coherent() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: Remove set but not used variable 'pln' (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix NULL pointer dereference in csio_vport_set_state() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix incorrect dma device in case of vport (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: switch to generic DMA API (Arjun Vynipadath) [1664680]
- [netdrv] thunderx: eliminate extra calls to put_page() for pages held for recycling (Dean Nelson) [1644011]
- [netdrv] thunderx: enable page recycling for non-XDP case (Dean Nelson) [1644011]
- [cpufreq] cpufreq: intel_pstate: Also use CPPC nominal_perf for base_frequency (Prarit Bhargava) [1696131]
- [acpi] ACPI / CPPC: Fix guaranteed performance handling (Prarit Bhargava) [1696131]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659169]
- [netdrv] igbvf: Replace spin_is_locked() with lockdep (Corinna Vinschen) [1659169]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659169]
- [netdrv] igbvf: netdev: Mark expected switch fall-through (Corinna Vinschen) [1659169]
- [x86] x86/MCE: Initialize mce.bank in the case of a fatal error in mce_no_way_out() (David Arcari) [1698959]
- [x86] x86/mce: Restore MCE injector's module name (David Arcari) [1698959]
- [x86] x86/mce: Streamline MCE subsystem's naming (David Arcari) [1698959]
- [x86] x86: Fix various typos in comments (David Arcari) [1698959]
- [x86] x86/MCE/AMD: Fix the thresholding machinery initialization order (David Arcari) [1698959]
- [x86] x86/mce: Fix -Wmissing-prototypes warnings (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Validate a MCE's address before using it (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Handle only uncorrectable machine checks (David Arcari) [1698959]
- [x86] x86: Clean up 'sizeof x' => 'sizeof(x)' (David Arcari) [1698959]
- [x86] x86/mcelog: Remove one mce_helper definition (David Arcari) [1698959]
- [x86] x86/mce-inject: Reset injection struct after injection (David Arcari) [1698959]
- [mm] x86/mce: Fix set_mce_nospec() to avoid #GP fault (David Arcari) [1698959]
- [x86] x86/memory_failure: Introduce {set, clear}_mce_nospec() (David Arcari) [1698959]
- [x86] x86/mce: Cleanup __mc_scan_banks() (David Arcari) [1698959]
- [x86] x86/mce: Carve out bank scanning code (David Arcari) [1698959]
- [x86] x86/mce: Carve out the crashing_cpu check (David Arcari) [1698959]
- [x86] x86/mce: Always use 64-bit timestamps (David Arcari) [1698959]
- [x86] x86/mce: Remove !banks check (David Arcari) [1698959]
- [md] dm cache metadata: Fix loading discard bitset (Mike Snitzer) [1701618]
- [block] null_blk: prevent crash from bad home_node value (Ming Lei) [1696951]
- [powerpc] powerpc/security: Fix spectre_v2 reporting (Gustavo Duarte) [1694456]
- [powerpc] powerpc/powernv: Query firmware for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/pseries: Query hypervisor for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add support for software count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add new security feature flags for count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/asm: Add a patch_site macro & helpers for patching instructions (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Call setup_barrier_nospec() from setup_arch() (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Add CONFIG_PPC_BARRIER_NOSPEC (Gustavo Duarte) [1694456]
- [powerpc] powerpc64s: Show ori31 availability in spectre_v1 sysfs file not v2 (Gustavo Duarte) [1694456]

* Mon Apr 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.23.el8]
- [kernel] sched/fair: Limit sched_cfs_period_timer() loop to avoid hard lockup (Joel Savitz) [1695651]
- [crypto] crypto: ux500 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: talitos - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sun4i-ss - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: stm32 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: rockchip - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: qce - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: picoxcell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: omap - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: n2 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: marvell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ixp4xx - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: hifn_795x - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccree - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccp - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: cavium - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: caam - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: bcm - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: atmel - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sparc - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [s390] crypto: s390 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: des_generic - Forbid 2-key in 3DES and add helpers (Herbert Xu) [1687908]
- [crypto] crypto: mxc-scc - Remove broken driver (Herbert Xu) [1687908]
- [kernel] ntp: Audit NTP parameters adjustment (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Audit clock adjustments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove duplicated include (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping/ntp: Constify some function arguments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Use kstrtos64 for s64 variable (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove redundant arguments (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Use ktime_get_real_ts64() instead of getnstimeofday64() (Ondrej Mosnacek) [1680034]
- [netdrv] hinic: Add pci device ids (Xiaojun Tan) [1662040]
- [netdrv] net-next/hinic:add shutdown callback (Xiaojun Tan) [1662040]
- [netdrv] hinic: optmize rx refill buffer mechanism (Xiaojun Tan) [1662040]
- [netdrv] net: hinic: remove redundant pointer pfhwdev (Xiaojun Tan) [1662040]
- [netdrv] net: hns: fix unsigned comparison to less than zero (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix sparse: some warnings in HNS drivers (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix WARNING when remove HNS driver with SMMU enabled (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix ICMP6 neighbor solicitation messages discard problem (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix probabilistic memory overwrite when HNS driver initialized (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use NAPI_POLL_WEIGHT for hns driver (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix KASAN: use-after-free in hns_nic_net_xmit_hw() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fixes the missing put_device in positive leg for roce reset (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix object reference leaks in hns_dsaf_roce_reset() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Restart autoneg need return failed when autoneg off (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix for missing of_node_put() after of_parse_phandle() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix use after free identified by SLUB debug (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make function hns_gmac_wait_fifo_clean() static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use eth_get_headlen interface instead of hns_nic_get_headlen (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Mark expected switch fall-through (Xiaojun Tan) [1661885]
- [netdrv] net: hns: remove redundant variables 'max_frm' and 'tmp_mac_key' (Xiaojun Tan) [1661885]
- [netdrv] net: hisilicon: hns: Replace mdelay() with msleep() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make hns_dsaf_roce_reset non static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Make many functions static (Xiaojun Tan) [1661885]
- [bluetooth] Bluetooth: btusb: Add support for Intel bluetooth device 8087:0029 (Gopal Tiwari) [1678084]
- [bluetooth] Bluetooth: btusb: Use bt_dev_err for Intel firmware loading errors (Gopal Tiwari) [1678084]

* Fri Apr 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.22.el8]
- [vfio] vfio/pci: Restore device state on PM transition (Alex Williamson) [1700254]
- [vfio] vfio/pci: Parallelize device open and release (Alex Williamson) [1700254]
- [pci] Revert "PCI/ASPM: Do not initialize link state when aspm_disabled is set" (Myron Stowe) [1694143]
- [pci] PCI: Fix incorrect value returned from pcie_get_speed_cap() (Myron Stowe) [1694143]
- [x86] x86/PCI: Apply VMD's AERSID fixup generically (Myron Stowe) [1694143]
- [pci] PCI/IOV: Remove unnecessary include of <linux/pci-ats.h> (Myron Stowe) [1694143]
- [pci] PCI: pcie: Remove redundant 'default n' from Kconfig (Myron Stowe) [1694143]
- [documentation] NTB: switchtec_ntb: Update switchtec documentation with prerequisites for NTB (Myron Stowe) [1694143]
- [pci] PCI: Fix Switchtec DMA aliasing quirk dmesg noise (Myron Stowe) [1694143]
- [pci] PCI: Add macro for Switchtec quirk declarations (Myron Stowe) [1694143]
- [pci] PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk (Myron Stowe) [1694143]
- [pci] PCI / ACPI: Mark expected switch fall-through (Myron Stowe) [1694143]
- [pci] PCI: Remove set but unused variable (Myron Stowe) [1694143]
- [pci] PCI: Fix pci.c kernel-doc parameter warning (Myron Stowe) [1694143]
- [pci] PCI: Allocate dma_alias_mask with bitmap_zalloc() (Myron Stowe) [1694143]
- [include] PCI: Remove unused NFP32xx IDs (Myron Stowe) [1694143]
- [maintainers] maintainers: Add Hyper-V IOMMU driver into Hyper-V CORE AND DRIVERS scope (Vitaly Kuznetsov) [1663292 1669989]
- [iommu] hyper-v: Add Hyper-V stub IOMMU driver (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Set x2apic destination mode to physical when x2apic is available (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Enable PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [clocksource] clockevents/drivers/i8253: Add support for PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Enable PV qspinlock for Hyper-V (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add GUEST_IDLE_MSR support (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hv: vmbus: Make TLFS #define names architecture neutral (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add interrupt handler annotations (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Refactor hv_irq_unmask() to use cpumask_to_vpset() (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Replace hv_vp_set with hv_vpset (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Add __aligned(8) to struct retarget_msi_interrupt (Vitaly Kuznetsov) [1663292 1669989]
- [vfio] vfio-pci/nvlink2: Fix ancient gcc warnings (Sam Bobroff) [1524679]
- [vfio] vfio/pci: Cleanup license mess (Sam Bobroff) [1524679]
- [vfio] vfio/pci: set TRACE_INCLUDE_PATH to fix the build error (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Add NVIDIA GV100GL [Tesla V100 SXM2] subdriver (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow regions to add own capabilities (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow mapping extra regions (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Fault user page into the hypervisor's pagetable (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Check mmio_atsd array bounds when populating (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add release_ownership hook (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add compound IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Convert NPU IOMMU helpers to iommu_table_group_ops (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move single TVE handling to NPU PE (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Reference iommu_table while it is linked to a group (Sam Bobroff) [1524679]
- [powerpc] powerpc/iommu_api: Move IOMMU groups setup to a single place (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/pseries: Rework device adding to IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries: Remove IOMMU API support for non-LPAR systems (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/npu: Enable platform support (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/iommu: Use memory@ nodes in max RAM address calculation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move OPAL calls away from context manipulation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Move npu struct from pnv_phb to pci_controller (Sam Bobroff) [1524679]
- [powerpc] powerpc/vfio/iommu/kvm: Do not pin device memory (Sam Bobroff) [1524679]
- [vfio] powerpc/mm/iommu/vfio_spapr_tce: Change mm_iommu_get to reference a region (Sam Bobroff) [1524679]
- [powerpc] powerpc/ioda/npu: Call skiboot's hot reset hook when disabling NPU2 (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels of cached userspace addresses on demand (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda1: Remove dead code for a single device PE (Sam Bobroff) [1524679]
- [rpmspec] redhat: add TC selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add net selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add pktgen samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: rename bpf_samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: remove bpf_samples dependency on glibc-static and build it by default (Ivan Vecera) [1691376]
- [tools] selftests: bpf: modify urandom_read and link it non-statically (Ivan Vecera) [1691376]

* Wed Apr 24 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.21.el8]
- [netdrv] ibmvnic: Fix netdev feature clobbering during a reset (Steve Best) [1699018]
- [netdrv] ibmvnic: Enable GRO (Steve Best) [1699018]
- [x86] x86/perf/amd: Remove need to check "running" bit in NMI handler (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve NMI latency issues for active PMCs (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve race condition when disabling PMC (David Arcari) [1640238]
- [netdrv] qed: Fix qed_mcp_halt|resume() (Manish Chopra) [1697310]

* Tue Apr 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.20.el8]
- [x86] x86/kexec: Fix a kexec_file_load() failure (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: include linux/vmalloc.h (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: handle empty command-line (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: return successfully even if kaslr-seed doesn't exist (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: Refactor setup_dtb() to consolidate error checking (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: add kaslr support (Bhupesh Sharma) [1666078]
- [char] random: Make crng state queryable (Bhupesh Sharma) [1666078]
- [include] include: pe.h: remove message[] from mz header definition (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: invoke the kernel without purgatory (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: allow for loading Image-format kernel (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: load initrd and device-tree (Bhupesh Sharma) [1666078]
- [arm64] arm64: enable KEXEC_FILE config (Bhupesh Sharma) [1666078]
- [arm64] arm64: cpufeature: add MMFR0 helper functions (Bhupesh Sharma) [1666078]
- [arm64] arm64: add image head flag definitions (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: kexec_walk_memblock() only walks a dedicated region at kdump (Bhupesh Sharma) [1666078]
- [kernel] powerpc, kexec_file: factor out memblock-based arch_kexec_walk_mem() (Bhupesh Sharma) [1666078]
- [kernel] s390, kexec_file: drop arch_kexec_mem_walk() (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: make kexec_image_post_load_cleanup_default() global (Bhupesh Sharma) [1666078]
- [include] asm-generic: add kexec_file_load system call to unistd.h (Bhupesh Sharma) [1666078]
- [include] asm-generic: unistd.h: Wire up sys_rseq (Bhupesh Sharma) [1666078]
- [fs] xfs: don't overflow xattr listent buffer (Bill O'Donnell) [1683531]
- [drm] drm/i915/gvt: Add in context mmio 0x20D8 to gen9 mmio list (Paul Lai) [1651589]
- [fs] copy_mount_string: Limit string length to PATH_MAX (Miklos Szeredi) [1655272]
- [include] redhat: Reuse other arch's cpuhp_state to protect kABI (Robert Richter) [1658476]
- [drivers] drivers/perf: Add Cavium ThunderX2 SoC UNCORE PMU driver (Robert Richter) [1658476]
- [documentation] Documentation: perf: Add documentation for ThunderX2 PMU uncore driver (Robert Richter) [1658476]

* Mon Apr 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.19.el8]
- [arm64] arm64: apply workaround on A64FX v1r0 (Mark Langsdorf) [1692306]
- [fs] kernfs: fix xattr name handling in LSM helpers (Ondrej Mosnacek) [1558179]
- [include] LSM: lsm_hooks.h - fix missing colon in docstring (Ondrej Mosnacek) [1558179]
- [security] selinux: Make selinux_kernfs_init_security static (Ondrej Mosnacek) [1558179]
- [fs] kernfs: initialize security of newly created nodes (Ondrej Mosnacek) [1558179]
- [security] selinux: implement the kernfs_init_security hook (Ondrej Mosnacek) [1558179]
- [include] LSM: add new hook for kernfs node initialization (Ondrej Mosnacek) [1558179]
- [fs] kernfs: use simple_xattrs for security attributes (Ondrej Mosnacek) [1558179]
- [security] selinux: try security xattr after genfs for kernfs filesystems (Ondrej Mosnacek) [1558179]
- [fs] kernfs: do not alloc iattrs in kernfs_xattr_get (Ondrej Mosnacek) [1558179]
- [fs] kernfs: clean up struct kernfs_iattrs (Ondrej Mosnacek) [1558179]
- [fs] kernfs: allow creating kernfs objects with arbitrary uid/gid (Ondrej Mosnacek) [1558179]
- [tools] tools/power turbostat: Add Icelake support (Steve Best) [1698546]
- [tools] tools/power turbostat: consolidate duplicate model numbers (Steve Best) [1698546]
- [mm] s390/mm: silence compiler warning when compiling without CONFIG_PGSTE (Thomas Huth) [1698848]
- [scripts] unifdef: use memcpy instead of strncpy (Thomas Huth) [1698848]
- [s390] s390: align struct lowcore to double page size (Thomas Huth) [1698848]
- [powerpc] KVM: PPC: Book3S HV: Perserve PSSCR FAKE_SUSPEND bit on guest exit (Suraj Jitindar Singh) [1689768]

* Thu Apr 18 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.18.el8]
- [virtio] virtio: Honour 'may_reduce_num' in vring_create_virtqueue (Cornelia Huck) [1697505]
- [s390] setup: set control program code via diag 318 (Thomas Huth) [1592336]
- [s390] kvm: s390: set host program identifier (Thomas Huth) [1592336]
- [edac] EDAC, skx: Fix randconfig builds in a better way (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx: Fix randconfig builds (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx_edac: Add address translation for non-volatile DIMMs (Aristeu Rozanski) [1501612 1649988 1571534]
- [acpi] ACPI/ADXL: Add address translation interface using an ACPI DSM (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Add macros for the corrected error count bit field (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Use BIT_ULL(x) for bit mask definitions (Aristeu Rozanski) [1501612 1649988 1571534]
- [crypto] crypto: ecc - regularize scalar for scalar multiplication (Neil Horman) [1687888]
- [crypto] crypto: ecc - check for invalid values in the key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - make crypto_dh_encode_key() make robust (Neil Horman) [1687888]
- [crypto] crypto: dh - fix calculating encoded key size (Neil Horman) [1687888]
- [crypto] crypto: ecdh - fix typo of P-192 b value (Neil Horman) [1687888]
- [crypto] crypto: ecdh - add public key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - fix memory leak (Neil Horman) [1687888]
- [crypto] crypto: dh - add public key verification test (Neil Horman) [1687888]
- [scsi] scsi: hisi_sas: Add softreset in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change SERDES_CFG init value to increase reliability of HiLink (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Send HARD RESET to clear the previous affiliation of STP target port (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set PHY linkrate when disconnected (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: print PHY RX errors count for later revision of v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix a timeout race of driver internal and SMP IO (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change return variable type in phy_up_v3_hw() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: fix calls to dma_set_mask_and_coherent() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Do some more tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Use pci_irq_get_affinity() for v3 hw as experimental (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Issue internal abort on all relevant queues (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change queue depth from 512 to 4096 (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add manual trigger for debugfs dump (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIX feature for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add missing seq_printf() call in hisi_sas_show_row_32() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix to only call scsi_get_prot_op() for non-NULL scsi_cmnd (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Correct memory allocation size for DQ debugfs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix losing directly attached disk when hot-plug (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Reject setting programmed minimum linkrate > 1.5G (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove unused parameter of function hisi_sas_alloc() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: remove the check of sas_dev status in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: shutdown axi bus to avoid exception CQ returned (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: send primitive NOTIFY to SSP situation only (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs ITCT file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix type casting and missing static qualifier in debugfs code (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: No need to check return value of debugfs_create functions (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set protection parameters prior to adding SCSI host (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs IOST file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs DQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs CQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs for port registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Debugfs global register create file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Take debugfs snapshot for all regs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Alloc debugfs snapshot buffer memory for all registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create root and device debugfs directories (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIF feature for v2 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Make sg_tablesize consistent value (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some code to reduce complexity (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix warnings detected by sparse (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change the time of SAS SSP connection (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some codes to avoid an unused check (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt coalescing for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt converge for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create separate host attributes per HBA (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: use dma_set_mask_and_coherent (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove set but not used variable 'dq_list' (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix NULL pointer dereference (Xiaojun Tan) [1662038]
- [nvme] nvme-pci: add missing unlock for reset error (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix rapid add remove sequence (Gopal Tiwari) [1665354]
- [nvme] nvme: remove the .stop_ctrl callout (Gopal Tiwari) [1665354]
- [nvme] nvme: add support for the Write Zeroes command (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix null dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix uninitialized variable access (Gopal Tiwari) [1665354]
- [nvme] nvme: don't initlialize ctrl->cntlid twice (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: remove dead code (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: don't ask if controller is fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: unset write/poll queues for discovery controllers (Gopal Tiwari) [1665354]
- [nvme] nvme: pad fake subsys NQN vid and ssvid with zeros (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix out of bounds access in nvme_cqe_pending (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: use the same attributes when freeing host_mem_desc_bufs. (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix the wrong setting of nr_maps (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: rerun irq setup on IO queue init errors (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: trace SQ status on completions (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to pass in nr_poll_queues (Gopal Tiwari) [1665354]
- [nvme] nvme-core: optionally poll sync commands (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix spelling mistake "attepmpt" -> "attempt" (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: refactor nvme_poll_irqdisable to make sparse happy (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: only set nr_maps to 2 if poll queues are supported (Gopal Tiwari) [1665354]
- [nvme] nvmet: use a macro for default error location (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix comparison of a u16 with -1 (Gopal Tiwari) [1665354]
- [nvme] nvme: fix kernel paging oops (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [include] block: make request_to_qc_t public (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to set nr_write_queues for separate queue maps (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: add missing nvmf_ctrl_options documentation (Gopal Tiwari) [1665354]
- [nvme] blk-mq-rdma: pass in queue map to blk_mq_rdma_map_queues (Gopal Tiwari) [1665354]
- [nvme] nvmet: update smart log with num err log entries (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for file backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log page cmd handler (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for bdev backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for admin-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for fabrics-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for rdma backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support in the core (Gopal Tiwari) [1665354]
- [nvme] nvmet: add interface to update error-log page (Gopal Tiwari) [1665354]
- [include] nvme: add error log page slot definition (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error-log definitions (Gopal Tiwari) [1665354]
- [nvme] nvme: remove nvme_common command cdw10 array (Gopal Tiwari) [1665354]
- [nvme] nvme: provide fallback for discard alloc failure (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unused variable (Gopal Tiwari) [1665354]
- [nvme] nvme: add __exit annotation (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow configfs tcp trtype configuration (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: add NVMe over TCP host driver (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: add NVMe over TCP target driver (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing data digest (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing header digest (Gopal Tiwari) [1665354]
- [nvme] nvmet: Add install_queue callout (Gopal Tiwari) [1665354]
- [nvme] nvmet: use unlikely for req status check (Gopal Tiwari) [1665354]
- [include] nvme-tcp: Add protocol header (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: Add unlikely for response allocated check (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix the structure member indentation (Gopal Tiwari) [1665354]
- [nvme] nvme: implement Enhanced Command Retry (Gopal Tiwari) [1665354]
- [nvme] nvme: remove unused function nvme_ctrl_ready (Gopal Tiwari) [1665354]
- [nvme] nvmet: support fabrics sq flow control (Gopal Tiwari) [1665354]
- [nvme] nvmet: enable Discovery Controller AENs (Gopal Tiwari) [1665354]
- [nvme] nvmet: expose support for fabrics SQ flow control disable in treq (Gopal Tiwari) [1665354]
- [nvme] nvme: disable fabrics SQ flow control when asked by the user (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: remove the IN_ISR deferred scheduling options (Gopal Tiwari) [1665354]
- [nvme] nvme: Remove unused forward declaration (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow host connect even if no allowed subsystems are exported (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't override treq upon modification. (Gopal Tiwari) [1665354]
- [nvme] nvmet: mark nvmet_genctr static (Gopal Tiwari) [1665354]
- [nvme] nvmet: add defines for discovery change async events (Gopal Tiwari) [1665354]
- [nvme] nvmet: support for traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvmet: make kato and AEN processing for use by other controllers (Gopal Tiwari) [1665354]
- [nvme] nvmet: change aen mask functions to use bit numbers (Gopal Tiwari) [1665354]
- [nvme] nvmet: provide aen bit functions for multiple controller types (Gopal Tiwari) [1665354]
- [nvme] nvmet: add support to Discovery controllers for commands (Gopal Tiwari) [1665354]
- [nvme] nvmet: use IOCB_NOWAIT for file-ns buffered I/O (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow Keep Alive for Discovery controller (Gopal Tiwari) [1665354]
- [nvme] nvme: support traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvme: cache controller attributes (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce ctrl attributes enumeration (Gopal Tiwari) [1665354]
- [nvme] nvme: consolidate memset calls in the nvme_setup_cmd path (Gopal Tiwari) [1665354]
- [nvme] nvme: warn when finding multi-port subsystems without multipathing enabled (Gopal Tiwari) [1665354]
- [nvme] Revert "nvmet-rdma: use a private workqueue for delete" (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: move controller options matching to fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: always have a valid trsvcid (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: remove duplicate check (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix hot removal during error handling (Gopal Tiwari) [1665354]
- [nvme] nvmet-fcloop: suppress a compiler warning (Gopal Tiwari) [1665354]
- [nvme] nvme-core: make implicit seed truncation explicit (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: fix kernel-doc headers (Gopal Tiwari) [1665354]
- [nvme] nvmet: avoid integer overflow in the discard code (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strlcpy() instead of strcpy() (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix nvme_suspend_queue() kernel-doc header (Gopal Tiwari) [1665354]
- [nvme] nvme-core: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvme-core: rework a NQN copying operation (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strcmp() instead of strncmp() for subsystem lookup (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: check for timeout in nvme_rdma_wait_for_cm() (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unreachable code (Gopal Tiwari) [1665354]
- [nvme] nvme: update node paths after adding new path (Gopal Tiwari) [1665354]
- [nvme] nvme: remove ns sibling before clearing path (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: use a private workqueue for delete (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't split large I/Os unconditionally (Gopal Tiwari) [1665354]
- [nvme] nvme-core: add async event trace helper (Gopal Tiwari) [1665354]
- [nvme] nvmet_fc: support target port removal with nvmet layer (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove redundant module prefix (Gopal Tiwari) [1665354]
- [nvme] nvme: fix typo in nvme_identify_ns_descs (Gopal Tiwari) [1665354]
- [nvme] nvme: register ns_id attributes as default sysfs groups (Gopal Tiwari) [1665354]
- [block] block: genhd: add 'groups' argument to device_add_disk (Gopal Tiwari) [1665354]
- [nvme] nvme: count all ANA groups for ANA Log page (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix possible bogus dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvmet: free workqueue object if module init fails (Gopal Tiwari) [1665354]
- [nvme] nvme-fcloop: Fix dropped LS's to removed target port (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: add a memory barrier to nvme_dbbuf_update_and_check_event (Gopal Tiwari) [1665354]
- [nvme] nvmet: add ns write protect support (Gopal Tiwari) [1665354]
- [nvme] nvme: set gendisk read only based on nsattr (Gopal Tiwari) [1665354]
- [include] nvme.h: add support for ns write protect definitions (Gopal Tiwari) [1665354]
- [nvme] nvmet: use Retain Async Event bit to clear AEN (Gopal Tiwari) [1665354]
- [nvme] nvmet: support configuring ANA groups (Gopal Tiwari) [1665354]
- [nvme] nvmet: add minimal ANA support (Gopal Tiwari) [1665354]
- [nvme] nvmet: track and limit the number of namespaces per subsystem (Gopal Tiwari) [1665354]
- [nvme] nvmet: keep a port pointer in nvmet_ctrl (Gopal Tiwari) [1665354]
- [nvme] nvmet: check fileio lba range access boundaries (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't use uuid_le type (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize admin/io queue teardown sequence (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix file discard return status (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize controller setup sequence (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: unquiesce queues when deleting the controller (Gopal Tiwari) [1665354]
- [nvme] nvme: add disk name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: mark expected switch fall-through (Gopal Tiwari) [1665354]
- [nvme] nvme: add controller name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme: use hw qid in trace events (Gopal Tiwari) [1665354]
- [nvme] nvmet: add buffered I/O support for file backed ns (Gopal Tiwari) [1665354]
- [nvme] nvme: move init of keep_alive work item to controller initialization (Gopal Tiwari) [1665354]
- [nvme] nvmet: add commands supported and effects log page (Gopal Tiwari) [1665354]
- [nvme] lightnvm: limit get chunk meta request size (Gopal Tiwari) [1665354]
- [nvme] lightnvm: Remove redundant rq->__data_len initialization (Gopal Tiwari) [1665354]
- [block] nbd: restrict use to AF_UNIX sockets (Mike Christie) [1673307]
- [block] nbd: don't allow invalid blocksize settings (Mike Christie) [1673307]
- [documentation] doc, block, bfq: add information on bfq execution time (Ming Lei) [1686682]
- [block] block, bfq: save & resume weight on a queue merge/split (Ming Lei) [1686682]
- [block] block, bfq: print SHARED instead of pid for shared queues in logs (Ming Lei) [1686682]
- [block] block, bfq: always protect newly-created queues from existing active queues (Ming Lei) [1686682]
- [block] block, bfq: do not tag totally seeky queues as soft rt (Ming Lei) [1686682]
- [block] block, bfq: do not merge queues on flash storage with queueing (Ming Lei) [1686682]
- [block] block, bfq: tune service injection basing on request service times (Ming Lei) [1686682]
- [block] block, bfq: do not idle for lowest-weight queues (Ming Lei) [1686682]
- [block] block, bfq: increase idling for weight-raised queues (Ming Lei) [1686682]
- [block] block/bfq: fix ifdef for CONFIG_BFQ_GROUP_IOSCHED=y (Ming Lei) [1686682]
- [block] block, bfq: fix in-service-queue check for queue merging (Ming Lei) [1686682]
- [block] block, bfq: do not overcharge writes in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: port commit "cfq-iosched: improve hw_tag detection" (Ming Lei) [1686682]
- [block] block, bfq: reduce threshold for detecting command queueing (Ming Lei) [1686682]
- [block] block, bfq: fix queue removal from weights tree (Ming Lei) [1686682]
- [block] block, bfq: fix sequential rq detection in rate estimation (Ming Lei) [1686682]
- [block] block, bfq: unconditionally plug I/O in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: do not plug I/O of in-service queue when harmful (Ming Lei) [1686682]
- [block] block, bfq: split function bfq_better_to_idle (Ming Lei) [1686682]
- [block] block, bfq: consider also ioprio classes in symmetry detection (Ming Lei) [1686682]
- [block] block, bfq: remove case of redirected bic from insert_request (Ming Lei) [1686682]
- [block] block, bfq: make sure queue budgets are not below service received (Ming Lei) [1686682]
- [block] block, bfq: avoid selecting a queue w/o budget (Ming Lei) [1686682]
- [block] block, bfq: do not consider interactive queues in srt filtering (Ming Lei) [1686682]
- [net] net: switchdev: Add extack to switchdev_handle_port_obj_add() callback (Ivan Vecera) [1690125]
- [net] switchdev: Add extack to struct switchdev_notifier_info (Ivan Vecera) [1690125]
- [net] vxlan: Add a function to init switchdev_notifier_vxlan_fdb_info (Ivan Vecera) [1690125]
- [net] switchdev: Add extack argument to switchdev_port_obj_add() (Ivan Vecera) [1690125]
- [net] bridge: Propagate extack to switchdev (Ivan Vecera) [1690125]
- [net] ndo_bridge_setlink: Add extack (Ivan Vecera) [1690125]
- [net] rocker, dsa, ethsw: Don't filter VLAN events on bridge itself (Ivan Vecera) [1690125]
- [net] switchdev: Replace port obj add/del SDO with a notification (Ivan Vecera) [1690125]
- [net] ocelot: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add helpers to aid traversal through lower devices (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Introduce ethsw_port_dev_check() (Ivan Vecera) [1690125]
- [net] dsa: slave: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] rocker: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add SWITCHDEV_PORT_OBJ_ADD, SWITCHDEV_PORT_OBJ_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add a blocking notifier chain (Ivan Vecera) [1690125]
- [net] switchdev: SWITCHDEV_OBJ_PORT_{VLAN, MDB}(): Sanitize (Ivan Vecera) [1690125]
- [net] selftests: forwarding: Fix test for different devices (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add learning test (Ivan Vecera) [1693316]
- [net] bridge: Allow querying bridge port flags (Ivan Vecera) [1693316]
- [netdrv] vxlan: Allow changing ageing time (Ivan Vecera) [1693316]
- [netdrv] vxlan: Add hardware FDB learning (Ivan Vecera) [1693316]
- [netdrv] vxlan: Don't override user-added entries with ext-learned ones (Ivan Vecera) [1693316]
- [netdrv] vxlan: Mark user-added FDB entries (Ivan Vecera) [1693316]
- [netdrv] vxlan: vxlan_fdb_notify(): Make switchdev notification configurable (Ivan Vecera) [1693316]
- [netdrv] vxlan: __vxlan_fdb_delete(): Drop unused argument vid (Ivan Vecera) [1693316]
- [netdrv] vxlan: support NTF_USE refresh of fdb entries (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d_port_8472: New test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN decap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN encap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TOS test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TTL test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Reconfigure & rerun tests (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add unicast test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add flood test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add ping test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Add a skeleton of vxlan_bridge_1d (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add link_stats_rx_errors_get() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_do(): Allow passing ping arguments (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_test(): Add description argument (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add in_ns() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Support NUM_NETIFS of 0 (Ivan Vecera) [1693316]
- [net] skb_scrub_packet(): Scrub offload_fwd_mark (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: extract ping and ping6 so they can be reused (Ivan Vecera) [1693316]
- [net] selftests: forwarding: README: Require diagrams (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Extract interface-init functions (Ivan Vecera) [1693316]
- [net] selftests: forwarding: tc_rule_stats_get: Parameterize direction (Ivan Vecera) [1693316]
- [net] selftests: forwarding: multipath_eval(): Improve style (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Move multipath_eval() to lib.sh (Ivan Vecera) [1693316]
- [net] selftests: Add test_vxlan_fdb_changelink.sh (Ivan Vecera) [1690309]
- [netdrv] vxlan: changelink: Fix handling of default remotes (Ivan Vecera) [1690309]
- [netdrv] vxlan: Fix error path in __vxlan_dev_create() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Unmark offloaded bit on replaced FDB entries (Ivan Vecera) [1690309]
- [net] bridge: switchdev: Allow clearing FDB entry offload indication (Ivan Vecera) [1690309]
- [netdrv] vxlan: Notify for each remote of a removed FDB entry (Ivan Vecera) [1690309]
- [netdrv] vxlan: Support marking RDSTs as offloaded (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add vxlan_fdb_find_uc() for FDB querying (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add switchdev notifications (Ivan Vecera) [1690309]
- [netdrv] net: Add netif_is_vxlan() (Ivan Vecera) [1690309]
- [net] inet: Refactor INET_ECN_decapsulate() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Export address checking functions (Ivan Vecera) [1690309]
- [net] vxlan: Remove duplicated include from vxlan.h (Ivan Vecera) [1690309]
- [netdrv] geneve: correctly handle ipv6.disable module parameter (Jiri Benc) [1692390]
- [net] ipv6: sit: reset ip header pointer in ipip6_rcv (Lorenzo Bianconi) [1691626]
- [net] vxlan: Don't call gro_cells_destroy() before device is unregistered (Andrea Claudi) [1692499]
- [net] xsk: do not remove umem from netdevice on fall-back to copy-mode (Petr Oros) [1690568]
- [net] xsk: Check if a queue exists during umem setup (Petr Oros) [1690568]
- [net] xsk: simplify xdp_clear_umem_at_qid implementation (Petr Oros) [1690568]
- [net] ethtool: don't allow disabling queues with umem installed (Petr Oros) [1690568]
- [net] ethtool: rename local variable max -> curr (Petr Oros) [1690568]
- [net] xsk: fix bug when trying to use both copy and zero-copy on one queue id (Petr Oros) [1690568]
- [net] add umem reference in netdev{_rx}_queue (Petr Oros) [1690568]
- [net] xsk: remove unnecessary assignment (Petr Oros) [1690568]
- [net] xsk: fix return value of xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] xsk: don't allow umem replace at stack level (Petr Oros) [1690568]
- [net] xsk: refactor xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] update real_num_rx_queues even when !CONFIG_SYSFS (Petr Oros) [1690568]
- [net] core: add __netdev_sent_queue as variant of __netdev_tx_sent_queue (Petr Oros) [1690127]
- [net] net: do not abort bulk send on BQL status (Petr Oros) [1690129]
- [net] net: bql: add __netdev_tx_sent_queue() (Petr Oros) [1690129]
- [net] net: ip6_gre: fix possible NULL pointer dereference in ip6erspan_set_version (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: initialize erspan_ver just for erspan tunnels (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] net: ip_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] tcp: handle inet_csk_reqsk_queue_add() failures (Guillaume Nault) [1690157]
- [net] ip_gre: use erspan key field for tunnel lookup (Lorenzo Bianconi) [1664570]
- [net] ip6_gre: simplify gre header parsing in ip6gre_err (Lorenzo Bianconi) [1664570]
- [net] ipv4: use a dedicated counter for icmp_v4 redirect packets (Lorenzo Bianconi) [1664209]
- [net] virtchnl: Fix off by one error (Ivan Vecera) [1690114]
- [net] virtchnl: white space and reorder (Ivan Vecera) [1690114]
- [net] i40e: Update status codes (Ivan Vecera) [1690114]
- [net] ethtool: Add WAKE_FILTER and RX_CLS_FLOW_WAKE (Ivan Vecera) [1690091]
- [net] geneve: allow to clear ttl inherit (Hangbin Liu) [1671251]
- [net] geneve: add ttl inherit support (Hangbin Liu) [1671251]
- [net] tipc: fix a double kfree_skb() (Jon Maloy) [1684290]
- [net] vxlan: Fix GRO cells race condition between receive and link delete (Andrea Claudi) [1687046]
- [net] sock: consistent handling of extreme SO_SNDBUF/SO_RCVBUF values (Guillaume Nault) [1686564]
- [net] tun: implement carrier change (Guillaume Nault) [1686566]
- [net] ip6_tunnel: respect ttl inherit for ip6tnl (Hangbin Liu) [1664944]
- [net] ip6_gre: update version related info when changing link (Hangbin Liu) [1664900]
- [net] ipv4/route: fail early when inet dev is missing (Paolo Abeni) [1685424]
- [net] bonding/802.3ad: fix link_failure_count tracking (Matteo Croce) [1657905]
- [net] bonding: avoid possible dead-lock (Matteo Croce) [1657905]
- [net] bonding: fix length of actor system (Matteo Croce) [1657905]
- [net] bonding: fix warning message (Matteo Croce) [1657905]
- [net] bonding: pass link-local packets to bonding master also. (Matteo Croce) [1657905]

* Wed Apr 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.17.el8]
- [infiniband] IB/usnic: fix spelling mistake "unvalid" -> "invalid" (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Get rid of ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] RDMA/usnic: Do not use ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] infiniband: remove redundant condition check before debugfs_remove (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rdmavt: Fix rvt_create_ah function signature (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use core provided API for registering device attributes (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Remove unnecessary enum values (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move ruc_loopback to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move send completion logic to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move copy SGE logic into rdmavt (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rxe: Remove unused addr_same() (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid srq memory leak (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: replace kvfree with vfree (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/drivers: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] IB/rxe: fixes for rdma read retry (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid back-to-back retries (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Refactor lookup memory function (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Avoid NULL check when search is successful (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Change pool state enums to capital letters (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Replace spinlock with rwlock (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Simplify rxe_find_route() to avoid GID query for netdev (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: remove redudant qpn check (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: vary the source udp port for receive scaling (Jonathan Toppins) [1685307]
- [infiniband] iser: set sector for ambiguous mr status errors (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove try_module_get from backchannel (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove ->release_rqst call in bc reply handler (Jonathan Toppins) [1685307]
- [net] xprtrdma: Clean up xprt_rdma_disconnect_inject (Jonathan Toppins) [1685307]
- [net] xprtrdma: Add documenting comments (Jonathan Toppins) [1685307]
- [net] xprtrdma: Report when there were zero posted Receives (Jonathan Toppins) [1685307]
- [net] xprtrdma: Move rb_flags initialization (Jonathan Toppins) [1685307]
- [net] xprtrdma: Don't disable BH's in backchannel server (Jonathan Toppins) [1685307]
- [net] xprtrdma: Remove memory address of "ep" from an error message (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_qp_async_error_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Simplify RPC wake-ups on connect (Jonathan Toppins) [1685307]
- [net] xprtrdma: Re-organize the switch() in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Eliminate "connstate" variable from rpcrdma_conn_upcall() (Jonathan Toppins) [1685307]
- [net] xprtrdma: Conventional variable names in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] sunrpc: Report connect_time in seconds (Jonathan Toppins) [1685307]
- [net] sunrpc: Fix connect metrics (Jonathan Toppins) [1685307]
- [net] xprtrdma: Name MR trace events consistently (Jonathan Toppins) [1685307]
- [net] xprtrdma: Explicitly resetting MRs is no longer necessary (Jonathan Toppins) [1685307]
- [net] xprtrdma: Create more MRs at a time (Jonathan Toppins) [1685307]
- [net] xprtrdma: xprt_release_rqst_cong is called outside of transport_lock (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Log sysfs 'dev_id' accesses from userspace (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Use dev_port to expose network interface port numbers (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Ensure that MTU isn't less than minimum permitted (Jonathan Toppins) [1685307]
- [infiniband] IB/srp: Remove unnecessary unlikely() (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Fix oops in netdev_next_upper_dev_rcu() (Jonathan Toppins) [1685307]
- [infiniband] IB/umem: Set correct address to the invalidation function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Add GIDs while changing MAC addr only for registered ndev (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fix comment for hw stats init for port == 0 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refactor ib_register_device() function (Jonathan Toppins) [1685307]
- [infiniband] IB/mlx4: Refer to the device kobject instead of ports_parent (Jonathan Toppins) [1685307]
- [include] RDMA/core: Allow existing drivers to set one sysfs group per device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umad: Use kernel API to allocate umad indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use kernel API to allocate uverbs indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Increase total number of RDMA ports across all devices (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename ports_parent to ports_kobj (Jonathan Toppins) [1685307]
- [infiniband] RDMA/nldev: Allow IB device rename through RDMA netlink (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Implement IB device rename function (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Annotate timeout as unsigned long (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Align multiple functions to kernel coding style (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Remove unused timeout_ms parameter from cma_resolve_iw_route() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cm: Respect returned status of cm_init_av_by_path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Protect from reentry to resource return path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Release task struct which was hold by CM_ID object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Consolidate task name updates in one place (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Un-inline set task implementation (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Check error status of rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [include] IB/mlx4: Avoid implicit enumerated type conversion (Jonathan Toppins) [1685307]
- [infiniband] RDMA/netlink: Simplify netlink listener existence check (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Remove unused parameter from ib_modify_qp_is_ok() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix RCU annotation for radix slot deference (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Fix building with CONFIG_MMU=n (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_ib_acquire_dev() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_acquire_dev_by_src_ip() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Allow accepting requests for multi port rdma device (Jonathan Toppins) [1685307]
- [infiniband] IB/rdmavt: Rename check_send_wqe as setup_wqe (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Acquire and release mmap_sem on page range (Jonathan Toppins) [1685307]
- [infiniband] IB/sa: simplify return code logic for ib_nl_send_msg() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ulp: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA: Fully setup the device name in ib_register_device (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/umem: Fix potential addition overflow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Minor optimizations (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Avoid synchronize_srcu in the ODP MR destruction path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Handle a half-complete start/end sequence (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of per_mm->notifier_count (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use umem->owning_mm inside ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Move all the ODP related stuff out of ucontext and into per_mm (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of struct ib_umem.odp_data (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Make ib_umem_odp into a sub structure of ib_umem (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use ib_umem_odp in all function signatures connected to ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Do not use current->tgid to track the mm_struct (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Get rid of the old disassociate flow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Add a core API for mmaping driver IO memory (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix error unwind in ib_uverbs_add_one (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Properly return the error code of rdma_set_src_addr_rcu (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Remove is_closed from ib_uverbs_file (Jonathan Toppins) [1685307]
- [include] IB/rxe: Revise the ib_wr_opcode enum (Jonathan Toppins) [1685307]
- [include] RDMA: Remove duplicated include from ib_addr.h (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Consider net ns of gid attribute for RoCE (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce rdma_read_gid_attr_ndev_rcu() to check GID attribute (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Simplify roce_resolve_route_from_path() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Protect against changing dst->dev during destination resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refer to network type instead of device type (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use common code flow for IPv4/6 for addr resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename rdma_copy_addr to rdma_copy_src_l2_addr (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce and use rdma_set_src_addr() between IPv4 and IPv6 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Let protocol specific function typecast sockaddr structure (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Avoid unnecessary sa_family overwrite (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core Introduce and use rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Schedule multi RC/UC packets instead of posting (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Move flow resources initialization (Jonathan Toppins) [1685307]
- [infiniband] IB/uverbs: Add IDRs array attribute type to ioctl() interface (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document QP @event_handler function (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document CM @event_handler function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Assign device ifindex before publishing the device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Follow correct unregister order between sysfs and cgroup (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Restore lockdep check while downgrading lock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Define client_data_lock as rwlock instead of spinlock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simpler spin lock irq API from blocking context (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Remove context entries from list while unregistering device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simplified list_for_each (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: No need to protect kfree with spin lock and semaphore (Jonathan Toppins) [1685307]
- [infiniband] RDMA/{cma, core}: Avoid callback on rdma_addr_cancel() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rate limit MAD error messages (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fail early if unsupported QP is provided (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use device.groups to initialize device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use cdev_device_add() instead of cdev_add() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Depend on device_add() to add device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Replace open-coded variant of get_device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Declare closing variable as boolean (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Add an unbound WQ type to the new CQ API (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add UVERBS_ATTR_CONST_IN to the specs language (Jonathan Toppins) [1685307]
- [netdrv] ibmvnic: Fix completion structure initialization (Steve Best) [1697103]
- [rpmspec] redhat: limit headers_install_all to arches we care about (Denys Vlasenko) [1692404]
- [lib] ida: Add new API (Jonathan Toppins) [1697588]
- [edac] EDAC: Drop per-memory controller buses (Frank Ramsay) [1686477]
- [edac] EDAC: Don't add devices under /sys/bus/edac (Frank Ramsay) [1686477]
- [x86] x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls (Frank Ramsay) [1677695]

* Tue Apr 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.16.el8]
- [pci] PCI: pciehp: Fix re-enabling the slot marked for safe removal (Myron Stowe) [1695922]
- [rpmspec] redhat: Enable gdb_index (Juri Lelli) [1696747]
- [fs] ovl: Do not lose security.capability xattr over metadata file copy-up (Vivek Goyal) [1694757]
- [fs] ovl: During copy up, first copy up data and then xattrs (Vivek Goyal) [1694757]

* Mon Apr 15 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.15.el8]
- [netdrv] mark the intel igc driver as tech preview (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded hw_dbg prints (David Arcari) [1495358]
- [netdrv] igc: Fix the typo in igc_base.h header definition (David Arcari) [1495358]
- [netdrv] igc: Add support for the ntuple feature (David Arcari) [1495358]
- [netdrv] igc: Add support for statistics (David Arcari) [1495358]
- [netdrv] igc: Extend the ethtool supporting (David Arcari) [1495358]
- [netdrv] igc: Add multiple receive queues control supporting (David Arcari) [1495358]
- [netdrv] igc: Use struct_size() helper (David Arcari) [1495358]
- [netdrv] igc: Add ethtool support (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_get_phy_id_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_read_mac_addr_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded code (David Arcari) [1495358]
- [netdrv] igc: Remove unused code (David Arcari) [1495358]
- [netdrv] igc: Fix code redundancy (David Arcari) [1495358]
- [netdrv] igc: Remove unreachable code from igc_phy.c file (David Arcari) [1495358]
- [netdrv] igc: Remove obsolete IGC_ERR define (David Arcari) [1495358]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1495358]
- [netdrv] igc: Clean up code (David Arcari) [1495358]
- [netdrv] igc: Tidy up some white space (David Arcari) [1495358]
- [netdrv] igc: fix error return handling from call to netif_set_real_num_tx_queues (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variable 'pci_using_dac' (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variables 'ctrl_ext, link_mode' (David Arcari) [1495358]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (David Arcari) [1495358]
- [netdrv] igc: Add watchdog (David Arcari) [1495358]
- [netdrv] igc: Add setup link functionality (David Arcari) [1495358]
- [netdrv] igc: Add code for PHY support (David Arcari) [1495358]
- [netdrv] igc: Add NVM support (David Arcari) [1495358]
- [netdrv] igc: Add HW initialization code (David Arcari) [1495358]
- [netdrv] igc: Add transmit and receive fastpath and interrupt handlers (David Arcari) [1495358]
- [netdrv] igc: Add support for Tx/Rx rings (David Arcari) [1495358]
- [netdrv] igc: Add interrupt support (David Arcari) [1495358]
- [netdrv] igc: Add netdev (David Arcari) [1495358]
- [netdrv] igc: Add support for PF (David Arcari) [1495358]
- [netdrv] igc: Add skeletal frame for Intel(R) 2.5G Ethernet Controller support (David Arcari) [1495358]
- [s390] virtio-ccw: wire up ->bus_name callback (Cornelia Huck) [1695630]
- [s390] s390/virtio: handle find on invalid queue gracefully (Cornelia Huck) [1695630]
- [s390] virtio/s390: fix race in ccw_io_helper() (Cornelia Huck) [1695630]
- [s390] virtio/s390: avoid race on vcdev->config (Cornelia Huck) [1695630]
- [kvm] KVM: s390: make bitmap declaration consistent (Thomas Huth) [1695090]
- [kvm] KVM: s390: drop obsolete else path (Thomas Huth) [1695090]
- [kvm] KVM: s390: clarify kvm related kernel message (Thomas Huth) [1695090]
- [kvm] s390: vsie: Use effective CRYCBD.31 to check CRYCBD validity (Thomas Huth) [1695090]
- [kvm] KVM: s390: fix kmsg component kvm-s390 (Thomas Huth) [1695090]
- [kvm] KVM: s390: unregister debug feature on failing arch init (Thomas Huth) [1695090]
- [kvm] KVM: s390/vsie: avoid sparse warning (Thomas Huth) [1695090]

* Thu Apr 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.14.el8]
- [powerpc] powerpc: use mm zones more sensibly (David Gibson) [1654978]
- [s390] s390/mem_detect: add missing include (Philipp Rudo) [1695615]
- [s390] s390: avoid vmlinux segments overlap (Philipp Rudo) [1695615]
- [s390] s390/decompressor: add missing FORCE to build targets (Philipp Rudo) [1695615]
- [s390] s390: move ipl block and cmd line handling to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: introduce sclp_early_get_hsa_size (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: add info source debug print (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: replace tprot loop with binary search (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: use SCLP info for continuous memory detection (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce z/VM specific diag260 call (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce SCLP storage info (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section compile time validation (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: move tprot loop to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: move sclp_early_read_info to sclp_early_core.c (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: clean up and rename compressed/misc.c (Philipp Rudo) [1695615]
- [s390] s390: rescue initrd as early as possible (Philipp Rudo) [1695615]
- [s390] s390/sclp: simplify early hsa_size detection (Philipp Rudo) [1695615]
- [s390] s390/decompressor: get rid of .bss usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rework uncompressed image info collection (Philipp Rudo) [1695615]
- [s390] s390: remove decompressor's head.S (Philipp Rudo) [1695615]
- [s390] s390: clean up stacks setup (Philipp Rudo) [1695615]
- [s390] s390: add initial 64-bit restart PSW (Philipp Rudo) [1695615]
- [s390] s390/hibernate: fix error handling when suspend cpu != resume cpu (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support extra debug flags (Philipp Rudo) [1695615]
- [s390] s390/build: add *.o.chkbss files to targets list (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid packing *.o.chkbss files into startup.a (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid constant startup.a rebuilds (Philipp Rudo) [1695615]
- [s390] s390/boot: block uncompressed vmlinux booting attempts (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct EXCLUDE_FILE construct (Philipp Rudo) [1695615]
- [s390] s390: move _text to an actual .text start (Philipp Rudo) [1695615]
- [s390] s390: correct _stext offset (Philipp Rudo) [1695615]
- [s390] s390: get rid of the first mb of uncompressed image (Philipp Rudo) [1695615]
- [s390] s390: remove unused _ehead symbol (Philipp Rudo) [1695615]
- [s390] s390: put expoline execute-trampolines into .text section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: discard ___kcrctab section (Philipp Rudo) [1695615]
- [s390] s390/setup: do not reserve the decompressor code (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support uncompressed kernel (Philipp Rudo) [1695615]
- [init] init/Kconfig: add an option for uncompressed kernel (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow to pack uncompressed vmlinux.bin into piggy.o (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow preprocessor in piggy.o linker script (Philipp Rudo) [1695615]
- [s390] s390/decompressor: extend .bss check for early code (Philipp Rudo) [1695615]
- [s390] s390: add custom target and make path extension optional for .bss check (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid repeating objects list in Makefile (Philipp Rudo) [1695615]
- [s390] s390/decompressor: reuse lib/mem.S for mem functions (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid reusing uncompressed image objects (Philipp Rudo) [1695615]
- [s390] s390/als: avoid .init.* sections usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rename entry point to startup_decompressor (Philipp Rudo) [1695615]
- [s390] s390/boot: make head.S and als.c be part of the decompressor only (Philipp Rudo) [1695615]
- [s390] s390/decompressor: trim the kernel image up to 1M (Philipp Rudo) [1695615]
- [s390] s390: remove uncompressed kernel image build (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct build flags (Philipp Rudo) [1695615]
- [s390] s390/build: remove obsolete -mkernel-backchain flag (Philipp Rudo) [1695615]
- [tools] tools/power turbostat: return the exit status of a command (David Arcari) [1642739]
- [misc] misc: hpilo: Do not claim unsupported hardware (Joseph Szczypek) [1665635]
- [misc] misc: hpilo: Exclude unsupported device via blacklist (Joseph Szczypek) [1665635]

* Wed Apr 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.13.el8]
- [fs] xfs: set buffer ops when repair probes for btree type (Bill O'Donnell) [1689281]
- [fs] xfs: end sync buffer I/O properly on shutdown error (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_fsops: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_buf: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] iomap: fix a use after free in iomap_dio_rw (Bill O'Donnell) [1689281]
- [fs] xfs: reallocate realtime summary cache on growfs (Bill O'Donnell) [1689281]
- [fs] xfs: stringify scrub types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: stringify btree cursor types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_INODE_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_AG_BTREE_CMP_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: fix symbolic enum printing in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: fix function pointer type in ftrace format (Bill O'Donnell) [1689281]
- [fs] xfs: Fix x32 ioctls when cmd numbers differ from ia32. (Bill O'Donnell) [1689281]
- [fs] xfs: Fix bulkstat compat ioctls on x32 userspace. (Bill O'Donnell) [1689281]
- [fs] xfs: Align compat attrlist_by_handle with native implementation. (Bill O'Donnell) [1689281]
- [fs] xfs: require both realtime inodes to mount (Bill O'Donnell) [1689281]
- [fs] xfs: cache minimum realtime summary level (Bill O'Donnell) [1689281]
- [fs] xfs: count inode blocks correctly in inobt scrub (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate cluster alignment in inodes and blocks (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate inodes and blocks per inode cluster (Bill O'Donnell) [1689281]
- [fs] xfs: add a block to inode count converter (Bill O'Donnell) [1689281]
- [fs] xfs: remove xfs_rmap_ag_owner and friends (Bill O'Donnell) [1689281]
- [fs] xfs: const-ify xfs_owner_info arguments (Bill O'Donnell) [1689281]
- [fs] xfs: streamline defer op type handling (Bill O'Donnell) [1689281]
- [fs] xfs: idiotproof defer op type configuration (Bill O'Donnell) [1689281]
- [fs] xfs: clean up indentation issues, remove an unwanted space (Bill O'Donnell) [1689281]
- [fs] xfs: libxfs: move xfs_perag_put late (Bill O'Donnell) [1689281]
- [fs] xfs: split up the xfs_reflink_end_cow work into smaller transactions (Bill O'Donnell) [1689281]
- [crypto] crypto: testmgr - add AES-CFB tests (Neil Horman) [1687897]
- [scsi] scsi: iscsi: flush running unbind operations when removing a session (Maurizio Lombardi) [1695007]
- [crypto] crypto: vmx - fix copy-paste error in CTR mode (Herbert Xu) [1693350]
- [rpmspec] Fix cross builds (Jiri Olsa) [1694956]
- [lib] sbitmap: order READ/WRITE freed instance and setting clear bit (Ming Lei) [1694521]
- [block] blk-mq: fix sbitmap ws_active for shared tags (Ming Lei) [1694521]
- [block] blk-mq: update comment for blk_mq_hctx_has_pending() (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_put_driver_tag() to put tag (Ming Lei) [1694521]
- [include] sbitmap: trivial - update comment for sbitmap_deferred_clear_bit (Ming Lei) [1694521]
- [block] blkcg: Fix kernel-doc warnings (Ming Lei) [1694521]
- [block] block: Unexport blk_mq_add_to_requeue_list() (Ming Lei) [1694521]
- [block] block: add BLK_MQ_POLL_CLASSIC for hybrid poll and return EINVAL for unexpected value (Ming Lei) [1694521]
- [include] blk-mq: remove unused 'nr_expired' from blk_mq_hw_ctx (Ming Lei) [1694521]
- [block] loop: access lo_backing_file only when the loop device is Lo_bound (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_sched_mark_restart_hctx to set RESTART (Ming Lei) [1694521]
- [kernel] blkcg: annotate implicit fall through (Ming Lei) [1694521]
- [block] block: Replace function name in string with __func__ (Ming Lei) [1694521]
- [block] block: fix NULL pointer dereference in register_disk (Ming Lei) [1694521]
- [fs] fs: fix guard_bio_eod to check for real EOD errors (Ming Lei) [1694521]
- [block] blk-mq: use HCTX_TYPE_DEFAULT but not 0 to index blk_mq_tag_set->map (Ming Lei) [1694521]
- [include] block: remove bvec_iter_rewind() (Ming Lei) [1694521]
- [block] block: don't use bio->bi_vcnt to figure out segment number (Ming Lei) [1694521]
- [fs] btrfs: look at bi_size for repair decisions (Ming Lei) [1694521]
- [block] block: avoid setting none scheduler if it's already none (Ming Lei) [1694521]
- [block] block: avoid setting wbt_lat_usec to current value (Ming Lei) [1694521]
- [block] blk-sysfs: Rework documention of __blk_release_queue (Ming Lei) [1694521]
- [block] blk-cgroup: Fix doc related to blkcg_exit_queue (Ming Lei) [1694521]
- [block] block: kill QUEUE_FLAG_FLUSH_NQ (Ming Lei) [1694521]
- [block] block: avoid setting nr_requests to current value (Ming Lei) [1694521]
- [block] blk-mq: save default hctx into ctx->hctxs for not-supported type (Ming Lei) [1694521]
- [block] blk-mq: save queue mapping result into ctx directly (Ming Lei) [1694521]
- [block] block: mq-deadline: Fix write completion handling (Ming Lei) [1694521]
- [crypto] crypto: user - fix leaking uninitialized memory to userspace (Herbert Xu) [1657880] {CVE-2018-19854}
- [char] ipmi: fix sleep-in-atomic in free_user at cleanup SRCU user->release_barrier (Xiaojun Tan) [1689480]
- [infiniband] usnic_verbs: fix deadlock (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix locking when unregistering (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix potential deadlock (Govindarajulu Varadarajan) [1688505]
- [netdrv] net: hns3: fix improper error handling in the hclge_init_ae_dev() (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: fix netif_napi_del() not do problem when unloading (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Fix NULL deref when unloading driver (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Modify the order of initializing command queue register (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: remove the Redundant put_vector in hns3_client_uninit (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: reuse reinitialization interface in the hns3_set_channels (Xiaojun Tan) [1687060]

* Tue Apr 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.12.el8]
- [powercap] powercap/intel_rapl: add Ice Lake mobile (Steve Best) [1483427]
- [x86] x86/CPU: Add Icelake model number (Steve Best) [1483427]
- [watchdog] watchdog/hpwdt: Update Kconfig documentation (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Update driver version. (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Do not claim unsupported hardware (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Exclude via blacklist (Joseph Szczypek) [1664861]
- [fs] autofs: add strictexpire mount option (Ian Kent) [1672134]
- [fs] autofs: change catatonic setting to a bit flag (Ian Kent) [1672134]
- [fs] autofs: simplify parse_options() function call (Ian Kent) [1672134]
- [fs] autofs: add AUTOFS_EXP_FORCED flag (Ian Kent) [1672134]
- [fs] autofs: make expire flags usage consistent with v5 params (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_indirect() static (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_direct() static (Ian Kent) [1672134]
- [fs] autofs: fix clearing AUTOFS_EXP_LEAVES in autofs_expire_indirect() (Ian Kent) [1672134]
- [fs] autofs: fix inconsistent use of now variable (Ian Kent) [1672134]
- [md] md: Fix failed allocation of md_register_thread (Nigel Croxon) [1665346]
- [md] It's wrong to add len to sector_nr in raid10 reshape twice (Nigel Croxon) [1665346]
- [md] raid5: set write hint for PPL (Nigel Croxon) [1665346]
- [netdrv] amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs (Gary Hook) [1669565]

* Mon Apr 08 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.11.el8]
- [x86] x86/retpolines: Disable switch jump tables when retpolines are enabled (Waiman Long) [1688258]
- [x86] x86, retpolines: Raise limit for generating indirect calls from switch-case (Waiman Long) [1688258]
- [net] vsock/virtio: fix kernel panic from virtio_transport_reset_no_sock (Stefano Garzarella) [1676595]
- [net] vsock/virtio: reset connected sockets on device removal (Stefano Garzarella) [1676595]
- [net] vsock/virtio: fix kernel panic after device hot-unplug (Stefano Garzarella) [1676595]
- [powerpc] powerpc/livepatch: return -ERRNO values in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: small cleanups in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: relax reliable stack tracer checks for first-frame (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Make reliable stacktrace dependency clearer (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Clear on-stack exception marker upon exception return (Joe Lawrence) [1659856]
- [infiniband] iw_cxgb4: Support FW write completion WR (Arjun Vynipadath) [1671320]
- [infiniband] iw_cxgb4: RDMA write with immediate support (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: fix some info leaks (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: Add support for 64Byte cqes (Arjun Vynipadath) [1671320]
- [pci] pci: remove unused functionality (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] aacraid: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] be2iscsi: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] mpt3sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla2xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla4xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] megaraid_sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] lfpc: remove Lancer FCoE (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lpfc: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lfpc: add Lancer FCoE to the removed devices" (Tomas Henzl) [1622638]

* Fri Apr 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.10.el8]
- [kernel] printk: Export console_printk (Prarit Bhargava) [1642870]
- [video] fbcon: Silence fbcon logo on 'quiet' boots (Prarit Bhargava) [1642870]
- [scsi] scsi: ibmvscsi: Fix empty event pool access during host removal (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Protect ibmvscsi_head from concurrent modificaiton (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Improve strings handling (Steve Best) [1692463]
- [x86] x86/mce: Handle varying MCA bank counts (David Arcari) [1668779]
- [block] virtio_blk: add discard and write zeroes support (Stefano Garzarella) [1692939]
- [arm64] arm64: kaslr: ensure randomized quantities are clean also when kaslr is off (Mark Salter) [1673068]
- [arm64] arm64: kaslr: ensure randomized quantities are clean to the PoC (Mark Salter) [1673068]
- [tools] perf annotate: Fix getting source line failure (Michael Petlan) [1614435]
- [infiniband] IB/hfi1: Remove overly conservative VM_EXEC flag check (Alex Estrin) [1680018]

* Thu Apr 04 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.9.el8]
- [scsi] scsi: qla2xxx: Fix NULL pointer crash due to stale CPUID (Himanshu Madhani) [1685013]
- [scsi] scsi: core: Avoid that system resume triggers a kernel warning (Ewan Milne) [1691903]
- [scsi] scsi: core: reset host byte in DID_NEXUS_FAILURE case (Ewan Milne) [1691903]
- [scsi] scsi: core: Synchronize request queue PM status only on successful resume (Ewan Milne) [1691903]
- [scsi] scsi: sd: Fix cache_type_store() (Ewan Milne) [1691903]
- [scsi] scsi: sd: use mempool for discard special page (Ewan Milne) [1691903]
- [scsi] scsi: core: Remove scsi_block_when_processing_errors: message (Ewan Milne) [1691903]
- [scsi] scsi: core: Allow state transitions from OFFLINE to BLOCKED (Ewan Milne) [1691903]
- [scsi] scsi: core: remove unnecessary unlikely() (Ewan Milne) [1691903]
- [scsi] scsi: st: remove redundant pointer STbuffer (Ewan Milne) [1691903]
- [scsi] scsi: core: Avoid that SCSI device removal through sysfs triggers a deadlock (Ewan Milne) [1691903]
- [fs] scsi: sysfs: Introduce sysfs_{un,}break_active_protection() (Ewan Milne) [1691903]
- [scsi] scsi sg: remove incorrect scsi command checking logic (Ewan Milne) [1691903]
- [scsi] scsi: read host_busy via scsi_host_busy() (Ewan Milne) [1691903]
- [scsi] scsi: sd: Remove a superfluous assignment (Ewan Milne) [1691903]
- [scsi] scsi: don't add scsi command result bytes (Ewan Milne) [1691903]
- [scsi] scsi: core: check for equality of result byte values (Ewan Milne) [1691903]
- [scsi] scsi: scsi_transport_fc: use 64-bit timestamps consistently (Ewan Milne) [1691903]
- [scsi] scsi: sg: clean up gfp_mask in sg_build_indirect (Ewan Milne) [1691903]
- [scsi] scsi: core: remove Scsi_Cmnd typedef (Ewan Milne) [1691903]
- [netdrv] ibmvnic: Report actual backing device speed and duplex values (Steve Best) [1691862]
- [kernel] sched/fair: Fix O(nr_cgroups) in the load balancing path (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix insertion in rq->leaf_cfs_rq_list (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Add tmp_alone_branch assertion (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix infinite loop in update_blocked_averages() by reverting a9e7f6544b9c (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] tracing: Do a WARN_ON() if start_thread() in hwlat is called when thread exists (Jerome Marchand) [1693050]
- [kernel] ftrace: Add missing check for existing hwlat thread (Jerome Marchand) [1693050]
- [kernel] tracing: Do not call start/stop() functions when tracing_on does not change (Jerome Marchand) [1693050]

* Wed Apr 03 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.8.el8]
- [scsi] scsi: lpfc: Fixup eq_clr_intr references (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix build error (Dick Kennedy) [1692882]
- [scsi] scsi: be2iscsi: lpfc: fix typo (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.1 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update Copyright in driver version (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Enhance 6072 log string (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix duplicate log message numbers (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Specify node affinity for queue memory allocation (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Reduce memory footprint for lpfc_queue (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Add loopback testing to trunking mode (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix link speed reporting for 4-link trunk (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix handling of trunk links state reporting (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix protocol support on G6 and G7 adapters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct boot bios information to FDMI registration (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix HDMI2 registration string for symbolic name (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix fc4type information for FDMI (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix FDMI manufacturer attribute value (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix io lost on host resets (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix mailbox hang on adapter init (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix driver crash in target reset handler (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct localport timeout duration error (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: nvmet: avoid hang / use-after-free when destroying targetport (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Convert bootstrap mbx polling from msleep to udelay (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Coordinate adapter error handling with offline handling (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Stop adapter if pci errors detected (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix deadlock due to nested hbalock call (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet handling of first burst cmd (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix lpfc_nvmet_mrq attribute handling when 0 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet async receive buffer replenishment (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix location of SCSI ktime counters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix SLI3 commands being issued on SLI4 devices (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix use-after-free mailbox cmd completion (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve irq-unsafe lockdep heirarchy warning in lpfc_io_free (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve inconsistent check of hdwq in lpfc_scsi_cmd_iocb_cmpl (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error codes in lpfc_sli4_pci_mem_setup() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix 32-bit format string warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix unused variable warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: resolve static checker warning in lpfc_sli4_hba_unset (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct __lpfc_sli_issue_iocb_s4 lockdep check (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix calls to dma_set_mask_and_coherent() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: use dma_set_mask_and_coherent (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Remove set but not used variable 'phys_id' (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix a handful of indentation issues (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error code if kcalloc() fails (Dick Kennedy) [1692882]
- [security] security/selinux: fix SECURITY_LSM_NATIVE_LABELS on reused superblock (Ondrej Mosnacek) [1683296]
- [security] selinux: add the missing walk_size + len check in selinux_sctp_bind_connect (Ondrej Mosnacek) [1683296]
- [security] selinux: fix avc audit messages (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace BUG_ONs with WARN_ONs in avc.c (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: log invalid contexts in AVCs (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace some BUG_ON()s with a WARN_ON() (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: inline some AVC functions used only once (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: do not override context on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: never allow relabeling on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: stop passing MAY_NOT_BLOCK to the AVC upon follow_link (Ondrej Mosnacek) [1683296]
- [security] selinux: avoid silent denials in permissive mode under RCU walk (Ondrej Mosnacek) [1683296]
- [security] selinux: fix GPF on invalid policy (Ondrej Mosnacek) [1683296]
- [security] selinux: overhaul sidtab to fix bug and improve performance (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: use separate table for initial SID lookup (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: make "selinux_policycap_names[]" const char * (Ondrej Mosnacek) [1683296]
- [security] selinux: always allow mounting submounts (Ondrej Mosnacek) [1647723 1683296]
- [security] selinux: refactor sidtab conversion (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: fix non-MLS handling in mls_context_to_sid() (Ondrej Mosnacek) [1683296]
- [security] selinux: check length properly in SCTP bind hook (Ondrej Mosnacek) [1683296]
- [security] selinux: policydb - fix byte order and alignment issues (Ondrej Mosnacek) [1668222 1683296]
- [security] selinux: Add __GFP_NOWARN to allocation at str_read() (Ondrej Mosnacek) [1683296]
- [security] selinux: refactor mls_context_to_sid() and make it stricter (Ondrej Mosnacek) [1683296]
- [security] selinux: fix mounting of cgroup2 under older policies (Ondrej Mosnacek) [1683296]
- [security] selinux: cleanup dentry and inodes on error in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: constify write_op[] (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netnode (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avc (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netif (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netport (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in sidtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netlink (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in services (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in hooks (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in policydb (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in ebitmap (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in conditional (Ondrej Mosnacek) [1683296]
- [fs] fs/proc/kcore.c: fix invalid memory access in multi-page read optimization (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: add vmcoreinfo note to /proc/kcore (Bhupesh Sharma) [1627539]
- [kernel] crash_core: use VMCOREINFO_SYMBOL_ARRAY() for swapper_pg_dir (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: optimize multiple page reads (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: clean up ELF header generation (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: hold lock during read (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: fix memory hotplug vs multiple opens race (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: replace kclist_lock rwlock with rwsem (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for memory hotplug notifier (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for kclist_add() (Bhupesh Sharma) [1627539]

* Tue Apr 02 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.7.el8]
- [net] Merge branch 'linus/master' into rdma.git for-next (Jonathan Toppins) [1685304]
- [netdrv] net: cisco: enic: Replace GFP_ATOMIC with GFP_KERNEL (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Remove pointless functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/usnic: Suppress a compiler warning (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: usnic should not select INFINIBAND_USER_ACCESS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/vmw_pvrdma: Delete unused function (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: Update with bug fixes from core code (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Fix return value from create_srq callbacks (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rxe: Simplify the error handling code in rxe_create_ah() (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: avoid unnecessary NULL check (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: increase max MR limit (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Do not hide uABI stuff in memcpy (Jonathan Toppins) [1685304]
- [net] rpc: remove unneeded variable 'ret' in rdma_listen_handler (Jonathan Toppins) [1685304]
- [net] svcrdma: Clean up Read chunk path (Jonathan Toppins) [1685304]
- [net] svcrdma: Avoid releasing a page in svc_xprt_release() (Jonathan Toppins) [1685304]
- [net] sunrpc: remove redundant variables 'checksumlen', 'blocksize' and 'data' (Jonathan Toppins) [1685304]
- [scsi] scsi: target: srp, vscsi, sbp, qla: use target_remove_session (Jonathan Toppins) [1685304]
- [target] scsi: target: add session removal function (Jonathan Toppins) [1685304]
- [target] scsi: target: rename target_alloc_session (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix check for return code from ib_create_srq (Jonathan Toppins) [1685304]
- [infiniband] IB/ipoib: Fix error return code in ipoib_dev_init() (Jonathan Toppins) [1685304]
- [infiniband] IPoIB: use kvzalloc to allocate an array of bucket pointers (Jonathan Toppins) [1685304]
- [infiniband] ib_srpt: use kvmalloc to allocate ring pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix return code from ipoib_cm_dev_init (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Prefer unsigned int to bare use of unsigned (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Use min_t() macro instead of min() (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Remove driver version and release data information (Jonathan Toppins) [1685304]
- [target] scsi: target: Remove second argument from fabric_make_tpg() (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: set can_queue earlier to allow setting higher queue depth (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Set right entry state before releasing reference (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Free uapi on destroy (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Fix error cleanup path of ib_uverbs_add_one() (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Release object lock if destroy failed (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: fix UCM link error (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Change filter function return type from int to bool (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Update GID entries for netdevice whose mac address changes (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add default GIDs of the bond master netdev (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Consider adding default GIDs of bond device (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Delete lower netdevice default GID entries in bonding scenario (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Avoid confusing del_netdev_default_ips (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add comment for change upper netevent handling (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Fix compiling ucm.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not check for device disassociation during ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove struct uverbs_root_spec and all supporting code (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to unmarshal ioctl commands (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a simple allocator to uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove the ib_uverbs_attr pointer from each attr (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Provide implementation private memory for the uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to manage the object type inside the uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Build the specs into a radix tree at runtime (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Have the core code create the uverbs_root_spec (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix reading of 32 bit flags (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Initialize sgid request GID attribute pointer (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow all DESTROY commands to succeed after disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not block disassociate during write() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the write based methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Lower the test for ongoing disassociation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow uobject allocation to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow RDMA_REMOVE_DESTROY to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Convert 'bool exclusive' into an enum (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Consolidate uobject destruction (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Make the write path destroy methods use the same flow as ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove rdma_explicit_destroy() from the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Prefix _ib to IB/RoCE specific functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify gid type check in cma_acquire_dev() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Return bool instead of int (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Get rid of 1 bit boolean (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Constify path record, ib_cm_event, listen_id pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Constify dst_addr argument (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Simplify rdma_resolve_addr() error flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Initialize resource type in __rdma_create_id() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Check for verbs callbacks before using them (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove {create,destroy}_ah from mandatory verbs (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Jonathan Toppins) [1685304]
- [infiniband] RDMA, core and ULPs: Declare ib_post_send() and ib_post_recv() arguments const (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5, ib_post_send(), IB_WR_REG_SIG_MR: Do not modify the 'wr' argument (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Restore needed argument to ib_post_send (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvmet-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvme-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srpt: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/isert: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/IPoIB: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Constify the argument of the work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Inline two work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider netdevice for RoCE ports (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce and use sgid_attr in CM requests (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Remove extra parentheses (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix locking around struct ib_uverbs_file ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move the FD uobj type struct file allocation to alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Always propagate errors from rdma_alloc_commit_uobject() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Rework the locking for cleaning up the ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise and clarify the rwsem and uobjects_lock (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify and revise uverbs_close_fd (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise the placement of get/puts on uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify the kref'ing ordering for alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Handle IDR and FD types without truncation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Get rid of null_obj_type (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [include] IB/core: Allow ULPs to specify NULL as the third ib_post_(send|recv|srq_recv)() argument (Jonathan Toppins) [1685304]
- [include] IB/mlx5: Introduce driver create and destroy flow methods (Jonathan Toppins) [1685304]
- [infiniband] IB: Support ib_flow creation in drivers (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Move ib_access_flags and ib_read_counters_flags to uapi (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove cma_multicast->igmp_joined (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Refactor exit paths in ib_umem_get (Jonathan Toppins) [1685304]
- [infiniband] IB: Enable uverbs_destroy_def_handler to be used by drivers (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Pass IB_UVERBS_QPF_GRH_REQUIRED to user space (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Validate grh_required when handling AVs (Jonathan Toppins) [1685304]
- [infiniband] RDMA/hfi1: Move grh_required into update_sm_ah (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Simplify check for RoCE route resolve (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not use uverbs_cmd_mask in the ioctl path (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rw: Fix rdma_rw_ctx_signature_init() kernel-doc header (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove ib_find_cached_gid() and ib_find_cached_gid_by_port() (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove unused and erroneous msg sequence encoding (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucq_object uverbs_file with the one in ib_uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove ib_uobject_file (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Tidy up remaining references to ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace file->ucontext with file in uverbs_cmd.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucontext with ib_uverbs_file in core function calls (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move non driver related elements from ib_ucontext to ib_ufile (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a uobj_perform_destroy helper (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Combine MIN_SZ_OR_ZERO with UVERBS_ATTR_STRUCT (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Use UVERBS_ATTR_MIN_SIZE correctly and uniformly (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove UA_FLAGS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Get rid of the & in method specifications (Jonathan Toppins) [1685304]
- [infiniband] IB: Improve uverbs_cleanup_ucontext algorithm (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_OBJECT and _TREE family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify method definition macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_ATTR family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Split UVERBS_ATTR_FLOW_ACTION_ESP_HANDLE (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Store the specs_root in the struct ib_uverbs_device (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove now useless rcu_lock in dst_fetch_ha (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Check for rdma_protocol_ib only after validating port_num (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove redundant check (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Don't check for a negative return value of dma_map_sg_attrs() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of destroy_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of create_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Check existence of create_flow callback (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove unused ib cache functions (Jonathan Toppins) [1685304]
- [infiniband] Revert "[infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set" (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use the AH's sgid_attr in post_wr paths (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx4: Use GID attribute from ah attribute (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Use rdma GID API (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Use sgid_attr from the AV (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Replace members of sa_path_rec with 'struct sgid_attr *' (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Pass the sgid_attr through various events (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Keep track of the sgid_attr that created the cm id (Jonathan Toppins) [1685304]
- [infiniband] IB: Make init_ah_attr_grh_fields set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_from_mcmember set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_attr_from_wc set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Free GID table entry during GID deletion (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider net namespace while leaving multicast group (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Delete type and id from uverbs_obj_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/rdmavt, IB/hfi1: Create device dependent s_flags (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Expose ib_ucontext from a given ib_uverbs_file (Jonathan Toppins) [1685304]
- [include] IB/core: Introduce DECLARE_UVERBS_GLOBAL_METHODS (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow an empty namespace in ioctl() framework (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a macro to define a type with no kernel known size (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add PTR_IN attributes that are allocated/copied automatically (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Refactor uverbs_finalize_objects (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Export uverbs idr and fd types (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Use IDR for agent IDs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Hold the sgid_attr inside the struct ib_ah/qp (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use sgid_attr instead of sgid_index (Jonathan Toppins) [1685304]
- [infiniband] IB{cm, core}: Introduce and use ah_attr copy, move, replace APIs (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Tidy ib_resolve_eth_dmac (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add a sgid_attr pointer to struct rdma_ah_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Ensure that all rdma_ah_attr's are zero initialized (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Agent registration is process context only (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Refactor flow_resources_alloc() function (Jonathan Toppins) [1685304]
- [infiniband] RDMA/nldev: Return port capability flag for IB only (Jonathan Toppins) [1685304]
- [net] RDMA/smc: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [include] IB/cache: Restore compatibility for ib_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB: Replace ib_query_gid/ib_get_cached_gid with rdma_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Make rdma_find_gid_by_filter support all protocols (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Provide rdma_ versions of the gid cache API (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID attribute get, put and hold APIs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Use GID from the ib_gid_attr during the add_gid() callback (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID entry reference counts (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Store default GID property per-table instead of per-entry (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Do not set the gid type when reserving default entries (Jonathan Toppins) [1685304]
- [include] IDR: Expose the XArray lock (Jonathan Toppins) [1688319]
- [x86] x86/cpufeatures: Enumerate MOVDIR64B instruction (Steve Best) [1482754]
- [x86] x86/cpufeatures: Enumerate MOVDIRI instruction (Steve Best) [1482754]
- [nvme] nvme: allow ANA support to be independent of native multipathing (Ewan Milne) [1690940]
- [nvme] nvme: multipath: Change default of kernel NVMe multipath to be disabled (Ewan Milne) [1690940]
- [nvme] nvme: convert to SPDX identifiers (Ewan Milne) [1690940]
- [nvme] nvme-multipath: round-robin I/O policy (Ewan Milne) [1690940]
- [nvme] nvme-multipath: drop optimization for static ANA group IDs (Ewan Milne) [1690940]
- [nvme] nvme-multipath: zero out ANA log buffer (Ewan Milne) [1690940]
- [nvme] nvme-fc: fix numa_node when dev is null (Ewan Milne) [1690940]
- [nvme] nvme: add a numa_node field to struct nvme_ctrl (Ewan Milne) [1690940]
- [nvme] nvme: update node paths after adding new path (Ewan Milne) [1690940]
- [nvme] nvme: take node locality into account when selecting a path (Ewan Milne) [1690940]
- [s390] s390/mm: Fix ERROR: "__node_distance" undefined! (Ewan Milne) [1690940]
- [nvme] nvme: call nvme_complete_rq when nvmf_check_ready fails for mpath I/O (Ewan Milne) [1690940]
- [nvme] nvme: properly propagate errors in nvme_mpath_init (Ewan Milne) [1690940]
- [nvme] nvme: fixup crash on failed discovery (Ewan Milne) [1690940]
- [nvme] nvme: add ANA support (Ewan Milne) [1690940]
- [include] nvme.h: fixup ANA group descriptor format (Ewan Milne) [1690940]
- [include] nvme.h: add ANA definitions (Ewan Milne) [1690940]
- [nvme] nvme: remove nvme_req_needs_failover (Ewan Milne) [1690940]
- [nvme] nvme: simplify the API for getting log pages (Ewan Milne) [1690940]
- [include] nvme.h: add support for the log specific field (Ewan Milne) [1690940]

* Fri Mar 29 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.6.el8]
- [md] dm writecache: set "Tech Preview" taint using mark_tech_preview() (Mike Snitzer) [1690587]
- [md] dm integrity: limit the rate of error messages (Mike Snitzer) [1690105]
- [md] dm snapshot: don't define direct_access if we don't support it (Mike Snitzer) [1690105]
- [md] dm cache: add support for discard passdown to the origin device (Mike Snitzer) [1690105]
- [md] dm writecache: fix typo in name for writeback_wq (Mike Snitzer) [1690105]
- [md] dm thin: add sanity checks to thin-pool and external snapshot creation (Mike Snitzer) [1690105]
- [md] dm block manager: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm verity fec: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm integrity: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm switch: use struct_size() in kzalloc() (Mike Snitzer) [1690105]
- [md] dm: remove unused _rq_tio_cache and _rq_cache (Mike Snitzer) [1690105]
- [md] dm crypt: don't overallocate the integrity tag space (Mike Snitzer) [1690105]
- [md] dm: eliminate 'split_discard_bios' flag from DM target interface (Mike Snitzer) [1690105]
- [md] dm: always call blk_queue_split() in dm_process_bio() (Mike Snitzer) [1690105]
- [md] dm: update dm_process_bio() to split bio if in ->make_request_fn() (Mike Snitzer) [1690105]
- [md] dm rq: remove unused arguments from rq_completed() (Mike Snitzer) [1690105]
- [md] dm integrity: replace open-coded allocation size multiplication (Mike Snitzer) [1690105]
- [md] dm: Remove VLA usage from hashes (Mike Snitzer) [1690105]
- [crypto] crypto: hash - Remove VLA usage (Mike Snitzer) [1690105]
- [md] dm: Avoid namespace collision with bitmap API (Mike Snitzer) [1690105]
- [md] md/dm-writecache: Don't request pointer dummy_addr when not required (Mike Snitzer) [1690105]
- [scsi] scsi: qla2xxx: avoid printf format warning (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix issue reported by static checker for qla2x00_els_dcmd2_sp_done() (Himanshu Madhani) [1664534]
- [scsi] qla2xxx: Update driver version to 10.00.00.14.08.1-k (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue is not supported (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add new FW dump template entry types (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix code indentation for qla27xx_fwdt_entry (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move marker request behind QPair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent SysFS access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for setting port speed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent multiple ADISC commands per session (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for FW started flag before aborting (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix unload when NVMe devices are configured (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add First Burst support for FC-NVMe devices (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix LUN discovery if loop id is not assigned yet by firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove redundant null check on pointer sess (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move debug messages before sending srb preventing panic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use complete switch scan for RSCN events (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix fw options handle eh_bus_reset() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Restore FAWWPN of Physical Port only for loop down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent memory leak for CT req/rsp allocation (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix SRB allocation flag to avoid sleeping in IRQ context (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: allow session delete to finish before create. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix fcport null pointer access. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: flush IO on chip reset or sess delete (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session cleanup hang (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Change default ZIO threshold. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add pci function reset support. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N target discovery with Local loop (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: no need to check return value of debugfs_create functions (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix DMA error when the DIF sg buffer crosses 4GB boundary (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add protection mask module parameters (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for FC-NVMe discovery for NPIV port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NPIV handling for FC-NVMe (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Enable FC-NVME on NPIV ports (Himanshu Madhani) [1664534]
- [scsi] Revert "scsi: qla2xxx: Fix NVMe Target discovery" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: NULL check before some freeing functions is not needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Split the __qla2x00_abort_all_cmds() function (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Introduce a switch/case statement in qlt_xmit_tm_rsp() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix a typo in MODULE_PARM_DESC (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove two arguments from qlafx00_error_entry() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make sure that qlafx00_ioctl_iosb_entry() initializes 'res' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove a set-but-not-used variable (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make qla2x00_sysfs_write_nvram() easier to analyze (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Declare local functions 'static' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Improve several kernel-doc headers (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Modify fall-through annotations (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fully convert to the generic DMA API (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Simplify conditional check (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove unnecessary self assignment (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Return switch command on a timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move log messages before issuing command to firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for double free of SRB structure (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix recursive mailbox timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NVMe Target discovery (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: don't allow negative thresholds (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix comment in MODULE_PARM_DESC in qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove set but not used variable 'ptr_dma' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix typo "CT-PASSTRHU" -> "CT-PASSTHRU" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix double increment of switch scan retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix duplicate switch's Nport ID entries (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix premature command free (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reject bsg request if chip is down. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: shutdown chip if reset fail (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix stuck session in PLOGI state (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix early srb free on abort (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add mode control for each physical port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race condition for resource cleanup (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix dropped srb resource. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix port speed display on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Increase abort timeout value (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Allow FC-NVMe underrun to be handled by transport (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move ABTS code behind qpair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale ADISC_DONE event (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Remote port registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove ASYNC GIDPN switch command (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reduce holding sess_lock to prevent CPU lock-up (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move {get|rel}_sp to base_qpair struct (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for ZIO6 interrupt threshold (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix out of order Termination and ABTS response (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add logic to detect ABTS hang and response completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add appropriate debug info for invalid RX_ID (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix deadlock between ATIO and HW lock (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Serialize mailbox request (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Terminate Plogi/PRLI if WWN is 0 (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Defer chip reset until target mode is enabled (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove all rports if fabric scan retry fails (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Force fw cleanup on ADISC error (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Turn off IOCB timeout timer on IOCB completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Decrement login retry count for only plogi (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move rport registration out of internal work_list (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove redundant check for fcport deletion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Update rscn_rcvd field to more meaningful scan_needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use correct qpair for ABTS/CMD (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix process response queue for ISP26XX and above (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Migrate NVME N2N handling into state machine (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Save frame payload size from ICB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race between switch cmd completion and timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Management Server NPort handle reservation logic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Flush mailbox commands on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session state stuck in Get Port DB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix redundant fc_rport registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Silent erroneous message (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent sysfs access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add longer window for chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix login retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N link re-connect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Cleanup for N2N code (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove irq save in qla2x00_poll() (Himanshu Madhani) [1664534]
- [netdrv] ice: Do autoneg based on VSI state (Jonathan Toppins) [1687903]
- [fs] xfs: use the latest extent at writeback delalloc conversion time (Brian Foster) [1661968]
- [fs] xfs: create delalloc bmapi wrapper for full extent allocation (Brian Foster) [1661968]
- [fs] xfs: remove superfluous writeback mapping eof trimming (Brian Foster) [1661968]
- [fs] xfs: validate writeback mapping using data fork seq counter (Brian Foster) [1661968]
- [fs] xfs: update fork seq counter on data fork changes (Brian Foster) [1661968]
- [fs] xfs: eof trim writeback mapping as soon as it is cached (Brian Foster) [1661968]
- [perf] drivers/perf: hisi: update the sccl_id/ccl_id when MT is supported (Xiaojun Tan) [1677815]

* Tue Mar 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.5.el8]
- [x86] x86/hyperv: Fix kernel panic when kexec on HyperV (Kairui Song) [1684451]
- [rpmspec] apply linux-kernel-test.patch when building ("Herton R. Krzesinski") [1690534]
- [netdrv] net: ena: update driver version from 2.0.2 to 2.0.3 (John Linville) [1690106]
- [netdrv] net: ena: fix race between link up and device initalization (John Linville) [1690106]
- [netdrv] net: phy: add phy_speed_down and phy_speed_up (Petr Oros) [1690131]
- [netdrv] net: phy: add helper phy_config_aneg (Petr Oros) [1690131]
- [nvme] nvme-fabrics: convert to SPDX identifiers (Ewan Milne) [1690909]
- [nvme] nvme-fabrics: fix ctrl_loss_tmo < 0 to reconnect forever (Ewan Milne) [1690909]
- [nvme] nvme-fc: reject reconnect if io queue count is reduced to zero (Ewan Milne) [1690601]
- [nvme] nvme-fc: use nr_phys_segments to determine existence of sgl (Ewan Milne) [1690601]
- [include] nvme-fc: convert to SPDX identifiers (Ewan Milne) [1690601]
- [nvme] nvme-fc: initialize nvme_req(rq)->ctrl after calling __nvme_fc_init_request() (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix request private initialization (Ewan Milne) [1690601]
- [nvme] nvme-fc: rework the request initialization code (Ewan Milne) [1690601]
- [nvme] nvme-fc: introduce struct nvme_fcp_op_w_sgl (Ewan Milne) [1690601]
- [nvme] nvme: cache struct nvme_ctrl reference to struct nvme_request (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix kernel-doc headers (Ewan Milne) [1690601]
- [nvme] nvme_fc: add 'nvme_discovery' sysfs attribute to fc transport device (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix for a minor typos (Ewan Milne) [1690601]
- [crypto] crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling (Neil Horman) [1689185]
- [mm] mm: enforce min addr even if capable() in expand_downwards() (Rafael Aquini) [1687667] {CVE-2019-9213}
- [pci] PCI/VMD: Configure MPS settings before adding devices (Prarit Bhargava) [1659270]
- [pci] PCI: vmd: Detach resources after stopping root bus (Prarit Bhargava) [1659270]
- [char] tpm: separate cmd_ready/go_idle from runtime_pm (Jerry Snitselaar) [1677735]
- [block] loop: set GENHD_FL_NO_PART_SCAN after blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: do not print warn message if partition scan is successful (Ming Lei) [1683593]
- [block] loop: drop caches if offset or block_size are changed (Ming Lei) [1683593]
- [block] block: loop: remove redundant code (Ming Lei) [1683593]
- [block] block: loop: check error using IS_ERR instead of IS_ERR_OR_NULL in loop_add() (Ming Lei) [1683593]
- [block] loop: Fix double mutex_unlock(&loop_ctl_mutex) in loop_control_ioctl() (Ming Lei) [1683593]
- [block] loop: Get rid of 'nested' acquisition of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Avoid circular locking dependency between loop_ctl_mutex and bd_mutex (Ming Lei) [1683593]
- [block] loop: Fix deadlock when calling blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: Move loop_reread_partitions() out of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Move special partition reread handling in loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_change_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_get_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down into loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Split setting of lo_state from loop_clr_fd (Ming Lei) [1683593]
- [block] loop: Push lo_ctl_mutex down into individual ioctls (Ming Lei) [1683593]
- [block] loop: Get rid of loop_index_mutex (Ming Lei) [1683593]
- [block] loop: Fold __loop_release into loop_release (Ming Lei) [1683593]
- [block] block/loop: Use global lock for ioctl() operation. (Ming Lei) [1683593]
- [block] block/loop: Don't grab "struct file" for vfs_getattr() operation. (Ming Lei) [1683593]
- [crypto] crypto: cfb - fix decryption (Herbert Xu) [1653188]

* Fri Mar 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.4.el8]
- [misc] VMCI: Support upto 64-bit PPNs (Cathy Avery) [1683479]
- [mm] mm, page_alloc: fix has_unmovable_pages for HugePages (David Gibson) [1688114]
- [pci] PCI: pciehp: Disable Data Link Layer State Changed event on suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Assign ctrl->slot_ctrl before writing it to hardware (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Queue one GHES event, not several uninitialized ones (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Refactor error injection fallbacks (Myron Stowe) [1688393]
- [pci] PCI/AER: Reuse existing pcie_port_find_device() interface (Myron Stowe) [1688393]
- [pci] PCI/AER: Use managed resource allocations (Myron Stowe) [1688393]
- [pci] PCI/AER: Use threaded IRQ for bottom half (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo_in_spinlocked() to insert locked elements (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo for tracking events instead of reimplementing it (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove error source from AER struct aer_rpc (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove unused aer_error_resume() (Myron Stowe) [1688393]
- [pci] PCI: pnv_php: Use kmemdup() (Myron Stowe) [1688393]
- [pci] PCI: cpqphp: Remove set but not used variable 'physical_slot' (Myron Stowe) [1688393]
- [pci] PCI/ERR: Remove duplicated include from err.c (Myron Stowe) [1688393]
- [pci] PCI: Equalize hotplug memory and io for occupied and empty slots (Myron Stowe) [1688393]
- [pci] PCI / ACPI: Whitelist D3 for more PCIe hotplug ports (Myron Stowe) [1688393 1537397]
- [acpi] ACPI / property: Allow multiple property compatible _DSD entries (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Implement runtime PM callbacks (Myron Stowe) [1688393 1537397]
- [pci] PCI/portdrv: Resume upon exit from system suspend if left runtime suspended (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Do not handle events if interrupts are masked (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Disable hotplug interrupt during suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI / ACPI: Enable wake automatically for power managed bridges (Myron Stowe) [1688393 1537397]
- [pci] PCI: Do not skip power-managed bridges in pci_enable_wake() (Myron Stowe) [1688393 1537397]
- [pci] PCI: Unify device inaccessible (Myron Stowe) [1688393]
- [pci] PCI/ERR: Always report current recovery status for udev (Myron Stowe) [1688393]
- [pci] PCI/ERR: Simplify broadcast callouts (Myron Stowe) [1688393]
- [pci] PCI/ERR: Run error recovery callbacks for all affected devices (Myron Stowe) [1688393]
- [pci] PCI/ERR: Handle fatal error recovery (Myron Stowe) [1688393]
- [pci] PCI/ERR: Use slot reset if available (Myron Stowe) [1688393]
- [pci] PCI/AER: Don't read upstream ports below fatal errors (Myron Stowe) [1688393]
- [pci] PCI/AER: Take reference on error devices (Myron Stowe) [1688393]
- [pci] PCI/DPC: Save and restore config state (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Restore PCI config state on slot reset (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Initialize service drivers directly (Myron Stowe) [1688393]
- [x86] x86/intel_rdt: Show missing resctrl mount options (David Arcari) [1689043]
- [xen] xen/balloon: Fix mapping PG_offline pages to user space (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: exclude all PageOffline() pages (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: use pfn_to_online_page() (David Hildenbrand) [1652790]
- [hv] hv_balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [xen] xen/balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [kernel] kexec: export PG_offline to VMCOREINFO (David Hildenbrand) [1652790]
- [include] mm: convert PG_balloon to PG_offline (David Hildenbrand) [1652790]
- [include] mm: balloon: update comment about isolation/migration/compaction (David Hildenbrand) [1652790]
- [mm] mm/page_alloc.c: memory hotplug: free pages as higher order (David Hildenbrand) [1652790]
- [mm] mm/memory.c: do_fault: avoid usage of stale vm_area_struct ("Herton R. Krzesinski") [1684734]
- [kernel] cpuset: remove unused task_has_mempolicy() (Waiman Long) [1548268]
- [kernel] cpuset: Remove set but not used variable 'cs' (Waiman Long) [1548268]
- [kernel] cgroup: Add .__DEBUG__. prefix to debug file names (Waiman Long) [1548268]
- [kernel] cpuset: Minor cgroup2 interface updates (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpuset.cpus.subpartitions with cgroup_debug (Waiman Long) [1548268]
- [documentation] cpuset: Add documentation about the new "cpuset.sched.partition" flag (Waiman Long) [1548268]
- [kernel] cpuset: Use descriptive text when reading/writing cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpus.effective and mems.effective on cgroup v2 root (Waiman Long) [1548268]
- [kernel] cpuset: Make generate_sched_domains() work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Make CPU hotplug work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Track cpusets that use parent's effective_cpus (Waiman Long) [1548268]
- [kernel] cpuset: Add an error state to cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Add new v2 cpuset.sched.partition flag (Waiman Long) [1548268]
- [kernel] cpuset: Simply allocation and freeing of cpumasks (Waiman Long) [1548268]
- [kernel] cpuset: Define data structures to support scheduling partition (Waiman Long) [1548268]
- [kernel] cpuset: Enable cpuset controller in default hierarchy (Waiman Long) [1548268]
- [kernel] cgroup/tracing: Move taking of spin lock out of trace event handlers (Waiman Long) [1548268]
- [powerpc] powerpc/powernv/ioda: Fix locked_vm counting for memory used by IOMMU tables (David Gibson) [1674410]
- [pci] PCI: dwc: Fix MSI-X EP framework address calculation bug (Myron Stowe) [1687935]
- [pci] PCI: cadence: Correct probe behaviour when failing to get PHY (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix PCI I/O mapping creation sequence (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Remove obsolete drivers/pci pattern from ACPI section (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix scheduling while atomic issues (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Move mobiveil PCI driver entry where it belongs (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Update PPC contacts for PCI core error handling (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add Gustavo Pimentel as DesignWare PCI maintainer (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add entries for PPC64 RPA PCI hotplug drivers (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Drop bogus comment above mvebu_pcie_map_registers() (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Convert to use pci_host_bridge directly (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Use resource_size() to remap I/O space (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Only remap I/O space if configured (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix I/O space end address calculation (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Remove redundant platform_set_drvdata() call (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add Kconfig/Makefile entries (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add missing ../pci.h include (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Fix struct mobiveil_pcie.pcie_reg_base address type (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI set maximum restriction (Myron Stowe) [1687935]
- [tools] tools: PCI: Add MSI-X support (Myron Stowe) [1687935]
- [documentation] pci_endpoint_test: Add 2 ioctl commands (Myron Stowe) [1687935]
- [documentation] pci-epf-test/pci_endpoint_test: Add MSI-X support (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Use irq_type module parameter (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Cleanup PCI_ENDPOINT_TEST memspace (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add legacy interrupt callback handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Rework MSI callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add MSI-X callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: Update xxx_pcie_ep_raise_irq() and pci_epc_raise_irq() signatures (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI-X interfaces (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix EP link notification implementation (Myron Stowe) [1687935]
- [pci] PCI: spear13xx: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: qcom: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: histb: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: designware-plat: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: artpec6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: armada8k: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: keystone: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: imx6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: exynos: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: kirin: Add MSI support (Myron Stowe) [1687935]
- [pci] PCI: pcie-cadence-ep: Remove redundant variable mmc (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add shutdown callback to host driver (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add Power Management ops for host and EP (Myron Stowe) [1687935]
- [documentation] dt-bindings: PCI: cadence: Add DT bindings for optional PHYs (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add generic PHY support to host and EP drivers (Myron Stowe) [1687935]
- [pci] PCI: cadence: Update cdns_pcie_writel() function signature (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Convert to use pci_host_probe() (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Size bridges before resources allocation (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Remove PCIe outbound window configuration (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Introduce an advk_pcie_valid_device() helper (Myron Stowe) [1687935]
- [pci] PCI/xilinx: Depend on OF instead of the ARCH (Myron Stowe) [1687935]
- [md] md: convert to kvmalloc (Nigel Croxon) [1661200]
- [md] raid1: simplify raid1_error function (Nigel Croxon) [1661200]
- [md] md-linear: use struct_size() in kzalloc() (Nigel Croxon) [1661200]
- [md] md/raid5: fix 'out of memory' during raid cache recovery (Nigel Croxon) [1661200]
- [md] md: Make bio_alloc_mddev use bio_alloc_bioset (Nigel Croxon) [1661200]
- [md] raid10: refactor common wait code from regular read/write request (Nigel Croxon) [1661200]
- [md] md: remvoe redundant condition check (Nigel Croxon) [1661200]
- [lib] lib/raid6: add option to skip algo benchmarking (Nigel Croxon) [1661200]
- [include] lib/raid6: avoid __attribute_const__ redefinition (Nigel Croxon) [1661200]
- [include] lib/raid6: add missing include for raid6test (Nigel Croxon) [1661200]
- [md] md: remove set but not used variable 'bi_rdev' (Nigel Croxon) [1661200]
- [md] MD: Memory leak when flush bio size is zero (Nigel Croxon) [1661200]
- [md] md: fix memleak for mempool (Nigel Croxon) [1661200]
- [md] md-cluster: remove suspend_info (Nigel Croxon) [1661200]
- [md] md-cluster: send BITMAP_NEEDS_SYNC message if reshaping is interrupted (Nigel Croxon) [1661200]
- [md] md-cluster/bitmap: don't call md_bitmap_sync_with_cluster during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: don't call remove_and_add_spares during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: call update_size in md_reap_sync_thread (Nigel Croxon) [1661200]
- [md] md-cluster: introduce resync_info_get interface for sanity check (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: support add disk under grow mode (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: resize all the bitmaps before start reshape (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk - try2 (Nigel Croxon) [1661200]
- [md] md/bitmap: use mddev_suspend/resume instead of ->quiesce() (Nigel Croxon) [1661200]
- [md] md: remove redundant code that is no longer reachable (Nigel Croxon) [1661200]
- [md] md: allow metadata updates while suspending an array - fix (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk (Nigel Croxon) [1661200]
- [md] md/raid10: Fix raid10 replace hang when new added disk faulty (Nigel Croxon) [1661200]
- [md] raid5: block failing device if raid will be failed (Nigel Croxon) [1661200]
- [md] md-cluster: release RESYNC lock after the last resync message (Nigel Croxon) [1661200]
- [md] RAID10 BUG_ON in raise_barrier when force is true and conf->barrier is 0 (Nigel Croxon) [1661200]
- [md] md/raid5-cache: disable reshape completely (Nigel Croxon) [1661200]
- [md] md/raid5: fix data corruption of replacements after originals dropped (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Do not disable irq on release_inactive_stripe_list() call (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Use irqsave variant of atomic_dec_and_lock() (Nigel Croxon) [1661200]
- [md] md/r5cache: remove redundant pointer bio (Nigel Croxon) [1661200]
- [md] md-cluster: don't send msg if array is closing (Nigel Croxon) [1661200]
- [md] md-cluster: show array's status more accurate (Nigel Croxon) [1661200]
- [md] md-cluster: clear another node's suspend_area after the copy is finished (Nigel Croxon) [1661200]
- [powerpc] KVM: PPC: Book3S HV: Add KVM stat largepages_[2M/1G] (Suraj Jitindar Singh) [1581563]
- [tools] perf mem/c2c: Fix perf_mem_events to support powerpc (Steve Best) [1685084]
- [powerpc] powerpc/perf: Add mem access events to sysfs (Steve Best) [1685084]
- [netdrv] net-next/hinic: replace disable_irq_nosync/enable_irq (Xiaojun Tan) [1668958]
- [powerpc] Fix access_ok() fallout for sparc32 and powerpc (Joe Lawrence) [1673980]
- [x86] Remove 'type' argument from access_ok() function (Joe Lawrence) [1673980]
- [arm64] arm64: move untagged_addr macro from uaccess.h to memory.h (Joe Lawrence) [1673980]
- [powerpc] powerpc/uaccess: fix warning/error with access_ok() (Joe Lawrence) [1673980]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]

* Sun Mar 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.3.el8]
- [rpmspec] redhat: speed up binary rpm compression (Denys Vlasenko) [1686921]
- [netdrv] net/mlx5e: RX, Verify MPWQE stride size is in range (Alaa Hleihel) [1683589]
- [fs] debugfs: Fix EPERM regression from kernel lockdown check (Lenny Szubowicz) [1686755]
- [infiniband] IB/hfi1: Close race condition on user context disable and close (Alex Estrin) [1682927]
- [rpmspec] redhat: parallelize modules compression (Denys Vlasenko) [1686404]
- [arm64] arm64: Add workaround for Fujitsu A64FX erratum 010001 (Mark Langsdorf) [1666951]
- [s390] vfio_ap: link the vfio_ap devices to the vfio_ap bus subsystem (Cornelia Huck) [1686044]
- [drm] drm/cirrus: fix connector leak at unload (Rob Clark) [1685773]
- [powerpc] powerpc/hugetlb: Handle mmap_min_addr correctly in get_unmapped_area callback (Steve Best) [1685181]
- [netdrv] net/mlx4_en: Force CHECKSUM_NONE for short ethernet frames (Alaa Hleihel) [1663914 1651509]
- [netdrv] net/mlx5e: Force CHECKSUM_UNNECESSARY for short ethernet frames (Alaa Hleihel) [1651509]
- [include] Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso) [1670118]

* Thu Mar 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.2.el8]
- [x86] x86/tsc: Make calibration refinement more robust (David Arcari) [1686254]
- [powerpc] powerpc/hugetlb: Don't do runtime allocation of 16G pages in LPAR configuration (Steve Best) [1686756]
- [rpmspec] parallelize "make mrproper" (Denys Vlasenko) [1686865]
- [rpmspec] use "make -jN" (via _smp_mflags) for modules_install (Denys Vlasenko) [1686308]
- [fs] xfs: zero length symlinks are not valid (Carlos Maiolino) [1589618]
- [drm] drm/bufs: Fix Spectre v1 vulnerability (Rob Clark) [1663467]
- [drm] drm/ioctl: Fix Spectre v1 vulnerabilities (Rob Clark) [1663467]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.0 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update 12.2.0.0 file copyrights to 2019 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix nvmet issues when link bounce under IO load (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct upcalling nvmet_fc transport during io done downcall (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix default driver parameter collision for allowing NPIV support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework locking on SCSI io completion (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Enable SCSI and NVME fc4s by default (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Resize cpu maps structures based on possible cpus (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Utilize new IRQ API when allocating MSI-X vectors (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework EQ/CQ processing to address interrupt coalescing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: convert eq_delay to usdelay (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Support non-uniform allocation of MSIX vectors to hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix setting affinity hints to correlate with hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Allow override of hardware queue selection policies (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt partitioned XRI lists to efficient sharing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize hardware queues with SCSI MQ interface (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Convert ring number to hardware queue for nvme wqe posting. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Move SCSI and NVME Stats to hardware queue structures (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt cpucheck debugfs logic to Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove unused FCP_XRI_ABORT_EVENT slowpath event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Partition XRI buffer list across Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Replace io_channels for nvme and fcp with general hdw_queues per cpu (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove extra vector and SLI4 queue for Expresslane (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement common IO buffers between NVME and SCSI (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove excess check on NVME io submit code path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: remove nrport from nvme command structure (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: no need to check return value of debugfs_create functions (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update lpfc version to 12.0.0.10 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adding ability to reset chip via pci bus reset (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Add log messages to aid in debugging fc4type discovery issues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix discovery failure when PLOGI is defered (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update fault value on successful trunk events. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct MDS loopback diagnostics support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix link state reporting for trunking when adapter is offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: do not set queue->page_count to 0 if pc_sli4_params.wqpcnt is invalid (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.9 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix dif and first burst use in write commands (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix driver release of fw-logging buffers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct topology type reporting on G7 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct code setting non existent bits in sli4 ABORT WQE (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Defer LS_ACC to FLOGI on point to point logins (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: ls_rjt erroneus FLOGIs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Cap NPIV vports to 256 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix kernel Oops due to null pring pointers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix a duplicate 0711 log message number. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix panic when FW-log buffsize is not initialized (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix block guard enablement on SLI3 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Use dma_zalloc_coherent (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.8 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add Trunking support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement GID_PT on Nameserver query to support faster failover (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix odd recovery in duplicate FLOGIs in point-to-point (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct LCB RJT handling (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fcoe: Fix link down issue after 1000+ link bounces (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct errors accessing fw log (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Reset link or adapter instead of doing infinite nameserver PLOGI retry (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS Timeout event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix lpfc_sli4_read_config return value check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct speeds on SFP swap (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix remoteport access (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'tgtp' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'psli' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'fc_hdr' and 'hw_page_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix spelling mistake "Resrouce" -> "Resource" (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove a bogus pci_dma_sync_single_for_device call (Dick Kennedy) [1665288]
- [netdrv] PCI/AER: Remove pci_cleanup_aer_uncorrect_error_status() calls (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize access to remoteport via rport (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'sgl_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.7 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add support to retrieve firmware logs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: reduce locking when updating statistics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix errors in log messages. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct invalid EQ doorbell write on if_type=6 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct irq handling via locks when taking adapter offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct soft lockup when running mds diagnostics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct race with abort on completion path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Raise nvme defaults to support a larger io and more connectivity (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: raise sg count for nvme to use available sg resources (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix GFT_ID and PRLI logic for RSCN (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove an unnecessary NULL check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Default fdmi_on to on (Dick Kennedy) [1665288]
- [powerpc] powerpc/mm/hash: Increase vmalloc space with hash translation mode (Steve Best) [1676974]
- [net] sunrpc: fix 4 more call sites that were using stack memory with a scatterlist (Scott Mayhew) [1679183]
- [net] sunrpc: Don't use stack buffer with scatterlist (Scott Mayhew) [1679183]
- [powerpc] powerpc/pseries: Perform full re-add of CPU for topology update post-migration (Steve Best) [1678209]
- [fs] proc/stat: Make the interrupt statistics more efficient (Waiman Long) [1675168]
- [kernel] genirq: Avoid summation loops for /proc/stat (Waiman Long) [1675168]
- [powerpc] powerpc/pseries: fix EEH recovery of some IOV devices (Steve Best) [1676889]
- [block] nvme: lock NS list changes while handling command effects (David Milburn) [1672759]
- [powerpc] powerpc/radix: Fix kernel crash with mremap() (Steve Best) [1674186]
- [crypto] crypto: ccp - fix the SEV probe in kexec boot path (Gary Hook) [1658806]
- [netdrv] HDLC Frame Relay: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] DLCI: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] ethoc: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dnet: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dl2k: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] mark qla3xxx driver as unsupported (John Linville) [1658840]
- [netdrv] sfc: initialise found bitmap in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: suppress duplicate nvmem partition types in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: extend MTD support for newer hardware (Jarod Wilson) [1668656]
- [netdrv] sfc: add missing NVRAM partition types for EF10 (Jarod Wilson) [1668656]
- [netdrv] ibmvnic: Fix non-atomic memory allocation in IRQ context (Steve Best) [1671474]
- [netdrv] ibmvnic: Convert reset work item mutex to spin lock (Steve Best) [1671474]
- [powerpc] powerpc/pseries: Export raw per-CPU VPA data via debugfs (Steve Best) [1608797]
- [powerpc] powerpc/pseries: Export maximum memory value (Steve Best) [1608797]
- [netdrv] ibmveth: Do not process frames after calling napi_reschedule (Desnes Augusto Nunes do Rosario) [1635577]
- [cpufreq] cpufreq: powernv: Remove global pstate ramp-down timer in POWER9 (Steve Best) [1670030]
- [of] of: __of_detach_node() - remove node from phandle cache (Steve Best) [1669198]
- [of] of: of_node_get()/of_node_put() nodes held in phandle cache (Steve Best) [1669198]
- [edac] EDAC, sb_edac: Fix signedness bugs in *_get_ha() functions (Aristeu Rozanski) [1641574]
- [edac] EDAC, sb_edac: Fix reporting for patrol scrubber errors (Aristeu Rozanski) [1641574]
- [documentation] proc.txt: Adding 'HardwareCorrupted' field and description. (Prashant Dhamdhere) [1658233]
- [netdrv] qed: Fix command number mismatch between driver and the mfw (Chad Dupuis) [1663500]
- Revert "[redhat] switch secureboot kernel image signing to release keys" ("Herton R. Krzesinski")

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.1.el8]
- [arm64] revert "arm64: tlb: Avoid synchronous TLBIs when freeing page tables" (Christoph von Recklinghausen) [1685697]

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-79.1.el8]
- [firmware] drivers/firmware: psci_checker: stash and use topology_core_cpumask for hotplug tests (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: re-introduce numa mask check for scheduler MC selection (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: rename llc_siblings to align with other struct members (Josh Poimboeuf) [1687101]
- [arm64] arm64: smp: remove cpu and numa topology information when hotplugging out CPU (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: restrict updating siblings_masks to online cpus only (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: add support to remove cpu topology sibling masks (Josh Poimboeuf) [1687101]
- [arm64] arm64: numa: separate out updates to percpu nodeid and NUMA node cpumap (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: refactor reset_cpu_topology to add support for removing topology (Josh Poimboeuf) [1687101]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-78.1.el8]
- [fs] gfs2: Fix missed wakeups in find_insert_glock (Andreas Grunbacher) [1678907]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-77.1.el8]
- [firmware] efi: Reduce the amount of memblock reservations for persistent allocations (Bhupesh Sharma) [1682988]
- [firmware] efi: Permit multiple entries in persistent memreserve data structure (Bhupesh Sharma) [1682988]
- [kernel] cpu/hotplug: Create SMT sysfs interface for all arches (Josh Poimboeuf) [1686068]
- [net] netfilter: nft_set_hash: bogus element self comparison from deactivation path (Florian Westphal) [1678574]
- [net] netfilter: nft_set_hash: fix lookups with fixed size hash on big endian (Florian Westphal) [1678574]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-76.1.el8]
- [security] revert "Add a SysRq option to lift kernel lockdown" (Lenny Szubowicz) [1684348]
- [s390] s390/setup: fix boot crash for machine without EDAT-1 (Philipp Rudo) [1677357]
- [s390] s390/setup: fix early warning messages (Philipp Rudo) [1677357]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-75.1.el8]
- [netdrv] net: hns3: add 8 BD limit for tx flow (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: fix a SSU buffer checking bug (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: aligning buffer size in SSU to 256 bytes (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: getting tx and dv buffer size through firmware (Xiaojun Tan) [1676771]
- [net] netfilter: nf_nat_snmp_basic: add missing length checks in ASN.1 cbs (Florian Westphal) [1676602]
- [char] ipmi: fix use-after-free of user->release_barrier.rda (Xiaojun Tan) [1677550]
- [char] ipmi: Prevent use-after-free in deliver_response (Xiaojun Tan) [1677550]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-74.1.el8]
- [x86] revert "cpu/hotplug: Add SMT policy options" (Josh Poimboeuf) [1683690]
- [crypto] net: crypto set sk to NULL when af_alg_release (Neil Horman) [1679450] {CVE-2019-8912}
- [drm] drm/i915/gvt: update force-to-nonpriv register whitelist (Paul Lai) [1643972]
- [kernel] MODSIGN: Also check platform keyring in mod_verify_sig() (Lenny Szubowicz) [1568532]
- [kernel] Fix for module sig verification (Lenny Szubowicz) [1568532]
- [security] efi: Lock down the kernel if booted in secure boot mode (Lenny Szubowicz) [1568532]
- [firmware] efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (Lenny Szubowicz) [1568532]
- [x86] Copy secure_boot flag in boot params across kexec reboot (Lenny Szubowicz) [1568532]
- [fs] debugfs: Restrict debugfs when the kernel is locked down (Lenny Szubowicz) [1568532]
- [mm] x86/mmiotrace: Lock down the testmmiotrace module (Lenny Szubowicz) [1568532]
- [kernel] Lock down module params that specify hardware parameters (eg. ioport) (Lenny Szubowicz) [1568532]
- [tty] Lock down TIOCSSERIAL (Lenny Szubowicz) [1568532]
- [pcmcia] Prohibit PCMCIA CIS storage when the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Disable ACPI table override if the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Ignore acpi_rsdp kernel param when the kernel has been locked down (Lenny Szubowicz) [1568532]
- [acpi] ACPI: Limit access to custom_method when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86/msr: Restrict MSR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86: Lock down IO port access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [pci] PCI: Lock down BAR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] uswsusp: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] hibernate: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] kexec_load: Disable at runtime if the kernel is locked down (Lenny Szubowicz) [1568532]
- [char] Restrict /dev/{mem, kmem, port} when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] MODSIGN: Enforce module signatures if the kernel is locked down (Lenny Szubowicz) [1568532]
- [security] Add a SysRq option to lift kernel lockdown (Lenny Szubowicz) [1568532]
- [security] Add the ability to lock down access to the running kernel image (Lenny Szubowicz) [1568532]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-73.1.el8]
- [net] tun: forbid iface creation with rtnl ops (Sabrina Dubroca) [1680969]
- [net] revert "bridge: do not add port to router list when receives query with source 0.0.0.0" (Hangbin Liu) [1679896]
- [net] sctp: walk the list of asoc safely (Marcelo Leitner) [1679920] {CVE-2019-8956}
- [net] netfilter: nf_nat: skip nat clash resolution for same-origin entries (Florian Westphal) [1677647]
- [net] netfilter: nf_conntrack: resolve clash for matching conntracks (Florian Westphal) [1677647]
- [net] netfilter: nf_tables: fix flush after rule deletion in the same batch (Phil Sutter) [1677672]
- [net] gro_cell: add napi_disable in gro_cells_destroy (Stefano Brivio) [1674408]
- [net] sctp: call gso_reset_checksum when computing checksum in sctp_gso_segment (Xin Long) [1669386]
- [net] ipvs: fix dependency on nf_defrag_ipv6 (Andrea Claudi) [1660808]
- [net] sctp: check and update stream->out_curr when allocating stream_out (Xin Long) [1651877]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-72.1.el8]
- [x86] cpu/hotplug: Add SMT policy options (Josh Poimboeuf) [1677405]

* Tue Mar 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-71.1.el8]
- [kernel] open the RHEL 8.1 development ("Herton R. Krzesinski")
- [pci] pci/quirks: Add quirk to reset nvgpu at boot for the Lenovo ThinkPad P50 (Lyude Paul) [1677022]
- [arm64] arm64, vmcoreinfo : Append 'MAX_USER_VA_BITS' to vmcoreinfo (Bhupesh Sharma) [1672962]
- [md] dm thin: fix bug where bio that overwrites thin block ignores FUA (Mike Snitzer) [1679211]
- [pci] PCI: Fix "try" semantics of bus and slot reset (Myron Stowe) [1662901]
- [acpi] acpi/nfit: Fix bus command validation (Jeff Moyer) [1673958]
- [pci] PCI/MSI: Return -ENOSPC from pci_alloc_irq_vectors_affinity() (Myron Stowe) [1667773]
- [fs] NFS: Don't use page_file_mapping after removing the page (Benjamin Coddington) [1664190]
- [fs] NFS: Fix up return value on fatal errors in nfs_page_async_flush() (Benjamin Coddington) [1664190]
- [md] md: fix raid10 hang issue caused by barrier (Xiao Ni) [1630921]
- [md] md/raid1: don't clear bitmap bits on interrupted recovery. (Xiao Ni) [1677360]
- [virt] kvm: fix kvm_ioctl_create_device() reference counting (CVE-2019-6974) (Paolo Bonzini) [1673843] {CVE-2019-6974}
- [block] blk-mq: fix a hung issue when fsync (Ming Lei) [1674399]
- [block] Revert "block: cover another queue enter recursion via BIO_QUEUE_ENTERED" (Ming Lei) [1673966]
- [tools] perf tools: Check for null when copying nsinfo. (Jiri Olsa) [1676451]
- [iommu] iommu/amd: Fix IOMMU page flush when detach device from a domain (Suravee Suthikulpanit) [1672476]

* Tue Feb 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-70.el8]
- [kernel] namespace: Add padding fix to user_table[] (Prarit Bhargava) [1677103]
- [x86] KVM: nVMX: unconditionally cancel preemption timer in free_nested (CVE-2019-7221) (Paolo Bonzini) [1673841] {CVE-2019-7221}
- [scsi] scsi: sd: fix entropy gathering for most rotational disks (Ewan Milne) [1676735]
- [scsi] scsi: sd: Contribute to randomness when running rotational device (Ewan Milne) [1676735]
- [rpmspec] Revert "Drop -doc subpackage" (Prarit Bhargava) [1657609]
- [net] svcrdma: Remove max_sge check at connect time (Don Dutile) [1638869]
- [net] svcrdma: Reduce max_send_sges (Don Dutile) [1638869]
- [arm64] arm64: mm: Introduce MAX_USER_VA_BITS definition (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Rewrite stale comment in asm/tlbflush.h (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Avoid synchronous TLBIs when freeing page tables (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Remove redundant !CONFIG_HAVE_RCU_TABLE_FREE code (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Allow stride to be specified for __flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Justify non-leaf invalidation in flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Add DSB ISHST prior to TLBI in __flush_tlb_[kernel_]pgtable() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Use last-level invalidation in flush_tlb_kernel_range() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: EXPORT vabits_user to modules (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: fix ARM64_USER_VA_BITS_52 builds (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: Kconfig: Re-jig CONFIG options for 52-bit VA (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Allow forcing all userspace addresses to 52-bit (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: introduce 52-bit userspace support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Prevent mismatched 52-bit VA support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Offset TTBR1 to allow 52-bit PTRS_PER_PGD (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Define arch_get_mmap_end, arch_get_mmap_base (Christoph von Recklinghausen) [1672997]
- [firmware] arm64: mm: Introduce DEFAULT_MAP_WINDOW (Christoph von Recklinghausen) [1672997]
- [mm] mm: mmap: Allow for "high" userspace addresses (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: apply r/o permissions of VM areas to its linear alias as well (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: purge lazily unmapped vm regions before changing permissions (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Don't wait for completion of TLB invalidation when page aging (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Use __pa_symbol() for set_swapper_pgd() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Drop the unused cpu parameter (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: move runtime pgds to rodata (Christoph von Recklinghausen) [1672997]
- [mm] arm64/mm: use fixmap to modify swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Separate boot-time page tables from swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Pass ttbr1 as a parameter to __enable_mmu() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: fix erroneous warnings in page freeing functions (Christoph von Recklinghausen) [1672997]
- [mm] arm64: Implement page table free interfaces (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Introduce __flush_tlb_kernel_pgtable (Christoph von Recklinghausen) [1672997]
- [lib] ioremap: Update pgtable free interfaces with addr (Christoph von Recklinghausen) [1672997]
- [mm] x86/mm: Disable ioremap free page handling on x86-PAE (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: KVM: Enable Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [arm64] arm64: mm: Support Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [kernel] cpu/hotplug: Fix "SMT disabled by BIOS" detection for KVM (Igor Mammedov) [1668147]
- [tools] perf tools: Compile perf with -g instead of -ggdb3 to workaround gdb crash (Jiri Olsa) [1667109]

* Thu Feb 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-69.el8]
- [fs] Revert "gfs2: Fix loop in gfs2_rbm_find" (Andreas Grunbacher) [1658528]
- [net] bpf: fix sanitation of alu op with pointer / scalar type from different paths (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: prevent out of bounds speculation on pointer arithmetic (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: move {prev_,}insn_idx into verifier env (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf/verifier: per-register parent pointers (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: restrict unknown scalars of mixed signed bounds for unprivileged (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: Simplify ptr_min_max_vals adjustment (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: fix inner map masking to prevent oob under speculation (Jiri Olsa) [1673631] {CVE-2019-7308}
- [include] KABI: struct class padding (Prarit Bhargava) [1670035]
- [include] KABI: struct timer_list padding (Prarit Bhargava) [1670035]
- [include] KABI: struct irq_domain padding (Prarit Bhargava) [1670035]
- [nvdimm] libnvdimm, pmem: Fix badblocks population for 'raw' namespaces (Jeff Moyer) [1672315]
- [netdrv] net/mlx5e: FPGA, fix Innova IPsec TX offload data path performance (Alaa Hleihel) [1648230]
- [kernel] exec: increase BINPRM_BUF_SIZE to 256 (Oleg Nesterov) [1447445]

* Wed Feb 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-68.el8]
- [include] KABI: struct kset padding (Prarit Bhargava) [1669796]
- [include] KABI: struct kobject and kobj_type padding (Prarit Bhargava) [1669796]
- [include] KABI: struct delayed_work padding (Prarit Bhargava) [1669796]
- [include] KABI: struct work_struct padding (Prarit Bhargava) [1669796]
- [include] KABI: struct hrtimer padding (Prarit Bhargava) [1669796]
- [include] KABI: struct user_namespace padding (Prarit Bhargava) [1669796]
- [include] KABI: struct resource padding (Prarit Bhargava) [1669796]
- [include] KABI: Protect device_driver struct (Prarit Bhargava) [1666316]
- [include] KABI: Protect radix functions (Prarit Bhargava) [1669079]
- [char] ipmi: msghandler: Fix potential Spectre v1 vulnerabilities (Tony Camuso) [1672582]
- [vhost] vhost: fix OOB in get_rx_bufs() (Jason Wang) [1668665] {CVE-2018-16880}

* Sat Feb 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-67.el8]
- [md] dm: don't use bio_trim() afterall (Mike Snitzer) [1673657]
- [md] dm: add memory barrier before waitqueue_active (Mike Snitzer) [1673110]
- [x86] x86: uaccess: Inhibit speculation past access_ok() in user_access_begin() (Joe Lawrence) [1670113] {CVE-2018-20669}
- [kernel] make 'user_access_begin()' do 'access_ok()' (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] i915: fix missing user_access_end() in page fault exception case (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] drm/i915: Force the slow path after a user-write error (Joe Lawrence) [1670113] {CVE-2018-20669}
- [x86] x86/microcode/amd: Don't falsely trick the late loading mechanism (David Arcari) [1654904]
- [fs] iomap: get/put the page in iomap_page_create/release() (Artem Savkov) [1664298]
- [scsi] scsi: qla2xxx: Add new FC-NVMe enable BIT to enable FC-NVMe feature (Himanshu Madhani) [1671569]
- [message] mptsas: pci-id table changes (Tomas Henzl) [1666730]
- [message] mptsas: Taint kernel if mptsas is loaded (Tomas Henzl) [1666730]
- [kernel] genirq/matrix: Improve target CPU selection for managed interrupts. (Gary Hook) [1669557]
- [kernel] irq/matrix: Spread managed interrupts on allocation (Gary Hook) [1669557]
- [kernel] irq/matrix: Split out the CPU selection code into a helper (Gary Hook) [1669557]
- [net] sit: check if IPv6 enabled before calling ip6_err_gen_icmpv6_unreach() (Stefano Brivio) [1671680]
- [net] geneve: should not call rt6_lookup() when ipv6 was disabled (Stefano Brivio) [1671680]
- [net] netfilter: physdev: relax br_netfilter dependency (Phil Sutter) [1650382]
- [net] netfilter: nf_tables: add NFTA_RULE_POSITION_ID to nla_policy (Phil Sutter) [1670563]
- [net] netfilter: nf_tables: Support RULE_ID reference in new rule (Phil Sutter) [1670563]
- [net] rtnetlink: fix incorrect handling of device stats passed to userspace (Ivan Vecera) [1668298]
- [net] netfilter: nf_tables: handle nft_object lookups via rhltable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: prepare nft_object for lookups via hashtable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: selective rule dump needs table to be specified (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Fix for endless loop when dumping ruleset (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Speed up selective rule dumps (Phil Sutter) [1659725]
- [net] exclude sock_reuseport from kABI protection (Paolo Abeni) [1665984]
- [include] KABI: struct device padding (Don Dutile) [1664445]
- [include] KABI: struct dma_map_ops padding (Don Dutile) [1664482]
- [kernel] swiotlb: clear io_tlb_start and io_tlb_end in swiotlb_exit (Don Dutile) [1664484]
- [kernel] dma-mapping: remove a few unused exports (Don Dutile) [1664484]
- [include] dma-mapping: properly stub out the DMA API for !CONFIG_HAS_DMA (Don Dutile) [1664484]
- [kernel] dma-mapping: remove dmam_{declare,release}_coherent_memory (Don Dutile) [1664484]
- [kernel] dma-mapping: implement dmam_alloc_coherent using dmam_alloc_attrs (Don Dutile) [1664484]
- [include] dma-mapping: implement dma_map_single_attrs using dma_map_page_attrs (Don Dutile) [1664484]
- [include] dma-mapping: fix flags in dma_alloc_wc (Don Dutile) [1664484]
- [include] dma-mapping: deprecate dma_zalloc_coherent (Don Dutile) [1664484]
- [arm64] arm64: default to the direct mapping in get_arch_dma_ops (Don Dutile) [1664484]
- [kernel] dma-mapping: fix inverted logic in dma_supported (Don Dutile) [1664484]
- [include] dma-mapping: bypass indirect calls for dma-direct (Don Dutile) [1664484]
- [kernel] dma-direct: merge swiotlb_dma_ops into the dma_direct code (Don Dutile) [1664484]
- [kernel] dma-direct: do not include SME mask in the DMA supported check (Don Dutile) [1664484]
- [kernel] dma-direct: use dma_direct_map_page to implement dma_direct_map_sg (Don Dutile) [1664484]
- [kernel] dma-direct: improve addressability error reporting (Don Dutile) [1664484]
- [kernel] dma-direct: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [xen] swiotlb: remove dma_mark_clean (Don Dutile) [1664484]
- [xen] swiotlb: remove SWIOTLB_MAP_ERROR (Don Dutile) [1664484]
- [xen] xen-swiotlb: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] swiotlb: Skip cache maintenance on map error (Don Dutile) [1664484]
- [kernel] swiotlb: add support for non-coherent DMA (Don Dutile) [1664484]
- [kernel] swiotlb: mark is_swiotlb_buffer static (Don Dutile) [1664484]
- [kernel] swiotlb: remove a pointless comment (Don Dutile) [1664484]
- [kernel] swiotlb: clean up reporting (Don Dutile) [1664484]
- [kernel] dma-direct: reject highmem pages from dma_alloc_from_contiguous (Don Dutile) [1664484]
- [kernel] dma-direct: provide page based alloc/free helpers (Don Dutile) [1664484]
- [include] dma-direct: Make DIRECT_MAPPING_ERROR viable for SWIOTLB (Don Dutile) [1664484]
- [kernel] dma-direct: respect DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [kernel] dma-direct: document the zone selection logic (Don Dutile) [1664484]
- [kernel] dma-direct: fix return value of dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-direct: always allow dma mask <= physiscal memory size (Don Dutile) [1664484]
- [kernel] dma-direct: implement complete bus_dma_mask handling (Don Dutile) [1664484]
- [kernel] dma-direct: refine dma_direct_alloc zone selection (Don Dutile) [1664484]
- [kernel] dma-direct: add an explicit dma_direct_get_required_mask (Don Dutile) [1664484]
- [kernel] kernel/dma/direct: take DMA offset into account in dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-mapping: factor out dummy DMA ops (Don Dutile) [1664484]
- [mm] arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing (Don Dutile) [1664484]
- [iommu] iommu/dma-iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/vt-d: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/intel: small map_page cleanup (Don Dutile) [1664484]
- [iommu] intel-iommu: mark intel_dma_ops static (Don Dutile) [1664484]
- [iommu] ia64: remove iommu_dma_supported (Don Dutile) [1664484]
- [iommu] iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/dma: Use fast DMA domain lookup (Don Dutile) [1664484]
- [x86] x86/amd_gart: fix unmapping of non-GART mappings (Don Dutile) [1664484]
- [x86] x86/amd_gart: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [mm] arm64: remove the dummy_dma_ops mapping_error method (Don Dutile) [1664484]
- [powerpc] powerpc: Do not redefine NEED_DMA_MAP_STATE (Don Dutile) [1664484]
- [powerpc] powerpc/iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [s390] s390: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] dma-mapping: always build the direct mapping code (Don Dutile) [1664484]
- [kernel] dma-mapping: move dma_cache_sync out of line (Don Dutile) [1664484]
- [kernel] dma-mapping: move various slow path functions out of line (Don Dutile) [1664484]
- [base] dma-mapping: move dma_get_required_mask to kernel/dma (Don Dutile) [1664484]
- [base] dma-mapping: move dma_default_get_required_mask under ifdef (Don Dutile) [1664484]
- [include] dma-mapping: merge dma_unmap_page_attrs and dma_unmap_single_attrs (Don Dutile) [1664484]
- [include] dma-mapping: simplify the dma_sync_single_range_for_{cpu,device} implementation (Don Dutile) [1664484]
- [include] dma-mapping: return an error code from dma_mapping_error (Don Dutile) [1664484]
- [pci] dma-mapping: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [include] dma-mapping: provide a generic DMA_MAPPING_ERROR (Don Dutile) [1664484]
- [kernel] dma-mapping: move the arm64 noncoherent alloc/free support to common code (Don Dutile) [1664484]
- [mm] arm64: fix warnings without CONFIG_IOMMU_DMA (Don Dutile) [1664484]
- [arm64] arm64: use the generic swiotlb_dma_ops (Don Dutile) [1664484]
- [kernel] swiotlb: don't dip into swiotlb pool for coherent allocations (Don Dutile) [1664484]
- [kernel] swiotlb: refactor swiotlb_map_page (Don Dutile) [1664484]
- [kernel] swiotlb: use swiotlb_map_page in swiotlb_map_sg_attrs (Don Dutile) [1664484]
- [kernel] swiotlb: merge swiotlb_unmap_page and unmap_single (Don Dutile) [1664484]
- [kernel] swiotlb: remove the overflow buffer (Don Dutile) [1664484]
- [kernel] swiotlb: do not panic on mapping failures (Don Dutile) [1664484]
- [mm] arm64/dma-mapping: Mildly optimise non-coherent IOMMU ops (Don Dutile) [1664484]
- [iommu] iommu: Add fast hook for getting DMA domains (Don Dutile) [1664484]
- [iommu] iommu: Remove the ->map_sg indirection (Don Dutile) [1664484]
- [iommu] kernel/dma: remove unsupported gfp_mask parameter from dma_alloc_from_contiguous() (Don Dutile) [1664484]
- [mm] mm/cma: remove unsupported gfp_mask parameter from cma_alloc() (Don Dutile) [1664484]
- [kernel] dma-mapping: move the remap helpers to a separate file (Don Dutile) [1664484]
- [include] dma-mapping: fix return type of dma_set_max_seg_size() (Don Dutile) [1664484]
- [include] dma-mapping: translate __GFP_NOFAIL to DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [include] dma-debug: Check for drivers mapping invalid addresses in dma_map_single() (Don Dutile) [1664484]
- [base] dma-mapping: make the get_required_mask method available unconditionally (Don Dutile) [1664484]
- [xen] dma-mapping: support non-coherent devices in dma_common_get_sgtable (Don Dutile) [1664484]
- [kernel] dma-mapping: consolidate the dma mmap implementations (Don Dutile) [1664484]
- [kernel] dma-mapping: merge direct and noncoherent ops (Don Dutile) [1664484]
- [include] dma-mapping: move the dma_coherent flag to struct device (Don Dutile) [1664484]
- [include] dma-mapping: remove dma_deconfigure (Don Dutile) [1664484]
- [base] dma-mapping: remove dma_configure (Don Dutile) [1664484]
- [include] dma-mapping: relax warning for per-device areas (Don Dutile) [1664484]
- [kernel] dma-mapping: add the missing ARCH_HAS_SYNC_DMA_FOR_CPU_ALL declaration (Don Dutile) [1664484]
- [kernel] dma-noncoherent: add a arch_sync_dma_for_cpu_all hook (Don Dutile) [1664484]
- [block] deprecate elevator= kernel parameter (Jeff Moyer) [1665295]
- [rpmspec] kernel.spec: disable kabi checks until RC (=?UTF-8?q?=C4=8Cestm=C3=ADr=20Kalina?=) [1671007]
- [iommu] iommu/amd: Unmap all mapped pages in error path of map_sg (Jerry Snitselaar) [1668448]
- [iommu] iommu/amd: Call free_iova_fast with pfn in map_sg (Jerry Snitselaar) [1668448]

* Thu Feb 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-66.el8]
- [arm64] arm64, vmcoreinfo : Append 'MAX_PHYSMEM_BITS' to vmcoreinfo (Bhupesh Sharma) [1666679]
- [kernel] sched/debug: Initialize sd_sysctl_cpus if !CONFIG_CPUMASK_OFFSTACK (Joe Lawrence) [1667840]
- [init] Small change to the message about certified hardware (Steve Best) [1671765]
- [x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr (Pingfan Liu) [1640799]
- [x86] Add back support for Intel processors (Steve Best) [1670529]
- [net] SUNRPC: Clean up initialisation of the struct rpc_rqst (Benjamin Coddington) [1650494]
- [x86] KABI, x86/paravirt: Protect paravirt ops structures (Waiman Long) [1669957]
- [include] KABI: struct module padding (Prarit Bhargava) [1669480]
- [include] KABI: struct stack_trace_struct padding (Prarit Bhargava) [1669480]
- [documentation] iommu: Fix passthrough option documentation (Gary Hook) [1658391]
- [iommu] iommu: Add config option to set passthrough as default (Gary Hook) [1658391]
- [kernel] redhat: kernel: clean up taint flags (Jiri Benc) [1654313]

* Wed Feb 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-65.el8]
- [scsi] scsi: qedi: Add the CRC size within iSCSI NVM image (Charles Rose) [1670186]
- [fs] iomap: don't search past page end in iomap_is_partially_uptodate (Eric Sandeen) [1657588]
- [netdrv] cxgb4: update supported DCB version (Arjun Vynipadath) [1668571]
- [x86] kexec, KEYS: Make use of platform keyring for signature verify (Kairui Song) [1640486]
- [security] integrity, KEYS: add a reference to platform keyring (Kairui Song) [1640486]
- [security] efi: Allow the "db" UEFI variable to be suppressed (Kairui Song) [1640486]
- [security] efi: Import certificates from UEFI Secure Boot (Kairui Song) [1640486]
- [security] efi: Add an EFI signature blob parser (Kairui Song) [1640486]
- [include] efi: Add EFI signature data types (Kairui Song) [1640486]
- [security] integrity: Load certs to the platform keyring (Kairui Song) [1640486]
- [security] integrity: Define a trusted platform keyring (Kairui Song) [1640486]
- [security] security/integrity: remove unnecessary 'init_keyring' variable (Kairui Song) [1640486]
- [x86] Fix kexec forbidding kernels signed with keys in the secondary keyring to boot (Kairui Song) [1640486]
- [crypto] Replace magic for trusting the secondary keyring with #define (Kairui Song) [1640486]
- [acpi] acpi/nfit: Fix command-supported detection (Jeff Moyer) [1665812]
- [acpi] acpi/nfit: Block function zero DSMs (Jeff Moyer) [1665812]
- [md] dm: add missing trace_block_split() to __split_and_process_bio() (Mike Snitzer) [1645283]
- [md] dm: fix dm_wq_work() to only use __split_and_process_bio() if appropriate (Mike Snitzer) [1645283]
- [md] dm: fix redundant IO accounting for bios that need splitting (Mike Snitzer) [1645283]
- [md] dm: fix clone_bio() to trigger blk_recount_segments() (Mike Snitzer) [1645283]
- [block] block: cover another queue enter recursion via BIO_QUEUE_ENTERED (Mike Snitzer) [1645283]
- [md] dm thin: fix passdown_double_checking_shared_status() (Mike Snitzer) [1668039]
- [tools] bpftool: Fix prog dump by tag (Jiri Olsa) [1667305]
- [arm64] arm64: ftrace: Fix to enable syscall events on arm64 (Don Dutile) [1668035]
- [arm64] arm64: implement syscall wrappers (Don Dutile) [1668035]
- [arm64] arm64: convert compat wrappers to C (Don Dutile) [1668035]
- [arm64] arm64: use SYSCALL_DEFINE6() for mmap (Don Dutile) [1668035]
- [arm64] arm64: use {COMPAT,}SYSCALL_DEFINE0 for sigreturn (Don Dutile) [1668035]
- [arm64] arm64: remove in-kernel call to sys_personality() (Don Dutile) [1668035]
- [include] kernel: add ksys_personality() (Don Dutile) [1668035]
- [arm64] arm64: drop alignment from syscall tables (Don Dutile) [1668035]
- [arm64] arm64: entry: remove unused register aliases (Don Dutile) [1668035]
- [arm64] arm64: convert native/compat syscall entry to C (Don Dutile) [1668035]
- [arm64] arm64: svc: Ensure hardirq tracing is updated before return (Don Dutile) [1668035]
- [arm64] arm64: convert syscall trace logic to C (Don Dutile) [1668035]
- [arm64] arm64: move sve_user_{enable,disable} to <asm/fpsimd.h> (Don Dutile) [1668035]
- [arm64] arm64: kill change_cpacr() (Don Dutile) [1668035]
- [arm64] arm64: convert raw syscall invocation to C (Don Dutile) [1668035]
- [arm64] arm64: introduce syscall_fn_t (Don Dutile) [1668035]
- [arm64] arm64: remove sigreturn wrappers (Don Dutile) [1668035]
- [arm64] arm64: rseq: Implement backend rseq calls and select HAVE_RSEQ (Don Dutile) [1668035]
- [sound] ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock (Jaroslav Kysela) [1664249]
- [infiniband] IB/hfi1: Fix an out-of-bounds access in get_hw_stats (Alex Estrin) [1667104]
- [infiniband] IB/hfi1: Incorrect sizing of sge for PIO will OOPs (Alex Estrin) [1667095]
- [drm] drm/nouveau: register backlight on pascal and newer (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp/gm200-: enforce identity-mapped SOR assignment for LVDS/eDP panels (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp: move eDP panel power handling (Ben Skeggs) [1664899]
- [drm] drm/nouveau/devinit: don't fail when PMU/PRE_OS is missing from VBIOS (Ben Skeggs) [1664899]
- [kernel] locking/rwsem: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] futex: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] sched/wake_q: Fix wakeup ordering for wake_q (Waiman Long) [1668014]
- [kernel] sched/wake_q: Document wake_q_add() (Waiman Long) [1668014]
- [kernel] sched/wait: Fix rcuwait_wake_up() ordering (Waiman Long) [1668014]
- [kernel] sched/Documentation: Update wake_up() & co. memory-barrier guarantees (Waiman Long) [1668014]
- [kvm] KVM: PPC: Book3S HV: Flush guest mappings when turning dirty tracking on/off (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Cleanups - constify memslots, fix comments (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Map single pages when doing dirty page logging (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Pass change type down to memslot commit function (Laurent Vivier) [1650386]
- [vhost] vhost: log dirty page correctly (Jason Wang) [1657578]
- [netdrv] netxen: taint as unsupported in RHEL8 (Tony Camuso) [1654825]
- [hid] HID: hiddev: fix potential Spectre v1 (Benjamin Tissoires) [1664611]
- [net] resort to custom code for sk_buff padding (Paolo Abeni) [1665984]
- [net] add padding to cipher_context (Paolo Abeni) [1665984]
- [net] add padding to tls_crypto_context (Paolo Abeni) [1665984]
- [net] add padding to ipv4_devconf (Paolo Abeni) [1665984]
- [net] ip6mr: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [net] ipv4: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [include] add KABI padding to file_system_type (Eric Sandeen) [1665320 1650565]
- [include] add KABI padding to multiple fs ops vectors (Eric Sandeen) [1665320]
- [fs] add KABI padding to dentry structure (Eric Sandeen) [1665320]
- [fs] add KABI padding to inode structure (Eric Sandeen) [1665320]
- [include] add KABI padding to file_lock structure (Eric Sandeen) [1665320]
- [include] KABI: add an iopoll method to struct file_operations (Eric Sandeen) [1665320]
- [sound] ALSA: emux: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [sound] ALSA: pcm: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: rme9652: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [powerpc] powerpc/tm: Unset MSR[TS] if not recheckpointing (Gustavo Duarte) [1663853]
- [netdrv] r8152: Add support for MAC address pass through on RTL8153-BND (Perry Yuan) [1658433]
- [hid] HID: debug: fix the ring buffer implementation (Tony Camuso) [1669469] {CVE-2019-3819}

* Wed Jan 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-64.el8]
- [netdrv] net: hns: Fix WARNING when hns modules installed (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ping failed when use net bridge and send multicast (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Add mac pcs config when enable|disable mac (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ntuple-filters status error. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Free irq when exit from abnormal branch (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Clean rx fbd when ae stopped. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Some registers use wrong address according to the datasheet. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: All ports can not work when insmod hns ko after rmmod. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Incorrect offset address used for some registers. (Xiaojun Tan) [1662120]
- [include] ipmi: RH_KABI macros to pad kabi exposed structs (Tony Camuso) [1658175]
- [scsi] reserve space in structures for KABI (Ewan Milne) [1664397]

* Sat Jan 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-63.el8]
- [include] PCI: Add reserved fields to 'struct hotplug_slot' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct hotplug_slot_ops' (Myron Stowe) [1663534]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [1663534]
- [pci] PCI: Add missing include to drivers/pci.h (Myron Stowe) [1663534]
- [pci] PCI/IOV: Use VF0 cached config space size for other VFs (Myron Stowe) [1663534]
- [include] PCI: always include 'p2pdma' in 'struct pci_dev' (Myron Stowe) [1663534]
- [ata] PCI: Remove pci_set_dma_max_seg_size() (Myron Stowe) [1663534]
- [pci] PCI: Remove pci_set_dma_seg_boundary() (Myron Stowe) [1663534]
- [include] PCI: Remove pci_unmap_addr() wrappers for DMA API (Myron Stowe) [1663534]
- [pci] PCI/AER: Abstract AER interrupt handling (Myron Stowe) [1663534]
- [pci] PCI: Uninline PCI bus accessors for better ftracing (Myron Stowe) [1663534]
- [pci] PCI/portdrv: Add runtime PM hooks for port service drivers (Myron Stowe) [1663534]
- [pci] PCI: Make link active reporting detection generic (Myron Stowe) [1663534]
- [block] block: don't lose track of REQ_INTEGRITY flag (Ming Lei) [1665684]
- [nvme] nvme-pci: fix nvme_setup_irqs() (Ming Lei) [1661439]
- [lib] sbitmap: Protect swap_lock from hardirq (Ming Lei) [1666192]
- [lib] sbitmap: Protect swap_lock from softirqs (Ming Lei) [1666192]
- [scsi] scsi: isci: initialize shost fully before calling scsi_add_host() (Ming Lei) [1664918]
- [nvme] nvmet-fc: Mark NVMe/FC target mode driver as unsupported (Ewan Milne) [1664838]
- [netdrv] bnx2x: Assign unique DMAE channel number for FW DMAE transactions. (Jonathan Toppins) [1638306]
- [fs] block: don't use un-ordered __set_current_state(TASK_UNINTERRUPTIBLE) (Ming Lei) [1664580]
- [netdrv] qed: Wait for ready indication before rereading the shmem (Chad Dupuis) [1652417]
- [netdrv] qed: Avoid sending mailbox commands when MFW is not responsive (Chad Dupuis) [1652417]
- [netdrv] qed: Wait for MCP halt and resume commands to take place (Chad Dupuis) [1652417]
- [netdrv] qed: Prevent a possible deadlock during driver load and unload (Chad Dupuis) [1652417]
- [fs] gfs2: Fix loop in gfs2_rbm_find (Andreas Grunbacher) [1658528]
- [fs] gfs2: Get rid of potential double-freeing in gfs2_create_inode (Andreas Grunbacher) [1658539]

* Thu Jan 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-62.el8]
- [vhost] vhost/vsock: fix vhost vsock cid hashing inconsistent (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [vhost] vhost/vsock: fix use-after-free in network stack callers (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [netdrv] bnx2x: Add VF spoof-checking configuration (Jonathan Toppins) [1646842]
- [netdrv] net-next: hinic: fix a problem in free_tx_poll() (Xiaojun Tan) [1642016]
- [netdrv] net: hns: fix for unmapping problem when SMMU is on (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add netif_carrier_off before change speed and duplex (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add the code for cleaning pkt in chip (Xiaojun Tan) [1640526]
- [netdrv] net: hns: modify variable type in hns_nic_reuse_page (Xiaojun Tan) [1640526]

* Wed Jan 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-61.el8]
- [irqchip] Mark GICv2 deprecated (Wei Huang) [1609391]
- [scsi] qla2xxx: Use correct number of vectors for online CPUs (Himanshu Madhani) [1644058]
- [scsi] megaraid_sas: mark Aero controllers as tech preview (Tomas Henzl) [1659972]
- [scsi] megaraid_sas: add retry logic in megasas_readl (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Introduce new Aero adapter type (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Fix Ventura series based checks (Tomas Henzl) [1659972]
- [scsi] scsi: libfc: retry PRLI if we cannot analyse the payload (Chris Leech) [1631843]
- [scsi] scsi: libfc: check fc_frame_payload_get() return value for null (Chris Leech) [1631843]
- [scsi] scsi: libfc: hold disc_mutex in fc_disc_stop_rports() (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup lockdep annotations (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup 'sleeping function called from invalid context' (Chris Leech) [1631843]
- [scsi] scsi: libfc: Add lockdep annotations (Chris Leech) [1631843]
- [md] dm crypt: fix parsing of extended IV arguments (Mike Snitzer) [1665290]
- [kernel] redhat: kabi: reserved padding for kernel sched data structures (Rafael Aquini) [1664858]
- [kernel] redhat: kabi: reserved padding for MM related data structures (Rafael Aquini) [1664858]
- [vfio] vfio/type1: Fix unmap overflow off-by-one (Alex Williamson) [1662291]
- [message] mptspi: pci-id table changes (Tomas Henzl) [1651803]
- [message] mptspi: Taint kernel if mptspi is loaded (Tomas Henzl) [1651803]
- [block] kabi: reserve space for public data structure (Ming Lei) [1551939]
- [block] kabi: reserve space for blk-mq related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for bsg related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for integrity related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for CONFIG_BLK_DEV_ZONED (Ming Lei) [1551939]
- [ata] ata: Disable AHCI ALPM feature for Ampere Computing eMAG SATA (David Milburn) [1663347]
- [kvm] KVM: x86: Add CPUID support for new instruction WBNOINVD (Andrew Jones) [1659491]
- [x86] KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup (Andrew Jones) [1659491]
- [virt] kvm: Change offset in kvm_write_guest_offset_cached to unsigned (Andrew Jones) [1659491]
- [virt] kvm: Disallow wraparound in kvm_gfn_to_hva_cache_init (Andrew Jones) [1659491]
- [kvm] KVM: x86: svm: report MSR_IA32_MCG_EXT_CTL as unsupported (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: Add ARM_EXCEPTION_IS_TRAP macro (Andrew Jones) [1659491]
- [arm64] arm64: KVM: Avoid setting the upper 32 bits of VTCR_EL2 to 1 (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix unintended stage 2 PMD mappings (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: vgic: Force VM halt when changing the active state of GICv3 PPIs/SGIs (Andrew Jones) [1659491]
- [arm64] KVM: arm/arm64: Fixup the kvm_exit tracepoint (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Consider priority and active state for pending irq (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Fix off-by-one bug in vgic_get_irq() (Andrew Jones) [1659491]
- [kvm] KVM: X86: Fix NULL deref in vcpu_scan_ioapic (Andrew Jones) [1659491]
- [kvm] KVM: Fix UAF in nested posted interrupt processing (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Cap SPIs to the VM-defined maximum (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Do not cond_resched_lock() with IRQs disabled (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic-v2: Set active_source to 0 when restoring state (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area() fails (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Install stage-2 translation before enabling traps (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Make VHE Stage-2 TLB invalidation operations non-interruptible (Andrew Jones) [1659491]
- [arm64] arm64: entry: Remove confusing comment (Andrew Jones) [1659491]
- [kvm] arm64: entry: Place an SB sequence following an ERET instruction (Andrew Jones) [1659491]
- [arm64] arm64: Add support for SB barrier and patch in over DSB; ISB sequences (Andrew Jones) [1659491]
- [kvm] kvm: nVMX: Set VM instruction error for VMPTRLD of unbacked page (Andrew Jones) [1659491]
- [kvm] kvm: svm: Ensure an IBPB on all affected CPUs when freeing a vmcb (Andrew Jones) [1659491]
- [kvm] kvm: mmu: Fix race in emulated page table writes (Andrew Jones) [1659491]
- [kvm] KVM: nVMX/nSVM: Fix bug which sets vcpu->arch.tsc_offset to L1 tsc_offset (Andrew Jones) [1659491]
- [kvm] KVM: VMX: Update shared MSRs to be saved/restored on MSR_EFER.LMA changes (Andrew Jones) [1659491]
- [kvm] KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall (Andrew Jones) [1659491]
- [kvm] svm: Add mutex_lock to protect apic_access_page_done on AMD systems (Andrew Jones) [1659491]
- [kvm] KVM/nVMX: Do not validate that posted_intr_desc_addr is page aligned (Andrew Jones) [1659491]
- [kvm] KVM: arm64: Safety check PSTATE when entering guest and handle IL (Andrew Jones) [1659491]
- [virt] KVM: arm64: Fix caching of host MDCR_EL2 value (Andrew Jones) [1659491]
- [kvm] x86/kvm/nVMX: allow bare VMXON state migration (Andrew Jones) [1659491]
- [kvm] x86/kvm/lapic: preserve gfn_to_hva_cache len on cache reinit (Andrew Jones) [1659491]
- [kvm] KVM: hyperv: define VP assist page helpers (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: move check_vmentry_postreqs() call to nested_vmx_enter_non_root_mode() (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Always reflect #NM VM-exits to L1 (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: consistently use 'hv_vcpu' for 'struct kvm_vcpu_hv' variables (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: enforce vp_index < KVM_MAX_VCPUS (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: restore host state in nested_vmx_vmexit for VMFail (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Clear reserved bits of #DB exit qualification (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Ensure only THP is candidate for adjustment (Andrew Jones) [1659491]
- [kvm] x86: kvm: avoid unused variable warning (Andrew Jones) [1659491]
- [kvm] powerpc64/ftrace: Include ftrace.h needed for enable/disable calls (Andrew Jones) [1659491]
- [kvm] x86/kvm/vmx: Remove duplicate l1d flush definitions (Andrew Jones) [1659491]
- [tools] perf kvm: Fix subcommands on s390 (Andrew Jones) [1659491]
- [arm64] arm64: add PSR_AA32_* definitions (Andrew Jones) [1659491]
- [pci] PCI: hotplug: Document TODOs (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Embed hotplug_slot (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Drop hotplug_slot_info (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Constify hotplug_slot_ops (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Reshuffle controller struct for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Rename controller struct members for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Unify controller and slot structs (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Tolerate Presence Detect hardwired to zero (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop hotplug_slot_ops wrappers (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop unnecessary includes (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Differentiate between surprise and safe removal (Myron Stowe) [1664454]
- [pci] PCI: Simplify disconnected marking (Myron Stowe) [1664454]
- [tools] perf vendor events arm64: Revise core JSON events for eMAG (Jiri Olsa) [1663353]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Jiri Olsa) [1663353]
- [perf] drivers/perf: xgene: Add CPU hotplug support (Jiri Olsa) [1663349]
- [scsi] mpt3sas: mark Aero controllers as tech preview (Tomas Henzl) [1663281]
- [powerpc] KVM: PPC: Book3S HV: Keep rc bits in shadow pgtable in sync with host (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Introduce kvmhv_update_nest_rmap_rc_list() (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Apply combination of host and l1 pte rc for nested guest (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Align gfn to L1 page size when inserting nest-rmap entry (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Hold kvm->mmu_lock across updating nested pte rc bits (Suraj Jitindar Singh) [1662029]
- [tools] perf python: Do not force closing original perf descriptor in evlist.get_pollfd (Jiri Olsa) [1659445]
- [mm] mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings (Andrea Arcangeli) [1613993]
- [rpmspec] spec: Add libperf-jvmti.so into perf debuginfo rpm (Jiri Olsa) [1653570]
- [scsi] scsi: hisi_sas: Fix spin lock management in slot_index_alloc_quirk_v2_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Update v3 hw AIP_LIMIT and CFG_AGING_TIME register values (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Use block layer tag instead for IPTT (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: unmask interrupts ent72 and ent74 (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Free slot later in slot_complete_vx_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Fix the race between IO completion and timeout for SMP/internal IO (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Move evaluation of hisi_hba in hisi_sas_task_prep() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Feed back linkrate(max/min) when re-attached (Xiaojun Tan) [1642819]
- [hwtracing] intel_th: pci: Add Ice Lake PCH support (Jiri Olsa) [1485529]

* Fri Jan 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-60.el8]
- [kernel] userns: also map extents in the reverse map to kernel IDs (Chris von Recklinghausen) [1652679] {CVE-2018-18955}
- [net] ipv6: route: Fix return value of ip6_neigh_lookup() on neigh_create() error (Stefano Brivio) [1662789]
- [net] ipv6: frags: Fix bogus skb->sk in reassembled packets (Herbert Xu) [1645839]
- [net] redhat: blacklist auto-loadable net modules in modules-extra (Marcelo Leitner) [1642795]
- [net] redhat: move sctp modules to kernel-modules-extra (Marcelo Leitner) [1642795]
- [net] add reserved fields to neighbour (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_stats* (Paolo Abeni) [1655084]
- [net] reserve bits in netdev_features_t for future features (Paolo Abeni) [1655084]
- [net] add reserved fields to sk_buff (Paolo Abeni) [1655084]
- [net] add reserved fields to ipv6_devconf (Paolo Abeni) [1655084]
- [net] add reserved fields to fib_rule (Paolo Abeni) [1655084]
- [net] add reserved fields to sock (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_family (Paolo Abeni) [1655084]
- [net] add reserved fields to proto_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to proto (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_entry (Paolo Abeni) [1655084]
- [net] add reserved fields to lwtunnel_state (Paolo Abeni) [1655084]
- [net] add reserved fields to packet_type (Paolo Abeni) [1655084]
- [net] add reserved fields to napi_struct (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device (Paolo Abeni) [1655084]
- [net] exclude wireless_dev from KABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to dcbnl_rtnl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrm_* (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_obj (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to l3mdev_ops (Paolo Abeni) [1655084]
- [net] exclude ndisc_ops from kABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrmdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to tlsdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_rx_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to ethtool_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to header_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to flowi* structs (Paolo Abeni) [1655084]
- [arm64] KVM: arm64: Clarify explanation of STAGE2_PGTABLE_LEVELS (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] KVM: arm/arm64: Rename kvm_arm_config_vm to kvm_arm_setup_stage2 (Christoph von Recklinghausen) [1643586 1643522]
- [virt] KVM: arm64: Drop __cpu_init_stage2 on the VHE path (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Allow tuning the physical address size for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Limit the minimum number of page table levels (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm64: Set a limit on the IPA size (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add 52bit support for PAR to HPFAR conversoin (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Switch to per VM IPA limit (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Configure VTCR_EL2.SL0 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Dynamic configuration of VTTBR mask (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Make stage2 page table layout dynamic (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Prepare for dynamic stage2 page table layout (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm/arm64: Prepare for VM specific stage2 translations (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Configure VTCR_EL2 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Allow arch specific configurations for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Clean up VTCR_EL2 initialisation (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] arm64: Add a helper for PARange to physical shift conversion (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add helper for loading the stage2 setting for a VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Remove spurious WARN_ON (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Fix stage2_flush_memslot for 4 level page table (Christoph von Recklinghausen) [1643586 1643522]
- [hv] hv_balloon: avoid touching uninitialized struct page during tail onlining (Vitaly Kuznetsov) [1662277]
- [x86] Mark AMD EPYC guests as supported (David Arcari) [1663356]
- [netdrv] be2net: Disable queue dump in be_tx_timeout handler (Petr Oros) [1646838]
- [vhost] vhost: Fix Spectre V1 vulnerability (Jason Wang) [1663469]
- [mm] mm/hugetlb.c: teach follow_hugetlb_page() to handle FOLL_NOWAIT (Andrea Arcangeli) [1575028]
- [tools] cpupower: Fix AMD Family 0x17 msr_pstate size (Prarit Bhargava) [1659883]
- [tools] cpupower: Fix coredump on VMWare (Prarit Bhargava) [1659883]
- [scsi] scsi: csiostor: remove flush_scheduled_work() (Arjun Vynipadath) [1663973]
- [powerpc] KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and MMU mode switch (David Gibson) [1663225]
- [fs] userfaultfd: check VM_MAYWRITE was set after verifying the uffd is registered (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE is not set (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: add i_size checks (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE vmas (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE shmem (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: use ENOENT instead of EFAULT if the atomic copy user fails (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: allow get_mempolicy(MPOL_F_NODE|MPOL_F_ADDR) to trigger userfaults (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: clear flag if remap event not enabled (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: disable irqs when taking the waitqueue lock (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] fs/userfaultfd.c: remove redundant pointer uwq (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] NFS: nfs_compare_mount_options always compare auth flavors. (Steve Dickson) [1661619]
- [infiniband] RDMA/hns: Bugfix for RoCE loopback test (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Update posting & querying mailbox (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Fix the bug while use multi-hop of pbl (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Init qp context when modify qp from reset to init (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Bugfix pbl configuration for rereg mr (Xiaojun Tan) [1663359]
- [security] selinux: add support for RTM_NEWCHAIN, RTM_DELCHAIN, and RTM_GETCHAIN (Ondrej Mosnacek) [1660564]
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1656261]
- [scsi] scsi: megaraid_sas: Use 63-bit DMA addressing (Tomas Henzl) [1656261]
- [x86] x86/kvm: mark as TechPreview when running as a nested hypervisor (Vitaly Kuznetsov) [1519039]
- [rpmspec] kernel.spec: Fix kernel-tools files section logic (Prarit Bhargava) [1661247]
- [crypto] crypto: ccp - Make function sev_get_firmware() static (Gary Hook) [1632894]
- [crypto] crypto: ccp - Allow SEV firmware to be chosen based on Family and Model (Gary Hook) [1632894]
- [crypto] crypto: ccp - Fix static checker warning (Gary Hook) [1632894]
- [crypto] crypto: ccp - add timeout support in the SEV command (Gary Hook) [1632894]
- [nvdimm] nvdimm: Use namespace index data to reduce number of label reads needed (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Split label init out from the logic for getting config data (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Remove empty if statement (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Clarify comment in sizeof_namespace_index (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Sanity check labeloff (Jeff Moyer) [1634345]
- [nvdimm] libnvdimm, dimm: Maximize label transfer size (Jeff Moyer) [1634345]
- [mm] mm/page-writeback.c: fix range_cyclic writeback vs writepages deadlock (Brian Foster) [1659528]
- [input] Input: elantech - disable elan-i2c for P52 and P72 (Benjamin Tissoires) [1658602]
- [fs] cachefiles: avoid deprecated get_seconds() (David Howells) [1655613]
- [fs] fscache, cachefiles: remove redundant variable 'cache' (David Howells) [1655613]
- [fs] cachefiles: Explicitly cast enumerated type in put_object (David Howells) [1655613]
- [fs] fscache: fix race between enablement and dropping of object (David Howells) [1655613]
- [fs] cachefiles: Fix page leak in cachefiles_read_backing_file while vmscan is active (David Howells) [1655613]
- [fs] fscache: Fix race in fscache_op_complete() due to split atomic_sub & read (David Howells) [1655613]
- [fs] cachefiles: Fix an assertion failure when trying to update a failed object (David Howells) [1655613]
- [fs] fscache: Fix out of bound read in long cookie keys (David Howells) [1655613]
- [fs] fscache: Fix incomplete initialisation of inline key space (David Howells) [1655613]
- [fs] cachefiles: fix the race between cachefiles_bury_object() and rmdir(2) (David Howells) [1655613]
- [kernel] ebpf: record usage of eBPF (Jiri Benc) [1654279]
- [kernel] add rh_features to /proc (Jiri Benc) [1654279]
- [kernel] add support for rh_features (Jiri Benc) [1654279]
- [fs] fs/lock: show locks taken by processes from another pidns (Miklos Szeredi) [1616125]
- [iommu] iommu/arm-smmu: Support non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm-v7s: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu: Add "iommu.strict" command line option (Xiaojun Tan) [1643114]
- [iommu] iommu/dma: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu: Ensure that page-table updates are visible before TLBI (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Implement flush_iotlb_all hook (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Avoid back-to-back CMD_SYNC operations (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Fix unexpected CMD_SYNC timeout (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Fix race handling in split_blk_unmap() (Xiaojun Tan) [1643114]
- [infiniband] RDMA/hns: Update some attributes of the RoCE device (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Limit the size of extend sge of sq (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for CM test (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Submit bad wr when post send wr exception (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for reserved qp number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Refactor the codes for setting transport opode (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Move all prints out of irq handle (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix an error code in hns_roce_v2_init_eq_table() (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix usage of bitmap allocation functions return values (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Support flush cqe for hip08 in kernel space (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Program the tclass and flow label into the hardware (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use macro instead of magic number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Modify qp will return errno when qp type is illegal (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Assign the value for vlan field of qp context (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Enable modify_cq for uverbs. (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the data type of immediate data (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use delay instead of usleep (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add illegal hop_num judgement (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add 50GE type of hnae3 device match (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Do not overwrite the error code during error unwind in hns_roce_init (Xiaojun Tan) [1639578]
- [infiniband] hns: Remove a set-but-not-used variable (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_mac (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_gid (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TPQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TSQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix endian conversions and annotations (Xiaojun Tan) [1639578]
- [scsi] scsi: hisi_sas: Add SATA FIS check for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: add memory barrier in task delivery function (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Tidy hisi_sas_task_prep() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Implement handlers of PCIe FLR for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: relocate some common code for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy host controller reset function a bit (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the failure of recovering PHY from STP link timeout (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy channel interrupt handler for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Drop hisi_sas_slot_abort() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Update a couple of register settings for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add missing PHY spinlock init (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Pre-allocate slot DMA buffers (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Release all remaining resources in clear nexus ha (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add a flag to filter PHY events during reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Adjust task reject period during host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the conflict between dev gone and host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Only process broadcast change in phy_bcast_v3_hw() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Use dmam_alloc_coherent() (Zhou Wang) [1639541]
- [netdrv] xen/netfront: fix waiting for xenbus state change (Petr Oros) [1638456]

* Thu Jan 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-59.el8]
- [x86] expand cpu feature/bug bits (David Arcari) [1662434]
- [x86] add kabi support for cpuinfo_x86 (David Arcari) [1662434]
- [init] Display a message about certified hardware (Steve Best) [1660523]
- [scsi] scsi: t10-pi: Return correct ref tag when queue has no integrity profile (Ming Lei) [1660719]
- [scsi] scsi: storvsc: Fix a race in sub-channel creation that can cause panic (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: set callbacks on open (Mohammed Gamal) [1650149]
- [hv] vmbus: fix subchannel removal (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: defer opening vmbus until first use (Mohammed Gamal) [1650149]
- [hv] vmbus: split ring buffer allocation from open (Mohammed Gamal) [1650149]
- [hv] vmbus: pass channel to hv_process_channel_removal (Mohammed Gamal) [1650149]
- [hv] Drivers: hv: vmbus: Reset the channel callback in vmbus_onoffer_rescind() (Mohammed Gamal) [1650149]
- [uio] hv_uio_generic: map ringbuffer phys addr (Mohammed Gamal) [1650149]
- [uio] uio: introduce UIO_MEM_IOVA (Mohammed Gamal) [1650149]
- [hv] vmbus: add driver_override support (Mohammed Gamal) [1650149]
- [hv] vmbus: keep pointer to ring buffer page (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: increase size of receive and send buffers (Mohammed Gamal) [1650149]
- [uio] uio: add SPDX license tags (Mohammed Gamal) [1650149]
- [fs] gfs2: take jdata unstuff into account in do_grow (Robert S Peterson) [1660519]
- [drm] drm/dp_mst: Check if primary mstb is null (Lyude Paul) [1658711]
- [tools] perf tests: Use shebangs in the shell scripts (Michael Petlan) [1613523]

* Mon Jan 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-58.el8]
- [mm] mm: put_and_wait_on_page_locked() while page is migrated (Baoquan He) [1649214]
- [netdrv] i40e: define proper net_device::neigh_priv_len (Stefan Assmann) [1658743]
- [netdrv] i40e: fix VLAN.TCI == 0 RX HW offload (Stefan Assmann) [1658743]
- [netdrv] i40e: fix mac filter delete when setting mac address (Stefan Assmann) [1658743]
- [netdrv] i40e: prevent overlapping tx_timeout recover (Stefan Assmann) [1658743]
- [netdrv] i40e: Use correct shift for VLAN priority (Stefan Assmann) [1658743]
- [netdrv] i40e: always set ks->base.speed in i40e_get_settings_link_up (Stefan Assmann) [1658743]
- [netdrv] i40e: don't restart nway if autoneg not supported (Stefan Assmann) [1658743]
- [netdrv] i40e: enable NETIF_F_NTUPLE and NETIF_F_HW_TC at driver load (Stefan Assmann) [1658743]
- [netdrv] i40e: restore NETIF_F_GSO_IPXIP[46] to netdev features (Stefan Assmann) [1658743]
- [acpi] ACPI/APEI: Clear GHES block_status before panic() (David Arcari) [1662442]
- [misc] VMCI: Resource wildcard match fixed (Vitaly Kuznetsov) [1652868]
- [mm] mm/page_alloc.c: don't call kasan_free_pages() at deferred mem init (Waiman Long) [1655964]
- [block] block/bio: Do not zero user pages (Ming Lei) [1662502]
- [vhost] disable zerocopy by default (Jason Wang) [1582756]
- [block] kyber: use sbitmap add_wait_queue/list_del wait helpers (Ming Lei) [1661426]
- [lib] sbitmap: add helpers for add/del wait queue handling (Ming Lei) [1661426]
- [net] Revert "sunrpc: Ensure we always close the socket after a connection shuts down" (Dave Wysochanski) [1657449]
- [vhost] vhost/vsock: fix reset orphans race with close timeout (Stefan Hajnoczi) [1660445]
- [misc] genwqe: Fix size check (Steve Best) [1660126]
- [fs] aio: fix spectre gadget in lookup_ioctx (Jeff Moyer) [1660963]
- [block] block: save irq state in blkg_lookup_create() (Ming Lei) [1660299]
- [md] dm: don't reuse bio for flushes (Ming Lei) [1660401]
- [wireless] mac80211_hwsim: Fix possible Spectre-v1 for hwsim_world_regdom_custom (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for NL80211_TXRATE_HT (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds (Stanislaw Gruszka) [1637113]
- [block] blk-mq: enable IO poll if .nr_queues of type poll > 0 (Ming Lei) [1660826]
- [powerpc] powerpc/rtas: Fix a potential race between CPU-Offline & Migration (Desnes Augusto Nunes do Rosario) [1639266]
- [x86] kvm: x86: Add AMD's EX_CFG to the list of ignored MSRs (Eduardo Habkost) [1625111]
- [scsi] scsi_sysfs: make unpriv_sgio queue attribute accessible for non-block devices (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: introduce unpriv_sgio queue flag (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: pass request_queue to blk_verify_command (Paolo Bonzini) [1584504]
- [fs] ext4: missing !bh check in ext4_xattr_inode_write() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in __ext4_read_dirblock() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_expand_extra_isize_ea() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_move_to_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: release bs.bh before re-using in ext4_xattr_block_find() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_get_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of s_journal_flag_rwsem in error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of sbi->s_group_desc_leak in error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid possible double brelse() in add_new_gdb() on error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak in ext4_orphan_add() after prior errors (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty() (Lukas Czerner) [1659481]
- [fs] ext4: fix possible inode leak in the retry loop of ext4_resize_fs() (Lukas Czerner) [1659481]
- [fs] ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails while resizing (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() update_backups()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() add_new_gdb_meta_bg()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() in set_flexbg_block_bitmap()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid potential extra brelse in setup_new_flex_group_blocks() (Lukas Czerner) [1659481]
- [scsi] scsi: lpfc: Enable Management features for IF_TYPE=6 (Dick Kennedy) [1658755]
- [scsi] scsi: mpt3sas: Update driver version to 27.101.00.00 (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Replace readl with ioc->base_readl (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Add separate function for aero doorbell reads (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Introduce flag for aero based controllers (Tomas Henzl) [1659035]
- [md] dm: do not allow readahead to limit IO size (Mike Snitzer) [1658757]
- [md] dm raid: fix false -EBUSY when handling check/repair message (Mike Snitzer) [1658757]
- [block] blk-mq: change blk_mq_queue_busy() to blk_mq_queue_inflight() (Mike Snitzer) [1658757]
- [md] dm rq: cleanup leftover code from recently removed q->mq_ops branching (Mike Snitzer) [1658757]
- [md] dm verity: log the hash algorithm implementation (Mike Snitzer) [1658757]
- [md] dm crypt: log the encryption algorithm implementation (Mike Snitzer) [1658757]
- [md] dm integrity: fix spelling mistake in workqueue name (Mike Snitzer) [1658757]
- [md] dm flakey: Properly corrupt multi-page bios. (Mike Snitzer) [1658757]
- [md] dm: Check for device sector overflow if CONFIG_LBDAF is not set (Mike Snitzer) [1658757]
- [md] dm crypt: use u64 instead of sector_t to store iv_offset (Mike Snitzer) [1658757]
- [md] dm kcopyd: Fix bug causing workqueue stalls (Mike Snitzer) [1658757]
- [md] dm snapshot: Fix excessive memory usage and workqueue stalls (Mike Snitzer) [1658757]
- [md] dm bufio: update comment in dm-bufio.c (Mike Snitzer) [1658757]
- [md] dm writecache: fix typo in error msg for creating writecache_flush_thread (Mike Snitzer) [1658757]
- [md] dm: remove indirect calls from __send_changing_extent_only() (Mike Snitzer) [1658757]
- [md] dm mpath: only flush workqueue when needed (Mike Snitzer) [1658757]
- [md] dm: avoid indirect call in __dm_make_request (Mike Snitzer) [1658757]
- [md] dm thin: bump target version (Mike Snitzer) [1658757]
- [md] dm thin: send event about thin-pool state change _after_ making it (Mike Snitzer) [1658757]
- [md] dm cache metadata: verify cache has blocks in blocks_are_clean_separate_dirty() (Mike Snitzer) [1658757]
- [md] dm writecache: remove disabled code in memory_entry() (Mike Snitzer) [1658757]
- [md] dm raid: avoid bitmap with raid4/5/6 journal device (Mike Snitzer) [1658757]
- [md] dm crypt: make workqueue names device-specific (Mike Snitzer) [1658757]
- [md] dm: add dm_table_device_name() (Mike Snitzer) [1658757]
- [md] dm ioctl: harden copy_params()'s copy_from_user() from malicious users (Mike Snitzer) [1658757]
- [md] dm: remove unnecessary unlikely() around WARN_ON_ONCE() (Mike Snitzer) [1658757]
- [md] dm thin: use refcount_t for thin_c reference counting (Mike Snitzer) [1658757]
- [netdrv] nfp: provide a better warning when ring allocation fails (Pablo Cascon) [1645456]
- [netdrv] nfp: use kvcalloc() to allocate SW buffer descriptor arrays (Pablo Cascon) [1645456]
- [scsi] scsi: lpfc: rport port swap discovery issue. (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Fix discovery failures during port failovers with lots of vports (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: refactor mailbox structure context fields (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Correct loss of fc4 type on remote port address change (Dick Kennedy) [1656635]
- [hid] HID: multitouch: Add pointstick support for Cirque Touchpad (Perry Yuan) [1656673]
- [powerpc] KVM: PPC: Book3S HV: Fix handling for interrupted H_ENTER_NESTED (Suraj Jitindar Singh) [1649980]
- [powerpc] powerpc: Select CONFIG_SWIOTLB (Gustavo Duarte) [1648466]
- [fs] nfs: Fix a missed page unlock after pg_doio() (Benjamin Coddington) [1651287]
- [arm64] arm64: fix possible spectre-v1 write in ptrace_hbp_set_event() (Mark Salter) [1637585]
- [fs] fsnotify: Fix busy inodes during unmount (Lukas Czerner) [1650462]
- [tools] perf vendor events arm64: Update ThunderX2 implementation defined pmu core events (Robert Richter) [1501638]
- [tools] perf tools: Fix undefined symbol scnprintf in libperf-jvmti.so (Jiri Olsa) [1579484]

* Tue Dec 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-57.el8]
- [block] blk-mq: export hctx->type in debugfs instead of sysfs (Ming Lei) [1660040]
- [block] blk-mq: fix dispatch from sw queue (Ming Lei) [1660040]
- [block] blk-mq: skip zero-queue maps in blk_mq_map_swqueue (Ming Lei) [1660040]
- [nvme] nvme-pci: don't share queue maps (Ming Lei) [1660040]
- [block] blk-mq: only dispatch to non-defauly queue maps if they have queues (Ming Lei) [1660040]
- [x86] KVM: LAPIC: Fix pv ipis use-before-initialization (Paul Lai) [1657702]
- [fs] autofs: fix directory and symlink access (Ian Kent) [1611967]
- [infiniband] IB/iser: Fix possible NULL deref at iser_inv_desc() (Don Dutile) [1657574]
- [infiniband] RDMA/core: Fix unwinding flow in case of error to register device (Don Dutile) [1657574]
- [infiniband] IB/rxe: fix for duplicate request processing and ack psns (Don Dutile) [1657574]
- [infiniband] IB/ipoib: Clear IPCB before icmp_send (Don Dutile) [1657574]
- [infiniband] RDMA/core: Do not expose unsupported counters (Don Dutile) [1657574]
- [infiniband] IB/ucm: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/ucma: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/uverbs: Don't overwrite NULL pointer with ZERO_SIZE_PTR (Don Dutile) [1657574]
- [infiniband] RDMA/cma: Do not ignore net namespace for unbound cm_id (Don Dutile) [1657574]
- [net] xprtrdma: Reset credit grant properly after a disconnect (Don Dutile) [1657574]
- [input] Input: hyper-v - fix wakeup from suspend-to-idle (Vitaly Kuznetsov) [1588888]
- [kernel] kernel: hung_task.c: disable on suspend (Vitaly Kuznetsov) [1588888]
- [kernel] redhat: add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc) [1656933]
- [rpmspec] Sign the aarch64 kernel (Jeremy Linton) [1659158]

* Mon Dec 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-56.el8]
- [netdrv] nfp: flower: add geneve option match offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: add geneve option push action offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: offload tos and tunnel flags for ipv4 udp tunnels (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: set ip tunnel ttl from encap action (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: extract ipv4 udp tunnel ttl from route (Pablo Cascon) [1655604]
- [net] sctp: hold transport before accessing its asoc in sctp_transport_get_next (Marcelo Leitner) [1656271]
- [net] sctp: fix the data size calculation in sctp_data_size (Marcelo Leitner) [1656271]
- [net] sctp: fix race on sctp_id2asoc (Marcelo Leitner) [1656271]
- [net] rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER devices (Hangbin Liu) [1657120]
- [netdrv] mlx5e: fix csum adjustments caused by RXFCS (Hangbin Liu) [1657120]
- [net] drop skb on failure in ip_check_defrag() (Hangbin Liu) [1657120]
- [net] rtnl_configure_link: fix dev flags changes arg to __dev_notify_flags (Hangbin Liu) [1657120]
- [net] socket: fix a missing-check bug (Hangbin Liu) [1657120]
- [net] rtnetlink: Disallow FDB configuration for non-Ethernet device (Hangbin Liu) [1657120]
- [net] rtnetlink: Fail dump if target netnsid is invalid (Hangbin Liu) [1657120]
- [net] rtnetlink: fix rtnl_fdb_dump() for ndmsg header (Hangbin Liu) [1657120]
- [net] rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096 (Hangbin Liu) [1657120]
- [net] socket: fix struct ifreq size in compat ioctl (Hangbin Liu) [1657120]
- [net] fix pskb_trim_rcsum_slow() with odd trim offset (Hangbin Liu) [1657120]
- [net] gso_segment: Reset skb->mac_len after modifying network header (Hangbin Liu) [1657120]
- [net] Use __kernel_clockid_t in uapi net_stamp.h (Davide Caratti) [1638022]
- [net] tun: Consistently configure generic netdev params via rtnetlink (Matteo Croce) [1657910]
- [net] tun: napi flags belong to tfile (Matteo Croce) [1657910]
- [net] tun: initialize napi_mutex unconditionally (Matteo Croce) [1657910]
- [net] tun: remove unused parameters (Matteo Croce) [1657910]
- [net] team: Forbid enslaving team device to itself (Matteo Croce) [1658725]
- [net] sched: Remove TCA_OPTIONS from policy (Davide Caratti) [1658516]
- [net] sched: cls_api: add missing validation of netlink attributes (Davide Caratti) [1658516]
- [net] sched: gred: pass the right attribute to gred_change_table_def() (Davide Caratti) [1658516]
- [net] sched: cls_u32: fix hnode refcounting (Davide Caratti) [1658516]
- [net] sched: Add policy validation for tc attributes (Davide Caratti) [1658516]
- [net] bpf: use __GFP_COMP while allocating page (Andrea Claudi) [1658231]
- [net] xsk: do not call synchronize_net() under RCU read lock (Andrea Claudi) [1658231]
- [net] bpf: fix partial copy of map_ptr when dst is scalar (Andrea Claudi) [1658231]
- [net] bpf: Fix bpf_msg_pull_data() (Andrea Claudi) [1658231]
- [net] bpf: fix shift upon scatterlist ring wrap-around in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix sg shift repair start offset in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix msg->data/data_end after sg shift repair in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix several offset tests in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] vlan: add support for tunnel offload (Andrea Claudi) [1656804]
- [net] 8021q: move vlan offload registrations into vlan_core (Hangbin Liu) [1657658]
- [net] ipv6/ndisc: Preserve IPv6 control buffer if protocol error handlers are called (Stefano Brivio) [1658010]
- [net] ipv6: Allow onlink routes to have a device mismatch if it is the default route (Stefano Brivio) [1658010]
- [net] ipv6: Fix index counter for unicast addresses in in6_dump_addrs (Stefano Brivio) [1658010]
- [net] ipv6: mcast: fix a use-after-free in inet6_mc_check (Stefano Brivio) [1658010]
- [net] ipv6: rate-limit probes for neighbourless routes (Stefano Brivio) [1658010]
- [net] ipv6: stop leaking percpu memory in fib6 info (Stefano Brivio) [1658010]
- [net] ipv6: Remove extra call to ip6_convert_metrics for multipath case (Stefano Brivio) [1658010]
- [net] ipv6: Display all addresses in output of /proc/net/if_inet6 (Stefano Brivio) [1658010]
- [net] ipv6: do not copy dst flags on rt init (Stefano Brivio) [1658010]
- [net] ipv6: Only update MTU metric if it set (Stefano Brivio) [1658010]
- [net] ipv6: don't get lwtstate twice in ip6_rt_copy_init() (Stefano Brivio) [1658010]
- [net] ipv6: Put lwtstate when destroying fib6_info (Stefano Brivio) [1658010]
- [net] ip6_tunnel: Fix encapsulation layout (Stefano Brivio) [1658008]
- [net] vxlan: fill ttl inherit info (Stefano Brivio) [1658008]
- [net] ip_tunnel: be careful when accessing the inner header (Stefano Brivio) [1658008]
- [net] vti6: remove !skb->ignore_df check from vti6_xmit() (Stefano Brivio) [1658008]
- [net] ip6_vti: fix a null pointer deference when destroy vti6 tunnel (Stefano Brivio) [1658008]
- [net] ip6_vti: fix creating fallback tunnel device for vti6 (Stefano Brivio) [1658008]
- [net] ip_vti: fix a null pointer deferrence when create vti fallback tunnel (Stefano Brivio) [1658008]
- [net] l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache (Stefano Brivio) [1658008]
- [net] macsec: let the administrator set UP state even if lowerdev is down (Sabrina Dubroca) [1645540]
- [net] macsec: update operstate when lower device changes (Sabrina Dubroca) [1645540]
- [net] tcp: do not restart timewait timer on rst reception (Paolo Abeni) [1657988]
- [net] tcp: really ignore MSG_ZEROCOPY if no SO_ZEROCOPY (Paolo Abeni) [1657988]
- [net] tcp, ulp: add alias for all ulp modules (Paolo Abeni) [1657988]
- [net] tcp, ulp: fix leftover icsk_ulp_ops preventing sock from reattach (Paolo Abeni) [1657988]
- [net] ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV and TIME-WAIT state (Paolo Abeni) [1657988]
- [net] neighbour: Avoid writing before skb->head in neigh_hh_output() (Stefano Brivio) [1643336]
- [net] ipv6: Check available headroom in ip6_xmit() even without options (Stefano Brivio) [1643336]
- [net] ipv6: fix possible use-after-free in ip6_xmit() (Stefano Brivio) [1643336]
- [net] openvswitch: Fix push/pop ethernet validation (Hangbin Liu) [1657226]
- [net] cgroup, netclassid: add a preemption point to write_classid (Hangbin Liu) [1657226]
- [net] ethtool: fix a privilege escalation bug (Hangbin Liu) [1657226]
- [net] llc: set SOCK_RCU_FREE in llc_sap_add_socket() (Hangbin Liu) [1657226]
- [net] dcb: For wild-card lookups, use priority -1, not 0 (Hangbin Liu) [1657226]
- [net] packet: fix packet drop as of virtio gso (Hangbin Liu) [1657226]
- [net] netlabel: check for IPV4MASK in addrinfo_get (Hangbin Liu) [1657226]
- [net] netfilter: seqadj: re-load tcp header pointer after possible head reallocation (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: avoid BUG_ON usage (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: deactivate expressions in rule replecement routine (Florian Westphal) [1654259]
- [net] netfilter: nat: fix double register in masquerade modules (Florian Westphal) [1654259]
- [net] netfilter: add missing error handling code for register functions (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: fix use-after-free when deleting compat expressions (Florian Westphal) [1654259]
- [net] netfilter: xt_RATEEST: remove netns exit routine (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: don't use position attribute on rule replacement (Florian Westphal) [1654259]
- [net] revert "netfilter: nft_numgen: add map lookups for numgen random operations" (Florian Westphal) [1654259]
- [net] netfilter: xt_IDLETIMER: add sysfs filename checking routine (Florian Westphal) [1654259]
- [net] netfilter: conntrack: fix calculation of next bucket number in early_drop (Florian Westphal) [1654259]
- [net] netfilter: conntrack: get rid of double sizeof (Florian Westphal) [1654259]
- [net] netfilter: nft_set_rbtree: add missing rb_erase() in GC routine (Florian Westphal) [1654259]
- [net] netfilter: nfnetlink_queue: Solve the NFQUEUE/conntrack clash for NF_REPEAT (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: release chain in flushing set (Florian Westphal) [1654259]
- [net] netfilter: xt_checksum: ignore gso skbs (Florian Westphal) [1654259]
- [net] netfilter: xt_cluster: add dependency on conntrack module (Florian Westphal) [1654259]
- [net] netfilter: fix memory leaks on netlink_dump_start error (Florian Westphal) [1654259]
- [net] netfilter: x_tables: do not fail xt_alloc_table_info too easilly (Florian Westphal) [1654259]
- [net] ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest() (Florian Westphal) [1654259]
- [net] netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses (Florian Westphal) [1654259]
- [net] xfrm: policy: use hlist rcu variants on insert (Sabrina Dubroca) [1657272]
- [net] xfrm: validate template mode (Sabrina Dubroca) [1657272]
- [net] xfrm: Fix NULL pointer dereference when skb_dst_force clears the dst_entry. (Sabrina Dubroca) [1657272]
- [net] xfrm: reset transport header back to network header after all input transforms ahave been applied (Sabrina Dubroca) [1657272]
- [net] xfrm: reset crypto_done when iterating over multiple input xfrms (Sabrina Dubroca) [1657272]
- [net] xfrm: Validate address prefix lengths in the xfrm selector. (Sabrina Dubroca) [1657272]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1657225]
- [net] tls: zero the crypto information from tls_context before freeing (Sabrina Dubroca) [1657225]
- [net] tls: clear key material from kernel memory when do_tls_setsockopt_conf fails (Sabrina Dubroca) [1657225]
- [net] tls: don't copy the key out of tls12_crypto_info_aes_gcm_128 (Sabrina Dubroca) [1657225]
- [net] tls: Set count of SG entries if sk_alloc_sg returns -ENOSPC (Sabrina Dubroca) [1657225]
- [net] tls: possible hang when do_tcp_sendpages hits sndbuf is full case (Sabrina Dubroca) [1657225]
- [net] tls: Fix improper revert in zerocopy_from_iter (Sabrina Dubroca) [1657225]
- [net] tls: Fix zerocopy_from_iter iov handling (Sabrina Dubroca) [1657225]
- [net] netfilter: conntrack: reset tcp maxwin on re-register (Florian Westphal) [1647310]
- [net] configs: Enable CONFIG_IP_SET_HASH_IPMAC as a module (Stefano Brivio) [1655301]
- [net] udp: fix handling of CHECKSUM_COMPLETE packets (Paolo Abeni) [1655656]
- [net] udp: Unbreak modules that rely on external __skb_recv_udp() availability (Paolo Abeni) [1655656]
- [net] udp6: fix encap return code for resubmitting (Paolo Abeni) [1655656]
- [net] team: no need to do team_notify_peers or team_mcast_rejoin when disabling port (Hangbin Liu) [1653197]
- [net] sctp: not increase stream's incnt before sending addstrm_in request (Xin Long) [1651428]
- [net] sctp: not allow to set asoc prsctp_enable by sockopt (Xin Long) [1647272]
- [net] revert "sctp: remove sctp_transport_pmtu_check" (Xin Long) [1643330]
- [net] fix XPS static_key accounting (Ivan Vecera) [1651781]
- [net] restore call to netdev_queue_numa_node_write when resetting XPS (Ivan Vecera) [1651781]
- [net] allow fallback function to pass netdev (Ivan Vecera) [1651781]
- [net] allow ndo_select_queue to pass netdev (Ivan Vecera) [1651781]
- [net] Add generic ndo_select_queue functions (Ivan Vecera) [1651781]
- [net] Add support for subordinate traffic classes to netdev_pick_tx (Ivan Vecera) [1651781]
- [net] ixgbe: Add code to populate and use macvlan TC to Tx queue map (Ivan Vecera) [1651781]
- [net] Add support for subordinate device traffic classes (Ivan Vecera) [1651781]
- [net] net-sysfs: Drop support for XPS and traffic_class on single queue device (Ivan Vecera) [1651781]
- [net] Provide stub for __netif_set_xps_queue if there is no CONFIG_XPS (Ivan Vecera) [1651781]
- [net] allow to call netif_reset_xps_queues() under cpus_read_lock (Ivan Vecera) [1651781]
- [net] documentation: Add explanation for XPS using Rx-queue(s) map (Ivan Vecera) [1651781]
- [net] net-sysfs: Add interface for Rx queue(s) map per Tx queue (Ivan Vecera) [1651781]
- [net] Enable Tx queue selection based on Rx queues (Ivan Vecera) [1651781]
- [net] Record receive queue number for a connection (Ivan Vecera) [1651781]
- [net] sock: Change tx_queue_mapping in sock_common to unsigned short (Ivan Vecera) [1651781]
- [net] Use static_key for XPS maps (Ivan Vecera) [1651781]
- [net] Refactor XPS for CPUs and Rx queues (Ivan Vecera) [1651781]
- [net] devlink: Add helper function for safely copy string param (Ivan Vecera) [1647914]
- [net] devlink: Fix param cmode driverinit for string type (Ivan Vecera) [1647914]
- [net] devlink: Fix param set handling for string type (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params-bnxt.txt (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params.txt (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_min (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_max (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter ignore_ari (Ivan Vecera) [1647914]
- [net] devlink: double free in devlink_resource_fill() (Ivan Vecera) [1647914]
- [net] devlink: Add extack for eswitch operations (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters region_snapshot (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot read command (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot delete command (Ivan Vecera) [1647914]
- [net] devlink: Extend the support querying for region snapshot IDs (Ivan Vecera) [1647914]
- [net] devlink: Add support for region get command (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating region snapshots (Ivan Vecera) [1647914]
- [net] devlink: Add callback to query for snapshot id before snapshot create (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating and destroying regions (Ivan Vecera) [1647914]
- [net] devlink: fix incorrect return statement (Ivan Vecera) [1647914]
- [net] devlink: Add enable_sriov boolean generic parameter (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters internal_err_reset and max_macs (Ivan Vecera) [1647914]
- [net] devlink: Add devlink notifications support for params (Ivan Vecera) [1647914]
- [net] devlink: Add support for get/set driverinit value (Ivan Vecera) [1647914]
- [net] devlink: Add param set command (Ivan Vecera) [1647914]
- [net] devlink: Add param get command (Ivan Vecera) [1647914]
- [net] devlink: Add devlink_param register and unregister (Ivan Vecera) [1647914]
- [net] ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf (Xin Long) [1645064]
- [net] ipv6: fix a dst leak when removing its exception (Xin Long) [1645064]
- [net] netfilter: ipset: list:set: Decrease refcount synchronously on deletion and replace (Stefano Brivio) [1649089]
- [net] bridge: remove ipv6 zero address check in mcast queries (Hangbin Liu) [1639666]
- [net] bridge: do not add port to router list when receives query with source 0.0.0.0 (Hangbin Liu) [1639666]
- [net] netfilter: ipv6: fix oops when defragmenting locally generated fragments (Florian Westphal) [1642341]
- [net] xfrm6: call kfree_skb when skb is toobig (Sabrina Dubroca) [1628851]
- [net] sched: act_police: fix memory leak in case of invalid control action (Ivan Vecera) [1638022]
- [net] sched: act_police: add missing spinlock initialization (Ivan Vecera) [1638022]
- [net] netfilter: xt_socket: check sk before checking for netns. (Ivan Vecera) [1638022]
- [net] sched: act_police: fix race condition on state variables (Ivan Vecera) [1638022]
- [net] sched: cls_flower: validate nested enc_opts_policy to avoid warning (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix memory leak when IDR allocation fails (Ivan Vecera) [1638022]
- [net] configs: disable CAKE, ETF & SKBPRIO qdisc in config (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' for exceed traffic in police.json (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' on 'random' traffic in gact.json (Ivan Vecera) [1638022]
- [net] sched: act_police: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] sched: act_gact: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] net_sched: fix a crash in tc_new_tfilter() (Ivan Vecera) [1638022]
- [net] core: make function ___gnet_stats_copy_basic() static (Ivan Vecera) [1638022]
- [net] net_sched: convert idrinfo->lock from spinlock to a mutex (Ivan Vecera) [1638022]
- [net] loopback: clear skb->tstamp before netif_rx() (Ivan Vecera) [1638022]
- [net] skbuff: preserve sock reference when scrubbing the skb. (Ivan Vecera) [1638022]
- [net] netfilter: check if the socket netns is correct. (Ivan Vecera) [1638022]
- [net] sched: make function qdisc_free_cb() static (Ivan Vecera) [1638022]
- [net] sched: use reference counting for tcf blocks on rules update (Ivan Vecera) [1638022]
- [net] sched: implement tcf_block_refcnt_{get|put}() (Ivan Vecera) [1638022]
- [net] sched: protect block idr with spinlock (Ivan Vecera) [1638022]
- [net] sched: implement functions to put and flush all chains (Ivan Vecera) [1638022]
- [net] sched: change tcf block reference counter type to refcount_t (Ivan Vecera) [1638022]
- [net] sched: use Qdisc rcu API instead of relying on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: add helper function to take reference to Qdisc (Ivan Vecera) [1638022]
- [net] sched: extend Qdisc with rcu (Ivan Vecera) [1638022]
- [net] sched: rename qdisc_destroy() to qdisc_put() (Ivan Vecera) [1638022]
- [net] core: netlink: add helper refcount dec and lock function (Ivan Vecera) [1638022]
- [net] sched: act_ipt: check for underflow in __tcf_ipt_init() (Ivan Vecera) [1638022]
- [net] sched: Add hardware specific counters to TC actions (Ivan Vecera) [1638022]
- [net] core: Add new basic hardware counter (Ivan Vecera) [1638022]
- [net] net_sched: change tcf_del_walker() to take idrinfo->lock (Ivan Vecera) [1638022]
- [net] sched: Use FIELD_SIZEOF directly instead of reimplementing its function (Ivan Vecera) [1638022]
- [net] sched: act_sample: fix NULL dereference in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: use per-cpu counters (Ivan Vecera) [1638022]
- [net] net_sched: notify filter deletion when deleting a chain (Ivan Vecera) [1638022]
- [net] htb: use anonymous union for simplicity (Ivan Vecera) [1638022]
- [net] net_sched: remove redundant qdisc lock classes (Ivan Vecera) [1638022]
- [net] sched: cls_flower: dump offload count value (Ivan Vecera) [1638022]
- [net] net_sched: properly cancel netlink dump on failure (Ivan Vecera) [1638022]
- [net] sched: fix memory leak in act_tunnel_key_init() (Ivan Vecera) [1638022]
- [net] sched: action_ife: take reference to meta module (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential use-after-free (Ivan Vecera) [1638022]
- [net] sched: act_nat: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: null actions array pointer before releasing action (Ivan Vecera) [1638022]
- [net] sched: fix type of htb statistics (Ivan Vecera) [1638022]
- [net] net_sched: add missing tcf_lock for act_connmark (Ivan Vecera) [1638022]
- [net] revert "net: sched: act: add extack for lookup callback" (Ivan Vecera) [1638022]
- [net] tc-testing: add test-cases for numeric and invalid control action (Ivan Vecera) [1638022]
- [net] net_sched: reject unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix dump of extended layered op (Ivan Vecera) [1638022]
- [net] sched: return -ENOENT when trying to remove filter from non-existent chain (Ivan Vecera) [1638022]
- [net] sched: fix extack error message when chain is failed to be created (Ivan Vecera) [1638022]
- [net] sched: Fix memory exposure from short TCA_U32_SEL (Ivan Vecera) [1638022]
- [net] net_sched: fix unused variable warning in stmmac (Ivan Vecera) [1638022]
- [net] sch_cake: Fix TC filter flow override and expand it to hosts as well (Ivan Vecera) [1638022]
- [net] sch_cake: Remove unused including <linux/version.h> (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential deadlock (Ivan Vecera) [1638022]
- [net] act_ife: move tcfa_lock down to where necessary (Ivan Vecera) [1638022]
- [net] revert "net: sched: act_ife: disable bh when taking ife_mod_lock" (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcfa_capab (Ivan Vecera) [1638022]
- [net] net_sched: remove list_head from tc_action (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcf_idr_check() (Ivan Vecera) [1638022]
- [net] net_sched: remove unused parameter for tcf_action_delete() (Ivan Vecera) [1638022]
- [net] net_sched: remove unnecessary ops->delete() (Ivan Vecera) [1638022]
- [net] net_sched: improve and refactor tcf_action_put_many() (Ivan Vecera) [1638022]
- [net] sched: always disable bh when taking tcf_lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: always release ife action on init error (Ivan Vecera) [1638022]
- [net] cls_matchall: fix tcf_unbind_filter missing (Ivan Vecera) [1638022]
- [net] sched: act_ife: disable bh when taking ife_mod_lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_vlan method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbmod method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_simple method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_pedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_nat method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_ipt method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_gact method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_sum method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_bpf method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_connmark method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] core: protect rate estimator statistics pointer with lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: extend action ops with put_dev callback (Ivan Vecera) [1638022]
- [net] sched: act_vlan: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbmod: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_simple: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_sample: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_pedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ipt: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_gact: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_csum: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_bpf: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] tc: Update README and add config (Ivan Vecera) [1638022]
- [net] sched: fix block->refcnt decrement (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of nat action unit tests (Ivan Vecera) [1638022]
- [net] sched: allow flower to match tunnel options (Ivan Vecera) [1638022]
- [net] flow_dissector: allow dissection of tunnel options from metadata (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in skbedit match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in connmark match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: flush gact actions on test teardown (Ivan Vecera) [1638022]
- [net] tc-testing: fix ip address in u32 test (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Fix an error code in fl_tmplt_create() (Ivan Vecera) [1638022]
- [net] sched: fix flush on non-existing chain (Ivan Vecera) [1638022]
- [net] sched: make tcf_chain_{get, put}() static (Ivan Vecera) [1638022]
- [net] sched: fix notifications for action-held chains (Ivan Vecera) [1638022]
- [net] sched: change name of zombie chain to "held_by_acts_only" (Ivan Vecera) [1638022]
- [net] act_mirred: use TC_ACT_REINSERT when possible (Ivan Vecera) [1638022]
- [net] tc: introduce TC_ACT_REINSERT. (Ivan Vecera) [1638022]
- [net] tc/act: remove unneeded RCU lock in action callback (Ivan Vecera) [1638022]
- [net] sched: user-space can't set unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] Add and use skb_mark_not_on_list(). (Ivan Vecera) [1638022]
- [net] sch_netem: Move private queue handler to generic location. (Ivan Vecera) [1638022]
- [net] sch_htb: Remove local SKB queue handling code. (Ivan Vecera) [1638022]
- [net] act_bpf: Use kmemdup instead of duplicating it in tcf_bpf_init_from_ops (Ivan Vecera) [1638022]
- [net] cls_bpf: Use kmemdup instead of duplicating it in cls_bpf_prog_from_ops (Ivan Vecera) [1638022]
- [net] act_pedit: remove unnecessary semicolon (Ivan Vecera) [1638022]
- [net] sched: don't dump chains only held by actions (Ivan Vecera) [1638022]
- [net] sch_cake: Make gso-splitting configurable from userspace (Ivan Vecera) [1638022]
- [net] sched: unmark chain as explicitly created on delete (Ivan Vecera) [1638022]
- [net] sched: cls_api: fix dead code in switch (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Use correct inline function for assignment of vlan tpid (Ivan Vecera) [1638022]
- [net] sched: fix trailing whitespace (Ivan Vecera) [1638022]
- [net] cbs: Add support for the graft function (Ivan Vecera) [1638022]
- [net] sched: add skbprio scheduler (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chain templates (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chains creation adn destruction (Ivan Vecera) [1638022]
- [net] selftests: forwarding: move shblock tc support check to a separate helper (Ivan Vecera) [1638022]
- [net] sched: cls_flower: propagate chain teplate creation and destruction to drivers (Ivan Vecera) [1638022]
- [net] sched: cls_flower: implement chain templates (Ivan Vecera) [1638022]
- [net] sched: cls_flower: change fl_init_dissector to accept mask and dissector (Ivan Vecera) [1638022]
- [net] sched: cls_flower: move key/mask dumping into a separate function (Ivan Vecera) [1638022]
- [net] sched: introduce chain templates (Ivan Vecera) [1638022]
- [net] sched: introduce chain object to uapi (Ivan Vecera) [1638022]
- [net] sched: Avoid implicit chain 0 creation (Ivan Vecera) [1638022]
- [net] sched: push ops lookup bits into tcf_proto_lookup_ops() (Ivan Vecera) [1638022]
- [net] nfp: bring back support for offloading shared blocks (Ivan Vecera) [1638022]
- [net] sched: use PTR_ERR_OR_ZERO macro in tcf_block_cb_register (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of fw filter unit tests (Ivan Vecera) [1638022]
- [net] sch_cake: Fix tin order when set through skb->priority (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: skbedit: use per-cpu counters (Ivan Vecera) [1638022]
- [net] tc-testing: add geneve options in tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] sched: fix unprotected access to rcu cookie pointer (Ivan Vecera) [1638022]
- [net] sched: act_ife: fix memory leak in ife init (Ivan Vecera) [1638022]
- [net] sched: refactor flower walk to iterate over idr (Ivan Vecera) [1638022]
- [net] sched: flower: Fix null pointer dereference when run tc vlan command (Ivan Vecera) [1638022]
- [net] sched: Fix warnings from xchg() on RCU'd cookie pointer. (Ivan Vecera) [1638022]
- [net] cls_flower: fix error values for commands not supported by drivers (Ivan Vecera) [1638022]
- [net] nfp: handle cls_flower command default case (Ivan Vecera) [1638022]
- [net] bnxt: simplify cls_flower command switch and handle default case (Ivan Vecera) [1638022]
- [net] sch_cake: Conditionally split GSO segments (Ivan Vecera) [1638022]
- [net] sch_cake: Add overhead compensation support to the rate shaper (Ivan Vecera) [1638022]
- [net] sch_cake: Add DiffServ handling (Ivan Vecera) [1638022]
- [net] sch_cake: Add NAT awareness to packet classifier (Ivan Vecera) [1638022]
- [net] netfilter: Add nf_ct_get_tuple_skb global lookup function (Ivan Vecera) [1638022]
- [net] sch_cake: Add optional ACK filter (Ivan Vecera) [1638022]
- [net] sch_cake: Add ingress mode (Ivan Vecera) [1638022]
- [net] sched: Add Common Applications Kept Enhanced (cake) qdisc (Ivan Vecera) [1638022]
- [net] Use __u32 in uapi net_stamp.h (Ivan Vecera) [1638022]
- [net] sched: flower: Add supprt for matching on QinQ vlan headers (Ivan Vecera) [1638022]
- [net] sched: flower: Dump the ethertype encapsulated in vlan (Ivan Vecera) [1638022]
- [net] flow_dissector: Add support for QinQ dissection (Ivan Vecera) [1638022]
- [net] sched: flower: Add support for matching on vlan ethertype (Ivan Vecera) [1638022]
- [net] flow_dissector: Save vlan ethertype from headers (Ivan Vecera) [1638022]
- [net] sched: change action API to use array of pointers to actions (Ivan Vecera) [1638022]
- [net] sched: atomically check-allocate action (Ivan Vecera) [1638022]
- [net] sched: use reference counting action init (Ivan Vecera) [1638022]
- [net] sched: don't release reference on action overwrite (Ivan Vecera) [1638022]
- [net] sched: implement reference counted action release (Ivan Vecera) [1638022]
- [net] sched: add 'delete' function to action ops (Ivan Vecera) [1638022]
- [net] sched: implement action API that deletes action by index (Ivan Vecera) [1638022]
- [net] sched: always take reference to action (Ivan Vecera) [1638022]
- [net] sched: implement unlocked action init API (Ivan Vecera) [1638022]
- [net] sched: change type of reference and bind counters (Ivan Vecera) [1638022]
- [net] sched: use rcu for action cookie update (Ivan Vecera) [1638022]
- [net] sched: Make etf report drops on error_queue (Ivan Vecera) [1638022]
- [net] sched: Add HW offloading capability to ETF (Ivan Vecera) [1638022]
- [net] sched: Introduce the ETF Qdisc (Ivan Vecera) [1638022]
- [net] sched: Allow creating a Qdisc watchdog with other clocks (Ivan Vecera) [1638022]
- [net] packet: Hook into time based transmission. (Ivan Vecera) [1638022]
- [net] ipv6: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] ipv4: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] Add a new socket option for a future transmit time. (Ivan Vecera) [1638022]
- [net] Clear skb->tstamp only on the forwarding path (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix possible memory leak in tcf_pedit_init() (Ivan Vecera) [1638022]
- [net] net sched actions: add extack messages in pedit action (Ivan Vecera) [1638022]
- [net] net:sched: add action inheritdsfield to skbedit (Ivan Vecera) [1638022]
- [net] tc-testing: initial version of tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] net sched actions: avoid bitwise operation on signed value in pedit (Ivan Vecera) [1638022]
- [net] net sched actions: fix misleading text strings in pedit action (Ivan Vecera) [1638022]
- [net] net sched actions: use sizeof operator for buffer length (Ivan Vecera) [1638022]
- [net] net sched actions: fix sparse warning (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit headers (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit action (Ivan Vecera) [1638022]
- [net] netem: slotting with non-uniform distribution (Ivan Vecera) [1638022]
- [net] check tunnel option type in tunnel flags (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: add extended ack support (Ivan Vecera) [1638022]
- [net] tc-tests: add an extreme-case csum action test (Ivan Vecera) [1638022]
- [net] net_sched: remove unused htb drop_list (Ivan Vecera) [1638022]

* Sun Dec 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-55.el8]
- [rpmspec] always run make with HOSTCFLAGS/HOSTLDFLAGS set (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to tools build (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to bpftool build (Jiri Olsa) [1624124]
- [kernel] kbuild: Use HOST*FLAGS options from the command line (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOST_LOADLIBES to KBUILD_HOSTLDLIBS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTLDFLAGS to KBUILD_HOSTLDFLAGS (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOSTCXXFLAGS to KBUILD_HOSTCXXFLAGS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTCFLAGS to KBUILD_HOSTCFLAGS (Jiri Olsa) [1624124]
- [tools] tools cpupower: Override CFLAGS assignments (Jiri Olsa) [1624124]
- [tools] tools cpupower debug: Allow to use outside build flags (Jiri Olsa) [1624124]
- [tools] perf tools: Pass build flags to traceevent build (Jiri Olsa) [1624124]
- [tools] tools lib traceevent: Use LDFLAGS in the build commands (Jiri Olsa) [1624124]
- [tools] perf tools: Link libperf-jvmti.so with LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow add linker flags via EXTRA_LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow to add compiler flags via EXTRA_CFLAGS variable (Jiri Olsa) [1624124]
- [block] blkcg: handle dying request_queue when associating a blkg (Ming Lei) [1655485]
- [block] block: deactivate blk_stat timer in wbt_disable_default() (Ming Lei) [1655485]
- [lib] sbitmap: flush deferred clears for resize and shallow gets (Ming Lei) [1655485]
- [md] dm: fix request-based dm's use of dm_wait_for_completion (Ming Lei) [1655485]
- [nvme] nvme: fix irq vs io_queue calculations (Ming Lei) [1655485]
- [md] dm: fix inflight IO check (Ming Lei) [1655485]
- [md] dm: remove the pending IO accounting (Ming Lei) [1655485]
- [block] block: return just one value from part_in_flight (Ming Lei) [1655485]
- [block] block: switch to per-cpu in-flight counters (Ming Lei) [1655485]
- [block] block: delete part_round_stats and switch to less precise counting (Ming Lei) [1655485]
- [block] block: stop passing 'cpu' to all percpu stats methods (Ming Lei) [1655485]
- [md] dm rq: leverage blk_mq_queue_busy() to check for outstanding IO (Ming Lei) [1655485]
- [md] dm: dont rewrite dm_disk(md)->part0.in_flight (Ming Lei) [1655485]
- [lib] sbitmap: silence bogus lockdep IRQ warning (Ming Lei) [1655485]
- [scsi] scsi: Fix a harmless double shift bug (Ming Lei) [1655485]
- [block] blk-mq: re-build queue map in case of kdump kernel (Ming Lei) [1655485]
- [block] blkcg: put back rcu lock in blkcg_bio_issue_check() (Ming Lei) [1655485]
- [block] block: convert io-latency to use rq_qos_wait (Ming Lei) [1655485]
- [block] block: convert wbt_wait() to use rq_qos_wait() (Ming Lei) [1655485]
- [block] block: add rq_qos_wait to rq_qos (Ming Lei) [1655485]
- [block] blkcg: rename blkg_try_get() to blkg_tryget() (Ming Lei) [1655485]
- [block] blkcg: change blkg reference counting to use percpu_ref (Ming Lei) [1655485]
- [block] blkcg: remove bio_disassociate_task() (Ming Lei) [1655485]
- [block] blkcg: remove additional reference to the css (Ming Lei) [1655485]
- [block] blkcg: remove bio->bi_css and instead use bio->bi_blkg (Ming Lei) [1655485]
- [block] blkcg: associate writeback bios with a blkg (Ming Lei) [1655485]
- [block] blkcg: associate a blkg for pages being evicted by swap (Ming Lei) [1655485]
- [block] blkcg: consolidate bio_issue_init() to be a part of core (Ming Lei) [1655485]
- [block] blkcg: associate blkg when associating a device (Ming Lei) [1655485]
- [block] dm: set the static flush bio device on demand (Ming Lei) [1655485]
- [block] blkcg: introduce common blkg association logic (Ming Lei) [1655485]
- [block] blkcg: convert blkg_lookup_create() to find closest blkg (Ming Lei) [1655485]
- [block] blkcg: update blkg_lookup_create() to do locking (Ming Lei) [1655485]
- [block] blkcg: fix ref count issue with bio_blkcg() using task_css (Ming Lei) [1655485]
- [block] blk-mq: remove QUEUE_FLAG_POLL from default MQ flags (Ming Lei) [1655485]
- [block] block: enable polling by default if a poll map is initalized (Ming Lei) [1655485]
- [block] block: only allow polling if a poll queue_map exists (Ming Lei) [1655485]
- [block] block: remove ->poll_fn (Ming Lei) [1655485]
- [nvme] nvme-mpath: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-rdma: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-pci: remove the CQ lock for interrupt driven queues (Ming Lei) [1655485]
- [nvme] nvme-pci: don't poll from irq context when deleting queues (Ming Lei) [1655485]
- [nvme] nvme-pci: refactor nvme_disable_io_queues (Ming Lei) [1655485]
- [nvme] nvme-pci: consolidate code for polling non-dedicated queues (Ming Lei) [1655485]
- [nvme] nvme-pci: only allow polling with separate poll queues (Ming Lei) [1655485]
- [nvme] nvme-pci: cleanup SQ allocation a bit (Ming Lei) [1655485]
- [nvme] nvme-pci: use atomic bitops to mark a queue enabled (Ming Lei) [1655485]
- [block] block: move queues types to the block layer (Ming Lei) [1655485]
- [fs] aio: clear IOCB_HIPRI (Ming Lei) [1655485]
- [lib] sbitmap: fix sbitmap_for_each_set() (Ming Lei) [1655485]
- [block] blk-mq: don't call ktime_get_ns() if we don't need it (Ming Lei) [1655485]
- [block] block: add cmd_flags to print_req_error (Ming Lei) [1655485]
- [lib] sbitmap: optimize wakeup check (Ming Lei) [1655485]
- [lib] sbitmap: ammortize cost of clearing bits (Ming Lei) [1655485]
- [block] block: avoid extra bio reference for async O_DIRECT (Ming Lei) [1655485]
- [lib] sbitmap: don't loop for find_next_zero_bit() for !round_robin (Ming Lei) [1655485]
- [block] blk-mq: use plug for devices that implement ->commits_rqs() (Ming Lei) [1655485]
- [block] blk-mq: use bd->last == true for list inserts (Ming Lei) [1655485]
- [block] ataflop: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] virtio_blk: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [nvme] nvme: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] blk-mq: add mq_ops->commit_rqs() (Ming Lei) [1655485]
- [block] block: improve logic around when to sort a plug list (Ming Lei) [1655485]
- [block] blk-mq: Add a NULL check in blk_mq_free_map_and_requests() (Ming Lei) [1655485]
- [block] ataflop: fix error handling in atari_floppy_init() (Ming Lei) [1655485]
- [block] block: add io timeout to sysfs (Ming Lei) [1655485]
- [block] block: use rcu_work instead of call_rcu to avoid sleep in softirq (Ming Lei) [1655485]
- [block] blk-mq: fix failure to decrement plug count on single rq removal (Ming Lei) [1655485]
- [block] sunvdc: Do not spin in an infinite loop when vio_ldc_send() returns EAGAIN (Ming Lei) [1655485]
- [block] block: sum requests in the plug structure (Ming Lei) [1655485]
- [block] blk-mq: Simplify request completion state (Ming Lei) [1655485]
- [scsi] scsi: Do not rely on blk-mq for double completions (Ming Lei) [1655485]
- [block] blk-mq: Return true if request was completed (Ming Lei) [1655485]
- [block] blk-mq: never redirect polled IO completions (Ming Lei) [1655485]
- [block] blk-mq: ensure mq_ops ->poll() is entered at least once (Ming Lei) [1655485]
- [block] block: make blk_poll() take a parameter on whether to spin or not (Ming Lei) [1655485]
- [nvme] nvme: remove opportunistic polling from bdev target (Ming Lei) [1655485]
- [block] blk-mq: remove 'tag' parameter from mq_ops->poll() (Ming Lei) [1655485]
- [block] blk-mq: when polling for IO, look for any completion (Ming Lei) [1655485]
- [block] block: fix attempt to assign NULL io_context (Ming Lei) [1655485]
- [block] block: Initialize BIO I/O priority early (Ming Lei) [1655485]
- [block] block: prevent merging of requests with different priorities (Ming Lei) [1655485]
- [fs] aio: Fix fallback I/O priority value (Ming Lei) [1655485]
- [block] block: Introduce get_current_ioprio() (Ming Lei) [1655485]
- [block] block: Remove bio->bi_ioc (Ming Lei) [1655485]
- [fs] aio: Comment use of IOCB_FLAG_IOPRIO aio flag (Ming Lei) [1655485]
- [nvme] nvme-fc: remove ->poll implementation (Ming Lei) [1655485]
- [block] block: have ->poll_fn() return number of entries polled (Ming Lei) [1655485]
- [block] block: avoid ordered task state change for polled IO (Ming Lei) [1655485]
- [nvme] nvme: default to 0 poll queues (Ming Lei) [1655485]
- [block] floppy: remove now unused 'flags' variable (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [block] ide: don't acquire queue_lock in ide_complete_pm_rq (Ming Lei) [1655485]
- [block] ide: don't acquire queue lock in ide_pm_execute_rq (Ming Lei) [1655485]
- [block] pktcdvd: remove queue_lock around blk_queue_max_hw_sectors (Ming Lei) [1655485]
- [block] floppy: remove queue_lock around floppy_end_request (Ming Lei) [1655485]
- [block] block: remove the rq_alloc_data request_queue field (Ming Lei) [1655485]
- [block] block: don't plug for aio/O_DIRECT HIPRI IO (Ming Lei) [1655485]
- [block] block: for async O_DIRECT, mark us as polling if asked to (Ming Lei) [1655485]
- [block] block: add polled wakeup task helper (Ming Lei) [1655485]
- [block] blk-rq-qos: inline check for q->rq_qos functions (Ming Lei) [1655485]
- [block] block: add queue_is_mq() helper (Ming Lei) [1655485]
- [nvme] nvme: provide optimized poll function for separate poll queues (Ming Lei) [1655485]
- [block] ide: clear ide_req()->special for non-passthrough requests (Ming Lei) [1655485]
- [nvme] nvme: fix handling of EINVAL on pci_alloc_irq_vectors_affinity() (Ming Lei) [1655485]
- [block] block: add wbt_disable_default export for BFQ (Ming Lei) [1655485]
- [block] block: remove the queue_lock indirection (Ming Lei) [1655485]
- [block] block: remove the lock argument to blk_alloc_queue_node (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [mmc] mmc: simplify queue initialization (Ming Lei) [1655485]
- [block] umem: don't override the queue_lock (Ming Lei) [1655485]
- [block] drbd: don't override the queue_lock (Ming Lei) [1655485]
- [block] blk-cgroup: move locking into blkg_destroy_all (Ming Lei) [1655485]
- [block] blk-cgroup: consolidate error handling in blkcg_init_queue (Ming Lei) [1655485]
- [block] block: remove a few unused exports (Ming Lei) [1655485]
- [block] block: update a few comments for the legacy request removal (Ming Lei) [1655485]
- [block] block: remove the unused lock argument to rq_qos_throttle (Ming Lei) [1655485]
- [block] block: remove queue_lockdep_assert_held (Ming Lei) [1655485]
- [block] block: use atomic bitops for ->queue_flags (Ming Lei) [1655485]
- [block] block: don't hold the queue_lock over blk_abort_request (Ming Lei) [1655485]
- [block] block: remove deadline __deadline manipulation helpers (Ming Lei) [1655485]
- [block] block: remove QUEUE_FLAG_BYPASS and ->bypass (Ming Lei) [1655485]
- [nvme] nvmet-rdma: fix response use after free (Ming Lei) [1655485]
- [nvme] nvme: validate controller state before rescheduling keep alive (Ming Lei) [1655485]
- [block] block, bfq: fix decrement of num_active_groups (Ming Lei) [1655485]
- [ata] libata: whitelist all SAMSUNG MZ7KM* solid-state disks (Ming Lei) [1655485]
- [nvme] nvme-rdma: fix double freeing of async event data (Ming Lei) [1655485]
- [nvme] nvme-pci: fix surprise removal (Ming Lei) [1655485]
- [nvme] nvme: Free ctrl device name on init failure (Ming Lei) [1655485]
- [nvme] nvme-fc: resolve io failures during connect (Ming Lei) [1655485]
- [nvme] nvme: make sure ns head inherits underlying device limits (Ming Lei) [1655485]
- [nvme] nvmet: don't try to add ns to p2p map unless it actually uses it (Ming Lei) [1655485]
- [nvme] nvme-pci: fix conflicting p2p resource adds (Ming Lei) [1655485]
- [nvme] nvmet: Optionally use PCI P2P memory (Ming Lei) [1655485]
- [nvme] nvmet: Introduce helper functions to allocate and free request SGLs (Ming Lei) [1655485]
- [nvme] nvme-pci: Add support for P2P memory in requests (Ming Lei) [1655485]
- [nvme] nvme-pci: Use PCI p2pmem subsystem to manage the CMB (Ming Lei) [1655485]
- [infiniband] IB/core: Ensure we map P2P memory correctly in rdma_rw_ctx_[init|destroy]() (Ming Lei) [1655485]
- [block] block: Add PCI P2P flag for request queue (Ming Lei) [1655485]
- [documentation] PCI/P2PDMA: Add P2P DMA driver writer's documentation (Ming Lei) [1655485]
- [documentation] docs-rst: Add a new directory for PCI documentation (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Introduce configfs/sysfs enable attribute helpers (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add PCI p2pmem DMA mappings to adjust the bus offset (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add sysfs group to display p2pmem stats (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Support peer-to-peer memory (Ming Lei) [1655485]
- [nvme] nvmet-rdma: support max(16KB, PAGE_SIZE) inline data (Ming Lei) [1655485]
- [nvme] nvme-rdma: support up to 4 segments of inline data (Ming Lei) [1655485]
- [fs] aio: fix failure to put the file pointer (Ming Lei) [1655485]
- [lib] scsi: Remove percpu_ida (Ming Lei) [1655485]
- [scsi] scsi: target: Convert target drivers to use sbitmap (Ming Lei) [1655485]
- [scsi] scsi: target: Abstract tag freeing (Ming Lei) [1655485]
- [block] mmc: block: Fix unsupported parallel dispatch of requests (Ming Lei) [1655485]
- [scsi] scsi: target: sbitmap: add seq_file forward declaration (Ming Lei) [1655485]
- [mm] mm, memory_hotplug: do not clear numa_node association after hot_remove (Waiman Long) [1657422]
- [fs] iomap: partially revert 4721a601099 (simulated directio short read on EFAULT) (Brian Foster) [1654713]
- [fs] splice: don't read more than available pipe space (Brian Foster) [1654713]
- [fs] vfs: allow some remap flags to be passed to vfs_clone_file_range (Brian Foster) [1654713]
- [fs] xfs: fix inverted return from xfs_btree_sblock_verify_crc (Brian Foster) [1654713]
- [fs] xfs: fix PAGE_MASK usage in xfs_free_file_space (Brian Foster) [1654713]
- [fs] fs/xfs: fix f_ffree value for statfs when project quota is set (Brian Foster) [1654713]
- [fs] iomap: readpages doesn't zero page tail beyond EOF (Brian Foster) [1654713]
- [fs] vfs: vfs_dedupe_file_range() doesn't return EOPNOTSUPP (Brian Foster) [1654713]
- [fs] iomap: dio data corruption and spurious errors when pipes fill (Brian Foster) [1654713]
- [fs] iomap: sub-block dio needs to zeroout beyond EOF (Brian Foster) [1654713]
- [fs] iomap: FUA is wrong for DIO O_DSYNC writes into unwritten extents (Brian Foster) [1654713]
- [fs] xfs: delalloc -> unwritten COW fork allocation can go wrong (Brian Foster) [1654713]
- [fs] xfs: flush removing page cache in xfs_reflink_remap_prep (Brian Foster) [1654713]
- [fs] xfs: extent shifting doesn't fully invalidate page cache (Brian Foster) [1654713]
- [fs] xfs: finobt AG reserves don't consider last AG can be a runt (Brian Foster) [1654713]
- [fs] xfs: fix transient reference count error in xfs_buf_resubmit_failed_buffers (Brian Foster) [1654713]
- [fs] xfs: uncached buffer tracing needs to print bno (Brian Foster) [1654713]
- [fs] xfs: make xfs_file_remap_range() static (Brian Foster) [1654713]
- [fs] xfs: fix shared extent data corruption due to missing cow reservation (Brian Foster) [1654713]
- [fs] xfs: fix overflow in xfs_attr3_leaf_verify (Brian Foster) [1654713]
- [fs] xfs: print buffer offsets when dumping corrupt buffers (Brian Foster) [1654713]
- [fs] xfs: Fix error code in 'xfs_ioc_getbmap()' (Brian Foster) [1654713]
- [fs] xfs: cancel COW blocks before swapext (Brian Foster) [1654713]
- [fs] xfs: clear ail delwri queued bufs on unmount of shutdown fs (Brian Foster) [1654713]
- [fs] xfs: use offsetof() in place of offset macros for __xfsstats (Brian Foster) [1654713]
- [fs] xfs: Fix xqmstats offsets in /proc/fs/xfs/xqmstat (Brian Foster) [1654713]
- [fs] xfs: fix use-after-free race in xfs_buf_rele (Brian Foster) [1654713]
- [fs] xfs: Add attibute remove and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add attibute set and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add helper function xfs_attr_try_sf_addname (Brian Foster) [1654713]
- [fs] xfs: Move fs/xfs/xfs_attr.h to fs/xfs/libxfs/xfs_attr.h (Brian Foster) [1654713]
- [fs] xfs: issue log message on user force shutdown (Brian Foster) [1654713]
- [fs] xfs: fix buffer state management in xrep_findroot_block (Brian Foster) [1654713]
- [fs] xfs: always assign buffer verifiers when one is provided (Brian Foster) [1654713]
- [fs] xfs: xrep_findroot_block should reject root blocks with siblings (Brian Foster) [1654713]
- [fs] xfs: add a define for statfs magic to uapi (Brian Foster) [1654713]
- [fs] xfs: print dangling delalloc extents (Brian Foster) [1654713]
- [fs] xfs: fix fork selection in xfs_find_trim_cow_extent (Brian Foster) [1654713]
- [fs] xfs: remove the unused trimmed argument from xfs_reflink_trim_around_shared (Brian Foster) [1654713]
- [fs] xfs: remove the unused shared argument to xfs_reflink_reserve_cow (Brian Foster) [1654713]
- [fs] xfs: handle zeroing in xfs_file_iomap_begin_delay (Brian Foster) [1654713]
- [fs] xfs: remove suport for filesystems without unwritten extent flag (Brian Foster) [1654713]
- [fs] xfs: remove XFS_IO_INVALID (Brian Foster) [1654713]
- [fs] xfs: remove [cm]time update from reflink calls (Brian Foster) [1654713]
- [fs] xfs: remove xfs_reflink_remap_range (Brian Foster) [1654713]
- [fs] xfs: remove redundant remap partial EOF block checks (Brian Foster) [1654713]
- [fs] xfs: support returning partial reflink results (Brian Foster) [1654713]
- [fs] xfs: clean up xfs_reflink_remap_blocks call site (Brian Foster) [1654713]
- [fs] xfs: fix pagecache truncation prior to reflink (Brian Foster) [1654713]
- [fs] vfs: clean up generic_remap_file_range_prep return value (Brian Foster) [1654713]
- [fs] vfs: hide file range comparison function (Brian Foster) [1654713]
- [fs] vfs: enable remap callers that can handle short operations (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs dedupe functions (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs clone functions (Brian Foster) [1654713]
- [fs] vfs: make remap_file_range functions take and return bytes completed (Brian Foster) [1654713]
- [fs] vfs: remap helper should update destination inode metadata (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_file_range_prep (Brian Foster) [1654713]
- [fs] vfs: combine the clone and dedupe into a single remap_file_range (Brian Foster) [1654713]
- [fs] vfs: rename clone_verify_area to remap_verify_area (Brian Foster) [1654713]
- [fs] vfs: rename vfs_clone_file_prep to be more descriptive (Brian Foster) [1654713]
- [fs] vfs: skip zero-length dedupe requests (Brian Foster) [1654713]
- [fs] vfs: avoid problematic remapping requests into partial EOF block (Brian Foster) [1654713]
- [fs] vfs: strengthen checking of file range inputs to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: exit early from zero length remap operations (Brian Foster) [1654713]
- [fs] vfs: check file ranges before cloning files (Brian Foster) [1654713]
- [fs] vfs: vfs_clone_file_prep_inodes should return EINVAL for a clone from beyond EOF (Brian Foster) [1654713]
- [block] blk-mq: not embed .mq_kobj and ctx->kobj into queue instance (Ming Lei) [1653124]
- [fs] fs: fix lost error code in dio_complete (Ming Lei) [1655364]
- [iommu] iommu/iova: Optimise attempts to allocate iova from 32bit address range (Robert Richter) [1639202]

* Fri Dec 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-54.el8]
- [drm] drm/nouveau/drm/nouveau: Check rc from drm_dp_mst_topology_mgr_resume() (Lyude Paul) [1658810]
- [x86] Mark Intel Apollo Lake supported (David Arcari) [1653799]
- [infiniband] IB/mlx5: Fix implicit ODP interrupted page fault (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Improve ODP debugging messages (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Use multi threaded workqueue for page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Return success for PAGE_FAULT_RESUME in internal error state (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Lock QP during page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Enumerate page fault types (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Add interface to hold and release core resources (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Release resource on error flow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Correctly set PFC param if global pause is turned off. (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_en: Change min MTU size to ETH_MIN_MTU (Alaa Hleihel) [1658085]
- [netdrv] mlx5: fix get_ip_proto() (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix page fault handling for MW (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Initialize return variable in case pagefault was skipped (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Skip non-ODP MR when handling a page fault (Alaa Hleihel) [1658085]
- [net] net/dim: Update DIM start sample after each DIM iteration (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Avoid load failure due to unknown link width (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Fix fence type for IB_WR_LOCAL_INV WR (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Removed unnecessary warnings in FEC caps query (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Fix selftest for small MTUs (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, verify received packet size in Linear Striding RQ (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Apply the correct check for supporting TC esw rules split (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Adjust to max number of channles when re-attaching (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Always use the match level enum when parsing TC rule match (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Claim TC hw offloads support only under a proper build config (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Don't match on vlan non-existence if ethertype is wildcarded (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: IPoIB, Reset QP after channels are closed (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4: Fix UBSAN warning of signed integer overflow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Fix uninitialized variable compilation warning (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix MR cache initialization (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove extraneous error check (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Take only bit 24-26 of wqe.pftype_wq for page fault type (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix memory leak when setting fpga ipsec caps (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Unmap DMA addr from HCA before IOMMU (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove superfluous version print (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Allow transition of DCI QP to reset (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Don't hold spin lock while checking device state (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Move mlx5e_priv_flags into en_ethtool.c (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix atomic_mode enum values (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Delete unneeded function argument (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, Prefetch the xdp_frame data area (Alaa Hleihel) [1658085]
- [drm] drm/i915: Synchronize hpd work in i915_hpd_storm_ctl_show() (Lyude Paul) [1658376]
- [drm] drm/i915: Add short HPD IRQ storm detection for non-MST systems (Lyude Paul) [1658376]
- [drm] drm/i915: Clarify flow for disabling IRQs on storms (Lyude Paul) [1658376]
- [drm] drm/i915: Fix threshold check in intel_hpd_irq_storm_detect() (Lyude Paul) [1658376]
- [drm] drm/i915: Fix NULL deref when re-enabling HPD IRQs on systems with MST (Lyude Paul) [1658376]
- [drm] drm/i915: Fix possible race in intel_dp_add_mst_connector() (Lyude Paul) [1658376]
- [x86] kvm: x86: bump KVM_(SOFT_)MAX_VCPUS to 384 (Radim Krcmar) [1635205]
- [block] blk-mq: punt failed direct issue to dispatch list (Ming Lei) [1656653]
- [block] blk-mq: fix corruption with direct issue (Ming Lei) [1656653]
- [pci] PCI: Add support for Immediate Readiness (Myron Stowe) [1483409]
- [x86] x86/PCI: Remove node-local allocation when initialising host controller (Myron Stowe) [1483409]
- [arm64] arm64: PCI: Remove node-local allocations when initialising host controller (Myron Stowe) [1483409]
- [cpufreq] cpufreq: intel_pstate: Add base_frequency attribute (Prarit Bhargava) [1648207]
- [acpi] ACPI / CPPC: Add support for guaranteed performance (Prarit Bhargava) [1648207]
- [block] block: fix single range discard merge (Ming Lei) [1654096]
- [scsi] SCSI: fix queue cleanup race before queue initialization is done (Ming Lei) [1642404]
- [netdrv] net: hinic: fix null pointer dereference on pointer hwdev (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: fix a bug in rx data flow (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:fix a bug in set mac address (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:add rx checksum offload for HiNIC (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:replace multiply and division operators (Xiaojun Tan) [1654207]
- [netdrv] hinic: Fix l4_type parameter in hinic_task_set_tunnel_l4 (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: add checksum offload and TSO support (Xiaojun Tan) [1654207]
- [netdrv] cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size (Arjun Vynipadath) [1651082]

* Thu Dec 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-53.el8]
- [x86] kvm: x86: Report STIBP on GET_SUPPORTED_CPUID (Eduardo Habkost) [1644870]
- [kernel] power: remove possible deadlock when unregistering power_supply (Benjamin Tissoires) [1657623]
- [md] dm: call blk_queue_split() to impose device limits on bios (Mike Snitzer) [1657340]
- [pinctrl] Revert "pinctrl: intel: Do pin translation when lock IRQ" (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix HOSTSW_OWN register offset of H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation in other GPIO operations as well (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix gpio base for GPP-E (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Don't shadow error code of gpiochip_lock_as_irq() (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix community ordering for H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation when lock IRQ (Benjamin Tissoires) [1658075]
- [firmware] efi: Prevent GICv3 WARN() by mapping the memreserve table before first use (Bhupesh Sharma) [1638640]
- [firmware] efi: Permit calling efi_mem_reserve_persistent() from atomic context (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Defer persistent reservations until after paging_init() (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Revert deferred unmap of early memmap mapping (Bhupesh Sharma) [1638640]
- [arm64] arm64: memblock: don't permit memblock resizing until linear mapping is up (Bhupesh Sharma) [1638640]
- [arm64] arm64: Fix /proc/iomem for reserved but not memory regions (Bhupesh Sharma) [1638640]
- [tty] tty: wipe buffer. (Christoph von Recklinghausen) [1655051]
- [tty] tty: wipe buffer if not echoing data (Christoph von Recklinghausen) [1655051]

* Wed Dec 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-52.el8]
- [powerpc] powerpc/perf: Remove sched_task function defined for thread-imc (Steve Best) [1657153]
- [s390] Add reserved fields to mm_context_t (Philipp Rudo) [1656874]
- [s390] Add reserved fields to thread_struct (Philipp Rudo) [1656874]
- [documentation] kdump: correct crashkernel=auto threshold (Raghavendra Rao) [1656698]
- [fs] NFSv4.x: fix lock recovery during delegation recall (Steve Dickson) [1656410]
- [x86] x86/spec_ctrl: Synchronize RHEL8 percpu SPEC_CTRL MSR states with new STIBP logic (Waiman Long) [1655662]
- [x86] x86/speculation: Provide IBPB always command line options (Waiman Long) [1655662]
- [x86] x86/speculation: Add seccomp Spectre v2 user space protection mode (Waiman Long) [1655662]
- [x86] x86/speculation: Enable prctl mode for spectre_v2_user (Waiman Long) [1655662]
- [x86] x86/speculation: Add prctl() control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare arch_smt_update() for PRCTL mode (Waiman Long) [1655662]
- [x86] x86/speculation: Prevent stale SPEC_CTRL msr content (Waiman Long) [1655662]
- [x86] x86/speculation: Split out TIF update (Waiman Long) [1655662]
- [x86] ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for conditional IBPB in switch_mm() (Waiman Long) [1655662]
- [x86] x86/speculation: Avoid __switch_to_xtra() calls (Waiman Long) [1655662]
- [x86] x86/process: Consolidate and simplify switch_to_xtra() code (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for per task indirect branch speculation control (Waiman Long) [1655662]
- [x86] x86/speculation: Add command line control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Unify conditional spectre v2 print functions (Waiman Long) [1655662]
- [x86] x86/speculataion: Mark command line parser data __initdata (Waiman Long) [1655662]
- [x86] x86/speculation: Mark string arrays const correctly (Waiman Long) [1655662]
- [x86] x86/speculation: Reorder the spec_v2 code (Waiman Long) [1655662]
- [x86] x86/l1tf: Show actual SMT state (Waiman Long) [1655662]
- [x86] x86/speculation: Rework SMT state change (Waiman Long) [1655662]
- [x86] sched/smt: Expose sched_smt_present static key (Waiman Long) [1655662]
- [x86] x86/Kconfig: Select SCHED_SMT if SMP enabled (Waiman Long) [1655662]
- [x86] sched/smt: Make sched_smt_present track topology (Waiman Long) [1655662]
- [x86] x86/speculation: Reorganize speculation control MSRs update (Waiman Long) [1655662]
- [x86] x86/speculation: Rename SSBD update functions (Waiman Long) [1655662]
- [x86] x86/speculation: Disable STIBP when enhanced IBRS is in use (Waiman Long) [1655662]
- [x86] x86/speculation: Move STIPB/IBPB string conditionals out of cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Remove unnecessary ret variable in cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Clean up spectre_v2_parse_cmdline() (Waiman Long) [1655662]
- [x86] x86/speculation: Update the TIF_SSBD comment (Waiman Long) [1655662]
- [x86] x86/retpoline: Remove minimal retpoline support (Waiman Long) [1655662]
- [x86] x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support (Waiman Long) [1655662]
- [x86] x86/spec_ctrl: Temporarily remove the IBRS code from process.c & bugs.c (Waiman Long) [1655662]
- [nvme] nvme: flush namespace scanning work just before removing namespaces (Ewan Milne) [1656028]
- [netdrv] i40e: Fix deletion of MAC filters (Stefan Assmann) [1646847]
- [scsi] mpt3sas: Display message on Configurable secure HBA (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Add support for Aero controllers (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Update MPI headers to support Aero controllers (Tomas Henzl) [1649314]
- [scsi] megaraid_sas: Add support for MegaRAID Aero controllers (Tomas Henzl) [1649384]
- [netdrv] nfp: flower: enabled offloading of Team LAG (Pablo Cascon) [1649876]
- [netdrv] net/mlx5: IPSec, Fix the SA context hash key (Alaa Hleihel) [1645857]
- [hwmon] hwmon/k10temp: Add support for AMD family 17h, model 30h CPUs (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add PCI device IDs for family 17h, model 30h (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add support for newer PCI topologies (Gary Hook) [1640681]
- [hwmon] hwmon/k10temp, x86/amd_nb: Consolidate shared device IDs (Gary Hook) [1640681]
- [net] tipc: fix info leak from kernel tipc_event (Jon Maloy) [1643279]
- [net] tipc: eliminate message disordering during binding table update (Jon Maloy) [1643279]
- [net] tipc: fix unsafe rcu locking when accessing publication list (Jon Maloy) [1643279]
- [net] tipc: queue socket protocol error messages into socket receive buffer (Jon Maloy) [1643279]
- [net] tipc: ignore STATE_MSG on wrong link session (Jon Maloy) [1643279]
- [net] tipc: fix failover problem (Jon Maloy) [1643279]
- [net] tipc: eliminate possible recursive locking detected by LOCKDEP (Jon Maloy) [1643279]
- [net] tipc: lock wakeup & inputq at tipc_link_reset() (Jon Maloy) [1643279]
- [net] tipc: reset bearer if device carrier not ok (Jon Maloy) [1643279]
- [net] tipc: fix flow control accounting for implicit connect (Jon Maloy) [1643279]
- [net] tipc: check return value of __tipc_dump_start() (Jon Maloy) [1643279]
- [net] tipc: call start and done ops directly in __tipc_nl_compat_dumpit() (Jon Maloy) [1643279]
- [net] tipc: orphan sock in tipc_release() (Jon Maloy) [1643279]
- [net] tipc: switch to rhashtable iterator (Jon Maloy) [1643279]
- [net] tipc: fix a missing rhashtable_walk_exit() (Jon Maloy) [1643279]
- [net] tipc: add missing dev_put() on error in tipc_enable_l2_media (Jon Maloy) [1643279]
- [net] tipc: initialize broadcast link stale counter correctly (Jon Maloy) [1643279]
- [net] tipc: set link tolerance correctly in broadcast link (Jon Maloy) [1643279]
- [net] tipc: extend link reset criteria for stale packet retransmission (Jon Maloy) [1643279]
- [crypto] crypto: ccp - Add support for new CCP/PSP device ID (Gary Hook) [1634201]
- [crypto] crypto: ccp - Support register differences between PSP devices (Gary Hook) [1634201]
- [crypto] crypto: ccp - Remove unused #defines (Gary Hook) [1634201]
- [crypto] crypto: ccp - Add psp enabled message when initialization succeeds (Gary Hook) [1634201]
- [crypto] crypto: ccp - Fix command completion detection race (Gary Hook) [1634201]
- [crypto] crypto: ccp - Check for NULL PSP pointer at module unload (Gary Hook) [1634201]
- [net] sctp: increase sk_wmem_alloc when head->truesize is increased (Xin Long) [1645419]
- [net] sctp: count sk_wmem_alloc by skb truesize in sctp_packet_transmit (Xin Long) [1645419]
- [net] ipv6: re-do dad when interface has IFF_NOARP flag change (Hangbin Liu) [1644594]
- [net] netfilter: nf_tables: don't skip inactive chains during update (Florian Westphal) [1643746]
- [net] inet: frags: better deal with smp races (Sabrina Dubroca) [1645397]
- [net] geneve, vxlan: Don't set exceptions if skb->len < mtu (Xin Long) [1642842]
- [net] geneve, vxlan: Don't check skb_dst() twice (Xin Long) [1642842]
- [net] sctp: fix strchange_flags name for Stream Change Event (Xin Long) [1641852]
- [net] sctp: update dst pmtu with the correct daddr (Xin Long) [1644478]
- [net] sctp: not free the new asoc when sctp_wait_for_connect returns err (Xin Long) [1644155]
- [net] l2tp: fix a sock refcnt leak in l2tp_tunnel_register (Xin Long) [1642749]
- [net] sctp: check policy more carefully when getting pr status (Xin Long) [1637786]
- [net] sctp: get pr_assoc and pr_stream all status with SCTP_PR_SCTP_ALL instead (Xin Long) [1637786]
- [net] ipv4/igmp: fix v1/v2 switchback timeout based on rfc3376, 8.12 (Hangbin Liu) [1638598]
- [net] netfilter: nft_compat: ebtables 'nat' table is normal chain type (Florian Westphal) [1645377]
- [net] sched: exclude TC from kABI guarantee (Ivan Vecera) [1628454]
- [net] netfilter: nft_set_rbtree: allow loose matching of closing element in interval (Phil Sutter) [1641993]
- [net] netfilter: xt_nat: fix DNAT target for shifted portmap ranges (Paolo Abeni) [1634258]
- [net] sched: Fix for duplicate class dump (Phil Sutter) [1631179]
- [x86] KVM: X86: Fix scan ioapic use-before-initialization (Bandan Das) [1653835] {CVE-2018-19407}

* Fri Dec 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-51.el8]
- [scsi] scsi: vmw_pscsi: Rearrange code to avoid multiple calls to free_irq during unload (Cathy Avery) [1590875]
- [netdrv] net/ibmvnic: Fix RTNL deadlock during device reset (Steve Best) [1656076]
- [s390] s390/qeth: fix length check in SNMP processing (Philipp Rudo) [1655612]
- [s390] s390/ism: clear dmbe_mask bit before SMC IRQ handling (Philipp Rudo) [1655611]
- [net] net/smc: use after free fix in smc_wr_tx_put_slot() (Philipp Rudo) [1655611]
- [net] net/smc: atomic SMCD cursor handling (Philipp Rudo) [1655611]
- [net] net/smc: add SMC-D shutdown signal (Philipp Rudo) [1655611]
- [net] net/smc: use queue pair number when matching link group (Philipp Rudo) [1655611]
- [net] net/smc: abort CLC connection in smc_release (Philipp Rudo) [1655611]
- [net] net/smc: unregister rkeys of unused buffer (Philipp Rudo) [1655611]
- [net] net/smc: add infrastructure to send delete rkey messages (Philipp Rudo) [1655611]
- [net] net/smc: avoid a delay by waiting for nothing (Philipp Rudo) [1655611]
- [net] net/smc: cleanup listen worker mutex unlocking (Philipp Rudo) [1655611]
- [net] net/smc: short wait for late smc_clc_wait_msg (Philipp Rudo) [1655611]
- [net] net/smc: no link delete for a never active link (Philipp Rudo) [1655611]
- [net] net/smc: allow fallback after clc timeouts (Philipp Rudo) [1655611]
- [net] net/smc: remove sock_error detour in clc-functions (Philipp Rudo) [1655611]
- [net] net/smc: make smc_lgr_free() static (Philipp Rudo) [1655611]
- [net] net/smc: cleanup tcp_listen_worker initialization (Philipp Rudo) [1655611]
- [net] net/smc: fix smc_buf_unuse to use the lgr pointer (Philipp Rudo) [1655611]
- [net] Revert "net: simplify sock_poll_wait" (Philipp Rudo) [1655611]
- [powerpc] powerpc/pseries: Fix unitialized timer reset on migration (Steve Best) [1655053]
- [powerpc] powerpc/pseries/mobility: Extend start/stop topology update scope (Steve Best) [1655053]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1641425]

* Wed Dec 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-50.el8]
- [x86] KVM: VMX: re-add ple_gap module parameter (Gary Hook) [1652953]
- [netdrv] tg3: Add PHY reset for 5717/5719/5720 in change ring and flow control paths (Steve Best) [1655515]
- [pci] PCI/ASPM: Do not initialize link state when aspm_disabled is set (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Allow _OSC presence to be optional for PCI (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Correct error message for ASPM disabling (Myron Stowe) [1655246]
- [pci] PCI/ASPM: Fix link_state teardown on device removal (Myron Stowe) [1655246]
- [netdrv] ice: Change req_speeds to be u16 (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix the bytecount sent to netdev_tx_sent_queue (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix tx_timeout in PF driver (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix napi delete calls for remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix typo in error message (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix flags for port VLAN (Jonathan Toppins) [1644403]
- [netdrv] ice: Remove duplicate addition of VLANs in replay path (Jonathan Toppins) [1644403]
- [netdrv] ice: Free VSI contexts during for unload (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix dead device link issue with flow control (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for reset in progress during remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Set carrier state and start/stop queues in rebuild (Jonathan Toppins) [1644403]
- [netdrv] virtchnl: Added support to exchange additional speed values (Jonathan Toppins) [1644403]
- [netdrv] ice: Poll for link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Allocate VF interrupts and set queue map (Jonathan Toppins) [1644403]
- [netdrv] ice: Introduce ice_dev_onetime_setup (Jonathan Toppins) [1644403]
- [netdrv] ice: Use capability count returned by the firmware (Jonathan Toppins) [1644403]
- [netdrv] ice: Update expected FW version (Jonathan Toppins) [1644403]
- [netdrv] ice: Change device ID define names to align with branding string (Jonathan Toppins) [1644403]
- [netdrv] ice: Make ice_msix_clean_rings static (Jonathan Toppins) [1644403]
- [netdrv] ice: Update version string (Jonathan Toppins) [1644403]
- [netdrv] ice: Use the right function to enable/disable VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add more flexibility on how we assign an ITR index (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix potential null pointer issues (Jonathan Toppins) [1644403]
- [netdrv] ice: Add code to go from ICE_FWD_TO_VSI_LIST to ICE_FWD_TO_VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix forward to queue group logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Extend malicious operations detection logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Notify VF of link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement virtchnl commands for AVF support (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handlers for VF netdevice operations (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for VF reset events (Jonathan Toppins) [1644403]
- [netdrv] ice: Update VSI and queue management code to handle VF VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handler to configure SR-IOV (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support to detect SR-IOV capability and mailbox queues (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix error on driver remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for dynamic interrupt moderation (Jonathan Toppins) [1644403]
- [netdrv] ice: Align ice_reset_req enum values to hardware reset values (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement ethtool hook for RSS switch (Jonathan Toppins) [1644403]
- [netdrv] ice: Split irq_tracker into sw_irq_tracker and hw_irq_tracker (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for actual link state of port after reset (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement VSI replay framework (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 2/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 1/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Change pf state behavior to protect reset path (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 7/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 6/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 5/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 4/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 3/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 2/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 1/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: fix changing of ring descriptor size (ethtool -G) (Jonathan Toppins) [1644403]
- [netdrv] ice: Update to capabilities admin queue command (Jonathan Toppins) [1644403]
- [netdrv] ice: Query the Tx scheduler node before adding it (Jonathan Toppins) [1644403]
- [netdrv] ice: Update comment for ice_fltr_mgmt_list_entry (Jonathan Toppins) [1644403]
- [netdrv] ice: update fw version check logic (Jonathan Toppins) [1644403]
- [netdrv] ice: update branding strings and supported device ids (Jonathan Toppins) [1644403]
- [netdrv] ice: replace unnecessary memcpy with direct assignment (Jonathan Toppins) [1644403]
- [netdrv] ice: use [sr]q.count when checking if queue is initialized (Jonathan Toppins) [1644403]
- [netdrv] ice: remove ndo_poll_controller (Jonathan Toppins) [1644403]
- [fs] fanotify: fix handling of events on child sub-directory (Miklos Szeredi) [1652432]
- [fs] fsnotify: generalize handling of extra event flags (Miklos Szeredi) [1652432]
- [netdrv] net: hns3: add common validation in hclge_dcb (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix for multiple unmapping DMA problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename hns_nic_dma_unmap (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add handling for big TX fragment (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: move DMA map into hns3_fill_desc (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hns3_fill_desc_tso (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after loopback test (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Enable promisc mode when mac vlan table is full (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for rx vlan id handle to support Rev 0x21 hardware (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add egress/ingress vlan filter for revision 0x21 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Optimize for unicast mac vlan table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix loss of coal configuration while doing reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify hns3_get_max_available_channels (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change return type of hclge_tm_schd_info_update() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for netdev not up problem when setting mtu (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for packet buffer setting bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set extra mac address of pause param for HW (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix speed/duplex information loss problem when executing ethtool ethx cmd of VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add get_media_type ops support for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove print messages for error packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add nic state check before calling netif_tx_wake_queue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add handle for default case (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Unify the prefix of vf functions (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tqp array traversal condition for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ets validate issue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix parameter type for q_id in hclge_tm_q_to_qs_map_cfg() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix client initialize state issue when roce client initialize failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Clear client pointer when initialize client failed or unintialize finished (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix cmdq registers initialization issue for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for setting speed for phy failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Check hdev state when getting link status (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set STATE_DOWN bit of hdev state when stopping net (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove packet statistics of public (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove tx budget to clean more TX descriptors in a napi (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine hns3_get_link_ksettings() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove redundant codes of query advertised flow control abilitiy (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change the dst mac addr of loopback packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Only update mac configuation when necessary (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Preserve vlan 0 in hardware table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ping exited problem when doing lp selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for loopback selftest failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix error of checking used vlan id (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for multicast failure (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for vf vlan delete failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify variable type in hns3_nic_reuse_page (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add vlan filter setting by ethtool command -K (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set tx ring' tc info when netdev is up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix desc num set to default when setting channel (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for information of phydev lost problem when down/up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add support for serdes loopback selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine the MSIX allocation for PF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix MSIX allocation issue for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix return value error while hclge_cmd_csq_clean failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify inconsistent bit mask macros (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for using wrong mask and shift in hclge_get_ring_chain_from_mbx (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Correct reset event status register (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent to request reset frequently (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent sending command during global or core reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add configure for mac minimal frame size (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for l4 checksum offload bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for waterline not setting correctly (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tc setup when netdev is first up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify hnae_ to hnae3_ (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: simplify hclge_cmd_csq_clean (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove some redundant assignments (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove back in struct hclge_hw (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add unlikely for error check (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add l4_type check for both ipv4 and ipv6 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add vector status check before free vector (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename the interface for init_client_instance and uninit_client_instance (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hclge_get_vector_index from hclge_bind_ring_with_vector (Xiaojun Tan) [1640945]
- [kernel] redhat: Enable -Werror for architectures (Laura Abbott) [1582754]
- [drm] drm/atomic_helper: Remove dangling variable (Laura Abbott) [1582754]
- [s390] s390/tools: fix gcc 8 stringop-truncation warnings (Laura Abbott) [1582754]
- [tty] kgdboc: Fix restrict error (Laura Abbott) [1582754]
- [misc] misc: kgdbts: Fix restrict error (Laura Abbott) [1582754]
- [scsi] scsi: ibmvscsis: Fix a stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/extmem: fix gcc 8 stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/perf: fix gcc 8 array-bounds warning (Laura Abbott) [1582754]
- [kernel] kdb: Use strscpy with destination buffer size (Laura Abbott) [1582754]
- [fs] configfs: replace strncpy with memcpy (Laura Abbott) [1582754]
- [fs] kernfs: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [kernel] disable stringop truncation warnings for now (Laura Abbott) [1582754]
- [sound] ALSA: intel_hdmi: Use strlcpy() instead of strncpy() (Laura Abbott) [1582754]
- [sound] ALSA: trident: Suppress gcc string warning (Laura Abbott) [1582754]
- [lib] kobject: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [tty] TTY: isdn: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [target] scsi: target/iscsi: Make iscsit_ta_authentication() respect the output buffer size (Laura Abbott) [1582754]
- [fs] fuse: don't need GETATTR after every READ (Miklos Szeredi) [1650538]
- [fs] fuse: allow fine grained attr cache invaldation (Miklos Szeredi) [1650538]

* Tue Dec 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-49.el8]
- [mm] mm: mremap: properly flush TLB before releasing the page (Rafael Aquini) [1645122] {CVE-2018-18281}
- [x86] x86/spec_ctrl: Change default Skylake Spectre v2 mitigation to retpoline (Waiman Long) [1651806]
- [fs] gfs2: write revokes should traverse sd_ail1_list in reverse (Andreas Grunbacher) [1652763]
- [fs] gfs2: Fix marking bitmaps non-full (Andreas Grunbacher) [1652762]
- [fs] GFS2: Flush the GFS2 delete workqueue before stopping the kernel threads (Andreas Grunbacher) [1652761]
- [fs] gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd (Andreas Grunbacher) [1652759]
- [fs] gfs2: Use fs_* functions instead of pr_* function where we can (Andreas Grunbacher) [1652757]
- [fs] gfs2: slow the deluge of io error messages (Andreas Grunbacher) [1652757]
- [fs] gfs2_meta: ->mount() can get NULL dev_name (Andreas Grunbacher) [1652754]
- [powerpc] powerpc/vdso: Correct call frame information (Steve Best) [1651281]
- [i2c] i2c: i801: Add support for Intel Ice Lake (David Arcari) [1637435]
- [usb] xhci: Add quirk to workaround the errata seen on Cavium Thunder-X2 Soc (Robert Richter) [1649829]
- [x86] x86: numa_emulation: fix uniform-split numa emulation (Rafael Aquini) [1620341]
- [x86] x86: numa_emulation: introduce uniform split capability (Rafael Aquini) [1620341]
- [kernel] perf/hw_breakpoint: Modify breakpoint even if the new attr has disabled set (Mark Salter) [1643174]
- [x86] KVM: vmx: hyper-v: don't pass EPT configuration info to vmx_hv_remote_flush_tlb() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: support CONFIG_KVM_AMD=y with CONFIG_CRYPTO_DEV_CCP_DD=m (Paolo Bonzini) [1636610]
- [x86] kvm: nVMX: fix entry with pending interrupt if APICv is enabled (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: hide flexpriority from guest when disabled at the module level (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check for existence of secondary exec controls before accessing (Paolo Bonzini) [1636610]
- [x86] KVM: x86: fix L1TF's MMIO GFN calculation (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: cut down decimal places in update interval dialog (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix emulation of VM_ENTRY_LOAD_BNDCFGS (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not use kvm_x86_ops->mpx_supported() directly (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Do not expose MPX VMX controls when guest MPX disabled (Paolo Bonzini) [1636610]
- [x86] KVM: x86: never trap MSR_KERNEL_GS_BASE (Paolo Bonzini) [1636610]
- [x86] KVM: LAPIC: Fix pv ipis out-of-bounds access (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix loss of pending IRQ/NMI before entering L2 (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: re-animate display of dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: indicate dead guests as such (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: handle guest removals more gracefully (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: don't reset stats when setting PID filter for debugfs (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix updates for dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix handling of invalid paths in debugfs provider (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix python3 issues (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Unexport x86_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Rename emulate_instruction() to kvm_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not re-{try, execute} after failed emulation in L2 (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Default to not allowing emulation retry in kvm_mmu_page_fault (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Invert emulation re-execute behavior to make it opt-in (Paolo Bonzini) [1636610]
- [x86] KVM: x86: SVM: Set EMULTYPE_NO_REEXECUTE for RSM emulation (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: Do not allow reexecute_instruction() when skipping MMIO instr (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: remove unused variable dst_vaddr_end (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: avoid redundant double assignment of nested_run_pending (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix bad cleanup on error of get/set nested state IOCTLs (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: Add platform_info_test (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Control guest reads of MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Turbo bits in MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] nVMX x86: Check VPID value on vmentry of L2 guests (Paolo Bonzini) [1636610]
- [x86] nVMX x86: check posted-interrupt descriptor addresss on vmentry of L2 (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Wake blocked vCPU in guest-mode if pending interrupt in virtual APICv (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check nested state and CR4.VMXE against SMM (Paolo Bonzini) [1636610]
- [x86] kvm: x86: make kvm_{load|put}_guest_fpu() static (Paolo Bonzini) [1636610]
- [x86] x86/hyper-v: rename ipi_arg_{ex, non_ex} structures (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: use preemption timer to force immediate VMExit (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: modify preemption timer bit only when arming timer (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: immediately mark preemption timer expired only for zero value (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: Switch to bitmap_zalloc() (Paolo Bonzini) [1636610]
- [lib] bitmap: Add bitmap_alloc(), bitmap_zalloc() and bitmap_free() (Paolo Bonzini) [1636610]
- [x86] KVM/MMU: Fix comment in walk_shadow_page_lockless_end() (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: use -pthread instead of -lpthread (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: add dirty logging test (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: pass in extra memory when create vm (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: include the tools headers (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: unify the guest port macros (Paolo Bonzini) [1636610]
- [x86] KVM: x86: don't reset root in kvm_mmu_setup() (Paolo Bonzini) [1636610]
- [x86] kvm: mmu: Don't read PDPTEs when paging is not enabled (Paolo Bonzini) [1636610]
- [x86] x86/kvm/lapic: always disable MMIO interface in x2APIC mode (Paolo Bonzini) [1636610]
- [s390] KVM: s390: Make huge pages unavailable in ucontrol VMs (Paolo Bonzini) [1636610]
- [s390] s390/mm: Check for valid vma before zapping in gmap_discard (Paolo Bonzini) [1636610]
- [tools] selftests: add headers_install to lib.mk (Paolo Bonzini) [1636610]
- [tools] selftests: kselftest: Remove outdated comment (Paolo Bonzini) [1636610]
- [tools] selftests: android: move config up a level (Paolo Bonzini) [1636610]
- [md] md: Avoid namespace collision with bitmap API (Paolo Bonzini) [1636610]

* Fri Nov 30 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-48.el8]
- [cpufreq] cpufreq / CPPC: Add cpuinfo_cur_freq support for CPPC (Prarit Bhargava) [1654361]
- [netdrv] nfp: flower: add ipv6 set flow label and hop limit offload (Pablo Cascon) [1651639]
- [netdrv] nfp: flower: add ipv4 set ttl and tos offload (Pablo Cascon) [1651639]
- [netdrv] ibmvnic: Update driver queues after change in ring size support (Steve Best) [1651947]
- [netdrv] ibmvnic: Fix RX queue buffer cleanup (Steve Best) [1651947]
- [netdrv] net/ibmnvic: Fix deadlock problem in reset (Steve Best) [1651947]
- [netdrv] ibmvnic: fix accelerated VLAN handling (Steve Best) [1651947]
- [netdrv] ibmvnic: Add ethtool private flag for driver-defined queue limits (Steve Best) [1651947]
- [netdrv] ibmvnic: Introduce driver limits for ring sizes (Steve Best) [1651947]
- [netdrv] ibmvnic: Increase maximum queue size limit (Steve Best) [1651947]
- [netdrv] ibmvnic: remove ndo_poll_controller (Steve Best) [1651947]
- [powerpc] powerpc/powernv/npu: Remove atsd_threshold debugfs setting (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Use size-based ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Reduce eieio usage when issuing ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Add a debugfs setting to change ATSD threshold (Steve Best) [1653661]
- [net] libceph: fall back to sendmsg for slab pages (Ilya Dryomov) [1653395]
- [s390] s390/qeth: utilize virtual MAC for Layer2 OSD devices (Philipp Rudo) [1653246]
- [fs] vfs: fix FIGETBSZ ioctl on an overlayfs file (Miklos Szeredi) [1651362]
- [fs] ovl: fix decode of dir file handle with multi lower layers (Miklos Szeredi) [1651362]
- [fs] ovl: fix missing override creds in link of a metacopy upper (Miklos Szeredi) [1651362]
- [fs] ovl: automatically enable redirect_dir on metacopy=on (Miklos Szeredi) [1651362]
- [fs] ovl: check whiteout in ovl_create_over_whiteout() (Miklos Szeredi) [1651362]
- [fs] ovl: fix recursive oi->lock in ovl_link() (Miklos Szeredi) [1651362]
- [fs] ovl: fix error handling in ovl_verify_set_fh() (Miklos Szeredi) [1651362]
- [mm] mm, memory_hotplug: check zone_movable in has_unmovable_pages (Baoquan He) [1643839]
- [netdrv] hv_netvsc: fix vf serial matching with pci slot info (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: remove ndo_poll_controller (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: pair VF based on serial number (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: fix schedule in RCU context (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Fix return value check in hv_pci_assign_slots() (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: support reporting serial number as slot information (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Replace GFP_ATOMIC with GFP_KERNEL in new_pcichild_device() (Vitaly Kuznetsov) [1637519]
- [char] ipmi: Fix timer race with module unload (Robert Richter) [1649812]
- [arm64] arm64: hugetlb: Avoid unnecessary clearing in huge_ptep_set_access_flags (Christoph von Recklinghausen) [1635192]
- [arm64] arm64: hugetlb: Fix handling of young ptes (Christoph von Recklinghausen) [1635192]
- [mm] mm: Preserve _PAGE_DEVMAP across mprotect() calls (Jeff Moyer) [1647647]

* Thu Nov 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-47.el8]
- [crypto] crypto: vmx - Fix sleep-in-atomic bugs (Steve Best) [1653662]
- [netdrv] net: ena: update driver version from 2.0.1 to 2.0.2 (John Linville) [1634044]
- [netdrv] net: ena: fix crash during ena_remove() (John Linville) [1634044]
- [netdrv] net: ena: fix crash during failed resume from hibernation (John Linville) [1634044]
- [netdrv] net: ena: enable CONFIG_ENA_ETHERNET for aarch64 (John Linville) [1634044]
- [netdrv] net: ena: enable Low Latency Queues (John Linville) [1634044]
- [netdrv] net: ena: Fix Kconfig dependency on X86 (John Linville) [1634044]
- [netdrv] net: ena: fix indentations in ena_defs for better readability (John Linville) [1634044]
- [netdrv] net: ena: update driver version to 2.0.1 (John Linville) [1634044]
- [netdrv] net: ena: remove redundant parameter in ena_com_admin_init() (John Linville) [1634044]
- [netdrv] net: ena: change rx copybreak default to reduce kernel memory pressure (John Linville) [1634044]
- [netdrv] net: ena: limit refill Rx threshold to 256 to avoid latency issues (John Linville) [1634044]
- [netdrv] net: ena: explicit casting and initialization, and clearer error handling (John Linville) [1634044]
- [netdrv] net: ena: use CSUM_CHECKED device indication to report skb's checksum status (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_netdev (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_com (John Linville) [1634044]
- [netdrv] net: ena: introduce Low Latency Queues data structures according to ENA spec (John Linville) [1634044]
- [netdrv] net: ena: complete host info to match latest ENA spec (John Linville) [1634044]
- [netdrv] net: ena: minor performance improvement (John Linville) [1634044]
- [netdrv] net: ena: fix auto casting to boolean (John Linville) [1634044]
- [netdrv] net: ena: fix NULL dereference due to untimely napi initialization (John Linville) [1634044]
- [netdrv] net: ena: fix rare bug when failed restart/resume is followed by driver removal (John Linville) [1634044]
- [netdrv] net: ena: fix warning in rmmod caused by double iounmap (John Linville) [1634044]
- [netdrv] net: ena: remove ndo_poll_controller (John Linville) [1634044]
- [netdrv] net: ena: fix incorrect usage of memory barriers (John Linville) [1634044]
- [netdrv] net: ena: fix missing calls to READ_ONCE (John Linville) [1634044]
- [netdrv] net: ena: fix missing lock during device destruction (John Linville) [1634044]
- [netdrv] net: ena: fix potential double ena_destroy_device() (John Linville) [1634044]
- [netdrv] net: ena: fix device destruction to gracefully free resources (John Linville) [1634044]
- [netdrv] net: ena: fix driver when PAGE_SIZE == 64kB (John Linville) [1634044]
- [netdrv] net: ena: fix surprise unplug NULL dereference kernel crash (John Linville) [1634044]
- [s390] s390/zcrypt: reinit ap queue state machine during device probe (Philipp Rudo) [1653668]
- [s390] s390/kdump: Make elfcorehdr size calculation ABI compliant (Philipp Rudo) [1653245]
- [s390] s390/kdump: Fix elfcorehdr size calculation (Philipp Rudo) [1653245]
- [block] block: fix 32 bit overflow in __blkdev_issue_discard() (Ming Lei) [1638826]
- [ata] libata: blacklist SAMSUNG MZ7TD256HAFV-000L9 SSD (Ming Lei) [1638826]
- [block] block: copy ioprio in __bio_clone_fast() and bounce (Ming Lei) [1638826]
- [trace] kyber: fix wrong strlcpy() size in trace_kyber_latency() (Ming Lei) [1638826]
- [block] floppy: fix race condition in __floppy_read_block_0() (Ming Lei) [1638826]
- [block] block: make blk_try_req_merge() static (Ming Lei) [1638826]
- [block] block: remove dead queue members (Ming Lei) [1638826]
- [block] block: clean up dead code that is now redundant (Ming Lei) [1638826]
- [nvme] nvme: fix boot hang with only being able to get one IRQ vector (Ming Lei) [1638826]
- [block] ide: don't clear special on ide_queue_rq() entry (Ming Lei) [1638826]
- [block] null_blk: remove unused nullb device (Ming Lei) [1638826]
- [block] ide: don't use req->special (Ming Lei) [1638826]
- [block] pd: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] aoe: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] skd_main: don't use req->special (Ming Lei) [1638826]
- [block] nullb: remove leftover legacy request code (Ming Lei) [1638826]
- [scsi] fnic: fix fnic_scsi_host_{start,end}_tag (Ming Lei) [1638826]
- [block] block: remove set but not used variable 'et' (Ming Lei) [1638826]
- [block] block: remove the BLKPREP_* values. (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from device handler ->prep_fn (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from scsi_init_io and ->init_command (Ming Lei) [1638826]
- [scsi] scsi: clean up error handling in scsi_init_io (Ming Lei) [1638826]
- [scsi] scsi: push blk_status_t up into scsi_setup_{fs,scsi}_cmnd (Ming Lei) [1638826]
- [scsi] scsi: simplify scsi_prep_state_check (Ming Lei) [1638826]
- [block] ide: cleanup ->prep_rq calling convention (Ming Lei) [1638826]
- [block] block: remove req->timeout_list (Ming Lei) [1638826]
- [block] blk-mq: provide a helper to check if a queue is busy (Ming Lei) [1638826]
- [block] blk-mq-tag: change busy_iter_fn to return whether to continue or not (Ming Lei) [1638826]
- [block] ms_block: remove unused pointer 'set' (Ming Lei) [1638826]
- [block] sunvdc: fix compiler warning (Ming Lei) [1638826]
- [nvme] nvme: add separate poll queue map (Ming Lei) [1638826]
- [block] block: add REQ_HIPRI and inherit it from IOCB_HIPRI (Ming Lei) [1638826]
- [nvme] nvme: utilize two queue maps, one for reads and one for writes (Ming Lei) [1638826]
- [block] blk-mq: initial support for multiple queue maps (Ming Lei) [1638826]
- [block] blk-mq: improve plug list sorting (Ming Lei) [1638826]
- [block] blk-mq: cleanup and improve list insertion (Ming Lei) [1638826]
- [block] blk-mq: cache request hardware queue mapping (Ming Lei) [1638826]
- [block] blk-mq: separate number of hardware queues from nr_cpu_ids (Ming Lei) [1638826]
- [block] blk-mq: support multiple hctx maps (Ming Lei) [1638826]
- [block] blk-mq: add 'type' attribute to the sysfs hctx directory (Ming Lei) [1638826]
- [block] blk-mq: allow software queue to map to multiple hardware queues (Ming Lei) [1638826]
- [block] blk-mq: pass in request/bio flags to queue mapping (Ming Lei) [1638826]
- [block] blk-mq: provide dummy blk_mq_map_queue_type() helper (Ming Lei) [1638826]
- [block] blk-mq: abstract out queue map (Ming Lei) [1638826]
- [block] blk-mq: kill q->mq_map (Ming Lei) [1638826]
- [kernel] genirq/affinity: Add support for allocating interrupt sets (Ming Lei) [1638826]
- [kernel] genirq/affinity: Pass first vector to __irq_build_affinity_masks() (Ming Lei) [1638826]
- [kernel] genirq/affinity: Move two stage affinity spreading into a helper function (Ming Lei) [1638826]
- [kernel] genirq/affinity: Spread IRQs to all available NUMA nodes (Ming Lei) [1638826]
- [block] block: kill request ->cpu member (Ming Lei) [1638826]
- [block] block: get rid of q->softirq_done_fn() (Ming Lei) [1638826]
- [block] block: get rid of blk_queued_rq() (Ming Lei) [1638826]
- [block] blk-merge: kill dead queue lock held check (Ming Lei) [1638826]
- [block] block: remove req_no_special_merge() from merging code (Ming Lei) [1638826]
- [block] block: kill request slab cache (Ming Lei) [1638826]
- [block] block: remove request_list code (Ming Lei) [1638826]
- [block] bsg: move bsg-lib parts outside of request queue (Ming Lei) [1638826]
- [block] block: kill legacy parts of timeout handling (Ming Lei) [1638826]
- [block] block: remove __blk_put_request() (Ming Lei) [1638826]
- [block] block: get rid of MQ scheduler ops union (Ming Lei) [1638826]
- [block] block: remove dead elevator code (Ming Lei) [1638826]
- [block] block: remove legacy IO schedulers (Ming Lei) [1638826]
- [block] block: cleanup kick/queued handling (Ming Lei) [1638826]
- [block] block: remove non mq parts from the flush code (Ming Lei) [1638826]
- [block] block: remove legacy rq tagging (Ming Lei) [1638826]
- [block] blk-cgroup: remove legacy queue bypassing (Ming Lei) [1638826]
- [block] blk-wbt: kill check for legacy queue type (Ming Lei) [1638826]
- [block] block: remove blk_complete_request() (Ming Lei) [1638826]
- [block] bsg: convert to use blk-mq (Ming Lei) [1638826]
- [block] bsg: provide bsg_remove_queue() helper (Ming Lei) [1638826]
- [block] bsg: pass in desired timeout handler (Ming Lei) [1638826]
- [s390] dasd: remove dead code (Ming Lei) [1638826]
- [block] block: remove q->lld_busy_fn() (Ming Lei) [1638826]
- [scsi] scsi: kill off the legacy IO path (Ming Lei) [1638826]
- [scsi] scsi: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: remove legacy check in queue blk_freeze_queue() (Ming Lei) [1638826]
- [block] blk-mq: remove the request_list usage (Ming Lei) [1638826]
- [block] ide: convert to blk-mq (Ming Lei) [1638826]
- [block] mspro_block: convert to blk-mq (Ming Lei) [1638826]
- [block] ms_block: convert to blk-mq (Ming Lei) [1638826]
- [block] sunvdc: convert to blk-mq (Ming Lei) [1638826]
- [block] null_blk: Add conventional zone configuration for zoned support (Ming Lei) [1638826]
- [ata] libata: Apply NOLPM quirk for SAMSUNG MZ7TD256HAFV-000L9 (Ming Lei) [1638826]
- [block] block, bfq: fix asymmetric scenarios detection (Ming Lei) [1638826]
- [cdrom] gdrom: fix mistake in assignment of error (Ming Lei) [1638826]
- [block] blk-mq: place trace_block_getrq() in correct place (Ming Lei) [1638826]
- [block] block: Introduce blk_revalidate_disk_zones() (Ming Lei) [1638826]
- [block] block: add a report_zones method (Ming Lei) [1638826]
- [block] block: Expose queue nr_zones in sysfs (Ming Lei) [1638826]
- [block] block: Improve zone reset execution (Ming Lei) [1638826]
- [block] block: Introduce BLKGETNRZONES ioctl (Ming Lei) [1638826]
- [block] block: Introduce BLKGETZONESZ ioctl (Ming Lei) [1638826]
- [block] block: Limit allocation of zone descriptors for report zones (Ming Lei) [1638826]
- [block] block: Introduce blkdev_nr_zones() helper (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Fix sd_zbc_check_zones() error checks (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Reduce boot device scan and revalidate time (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Rearrange code (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Remove an assignment from sd_zbc_setup_report_cmnd() (Ming Lei) [1638826]
- [scsi] scsi: sd: don't crash the host on invalid commands (Ming Lei) [1638826]
- [pci] PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice (Ming Lei) [1638826]
- [fs] f2fs: remove request_list check in is_idle() (Ming Lei) [1638826]
- [scsi] scsi: osd: initiator should use mq variant of request ending (Ming Lei) [1638826]
- [scsi] scsi: fnic: replace gross legacy tag hack with blk-mq hack (Ming Lei) [1638826]
- [infiniband] ib_srp: Remove WARN_ON in srp_terminate_io() (Ming Lei) [1638826]
- [scsi] scsi: ufs: Disable blk-mq for now (Ming Lei) [1638826]
- [block] sx8: convert to blk-mq (Ming Lei) [1638826]
- [block] z2ram: convert to blk-mq (Ming Lei) [1638826]
- [cdrom] gdrom: convert to blk-mq (Ming Lei) [1638826]
- [block] floppy: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: fix error handling during setup (Ming Lei) [1638826]
- [block] ataflop: fold headers into C file (Ming Lei) [1638826]
- [block] amiflop: convert to blk-mq (Ming Lei) [1638826]
- [block] amiflop: clean up on errors during setup (Ming Lei) [1638826]
- [block] amiflop: fold headers into C file (Ming Lei) [1638826]
- [block] swim3: convert to blk-mq (Ming Lei) [1638826]
- [block] swim3: add real error handling in setup (Ming Lei) [1638826]
- [block] swim: convert to blk-mq (Ming Lei) [1638826]
- [block] swim: fix cleanup on setup error (Ming Lei) [1638826]
- [mtd] mtd_blkdevs: convert to blk-mq (Ming Lei) [1638826]
- [block] xsysace: convert to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pf to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pd to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pcd to blk-mq (Ming Lei) [1638826]
- [block] ps3disk: convert to blk-mq (Ming Lei) [1638826]
- [block] blk-mq: provide helper for setting up an SQ queue and tag set (Ming Lei) [1638826]
- [block] null_blk: remove set but not used variable 'q' (Ming Lei) [1638826]
- [cdrom] cdrom: don't attempt to fiddle with cdo->capability (Ming Lei) [1638826]
- [block] block: remove bogus check for queue_lock assignment (Ming Lei) [1638826]
- [block] null_blk: remove legacy IO path (Ming Lei) [1638826]
- [block] um: Convert ubd driver to blk-mq (Ming Lei) [1638826]
- [block] skd: fixup usage of legacy IO API (Ming Lei) [1638826]
- [block] aoe: convert aoeblk to blk-mq (Ming Lei) [1638826]
- [block] ide: remove redundant variables queue_run_ms and left (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion convert BUGs to WARNs (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion hints on fastpath (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_reprep helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_action helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_nz_result function (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: rename variables (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: comment on end_request return (Ming Lei) [1638826]
- [scsi] scsi: core: use blk_mq_run_hw_queues in scsi_kick_queue (Ming Lei) [1638826]
- [scsi] scsi: sg: remove bad blk_end_request_all() call (Ming Lei) [1638826]
- [block] blk-mq: complete req in softirq context in case of single queue (Ming Lei) [1638826]
- [block] block, bfq: improve asymmetric scenarios detection (Ming Lei) [1638826]
- [block] block: remove redundant 'default n' from Kconfig-s (Ming Lei) [1638826]
- [block] blk-mq-debugfs: Also show requests that have not yet been started (Ming Lei) [1638826]
- [block] block: Finish renaming REQ_DISCARD into REQ_OP_DISCARD (Ming Lei) [1638826]
- [block] kyber: fix integer overflow of latency targets on 32-bit (Ming Lei) [1638826]
- [block] kyber: add tracepoints (Ming Lei) [1638826]
- [block] kyber: implement improved heuristics (Ming Lei) [1638826]
- [block] kyber: don't make domain token sbitmap larger than necessary (Ming Lei) [1638826]
- [block] block: export blk_stat_enable_accounting() (Ming Lei) [1638826]
- [block] block: move call of scheduler's ->completed_request() hook (Ming Lei) [1638826]
- [block] blk-mq: Enable support for runtime power management (Ming Lei) [1638826]
- [block] block: Make blk_get_request() block for non-PM requests while suspended (Ming Lei) [1638826]
- [block] block: Allow unfreezing of a queue while requests are in progress (Ming Lei) [1638826]
- [lib] percpu-refcount: Introduce percpu_ref_resurrect() (Ming Lei) [1638826]
- [block] block: Schedule runtime resume earlier (Ming Lei) [1638826]
- [block] block: Split blk_pm_add_request() and blk_pm_put_request() (Ming Lei) [1638826]
- [block] block, scsi: Change the preempt-only flag into a counter (Ming Lei) [1638826]
- [block] block: Move power management code into a new source file (Ming Lei) [1638826]
- [block] Blk-throttle: update to use rbtree with leftmost node cached (Ming Lei) [1638826]
- [block] block: use bio_add_page in bio_iov_iter_get_pages (Ming Lei) [1638826]
- [block] blok, bfq: do not plug I/O if all queues are weight-raised (Ming Lei) [1638826]
- [block] block, bfq: inject other-queue I/O into seeky idle queues on NCQ flash (Ming Lei) [1638826]
- [block] block, bfq: correctly charge and reset entity service in all cases (Ming Lei) [1638826]

* Wed Nov 28 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-46.el8]
- [rpmspec] redhat: fix bpf_samples build (Jiri Benc) [1611579]
- [fs] mnt: fix __detach_mounts infinite loop (Benjamin Coddington) [1628736]
- [pci] pcie: Enable Broadom iProc PCIE and mark it is as tech preview (Mark Langsdorf) [1576958]
- [pci] PCI/ACPI: Add iProc PCIe MCFG quirk (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Add ACPI/ECAM support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Remove PAXC slot check to allow VF support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reduce inbound/outbound mapping print level (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reject unconfigured physical functions from PAXC (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Disable MSI parsing in certain PAXC blocks (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Fix up corrupted PAXC root complex config registers (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Activate PAXC bridge quirk for more devices (Mark Langsdorf) [1576958]

* Tue Nov 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-45.el8]
- [s390] s390/mm: fix mis-accounting of pgtable_bytes (Joe Lawrence) [1644481]
- [mm] mm: add mm_pxd_folded checks to pgtable_bytes accounting functions (Joe Lawrence) [1644481]
- [mm] mm: introduce mm_[p4d|pud|pmd]_folded (Joe Lawrence) [1644481]
- [mm] mm: make the __PAGETABLE_PxD_FOLDED defines non-empty (Joe Lawrence) [1644481]
- [x86] x86/cpu/vmware: Do not trace vmware_sched_clock() (Vitaly Kuznetsov) [1650273]
- [fs] fuse: fix possibly missed wake-up after abort (Lukas Czerner) [1649244]
- [fs] fuse: fix leaked notify reply (Lukas Czerner) [1649244]
- [fs] fuse: fix blocked_waitq wakeup (Lukas Czerner) [1649244]
- [fs] fuse: set FR_SENT while locked (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_write() (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_read() (Lukas Czerner) [1649244]
- [fs] fuse: Add missed unlock_page() to fuse_readpages_fill() (Lukas Czerner) [1649244]
- [fs] fuse: Don't access pipe->buffers without pipe_lock() (Lukas Czerner) [1649244]
- [fs] fuse: fix initial parallel dirops (Lukas Czerner) [1649244]
- [fs] fuse: Fix oops at process_init_reply() (Lukas Czerner) [1649244]
- [fs] fuse: umount should wait for all requests (Lukas Czerner) [1649244]
- [fs] fuse: fix unlocked access to processing queue (Lukas Czerner) [1649244]
- [fs] fuse: fix double request_end() (Lukas Czerner) [1649244]
- [fs] fuse: fix use-after-free in fuse_direct_IO() (Lukas Czerner) [1599195]

* Fri Nov 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-44.el8]
- [firmware] efi: Fix debugobjects warning on 'efi_rts_work' (Waiman Long) [1652190]
- [rpmspec] kernel.spec: Do not zip modules on noarch builds (Prarit Bhargava) [1646471]
- [iommu] iommu/amd: Clear memory encryption mask from physical address (Gary Hook) [1640384]

* Thu Nov 22 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-43.el8]
- [powerpc] powerpc/mm/radix: Only need the Nest MMU workaround for R -> RW transition (Steve Best) [1651276]
- [powerpc] powerpc/mm/books3s: Add new pte bit to mark pte temporarily invalid (Steve Best) [1651276]
- [powerpc] powerpc/tm: Fix HFSCR bit for no suspend case (Steve Best) [1651275]

* Wed Nov 21 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-42.el8]
- [powerpc] powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage (Steve Best) [1651267]
- [tools] perf tools: Remove ext from struct kmod_path (Jiri Olsa) [1581390]
- [tools] perf tools: Add gzip_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add lzma_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add is_compressed callback to compressions array (Jiri Olsa) [1581390]
- [tools] perf tools: Move the temp file processing into decompress_kmodule (Jiri Olsa) [1581390]
- [tools] perf tools: Use compression id in decompress_kmodule() (Jiri Olsa) [1581390]
- [tools] perf tools: Store compression id into struct dso (Jiri Olsa) [1581390]
- [tools] perf tools: Add compression id into 'struct kmod_path' (Jiri Olsa) [1581390]
- [tools] perf tools: Make is_supported_compression() static (Jiri Olsa) [1581390]
- [tools] perf tools: Make decompress_to_file() function static (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in __open_dso() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in symbol__disassemble() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in read_object_code() (Jiri Olsa) [1581390]
- [rpmspec] redhat: Enable kernel-tools (for kvm_stat) on s390x, too (Thomas Huth) [1631222]

* Tue Nov 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-41.el8]
- [drm] drm/atomic_helper: Stop modesets on unregistered connectors harder (Lyude Paul) [1631575]
- [drm] drm/nouveau: Fix nv50_mstc->best_encoder() (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Allow DPMS On<->Off changes for unregistered connectors (Lyude Paul) [1631575]
- [drm] drm/i915: Fix intel_dp_mst_best_encoder() (Lyude Paul) [1631575]
- [drm] drm/i915: Skip vcpi allocation for MSTB ports that are gone (Lyude Paul) [1631575]
- [drm] drm/i915: Don't unset intel_connector->mst_port (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Disallow new modesets on unregistered connectors (Lyude Paul) [1631575]
- [s390] s390/qeth: fix HiperSockets sniffer (Philipp Rudo) [1649773]
- [s390] s390/qeth: report 25Gbit link speed (Philipp Rudo) [1649772]
- [s390] s390/qeth: sanitize strings in debug messages (Philipp Rudo) [1649770]
- [s390] s390/qeth: fix initial operstate (Philipp Rudo) [1649769]
- [s390] s390/qeth: unregister netdevice only when registered (Philipp Rudo) [1649769]
- [powerpc] powerpc/64s: consolidate MCE counter increment (Steve Best) [1633550]
- [powerpc] powerpc/64s: move machine check SLB flushing to mm/slb.c (Steve Best) [1633550]
- [powerpc] powernv/pseries: consolidate code for mce early handling (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Dump the SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Display machine check error details (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Flush SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Define MCE error event section (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Avoid using the size greater than RTAS_ERROR_LOG_MAX (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Defer the logging of rtas error to irq work queue (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Fix endianness while restoring of r3 in MCE handler (Steve Best) [1633550]
- [cdrom] cdrom: fix improper type cast, which can leat to information leak (Maurizio Lombardi) [1650476]

* Thu Nov 15 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-40.el8]
- [drm] drm/amdgpu/pm: Fix potential Spectre v1 (Rob Clark) [1637115]
- [drm] drm/i915/kvmgt: Fix potential Spectre v1 (Rob Clark) [1637115]
- [fs] gfs2: Fix metadata read-ahead during truncate (2) (Andreas Grunbacher) [1647982]
- [block] block: make sure writesame bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: cleanup __blkdev_issue_discard() (Ming Lei) [1648750]
- [block] block: make sure discard bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: Clear kernel memory before copying to user (Ming Lei) [1648752]
- [block] block: respect virtual boundary mask in bvecs (Ming Lei) [1648756]
- [block] xen: don't include <xen/xen.h> from <asm/io.h> and <asm/dma-mapping.h> (Ming Lei) [1648756]
- [block] block: remove ARCH_BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] xen: provide a prototype for xen_biovec_phys_mergeable in xen.h (Ming Lei) [1648756]
- [block] xen: remove the xen_biovec_phys_mergeable export (Ming Lei) [1648756]
- [block] arm: remove the unused BIOVEC_MERGEABLE define (Ming Lei) [1648756]
- [block] block: don't include bug.h from bio.h (Ming Lei) [1648756]
- [block] block: don't include io.h from bio.h (Ming Lei) [1648756]
- [block] block: remove bvec_to_phys (Ming Lei) [1648756]
- [block] block: merge BIOVEC_SEG_BOUNDARY into biovec_phys_mergeable (Ming Lei) [1648756]
- [block] block: add a missing BIOVEC_SEG_BOUNDARY check in bio_add_pc_page (Ming Lei) [1648756]
- [block] block: simplify BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] block: move req_gap_back_merge to blk.h (Ming Lei) [1648756]
- [block] block: move req_gap_{back,front}_merge to blk-merge.c (Ming Lei) [1648756]
- [block] block: move integrity_req_gap_{back,front}_merge to blk.h (Ming Lei) [1648756]
- [fs] gfs2: Fix iomap buffer head reference counting bug (Andreas Grunbacher) [1647073]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k1 (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Initialize port speed to avoid setting lower speed (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Fix incorrect port speed being set for FC adapters (Himanshu Madhani) [1615896]
- [block] block: brd: associate with queue until adding disk (Ming Lei) [1644602]
- [block] block: call rq_qos_exit() after queue is frozen (Ming Lei) [1641558]
- [block] block: fix the DISCARD request merge (Ming Lei) [1646776]
- [block] blk-mq: fallback to previous nr_hw_queues when updating fails (Ming Lei) [1642218]
- [block] blk-mq: realloc hctx when hw queue is mapped to another node (Ming Lei) [1642218]
- [block] blk-mq: change gfp flags to GFP_NOIO in blk_mq_realloc_hw_ctxs (Ming Lei) [1642218]
- [block] blk-mq: adjust debugfs and sysfs register when updating nr_hw_queues (Ming Lei) [1642218]
- [block] block: remove bio_rewind_iter() (Ming Lei) [1642208]

* Wed Nov 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-39.el8]
- [fs] jbd2: fix use after free in jbd2_log_do_checkpoint() (Lukas Czerner) [1644694]
- [fs] ext4: initialize retries variable in ext4_da_write_inline_data_begin() (Lukas Czerner) [1644694]
- [fs] ext4: fix build error when DX_DEBUG is defined (Lukas Czerner) [1644694]

* Tue Nov 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-38.el8]
- [pinctrl] pinctrl: intel: Add Ice Lake PCH pin controller support (David Arcari) [1483413]
- [netdrv] nfp: flower: fix vlan match by checking both vlan id and vlan pcp (Pablo Cascon) [1645220]
- [netdrv] nfp: flower: reject tunnel encap with ipv6 outer headers for offloading (Pablo Cascon) [1646644]
- [netdrv] nfp: populate bus-info on representors (Pablo Cascon) [1643998]
- [powerpc] KVM: PPC: Validate TCEs against preregistered memory page sizes (David Gibson) [1625821]
- [powerpc] KVM: PPC: Inform the userspace about TCE update failures (David Gibson) [1625821]
- [powerpc] KVM: PPC: Book3S: Fix guest DMA when guest partially backed by THP pages (David Gibson) [1625821]

* Fri Nov 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-37.el8]
- [kernel] locking/lockdep: Fix debug_locks off performance problem (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove duplicated 'lock_class_ops' percpu array (Waiman Long) [1647560]
- [kernel] locking/lockdep: Make class->ops a percpu counter and move it under CONFIG_DEBUG_LOCKDEP=y (Waiman Long) [1647560]
- [kernel] locking/lockdep: Add a faster path in __lock_release() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Eliminate redundant IRQs check in __lock_acquire() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove add_chain_cache_classes() (Waiman Long) [1647560]
- [fs] gfs2: Put bitmap buffers in put_super (Andreas Grunbacher) [1647073]
- [scsi] scsi: hpsa: limit transfer length to 1MB, not 512kB (Joseph Szczypek) [1643956]
- [netdrv] nfp: report FW vNIC stats in interface stats (Pablo Cascon) [1645032]
- [rpmspec] spec: Add bpftool debuginfo package (Jiri Olsa) [1633018]
- [crypto] crypto: chelsio: Fix memory corruption in DMA Mapped buffers (Arjun Vynipadath) [1631750]
- [cdrom] cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status (Maurizio Lombardi) [1627732] {CVE-2018-16658}

* Wed Nov 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-36.el8]
- [kernel] srcu: Make early-boot call_srcu() reuse workqueue lists (Waiman Long) [1644375]
- [tools] rcutorture: Test early boot call_srcu() (Waiman Long) [1644375]
- [kernel] srcu: Make call_srcu() available during very early boot (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_state.ofl_lock to raw_spinlock_t (Waiman Long) [1644375]
- [kernel] rcu: Remove obsolete ->dynticks_fqs and ->cond_resched_completed (Waiman Long) [1644375]
- [kernel] rcu: Switch ->dynticks to rcu_data structure, remove rcu_dynticks (Waiman Long) [1644375]
- [kernel] rcu: Switch dyntick nesting counters to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch urgent quiescent-state requests to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch lazy counts to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch last accelerate/advance to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch ->tick_nohz_enabled_snap to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Merge rcu_dynticks structure into rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_dynticks_snap() from Tiny RCU (Waiman Long) [1644375]
- [kernel] rcu: Convert "1UL << x" to "BIT(x)" (Waiman Long) [1644375]
- [kernel] rcu: Avoid resched_cpu() when rescheduling the current CPU (Waiman Long) [1644375]
- [kernel] rcu: More aggressively enlist scheduler aid for nohz_full CPUs (Waiman Long) [1644375]
- [kernel] rcu: Compute jiffies_till_sched_qs from other kernel parameters (Waiman Long) [1644375]
- [kernel] rcu: Provide functions for determining if call_rcu() has been invoked (Waiman Long) [1644375]
- [kernel] rcu: Eliminate ->rcu_qs_ctr from the rcu_dynticks structure (Waiman Long) [1644375]
- [kernel] rcu: Motivate Tiny RCU forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Dump reader protection sequence if failures or close calls (Waiman Long) [1644375]
- [kernel] rcu: Provide improved interrupt-from-idle check in rcu_check_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Make need_resched() respond to urgent RCU-QS needs (Waiman Long) [1644375]
- [kernel] rcu: Inline _rcu_barrier() into its sole remaining caller (Waiman Long) [1644375]
- [kernel] rcu: Define rcu_all_qs() only in !PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Remove !PREEMPT code from rcu_note_voluntary_context_switch() (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in update.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_exp.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tiny.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in srcutree.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcutorture.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcu.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in Kconfig (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate_wait.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rculist.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate.h (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused rcutorture APIs (Waiman Long) [1644375]
- [kernel] rcuperf: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcutorture: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcu: Stop testing RCU-bh and RCU-sched (Waiman Long) [1644375]
- [kernel] rcutorture: Add RCU-bh and RCU-sched support for extended readers (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-sched update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-bh update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Pull rcu_gp_kthread() FQS loop into separate function (Waiman Long) [1644375]
- [kernel] rcu: Inline increment_cpu_stall_ticks() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in force_qs_rnp()'s parameter's parameter (Waiman Long) [1644375]
- [kernel] rcu: Eliminate initialization-time use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate RCU-barrier use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate quiescent-state and grace-period-nonstart use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate callback-invocation/invocation use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate grace-period management code use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate stall-warning use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Restructure rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Simplify rcutorture_get_gp_data() (Waiman Long) [1644375]
- [kernel] rcu: Remove for_each_rcu_flavor() flavor-traversal macro (Waiman Long) [1644375]
- [kernel] rcu: Remove last non-flavor-traversal rsp local variable from tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data structure's ->rsp field (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_node tree accessor macros (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from expedited grace-period functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from no-CBs CPU functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall_info() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_spawn_one_boost_kthread() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from dump_blkd_tasks() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_print_detail_task_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_init_one() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_boot_init_percpu_data() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from _rcu_barrier() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_pending() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __call_rcu() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_process_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from force-quiescent-state functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_do_batch() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from CPU hotplug functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_quiescent_state() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_slow() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_advance_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs_unlocked() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread_wake() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_future_gp_cleanup() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from check_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_other_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_stall_kick_kthreads() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_dump_cpu_stacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from record_gp_stall_check_time() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_get_root() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_in_progress() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_unblock_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rsp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data_p pointer to default rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state_p pointer to default rcu_state structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state structure's ->rda field (Waiman Long) [1644375]
- [kernel] rcu: Eliminate rcu_state structure's ->call field (Waiman Long) [1644375]
- [kernel] rcu: Remove RCU_STATE_INITIALIZER() (Waiman Long) [1644375]
- [kernel] rcu: Express Tiny RCU updates in terms of RCU rather than RCU-sched (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-sched API in terms of RCU for Tree RCU PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in rcu_get_gp_kthreads_prio() header comment (Waiman Long) [1644375]
- [kernel] rcu: Drop "wake" parameter from rcu_report_exp_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Update comments and help text for no more RCU-bh updaters (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-bh update API in terms of RCU (Waiman Long) [1644375]
- [kernel] rcu: Report expedited grace periods at context-switch time (Waiman Long) [1644375]
- [kernel] rcu: Apply RCU-bh QSes to RCU-sched and RCU-preempt when safe (Waiman Long) [1644375]
- [kernel] rcu: Add warning to detect half-interrupts (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused ->b.exp_need_qs field from the rcu_special union (Waiman Long) [1644375]
- [kernel] rcu: Allow processing deferred QSes for exiting RCU-preempt readers (Waiman Long) [1644375]
- [kernel] rcutorture: Test extended "rcu" read-side critical sections (Waiman Long) [1644375]
- [kernel] rcu: Defer reporting RCU-preempt quiescent states when disabled (Waiman Long) [1644375]
- [kernel] rcu: Refactor rcu_{nmi,irq}_{enter,exit}() (Waiman Long) [1644375]
- [documentation] doc: Fix broken HTML directive (Waiman Long) [1644375]
- [documentation] doc: Update removal of RCU-bh/sched update machinery (Waiman Long) [1644375]
- [kernel] rcutorture: Maintain self-propagating CB only during forward-progress test (Waiman Long) [1644375]
- [kernel] rcutorture: Check GP completion at stutter end (Waiman Long) [1644375]
- [kernel] rcutorture: Print forward-progress test interval on error (Waiman Long) [1644375]
- [kernel] rcutorture: Adjust number of reader kthreads per CPU-hotplug operations (Waiman Long) [1644375]
- [kernel] rcutorture: Reduce priority of forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Limit reader duration if irq or bh disabled (Waiman Long) [1644375]
- [kernel] rcutorture: Increase rcu_read_delay() longdelay_ms (Waiman Long) [1644375]
- [kernel] rcutorture: Add self-propagating callback to forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Vary forward-progress test interval (Waiman Long) [1644375]
- [kernel] rcutorture: Avoid no-test complaint if too few forward-progress tries (Waiman Long) [1644375]
- [kernel] rcutorture: Also use GP sequence to judge forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Add forward-progress tests for RCU grace periods (Waiman Long) [1644375]
- [tools] rcutorture: Remove TREE06 and TREE08 from the default test list (Waiman Long) [1644375]
- [kernel] rcuperf: Warn on bad perf type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Warn on bad torture type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Force occasional reader waits (Waiman Long) [1644375]
- [tools] torture: Stop overwriting Make.out file with obsolete version (Waiman Long) [1644375]
- [documentation] doc: Improve rcu_dynticks::dynticks documentation (Waiman Long) [1644375]
- [documentation] doc: Fix broken RCU-requirements link to LKML archive (Waiman Long) [1644375]
- [documentation] doc: Add design documentation on interruption of NMI handlers (Waiman Long) [1644375]
- [kernel] rcutorture: Fix rcu_barrier successes counter (Waiman Long) [1644375]
- [kernel] rcutorture: Add support to detect if boost kthread prio is too low (Waiman Long) [1644375]
- [kernel] rcutorture: Use monotonic timestamp for stall detection (Waiman Long) [1644375]
- [kernel] rcutorture: Make boost test more robust (Waiman Long) [1644375]
- [kernel] rcutorture: Disable RT throttling for boost tests (Waiman Long) [1644375]
- [kernel] rcutorture: Emphasize testing of single reader protection type (Waiman Long) [1644375]
- [kernel] rcutorture: Handle extended read-side critical sections (Waiman Long) [1644375]
- [kernel] rcutorture: Make rcu_torture_timer() use rcu_torture_one_read() (Waiman Long) [1644375]
- [kernel] rcutorture: Use per-CPU random state for rcu_torture_timer() (Waiman Long) [1644375]
- [kernel] rcutorture: Use atomic increment for n_rcu_torture_timers (Waiman Long) [1644375]
- [kernel] rcutorture: Extract common code from rcu_torture_reader() (Waiman Long) [1644375]
- [kernel] rcuperf: Remove unused torturing_tasks() function (Waiman Long) [1644375]
- [kernel] rcu: Remove rcutorture test version and sequence number (Waiman Long) [1644375]
- [kernel] rcutorture: Change units of onoff_interval to jiffies (Waiman Long) [1644375]
- [kernel] rcu: Assign higher prio to RCU threads if rcutorture is built-in (Waiman Long) [1644375]
- [documentation] rculist: Improve documentation for list_for_each_entry_from_rcu() (Waiman Long) [1644375]
- [kernel] srcu: Add grace-period number to rcutorture statistics printout (Waiman Long) [1644375]
- [kernel] rcu: Print stall-warning NMI dyntick state in hexadecimal (Waiman Long) [1644375]
- [maintainers] MAINTAINERS: Update RCU, SRCU, and TORTURE-TEST entries (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_seq_diff() more exact (Waiman Long) [1644375]
- [documentation] doc: Update synchronize_rcu() definition in whatisRCU.txt (Waiman Long) [1644375]
- [kernel] rcu: Check the range of jiffies_till_{first, next}_fqs when setting them (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for rcutorture writer stall warning (Waiman Long) [1644375]
- [kernel] rcu: Add comment to the last sleep in the rcu tasks loop (Waiman Long) [1644375]
- [kernel] rcu: Speed up calling of RCU tasks callbacks (Waiman Long) [1644375]
- [kernel] rcu: Add comment documenting how rcu_seq_snap works (Waiman Long) [1644375]
- [kernel] rcu: Use RCU CPU stall timeout for rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove __maybe_unused from rcu_cpu_has_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_perf_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_torture_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from panic_on_rcu_stall() and rcu_blocking_is_gp() (Waiman Long) [1644375]
- [kernel] rcu: Remove unused local variable "cpu" (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_kick_nohz_cpu() function (Waiman Long) [1644375]
- [kernel] rcu: Clarify and correct the rcu_preempt_qs() header comment (Waiman Long) [1644375]
- [kernel] rcu: Inline rcu_dynticks_momentary_idle() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Mark task as .need_qs less aggressively (Waiman Long) [1644375]
- [kernel] rcu: Improve RCU-tasks naming and comments (Waiman Long) [1644375]
- [kernel] rcu: Use pr_fmt to prefix "rcu: " to logging output (Waiman Long) [1644375]
- [kernel] rcu: rcupdate.h: Get rid of Sphinx warnings at rcu_pointer_handoff() (Waiman Long) [1644375]
- [kernel] rcu: Improve rcu_note_voluntary_context_switch() reporting (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_read_unlock_special() static (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for offline CPUs failing to report QS (Waiman Long) [1644375]
- [kernel] rcu: Record ->gp_state for both phases of grace-period initialization (Waiman Long) [1644375]
- [kernel] rcu: Add CPU online/offline state to dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add up-tree information to dump_blkd_tasks() diagnostics (Waiman Long) [1644375]
- [kernel] rcu: Remove CPU-hotplug failsafe from force-quiescent-state code path (Waiman Long) [1644375]
- [kernel] rcu: Remove failsafe check for lost quiescent state (Waiman Long) [1644375]
- [kernel] rcu: Move grace-period pre-init delay after pre-init (Waiman Long) [1644375]
- [kernel] rcu: Add RCU-preempt check for waiting on newly onlined CPU (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs due to race with CPU offline (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive splats from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress more involved false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive offline-CPU lockdep-RCU splat (Waiman Long) [1644375]
- [kernel] rcu: Prevent useless FQS scan after all CPUs have checked in (Waiman Long) [1644375]
- [kernel] rcu: Replace smp_wmb() with smp_store_release() for stall check (Waiman Long) [1644375]
- [kernel] rcu: Fix typo and add additional debug (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_report_unblock_qs_rnp() warn on violated preconditions (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_init_new_rnp() stop upon already-set bit (Waiman Long) [1644375]
- [kernel] rcu: Fix an obsolete ->qsmaskinit comment (Waiman Long) [1644375]
- [kernel] rcu: Clean up handling of tasks blocked across full-rcu_node offline (Waiman Long) [1644375]
- [kernel] rcu: Identify grace period is in progress as we advance up the tree (Waiman Long) [1644375]
- [kernel] rcu: Use better variable names in funnel locking loop (Waiman Long) [1644375]
- [kernel] rcu: Rename the grace-period-request variables and parameters (Waiman Long) [1644375]
- [kernel] rcu: Regularize resetting of rcu_data wrap indicator (Waiman Long) [1644375]
- [kernel] rcutorture: Correctly handle grace-period sequence wrap (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_start_this_gp() check for grace period already started (Waiman Long) [1644375]
- [kernel] rcu: Fix cpustart tracepoint gp_seq number (Waiman Long) [1644375]
- [kernel] rcu: Produce last "CleanupMore" trace only if late-breaking request (Waiman Long) [1644375]
- [kernel] rcu: Don't funnel-lock above leaf node if GP in progress (Waiman Long) [1644375]
- [documentation] doc: Update RCU CPU stall-warning documentation (Waiman Long) [1644375]
- [documentation] doc: Update memory-ordering documentation for ->gp-seq (Waiman Long) [1644375]
- [documentation] doc: Update data-structure documentation for ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make simple callback acceleration refer to rdp->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcu: Remove ->gpnum and ->completed (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_fqs tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_quiescent_state_report tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_unlock_preempted_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_preempt_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period_init tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_future_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_nocb_wait_gp() check if GP already requested (Waiman Long) [1644375]
- [kernel] rcu: Move from ->need_future_gp[] to ->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcutorture: Convert rcutorture_get_gp_data() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make RCU CPU stall warnings use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert grace-period requests to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->completedqs to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->rcu_iw_gpnum to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_in_progress() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_nocb_gp_get() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_try_advance_all_cbs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_implicit_dynticks_qs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_gpnum_ovf() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move RCU's grace-period-change code to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert conditional grace-period primitives to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make quiescent-state reporting use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_check_gp_kthread_starvation() to GP sequence number (Waiman Long) [1644375]
- [kernel] rcu: Make rcutorture's batches-completed API use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_slow() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Introduce grace-period sequence numbers (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_gp_cleanup() write only once to ->gp_flags (Waiman Long) [1644375]
- [kernel] rcu: Diagnostics for grace-period startup hangs (Waiman Long) [1644375]
- [kernel] rcu: Exclude near-simultaneous RCU CPU stall warnings (Waiman Long) [1644375]
- [kernel] rcu: Use the proper lockdep annotation in dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add debugging info to assertion (Waiman Long) [1644375]
- [kernel] torture: Keep old-school dmesg format (Waiman Long) [1644375]
- [kernel] torture: Make online/offline messages appear only for verbose=2 (Waiman Long) [1644375]
- [tools] rcutorture: Make kvm-find-errors.sh find close calls (Waiman Long) [1644375]
- [tools] rcutorture: Remove obsolete TREE08-T.boot file (Waiman Long) [1644375]
- [tools] torture: Use a single build directory for torture scenarios (Waiman Long) [1644375]
- [kernel] srcu: Introduce srcu_read_{un,}lock_notrace() (Waiman Long) [1644375]
- [kernel] srcu: Add address of first callback to rcutorture output (Waiman Long) [1644375]
- [kernel] srcu: Document that srcu_funnel_gp_start() implies srcu_funnel_exp_start() (Waiman Long) [1644375]
- [kernel] srcu: Fix typos in __call_srcu() header comment (Waiman Long) [1644375]
- [kernel] rcu: Make expedited grace period use direct call on last leaf (Waiman Long) [1644375]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-35.el8]
- [netdrv] nfp: flower: use offsets provided by pedit instead of index for ipv6 (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix multiple keys per pedit action (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix pedit set actions for multiple partial masks (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: ignore checksum actions when performing pedit actions (Pablo Cascon) [1644400]
- [kernel] sched/fair: Fix throttle_list starvation with low CFS quota (Phil Auld) [1638526]
- [net] tipc: fix the big/little endian issue in tipc_dest (Jon Maloy) [1640712]
- [rpmspec] kernel.spec: Include kernel-signing-ca.cer public key (Prarit Bhargava) [1638465]
- [block] block: don't deal with discard limit in blkdev_issue_discard() (Ming Lei) [1631255]
- [powerpc] powerpc/mm: Check memblock_add against MAX_PHYSMEM_BITS range (Gustavo Duarte) [1561402]
- [powerpc] powerpc/mm: Increase MAX_PHYSMEM_BITS to 128TB with SPARSEMEM_VMEMMAP config (Gustavo Duarte) [1561402]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-34.el8]
- [s390] s390/crypto: Enhance paes cipher to accept variable length key material (Philipp Rudo) [1644387]
- [s390] s390/pkey: move pckmo subfunction available checks away from module init (Philipp Rudo) [1644387]
- [s390] s390/pkey: Load pkey kernel module automatically (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: fix broken zcrypt_send_cprb in-kernel api function (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for transforming key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key verification (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit secure key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit protected key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Define protected key blob format (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key generation (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: add ap_adapter_mask sysfs attribute (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: provide apfs failure code on type 86 error reply (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: zcrypt device driver cleanup (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: multiple zcrypt device nodes support (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: enable AP bus scan without a valid default domain (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: Use kmemdup to replace kmalloc + memcpy (Philipp Rudo) [1644387]
- [s390] s390/qeth: add TSO support for L2 devices (Philipp Rudo) [1644381]
- [s390] s390/qeth: add support for IPv6 TSO (Philipp Rudo) [1644381]
- [s390] s390/qeth: enhance TSO control sequence (Philipp Rudo) [1644381]
- [s390] s390/qeth: make TSO controls protocol-agnostic (Philipp Rudo) [1644381]
- [s390] s390: qeth: Fix potential array overrun in cmd/rc lookup (Philipp Rudo) [1644381]
- [s390] s390: qeth_core_mpc: Use ARRAY_SIZE instead of reimplementing its function (Philipp Rudo) [1644381]
- [scsi] scsi: mpt3sas: Remove unnecessary parentheses and simplify null checks (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Use dma_pool_zalloc (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove unused macro MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT without logging levels (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove KERN_WARNING from panic uses (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT and reply_q_name to s: (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert mlsleading uses of pr_<level> with MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert uses of pr_<level> with MPT3SAS_FMT to ioc_<level> (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Add ioc_<level> logging macros (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix calltrace observed while running IO & reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Improve kernel-doc headers (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Split _base_reset_handler(), mpt3sas_scsih_reset_handler() and mpt3sas_ctl_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix a race condition in mpt3sas_base_hard_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix _transport_smp_handler() error path (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Introduce struct mpt3sas_nvme_cmd (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Annotate switch/case fall-through (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove set-but-not-used variables (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix indentation (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Update driver version "26.100.00.00" (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: As per MPI-spec, use combined reply queue for SAS3.5 controllers when HBA supports more than 16 MSI-x vectors (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix, False timeout prints for ioctl and other internal commands during controller reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't access the structure after decrementing it's instance reference count (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Incorrect command status was set/marked as not used (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't abort I/Os issued to NVMe drives while processing Async Broadcast primitive event (Tomas Henzl) [1638649]
- [netdrv] net/mlx5e: Do not ignore netdevice TX/RX queues number (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Use non-delayed work for update stats (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Initialize all netdev common structures in one place (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Always initialize update stats delayed work (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Gather common netdev init/cleanup functionality in one place (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Fix netlink support in IPoIB (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Hoist alloc_netdev_mqs out of the driver (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Consolidate checking of the proposed child interface (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Maintain the child_intfs list from ndo_init/uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Do not remove child devices from within the ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of the sysfs_mutex (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Use priv_destructor for netdev cleanup (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move init code to ndo_init (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move all uninit code into ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Use cancel_delayed_work_sync for neigh-clean task (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of IPOIB_FLAG_GOING_DOWN (Alaa Hleihel) [1643103]
- [infiniband] RDMA/ipoib: Fix use of sizeof() (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Do not recycle RX pages in interface down flow (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5e: Replace call to MPWQE free with dealloc in interface down flow (Alaa Hleihel) [1643103 1643047]
- [net] net/xdp: Fix suspicious RCU usage warning (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5: WQ, fixes for fragmented WQ buffers API (Alaa Hleihel) [1643103 1636183]
- [netdrv] net/mlx4_en: Use minimal rx and tx ring sizes on kdump kernel (Alaa Hleihel) [1643103 1615267]
- [x86] mark coffeelake-s/h 8+2 as supported (David Arcari) [1575461 1575460]
- [x86] x86/spec_ctrl: Synchronize STIBP changes with RHEL IBRS code (Waiman Long) [1643233]
- [x86] x86/speculation: Propagate information about RSB filling mitigation to sysfs (Waiman Long) [1643233]
- [x86] x86/speculation: Enable cross-hyperthread spectre v2 STIBP mitigation (Waiman Long) [1643233]
- [x86] x86/speculation: Apply IBPB more strictly to avoid cross-process data leak (Waiman Long) [1643233]
- [x86] x86/speculation: Add RETPOLINE_AMD support to the inline asm CALL_NOSPEC variant (Waiman Long) [1643233]
- [x86] x86/CPU: Fix unused variable warning when !CONFIG_IA32_EMULATION (Waiman Long) [1643233]
- [x86] x86/pti/64: Remove the SYSCALL64 entry trampoline (Waiman Long) [1643233]
- [x86] x86/entry/64: Use the TSS sp2 slot for SYSCALL/SYSRET scratch space (Waiman Long) [1643233]
- [x86] x86/entry/64: Document idtentry (Waiman Long) [1643233]
- [x86] x86/asm-offsets: Move TSS_sp0 and TSS_sp1 to asm-offsets.c (Waiman Long) [1643233]
- [x86] x86: Add entry trampolines to kcore (Waiman Long) [1643233]
- [kernel] kallsyms, x86: Export addresses of PTI entry trampolines (Waiman Long) [1643233]
- [kernel] kallsyms: Simplify update_iter_mod() (Waiman Long) [1643233]
- [scsi] scsi: csiostor: fix incorrect port capabilities (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: add a check for NULL pointer after kmalloc() (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: update ingress pack and pad boundary value (Arjun Vynipadath) [1628866]

* Wed Oct 31 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-33.el8]
- [netdrv] nfp: flower: use host context count provided by firmware (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use stats array instead of storing stats per flow (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use rhashtable for flow caching (Pablo Cascon) [1639609]
- [netdrv] nfp: avoid soft lockups under control message storm (Pablo Cascon) [1639609]
- [kernel] sched: disable autogroups by default (Phil Auld) [1568166]
- [s390] s390/keyboard: sanitize array index in do_kdsk_ioctl (Steve Best) [1637591]
- [char] ipmi:ssif: Add support for multi-part transmit messages > 2 parts (Tony Camuso) [1622053]
- [scsi] scsi: libsas: fix a race condition when smp task timeout (Zhou Wang) [1640426]
- [scsi] scsi: libsas: check the ata device status by ata_dev_enabled() (Zhou Wang) [1640426]
- [scsi] scsi: libsas: always unregister the old device if going to discover new (Zhou Wang) [1640426]
- [scsi] scsi: libsas: dynamically allocate and free ata host (Zhou Wang) [1640426]
- [scsi] scsi: libsas: remove irq save in sas_ata_qc_issue() (Zhou Wang) [1640426]

* Sat Oct 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-32.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1643333 1589158]
- [netdrv] Taint kernel if e1000 is loaded (Neil Horman) [1643617]
- [netdrv] iavf: fix a typo (Stefan Assmann) [1627882]
- [netdrv] i40evf: remove ndo_poll_controller (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1627882]
- [netdrv] iavf: finish renaming files to iavf (Stefan Assmann) [1627882]
- [netdrv] iavf: rename most of i40e strings (Stefan Assmann) [1627882]
- [netdrv] iavf: tracing infrastructure rename (Stefan Assmann) [1627882]
- [netdrv] iavf: replace i40e_debug with iavf version (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_hw to iavf_hw (Stefan Assmann) [1627882]
- [netdrv] iavf: rename I40E_ADMINQ_DESC (Stefan Assmann) [1627882]
- [netdrv] iavf: rename device ID defines (Stefan Assmann) [1627882]
- [netdrv] iavf: remove references to old names (Stefan Assmann) [1627882]
- [netdrv] iavf: move i40evf files to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_status to iavf_status (Stefan Assmann) [1627882]
- [netdrv] iavf: rename functions and structs to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: diet and reformat (Stefan Assmann) [1627882]
- [netdrv] configs: enable CONFIG_IAVF=m (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: rename i40evf to iavf (Stefan Assmann) [1627882]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1627882]
- [netdrv] i40evf: cancel workqueue sync for adminq when a VF is removed (Stefan Assmann) [1627882]
- [netdrv] i40evf: Don't enable vlan stripping when rx offload is turned on (Stefan Assmann) [1627882]
- [netdrv] i40evf: set IFF_UNICAST_FLT flag for the VF (Stefan Assmann) [1627882]
- [netdrv] i40evf: Validate the number of queues a PF sends (Stefan Assmann) [1627882]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1627882]
- [netdrv] i40evf: update ethtool stats code and use helper functions (Stefan Assmann) [1627882]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1627882]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1627882]
- [netdrv] i40e/i40evf: remove redundant functions i40evf_aq_(set/get)_phy_register (Stefan Assmann) [1627882]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1627882]
- [init] init/main.c: Enable watchdog_thresh control from kernel line (Prarit Bhargava) [1643161]
- [s390] s390/purgatory: Remove duplicate variable definitions (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Add missing FORCE to Makefile targets (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Fix crash with expoline enabled (Philipp Rudo) [1642447]
- [s390] s390: disable asm code expolines if cc does not support it (Philipp Rudo) [1642447]
- [netdrv] Revert be2net: remove desc field from be_eq_obj (Ivan Vecera) [1639867]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-31.el8]
- [rpmspec] redhat: add optional bpf_samples package (Jiri Benc) [1611579]
- [powerpc] powerpc/time: Fix clockevent_decrementer initalisation for PR KVM (Steve Best) [1641615]
- [net] ip: frags: fix crash in ip_do_fragment() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipfrag: let ip(6)frag_high_thresh in ns be higher than in init_net (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: discard IP frag queue on more errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: fail fast on IP defrag errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: process in-order fragments efficiently (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: add helpers to process in-order fragments faster (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: defrag: drop non-last frags smaller than min mtu (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv4: frags: precedence bug in ip_expire() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: use rb trees for IP frag queue (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] modify skb_rbtree_purge to return the truesize of all purged skbs (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: discard IPv4 datagrams with overlapping segments (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [fs] ovl: fix format of setxattr debug (Miklos Szeredi) [1636875]
- [fs] ovl: fix access beyond unterminated strings (Miklos Szeredi) [1636875]
- [fs] ovl: make symbol 'ovl_aops' static (Miklos Szeredi) [1636875]
- [fs] vfs: swap names of (do,vfs)_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: fix memory leak on unlink of indexed file (Miklos Szeredi) [1636875]
- [fs] ovl: fix oopses in ovl_fill_super() failure paths (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fadvise() (Miklos Szeredi) [1636875]
- [fs] vfs: implement readahead(2) using POSIX_FADV_WILLNEED (Miklos Szeredi) [1636875]
- [fs] vfs: add the fadvise() file operation (Miklos Szeredi) [1636875]
- [fs] Documentation/filesystems: update documentation of file_operations (Miklos Szeredi) [1636875]
- [fs] ovl: fix GPF in swapfile_activate of file from overlayfs over xfs (Miklos Szeredi) [1636875]
- [fs] ovl: respect FIEMAP_FLAG_SYNC flag (Miklos Szeredi) [1636875]
- [fs] ovl: Enable metadata only feature (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metacopy only for ioctl modifying file attr (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metadata only copy-up for truncate operation (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to force data copy-up (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirect on index as well (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on upper inode when it is linked (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on metacopy files upon rename (Miklos Szeredi) [1636875]
- [fs] ovl: Do not set dentry type ORIGIN for broken hardlinks (Miklos Szeredi) [1636875]
- [fs] ovl: Add an inode flag OVL_CONST_INO (Miklos Szeredi) [1636875]
- [fs] ovl: Treat metacopy dentries as type OVL_PATH_MERGE (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirects for metacopy files (Miklos Szeredi) [1636875]
- [fs] ovl: Move some dir related ovl_lookup_single() code in else block (Miklos Szeredi) [1636875]
- [fs] ovl: Do not expose metacopy only dentry from d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: Open file with data except for the case of fsync (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_inode_realdata() (Miklos Szeredi) [1636875]
- [fs] ovl: Store lower data inode in ovl_inode (Miklos Szeredi) [1636875]
- [fs] ovl: Fix ovl_getattr() to get number of blocks from lower (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_dentry_lowerdata() to get lower data dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up meta inode data from lowest data inode (Miklos Szeredi) [1636875]
- [fs] ovl: Modify ovl_lookup() and friends to lookup metacopy dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Use out_err instead of out_nomem (Miklos Szeredi) [1636875]
- [fs] ovl: A new xattr OVL_XATTR_METACOPY for file on upper (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_already_copied_up() (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up only metadata during copy up where it makes sense (Miklos Szeredi) [1636875]
- [fs] ovl: During copy up, first copy up metadata and then data (Miklos Szeredi) [1636875]
- [fs] ovl: Provide a mount option metacopy=on/off for metadata copyup (Miklos Szeredi) [1636875]
- [fs] ovl: Move the copy up helpers to copy_up.c (Miklos Szeredi) [1636875]
- [fs] ovl: Initialize ovl_inode->redirect in ovl_get_inode() (Miklos Szeredi) [1636875]
- [fs] ovl: fix documentation of non-standard behavior (Miklos Szeredi) [1636875]
- [fs] ovl: obsolete "check_copy_up" module option (Miklos Szeredi) [1636875]
- [fs] vfs: remove open_flags from d_real() (Miklos Szeredi) [1636875]
- [fs] Revert "fsnotify: support overlayfs" (Miklos Szeredi) [1636875]
- [fs] Partially revert "locks: fix file locking on overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: do get_write_access() on upper layer of overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: add flags to d_real()" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: update ovl inode before relatime check" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix relatime for directories" (Miklos Szeredi) [1636875]
- [fs] vfs: fix freeze protection in mnt_want_write_file() for overlayfs (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: don't allow writing ioctl on lower layer" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix may_write_real() for overlayfs directories" (Miklos Szeredi) [1636875]
- [fs] vfs: don't open real (Miklos Szeredi) [1636875]
- [fs] ovl: add reflink/copyfile/dedup support (Miklos Szeredi) [1636875]
- [fs] ovl: add O_DIRECT support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fiemap() (Miklos Szeredi) [1636875]
- [fs] ovl: add lsattr/chattr support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fallocate() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_mmap() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fsync() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_read_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to return real file (Miklos Szeredi) [1636875]
- [fs] ovl: stack file ops (Miklos Szeredi) [1636875]
- [fs] ovl: deal with overlay files in ovl_d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: copy up file size as well (Miklos Szeredi) [1636875]
- [fs] Revert "Revert "ovl: get_write_access() in truncate"" (Miklos Szeredi) [1636875]
- [fs] ovl: copy up inode flags (Miklos Szeredi) [1636875]
- [fs] ovl: copy up times (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_dedupe_file_range_one() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_ioctl() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: make open_with_fake_path() not contribute to nr_files (Miklos Szeredi) [1636875]
- [fs] ovl: fix wrong use of impure dir cache in ovl_iterate() (Miklos Szeredi) [1636875]
- [fs] new helper: open_with_fake_path() (Miklos Szeredi) [1636875]
- [fs] now we can fold open_check_o_direct() into do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] lift fput() on late failures into path_openat() (Miklos Szeredi) [1636875]
- [fs] fold put_filp() into fput() (Miklos Szeredi) [1636875]
- [fs] introduce FMODE_OPENED (Miklos Szeredi) [1636875]
- [fs] ->file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] security_file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] get rid of cred argument of vfs_open() and do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] pass ->f_flags value to alloc_empty_file() (Miklos Szeredi) [1636875]
- [fs] pass creds to get_empty_filp(), make sure dentry_open() passes the right creds (Miklos Szeredi) [1636875]
- [fs] alloc_file(): switch to passing O_... flags instead of FMODE_... mode (Miklos Szeredi) [1636875]
- [fs] make sure do_dentry_open() won't return positive as an error (Miklos Szeredi) [1636875]
- [fs] create_pipe_files(): use fput() if allocation of the second file fails (Miklos Szeredi) [1636875]
- [fs] turn filp_clone_open() into inline wrapper for dentry_open() (Miklos Szeredi) [1636875]
- [fs] fold security_file_free() into file_free() (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: extract helper for a single dedup (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: rationalize args (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: return int (Miklos Szeredi) [1636875]
- [fs] vfs: limit size of dedupe (Miklos Szeredi) [1636875]
- [fs] ovl: set I_CREATING on inode being created (Miklos Szeredi) [1636875]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-30.el8]
- [rpmspec] redhat spec: Add new perf tools file (Jiri Olsa) [1579484]
- [tools] perf tools: Fix use of alternatives to find JDIR (Jiri Olsa) [1579484]
- [net] net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd() (Paolo Abeni) [1637576]
- [thunderbolt] thunderbolt: Add Intel as copyright holder (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Convert rest of the driver files to use SPDX identifier (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Print connected devices (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Make the driver less verbose (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove a meaningless NULL pointer check before dma_pool_destroy (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Initialize after IOMMUs (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not handle ICM events after domain is stopped (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Add support for runtime PM (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove redundant variable 'approved' (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use correct ICM commands in system suspend (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: No need to take tb->lock in domain suspend/complete (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not unnecessarily call ICM get route (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use 64-bit DMA mask if supported by the platform (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Fix small typo in variable name (Jarod Wilson) [1588929]
- [mm] Revert x86/e820: put !E820_TYPE_RAM regions into memblock.reserved (Baoquan He) [1639450]
- [mm] mm: return zero_resv_unavail optimization (Baoquan He) [1639450]
- [mm] mm: zero remaining unavailable struct pages (Baoquan He) [1639450]
- [mm] mm: skip invalid pages block at a time in zero_resv_unresv() (Baoquan He) [1639450]
- [mm] docs/mm: memblock: update kernel-doc comments (Baoquan He) [1639450]
- [mm] mm/memblock: add a name for memblock flags enumeration (Baoquan He) [1639450]
- [block] blk-wbt: wake up all when we scale up, not down (Ming Lei) [1640035]

* Sat Oct 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-29.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1589158]
- [kernel] EDAC: Raise the maximum number of memory controllers (Aristeu Rozanski) [1634077]
- [netdrv] i40e: disallow changing the number of descriptors when AF_XDP is on (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Rx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Tx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove unused msglen parameter from virtchnl functions (Stefan Assmann) [1630760]
- [netdrv] i40e: fix double 'NIC Link is Down' messages (Stefan Assmann) [1630760]
- [netdrv] i40e: add a helper function to validate a VF based on the vf id (Stefan Assmann) [1630760]
- [netdrv] i40e: use declared variables for pf and hw (Stefan Assmann) [1630760]
- [netdrv] i40e: Unset promiscuous settings on VF reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Fix VF's link state notification (Stefan Assmann) [1630760]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1630760]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1630760]
- [netdrv] i40e: fix possible compiler warning in xsk TX path (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Tx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Tx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] xsk: i40e: get rid of useless struct xdp_umem_props (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Rx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Rx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] i40e: refactor Rx path for re-use (Stefan Assmann) [1630760]
- [netdrv] i40e: added queue pair disable/enable functions (Stefan Assmann) [1630760]
- [netdrv] i40e: Prevent deleting MAC address from VF when set by PF (Stefan Assmann) [1630760]
- [netdrv] i40e: hold the rtnl lock on clearing interrupt scheme (Stefan Assmann) [1630760]
- [netdrv] i40e: Check and correct speed values for link on open (Stefan Assmann) [1630760]
- [netdrv] i40e: report correct statistics when XDP is enabled (Stefan Assmann) [1630760]
- [netdrv] i40e: static analysis report from community (Stefan Assmann) [1630760]
- [netdrv] i40e: use correct length for strncpy (Stefan Assmann) [1630760]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1630760]
- [netdrv] i40e: move ethtool stats boiler plate code to i40e_ethtool_stats.h (Stefan Assmann) [1630760]
- [netdrv] i40e: convert queue stats to i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: fix condition of WARN_ONCE for stat strings (Stefan Assmann) [1630760]
- [netdrv] i40e_txrx: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e_main: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e: fix i40e_add_queue_stats data pointer update (Stefan Assmann) [1630760]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1630760]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1630760]
- [netdrv] i40e: fix warning about shadowed ring parameter (Stefan Assmann) [1630760]
- [netdrv] i40e: remove unnecessary i variable causing -Wshadow warning (Stefan Assmann) [1630760]
- [netdrv] i40e: convert priority flow control stats to use helpers (Stefan Assmann) [1630760]
- [netdrv] i40e: convert VEB TC stats to use an i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: Set fec_config when forcing link state (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper to copy statistic values into ethtool buffer (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper function for copying strings from stat arrays (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove duplicated prepare call in i40e_shutdown (Stefan Assmann) [1630760]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1630760]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Stefan Assmann) [1630760]
- [net] ipv4: don't let PMTU updates increase route MTU (Sabrina Dubroca) [1638845]
- [net] ipv4: update fnhe_pmtu when first hop's MTU changes (Sabrina Dubroca) [1638845]
- [net] xsk: add a simple buffer reuse queue (Ivan Vecera) [1634774]
- [net] samples/bpf: add -c/--copy -z/--zero-copy flags to xdpsock (Ivan Vecera) [1634774]
- [net] add napi_if_scheduled_mark_missed (Ivan Vecera) [1634774]
- [net] xsk: expose xdp_umem_get_(data, dma) to drivers (Ivan Vecera) [1634774]
- [net] xdp: export xdp_rxq_info_unreg_mem_model (Ivan Vecera) [1634774]
- [net] xdp: implement convert_to_xdp_frame for MEM_TYPE_ZERO_COPY (Ivan Vecera) [1634774]
- [net] xdp: Helper function to clear kernel pointers in xdp_frame (Ivan Vecera) [1634774]
- [net] xsk: i40e: get rid of useless struct xdp_umem_props (Ivan Vecera) [1631809]
- [net] xdp: fix uninitialized 'err' variable (Ivan Vecera) [1631805]
- [tools] headers uapi: Update tools's copy of linux/if_link.h (Ivan Vecera) [1631805]
- [tools] selftests/bpf: add test for multiple programs (Ivan Vecera) [1631805]
- [net] netdevsim: add support for simultaneous driver and hw XDP (Ivan Vecera) [1631805]
- [net] xdp: support simultaneous driver and hw XDP attachment (Ivan Vecera) [1631805]
- [net] xdp: factor out common program/flags handling from drivers (Ivan Vecera) [1631805]
- [net] xdp: don't make drivers report attachment mode (Ivan Vecera) [1631805]
- [net] xdp: add per mode attributes for attached programs (Ivan Vecera) [1631805]
- [net] sched: cls_flower: set correct offload data in fl_reoffload (Ivan Vecera) [1631522]
- [net] sched: call reoffload op on block callback reg (Ivan Vecera) [1631522]
- [net] sched: cls_bpf: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_u32: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_matchall: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_flower: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: add tcf_proto_op to offload a rule (Ivan Vecera) [1631522]
- [net] sched: pass extack pointer to block binds and cb registration (Ivan Vecera) [1631522]

* Fri Oct 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-28.el8]
- [rpmspec] kernel.spec: s390/zfcpdump: add -zfcpdump kernel variant (Philipp Rudo) [1567291]
- [kernel] rh_taint: correct loaddable module support dependencies (Philipp Rudo) [1567291]
- [powerpc] KVM: PPC: Book3S HV: Avoid crash from THP collapse during radix page fault (David Gibson) [1639555]
- [irqchip] irqchip/gic-v3-its: Allow use of LPI tables in reserved memory (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Register LPI tables with EFI config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Check that all RDs have the same property table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Use pre-programmed redistributor tables with kdump kernels (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Allow use of pre-programmed LPI tables (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Keep track of property table's PA and VA (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Move pending table allocation to init time (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Split property table clearing from allocation (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Simplify LPI_PENDBASE_SZ usage (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Change initialization ordering for LPIs (Jeremy Linton) [1625746]
- [firmware] efi: add API to reserve memory persistently across kexec reboot (Jeremy Linton) [1625746]
- [firmware] efi/arm: libstub: add a root memreserve config table (Jeremy Linton) [1625746]
- [firmware] efi: honour memory reservations passed via a linux specific config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Cap lpi_id_bits to reduce memory footprint (Jeremy Linton) [1625746]
- [infiniband] RDMA/bnxt_re: Fix system crash during RDMA resource initialization (Selvin Xavier) [1637122]
- [infiniband] RDMA/bnxt_re: Fix couple of memory leaks that could lead to IOMMU call traces (Selvin Xavier) [1637120]
- [arm64] arm64: KVM: Sanitize PSTATE.M when being set from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [arm64] arm64: KVM: Tighten guest core register access from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [fs] fs/cifs: require sha512 (Leif Sahlberg) [1610619]
- [fs] smb3: simplify code by removing CONFIG_CIFS_SMB311 (Leif Sahlberg) [1610619]
- [fs] smb3: add support for statfs for smb3.1.1 posix extensions (Leif Sahlberg) [1610619]
- [fs] cifs: allow disabling insecure dialects in the config (Leif Sahlberg) [1610619]
- [fs] smb3: if server does not support posix do not allow posix mount option (Leif Sahlberg) [1610619]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-27.el8]
- [security] cap_inode_getsecurity: use d_find_any_alias() instead of d_find_alias() (Joe Lawrence) [1638647]
- [powerpc] powerpc/cacheinfo: Report the correct shared_cpu_map on big-cores (Steve Best) [1639265]
- [powerpc] powerpc: Use cpu_smallcore_sibling_mask at SMT level on bigcores (Steve Best) [1639265]
- [powerpc] powerpc: Detect the presence of big-cores via ibm, thread-groups (Steve Best) [1639265]
- [x86] mark amd rome as unsupported (David Arcari) [1638506]
- [netdrv] qed: Add support for virtual link (Chad Dupuis) [1638013]
- [netdrv] qede: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Fix shmem structure inconsistency between driver and the mfw (Chad Dupuis) [1638013]
- [netdrv] qed: Add missing device config for RoCE EDPM in UFP mode (Chad Dupuis) [1638013]
- [netdrv] qed: Add a flag which indicates if offload TC is set (Chad Dupuis) [1638013]
- [netdrv] qed: Do not add VLAN 0 tag to untagged frames in multi-function mode (Chad Dupuis) [1638013]
- [netdrv] qed: Fix populating the invalid stag value in multi function mode (Chad Dupuis) [1638013]
- [tools] perf python: Fix pyrf_evlist__read_on_cpu() interface (Jiri Olsa) [1628229]
- [tools] perf mmap: Store real cpu number in 'struct perf_mmap' (Jiri Olsa) [1628229]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-26.el8]
- [fs] gfs2: Fix iomap buffered write support for journaled files (2) (Andreas Grunbacher) [1637944]
- [xen] xen/manage: don't complain about an empty value in control/sysrq node (Vitaly Kuznetsov) [1623344]
- [drm] drm/amdgpu: Silence harmless WARN_ON() during MST disable (Lyude Paul) [1638137]
- [netdrv] net: macb: Fix regression breaking non-MDIO fixed-link PHYs (Petr Oros) [1638259]
- [netdrv] net: macb: do not disable MDIO bus at open/close time (Petr Oros) [1638259]
- [fs] proc: restrict kernel stack dumps to root (Waiman Long) [1638044]
- [base] firmware: Always initialize the fw_priv list object (Waiman Long) [1638044]
- [base] firmware: Fix security issue with request_firmware_into_buf() (Waiman Long) [1638044]
- [fs] sysfs: Do not return POSIX ACL xattrs via listxattr (Waiman Long) [1638044]
- [fs] vfs: don't evict uninitialized inode (Waiman Long) [1638044]
- [fs] new primitive: discard_new_inode() (Waiman Long) [1638044]
- [arm64] arm64: jump_label.h: use asm_volatile_goto macro instead of "asm goto" (Waiman Long) [1638044]
- [kernel] sched/topology: Set correct NUMA topology type (Waiman Long) [1638044]
- [kernel] bpf: 32-bit RSH verification must truncate input before the ALU op (Waiman Long) [1638044]
- [mm] mm: madvise(MADV_DODUMP): allow hugetlbfs pages (Waiman Long) [1638044]
- [x86] x86/pti: Fix section mismatch warning/error (Waiman Long) [1638044]
- [kernel] uaccess: Fix is_source param for check_copy_size() in copy_to_iter_mcsafe() (Waiman Long) [1638044]
- [x86] x86/mm: Expand static page table for fixmap space (Waiman Long) [1638044]
- [fs] fs/lock: skip lock owner pid translation in case we are in init_pid_ns (Waiman Long) [1638044]
- [x86] perf/x86/intel/lbr: Fix incomplete LBR call stack (Waiman Long) [1638044]
- [kernel] perf/hw_breakpoint: Split attribute parse and commit (Waiman Long) [1638044]
- [kernel] bitfield: fix *_encode_bits() (Waiman Long) [1638044]
- [kernel] posix-timers: Sanitize overrun handling (Waiman Long) [1638044]
- [kernel] posix-timers: Make forward callback return s64 (Waiman Long) [1638044]
- [kernel] alarmtimer: Prevent overflow for relative nanosleep (Waiman Long) [1638044]
- [x86] x86/entry/64: Add two more instruction suffixes (Waiman Long) [1638044]
- [powerpc] powerpc/kdump: Handle crashkernel memory reservation failure (Waiman Long) [1638044]
- [s390] s390/mm: correct allocate_pgste proc_handler callback (Waiman Long) [1638044]
- [x86] x86/numa_emulation: Fix emulated-to-physical node mapping (Waiman Long) [1638044]
- [x86] x86/paravirt: Fix some warning messages (Waiman Long) [1638044]
- [kernel] sched/fair: Fix vruntime_normalized() for remote non-migration wakeup (Waiman Long) [1638044]
- [kernel] bpf/verifier: disallow pointer subtraction (Waiman Long) [1638044]
- [mm] mm: shmem.c: Correctly annotate new inodes for lockdep (Waiman Long) [1638044]
- [kernel] sched/core: Use smp_mb() in wake_woken_function() (Waiman Long) [1638044]
- [kernel] bpf: fix rcu annotations in compute_effective_progs() (Waiman Long) [1638044]
- [x86] x86/mm/pti: Add an overflow check to pti_clone_pmds() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_pmd() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_p4d() (Waiman Long) [1638044]
- [powerpc] powerpc/pseries/mm: call H_BLOCK_REMOVE (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: factorize PTE slot computation (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: Introducing FW_FEATURE_BLOCK_REMOVE (Steve Best) [1637116]
- [watchdog] watchdog/hpwdt: Disable PreTimeout when Timeout is smaller (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update Driver Documentation (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update version number (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Module parameter alias (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Display module parameters (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Claim NMI from iLO (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Initialize pretimeout from module parameter (Joseph Szczypek) [1632945]

* Sat Oct 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-25.el8]
- [mm] mm/sparse: delete old sparse_init and enable new one (Baoquan He) [1625105]
- [mm] mm/sparse: add new sparse_init_nid() and sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse: move buffer init/fini to the common place (Baoquan He) [1625105]
- [mm] mm/sparse: use the new sparse buffer functions in non-vmemmap (Baoquan He) [1625105]
- [mm] mm/sparse: abstract sparse buffer allocations (Baoquan He) [1625105]
- [mm] mm/sparse: optimize memmap allocation during sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a new parameter 'data_unit_size' for alloc_usemap_and_memmap (Baoquan He) [1625105]
- [mm] mm/sparsemem.c: defer the ms->section_mem_map clearing (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a static variable nr_present_sections (Baoquan He) [1625105]
- [mm] mm/sparse.c: make sparse_init_one_section void and remove check (Baoquan He) [1625105]
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1628864]
- [target] scsi: target: iscsi: cxgbit: use pr_debug() instead of pr_info() (Arjun Vynipadath) [1628864]
- [infiniband] iw_cxgb4: only allow 1 flush on user qps (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: pass window scale in flowc work request (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: remove duplicate memcpy() in c4iw_create_listen() (Arjun Vynipadath) [1628865]
- [netdrv] mlxsw: spectrum_switchdev: Do not leak RIFs when removing bridge (Petr Oros) [1638268]
- [tty] tty: vt_ioctl: fix potential Spectre v1 (Prarit Bhargava) [1637123]
- [powerpc] powerpc/time: Add set_state_oneshot_stopped decrementer callback (Steve Best) [1638287]
- [powerpc] powerpc/time: Use clockevents_register_device(), fixing an issue with large decrementer (Steve Best) [1638287]
- [hwmon] hwmon: (nct6775) Fix potential Spectre v1 (Dean Nelson) [1637464]
- [vfio] vfio-pci: Disable binding to PFs with SR-IOV enabled (Alex Williamson) [1637871]
- [netdrv] net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns: fix skb->truesize underestimation (Petr Oros) [1638385]
- [netdrv] net: hns: fix length and page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix get_vector ops in hclgevf_main module (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix warning bug when doing lp selftest (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mac pause not disable in pfc mode (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mailbox message truncated problem (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix return value error in hns3_reset_notify_down_enet (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for reset_level default assignment probelm (Petr Oros) [1638385]
- [netdrv] net: hns3: Reset net device with rtnl_lock (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for phy link issue when using marvell phy driver (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for command format parsing error in hclge_is_all_function_id_zero (Petr Oros) [1638385]
- [net] xprtrdma: Fix disconnect regression (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Fix validity check for modify QP (Don Dutile) [1635418]
- [infiniband] IB/srp: Avoid that sg_reset -d $srp_device triggers an infinite loop (Don Dutile) [1635418]
- [infiniband] ucma: fix a use-after-free in ucma_resolve_ip() (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Atomically flush and mark closed the comp event queue (Don Dutile) [1635418]
- [infiniband] RDMA/mlx4: Ensure that maximal send/receive SGE less than supported by HW (Don Dutile) [1635418 1623100]
- [infiniband] RDMA/cma: Protect cma dev list with lock (Don Dutile) [1635418]
- [infiniband] IB/ipoib: Avoid a race condition between start_xmit and cm_rep_handler (Don Dutile) [1635418]
- [infiniband] RDMA/ucma: check fd type in ucma_migrate_id() (Don Dutile) [1635418]
- [infiniband] RDMA/rxe: Set wqe->status correctly if an unexpected response is received (Don Dutile) [1635418]
- [infiniband] IB/IPoIB: Set ah valid flag in multicast send flow (Don Dutile) [1635418]
- [infiniband] RDMA/core: Avoid holding lock while initializing fields on stack (Don Dutile) [1635418]
- [infiniband] IB/rxe: Drop QP0 silently (Don Dutile) [1635418]
- [infiniband] RDMA/umem: Don't hold mmap_sem for too long (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (2/2) (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (1/2) (Don Dutile) [1635418]
- [infiniband] RDMA: Fix storage of PortInfo CapabilityMask in the kernel (Don Dutile) [1635418]
- [infiniband] IB/core: type promotion bug in rdma_rw_init_one_mr() (Don Dutile) [1635418]
- [infiniband] RDMA/i40w: Hold read semaphore while looking after VMA (Don Dutile) [1635418]
- [infiniband] vmw_pvrdma: Release netdev when vmxnet3 module is removed (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in __srpt_close_all_ch() (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in srpt_close_ch() (Don Dutile) [1635418]
- [infiniband] IB/srpt: Support HCAs with more than two ports (Don Dutile) [1635418]
- [infiniband] IB/rxe: don't clear the tx queue on every transfer (Don Dutile) [1635418]
- [infiniband] IB/core: add max_send_sge and max_recv_sge attributes (Don Dutile) [1635418 1623100]
- [infiniband] IB/rxe: support for 802.1q VLAN on the listener (Don Dutile) [1635418]
- [netdrv] cxgb4: impose mandatory VLAN usage when non-zero TAG ID (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: when max_tx_rate is 0 disable tx rate limiting (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: do not return DUPLEX_UNKNOWN when link is down (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: expose stats fetched from firmware via debugfs (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: remove stats fetched from firmware (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: specify IQTYPE in fw_iq_cmd (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Fix the condition to check if the card is T5 (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Support ethtool private flags (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add support for FW_ETH_TX_PKT_VM_WR (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add flag tc_flower_initialized (Arjun Vynipadath) [1628863]
- [s390] s390/zcrypt: remove VLA usage from the AP bus (Philipp Rudo) [1637865]
- [s390] s390/ap_bus: replace PTR_RET with PTR_ERR_OR_ZERO (Philipp Rudo) [1637865]
- [s390] s390/crypto: fix gcc 8 stringop-truncation warning (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: code beautify (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: add copy_from_user length plausibility checks (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: Show load of cards and queues in sysfs (Philipp Rudo) [1637865]
- [s390] s390/kvm: fix deadlock when killed by oom (Philipp Rudo) [1638264]
- [fs] xfs: fix data corruption w/ unaligned reflink ranges (Brian Foster) [1633476]
- [fs] xfs: fix data corruption w/ unaligned dedupe ranges (Brian Foster) [1633476]
- [fs] xfs: update ctime and remove suid before cloning files (Brian Foster) [1633476]
- [fs] xfs: zero posteof blocks when cloning above eof (Brian Foster) [1633476]
- [fs] xfs: refactor clonerange preparation into a separate helper (Brian Foster) [1633476]
- [netdrv] nfp: avoid buffer leak when FW communication fails (Petr Oros) [1638233]
- [netdrv] nfp: don't fail probe on pci_sriov_set_totalvfs() errors (Petr Oros) [1638233]
- [netdrv] nfp: wait for posted reconfigs when disabling the device (Petr Oros) [1638233]
- [netdrv] liquidio: fix hang when re-binding VF host drv after running DPDK VF driver (Petr Oros) [1638224]
- [netdrv] r8169: set RxConfig after tx/rx is enabled for RTL8169sb/8110sb devices (Petr Oros) [1638210]
- [netdrv] r8169: add support for NCube 8168 network card (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8106e (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8168g (Petr Oros) [1638210]
- [powerpc] KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM workarounds (David Gibson) [1637766]
- [drm] drm/amdgpu: Suppress keypresses from ACPI_VIDEO events (Lyude Paul) [1631918]
- [infiniband] IB/hfi1: Remove race conditions in user_sdma send path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Eliminate races in the SDMA send error path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix destroy_qp hang after a link down (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix context recovery when PBC has an UnsupportedVL (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Invalid user input can result in crash (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix SL array bounds check (Alex Estrin) [1637068]
- [powerpc] powerpc/fadump: re-register firmware-assisted dump if already registered (Steve Best) [1637383]
- [powerpc] powerpc/fadump: cleanup crash memory ranges support (Steve Best) [1637383]
- [powerpc] powerpc/fadump: merge adjacent memory ranges to reduce PT_LOAD segements (Steve Best) [1637383]
- [powerpc] powerpc/fadump: handle crash memory ranges array index overflow (Steve Best) [1637383]
- [scsi] scsi: qedi: Initialize the stats mutex lock (Chad Dupuis) [1637245]
- [fs] gfs2: Fix iomap buffered write support for journaled files (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate update_rgrp_lvb_unlinked (Andreas Grunbacher) [1637944]
- [fs] gfs2: Fix gfs2_testbit to use clone bitmaps (Andreas Grunbacher) [1637944]
- [fs] gfs2: Get rid of gfs2_ea_strlen (Andreas Grunbacher) [1637944]
- [fs] GFS2: rgrp free blocks used incorrectly (Andreas Grunbacher) [1637944]
- [fs] gfs2: remove redundant variable 'moved' (Andreas Grunbacher) [1637944]
- [fs] gfs2: use iomap_readpage for blocksize == PAGE_SIZE (Andreas Grunbacher) [1637944]
- [fs] gfs2: Use iomap for stuffed direct I/O reads (Andreas Grunbacher) [1637944]
- [fs] gfs2: fallocate_chunk: Always initialize struct iomap (Andreas Grunbacher) [1637944]
- [fs] gfs2: Remove gfs2_write_(begin,end) (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap direct I/O support (Andreas Grunbacher) [1637944]
- [fs] gfs2: gfs2_extent_length cleanup (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap buffered write support (Andreas Grunbacher) [1637944]
- [fs] gfs2: Further iomap cleanups (Andreas Grunbacher) [1637944]
- [fs] fs: gfs2: Adding new return type vm_fault_t (Andreas Grunbacher) [1637944]
- [fs] gfs2: using posix_acl_xattr_size instead of posix_acl_to_xattr (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't reject a supposedly full bitmap if we have blocks reserved (Andreas Grunbacher) [1637944]
- [fs] gfs2: Eliminate redundant ip->i_rgd (Andreas Grunbacher) [1637944]
- [fs] gfs2: Stop messing with ip->i_rgd in the rlist code (Andreas Grunbacher) [1637944]
- [fs] gfs2: call ktime_get_coarse_real_ts64() directly (Andreas Grunbacher) [1637944]
- [fs] gfs2: Minor clarification to __gfs2_punch_hole (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't withdraw under a spin lock (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate rs_inum and reduce the size of gfs2 inodes (Andreas Grunbacher) [1637944]
- [drm] drm/nouveau/drm/nouveau: Grab runtime PM ref in nv50_mstc_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/disp: fix DP disable race (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on suspend/unload (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too early (Lyude Paul) [1628749]
- [drm] drm/nouveau: Reset MST branching unit before enabling (Lyude Paul) [1628749]
- [drm] drm/nouveau: Only write DP_MSTM_CTRL when needed (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in drm_load() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_disable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Fix deadlocks in nouveau_connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix deadlock with fb_helper with async RPM requests (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove duplicate poll_enable() in pmops_runtime_suspend() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable() placement (Lyude Paul) [1628749]
- [md] dm table: require that request-based DM be layered on blk-mq devices (Mike Snitzer) [1637682]
- [md] dm: rename DM_TYPE_MQ_REQUEST_BASED to DM_TYPE_REQUEST_BASED (Mike Snitzer) [1637682]
- [md] dm: remove legacy request-based IO path (Mike Snitzer) [1637682]
- [md] dm linear: fix linear_end_io conditional definition (Mike Snitzer) [1637682]
- [md] dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED disabled (Mike Snitzer) [1637682]
- [md] dm: fix report zone remapping to account for partition offset (Mike Snitzer) [1637682]
- [md] dm cache: destroy migration_cache if cache target registration failed (Mike Snitzer) [1637682]
- [md] dm cache: fix resize crash if user doesn't reload cache table (Mike Snitzer) [1637682]
- [md] dm cache metadata: ignore hints array being too small during resize (Mike Snitzer) [1637682]
- [md] dm raid: remove bogus const from decipher_sync_action() return type (Mike Snitzer) [1637682]
- [md] dm mpath: fix attached_handler_name leak and dangling hw_handler_name pointer (Mike Snitzer) [1637682]
- [md] dm thin metadata: fix __udivdi3 undefined on 32-bit (Mike Snitzer) [1637682]
- [md] dm thin metadata: try to avoid ever aborting transactions (Mike Snitzer) [1637682]
- [md] dm raid: bump target version, update comments and documentation (Mike Snitzer) [1637682]
- [md] dm raid: fix RAID leg rebuild errors (Mike Snitzer) [1637682]
- [md] dm raid: fix rebuild of specific devices by updating superblock (Mike Snitzer) [1637682]
- [md] dm raid: fix stripe adding reshape deadlock (Mike Snitzer) [1637682]
- [md] dm raid: fix reshape race on small devices (Mike Snitzer) [1637682]
- [md] dm: disable CRYPTO_TFM_REQ_MAY_SLEEP to fix a GFP_KERNEL recursion deadlock (Mike Snitzer) [1637682]
- [md] dm verity: fix crash on bufio buffer that was allocated with vmalloc (Mike Snitzer) [1637682]
- [md] dm writecache: fix a crash due to reading past end of dirty_bitmap (Mike Snitzer) [1637682]
- [md] dm crypt: don't decrease device limits (Mike Snitzer) [1637682]
- [md] dm cache metadata: set dirty on all cache blocks after a crash (Mike Snitzer) [1637682]
- [md] dm snapshot: remove stale FIXME in snapshot_map() (Mike Snitzer) [1637682]
- [md] dm snapshot: improve performance by switching out_of_order_list to rbtree (Mike Snitzer) [1637682]
- [md] dm kcopyd: avoid softlockup in run_complete_job (Mike Snitzer) [1637682]
- [md] dm cache metadata: save in-core policy_hint_size to on-disk superblock (Mike Snitzer) [1637682]
- [md] dm thin: stop no_space_timeout worker when switching to write-mode (Mike Snitzer) [1637682]
- [md] dm kcopyd: return void from dm_kcopyd_copy() (Mike Snitzer) [1637682]
- [md] dm thin: include metadata_low_watermark threshold in pool status (Mike Snitzer) [1637682]
- [md] dm writecache: report start_sector in status line (Mike Snitzer) [1637682]
- [md] dm crypt: convert essiv from ahash to shash (Mike Snitzer) [1637682]
- [md] dm crypt: use wake_up_process() instead of a wait queue (Mike Snitzer) [1637682]
- [md] dm integrity: recalculate checksums on creation (Mike Snitzer) [1637682]
- [md] dm integrity: flush journal on suspend when using separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: use version 2 for separate metadata (Mike Snitzer) [1637682]
- [md] dm integrity: allow separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: add ic->start in get_data_sector() (Mike Snitzer) [1637682]
- [md] dm integrity: report provided data sectors in the status (Mike Snitzer) [1637682]
- [md] dm integrity: implement fair range locks (Mike Snitzer) [1637682]
- [md] dm integrity: decouple common code in dm_integrity_map_continue() (Mike Snitzer) [1637682]
- [md] dm integrity: change 'suspending' variable from bool to int (Mike Snitzer) [1637682]
- [md] dm delay: add flush as a third class of IO (Mike Snitzer) [1637682]
- [md] dm delay: refactor repetitive code (Mike Snitzer) [1637682]
- [md] dm cache: only allow a single io_mode cache feature to be requested (Mike Snitzer) [1637682]
- [md] dm thin: update stale "Status" Documentation (Mike Snitzer) [1637682]
- [pci] PCI: Reprogram bridge prefetch registers on resume (Myron Stowe) [1637155]
- [input] Input: xen-kbdfront - fix multi-touch XenStore node's locations (Benjamin Tissoires) [1637027]
- [input] Input: elantech - enable middle button of touchpad on ThinkPad P72 (Benjamin Tissoires) [1637027]
- [hid] HID: i2c-hid: Use devm to allocate i2c_hid struct (Benjamin Tissoires) [1637027]
- [hid] HID: input: fix leaking custom input node name (Benjamin Tissoires) [1637027]
- [hid] HID: core: fix grouping by application (Benjamin Tissoires) [1637027]
- [hid] HID: multitouch: fix Elan panels with 2 input modes declaration (Benjamin Tissoires) [1637027]
- [input] Input: do not use WARN() in input_alloc_absinfo() (Benjamin Tissoires) [1637027]
- [s390] s390: vfio-ap: setup APCB mask using KVM dedicated function (Cornelia Huck) [1508118]
- [s390] KVM: s390: Tracing APCB changes (Cornelia Huck) [1508118]
- [s390] KVM: s390: fix locking for crypto setting error path (Cornelia Huck) [1508118]
- [s390] s390: doc: detailed specifications for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: CPU model support for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: device attrs to enable/disable AP interpretation (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-1 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-0 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Allow CRYCB FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Make use of CRYCB FORMAT2 clear (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Do the CRYCB validation first (Cornelia Huck) [1508118]
- [s390] KVM: s390: Clear Crypto Control Block when using vSIE (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_RESET ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: zeroize the AP queues (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_GET_INFO ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement mediated device open callback (Cornelia Huck) [1508118]
- [s390] KVM: s390: interface to clear CRYCB masks (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interface to view matrix mdev matrix (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure control domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure adapters (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: register matrix device with VFIO mdev framework (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: base implementation of VFIO AP device driver (Cornelia Huck) [1508118]
- [s390] KVM: s390: refactor crypto initialization (Cornelia Huck) [1508118]
- [s390] KVM: s390: introduce and use KVM_REQ_VSIE_RESTART (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: simulate VCPU SIE entry/exit (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: hex string mask improvements for apmask and aqmask (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: AP bus support for alternate driver(s) (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: switch return type to bool for ap_instructions_available() (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: fix ap_instructions_available() returncodes (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Integrate ap_asm.h into include/asm/ap.h (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Review inline assembler constraints (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Add ZAPQ inline function (Cornelia Huck) [1508118]
- [net] ipv6: use rt6_info members when dst is set in rt6_fill_node (Xin Long) [1625864 1625803 1625117]

* Thu Oct 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-24.el8]
- [netdrv] amd-xgbe: use dma_mapping_error to check map errors (David Arcari) [1637666]
- [crypto] crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe() (Waiman Long) [1629547]
- [powerpc] powerpc: fix csum_ipv6_magic() on little endian platforms (Diego Domingos) [1625579]
- [net] smc: generic netlink family should be __ro_after_init (Philipp Rudo) [1632435]
- [net] net/smc: fix sizeof to int comparison (Philipp Rudo) [1632435]
- [net] net/smc: no urgent data check for listen sockets (Philipp Rudo) [1632435]
- [net] net/smc: enable fallback for connection abort in state INIT (Philipp Rudo) [1632435]
- [net] net/smc: remove duplicate mutex_unlock (Philipp Rudo) [1632435]
- [net] net/smc: fix non-blocking connect problem (Philipp Rudo) [1632435]
- [net] net/smc: send response to test link signal (Philipp Rudo) [1632435]
- [net] net: simplify sock_poll_wait (Philipp Rudo) [1632435]
- [net] net/smc: Simplify ib_post_(send|recv|srq_recv)() calls (Philipp Rudo) [1632435]
- [net] net/smc: Remove a WARN_ON() statement (Philipp Rudo) [1632435]
- [powerpc] KVM: PPC: Book3S HV: Add NO_HASH flag to GET_SMMU_INFO ioctl result (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a VM capability to enable nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add nested shadow page tables to debugfs (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Allow HV module to load without hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle differing endianness for H_ENTER_NESTED (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Sanitise hv_regs on nested guest entry (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add one-reg interface to virtual PTCR register (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Don't access HFSCR, LPIDR or LPCR when running nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Invalidate TLB when nested vcpu moves physical cpu (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use hypercalls for TLB invalidation when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Implement H_TLB_INVALIDATE hcall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Introduce rmap to track nested guest mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle page fault for a nested guest (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypercalls correctly when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use XICS hypercalls when running as a nested hypervisor (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Nested guest entry via hypercall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Framework and hcall stubs for nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use kvmppc_unmap_pte() in kvm_unmap_radix() (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Refactor radix page fault handler (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Make kvmppc_mmu_radix_xlate process/partition table agnostic (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Clear partition table entry on vm teardown (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Use ccr field in pt_regs struct embedded in vcpu struct (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a debugfs file to dump radix mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypervisor instruction faults better (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Streamlined guest entry/exit path on P9 for radix guests (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Call kvmppc_handle_exit_hv() with vcore unlocked (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Rework TM save/restore code and make it C-callable (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Simplify real-mode interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Extract PMU save/restore operations as C-callable functions (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Move interrupt delivery on guest entry to C code (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Remove left-over code in XICS-on-XIVE emulation (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Simplify external interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc: Turn off CPU_FTR_P9_TM_HV_ASSIST in non-hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc/64s: Remove POWER9 DD1 support (Suraj Jitindar Singh) [1505999]
- [netdrv] net/mlx5: Add Fast teardown support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set vlan masks for all offloaded TC rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix out of bound access when setting vport rate (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Avoid unbounded peer devices when unpairing TC hairpin rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Cache the system image guid (Alaa Hleihel) [1636554]
- [netdrv] mlx5: remove ndo_poll_controller (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for SQ and not RQ state when modifying hairpin SQ (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix read from coherent memory (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: don't set CHECKSUM_COMPLETE on SCTP packets (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set ECN for received packets using CQE indication (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix possible deadlock from lockdep when adding fte to fg (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for error in mlx5_attach_interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Consider PCI domain in search for next dev (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix not releasing read lock when adding flow rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix memory leak when creating switchdev mode FDB tables (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer strides offset (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer fragment size (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix debugfs cleanup in the device init/remove flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix use-after-free in self-healing flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Make function mlx5i_grp_sw_update_stats() static (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Use priv stats in completion rx flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB child devices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB netdevices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Initialize max_opened_tc in mlx5i_init flow (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Fix leaking stack memory to userspace (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reorganize the makefile (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: clock.c depends on CONFIG_PTP_1588_CLOCK (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: vxlan.c depends on CONFIG_VXLAN (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move flow steering declarations into en/fs.h (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_ARFS for accelerated flow steering support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_RXNFC for ethtool rx nfc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Ethtool steering, move ethtool callbacks (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reduce command polling interval (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use max_num_eqs for calculation of required MSIX vectors (Alaa Hleihel) [1636554]
- [netdrv] RDMA/mlx5: Fix shift overflow in mlx5_ib_create_wq (Alaa Hleihel) [1636554]
- [netdrv] overflow.h: Add arithmetic shift helper (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Fix uninitialized variable (Alaa Hleihel) [1636554]
- [netdrv] RDMA: Fix return code check in rdma_set_cq_moderation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move vxlan logic to core driver (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add sync lock for add/del vxlan port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, return values for add/del port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename from mlx5e to mlx5 (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename struct mlx5e_vxlan to mlx5_vxlan_port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move netdev only logic to en_main.c (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add direct delete function (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, cleanup an unused member in vxlan work (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, replace ports radix-tree with hash table (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, check maximum number of UDP ports (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, reflect 4789 UDP port default addition to software database (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move XDP related code into new XDP files (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Restrict the combination of large MTU and XDP (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Gather all XDP pre-requisite checks in a single function (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: avoid excessive warning msgs when creating VFs on 2nd port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Use PARTIAL_GSO for UDP segmentation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Remove redundant WARN when we cannot find neigh entry (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix tristate and description for MLX5 module (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Better return types for CQE API (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use ERR_CAST() instead of coding it (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Add missing SET_DRIVER_VERSION command translation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Honor cnt_set_id_valid flag instead of set_id (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Fix GRE flow specification (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Remove set-but-not-used variables (Alaa Hleihel) [1636554]
- [infiniband] RDMA/mlx5: Don't leak UARs in case of free fails (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Update NIC HW stats on demand only (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for total num of NOP operations (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for MPWQE filler strides (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add channel events counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add a counter for congested UMRs (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add NAPI statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add XDP_TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: RX, Use existing WQ local variable (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Convert large order kzalloc allocations to kvzalloc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO remaining counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Rate limit errors in command interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Prevent warns in dmesg upon firmware commands (Alaa Hleihel) [1636554]
- [netdrv] mlx4: remove ndo_poll_controller (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4: Use cpumask_available for eq->affinity_mask (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/en_rx: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/mcg: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Use 4K pages for kernel QP's WQE buffer (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4_core: Allow MTTs starting at any index (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Test port number before querying type (Alaa Hleihel) [1636553]
- [powerpc] powerpc/numa: Skip onlining a offline node in kdump path (Steve Best) [1637118]
- [netdrv] net: aquantia: Make function aq_fw1x_set_power() static (David Arcari) [1636533]
- [netdrv] net: aquantia: memory corruption on jumbo frames (David Arcari) [1636533 1630377]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: renaming for better visibility (David Arcari) [1636533]
- [netdrv] net: aquantia: whitespace changes (David Arcari) [1636533]
- [netdrv] net: aquantia: implement EEE support (David Arcari) [1636533]
- [netdrv] net: aquantia: implement WOL support (David Arcari) [1636533]
- [netdrv] net: aquantia: definitions for WOL (David Arcari) [1636533]
- [netdrv] net: aquantia: fix hw_atl_utils_fw_upload_dwords (David Arcari) [1636533]
- [netdrv] net: aquantia: Make some functions static (David Arcari) [1636533]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: Add renegotiate ethtool operation support (David Arcari) [1636533]
- [netdrv] net: aquantia: Implement rx/tx flow control ethtools callback (David Arcari) [1636533]
- [netdrv] net: aquantia: Improve adapter init/deinit logic (David Arcari) [1636533]
- [netdrv] net: aquantia: Ethtool based ring size configuration (David Arcari) [1636533]
- [wireless] ath10k: fix memory leak of tpc_stats (Petr Oros) [1637528]
- [wireless] ath10k: snoc: use correct bus-specific pointer in RX retry (Petr Oros) [1637528]
- [wireless] ath10k: fix incorrect size of dma_free_coherent in ath10k_ce_alloc_src_ring_64 (Petr Oros) [1637528]
- [wireless] brcmsmac: fix wrap around in conversion from constant to s16 (Petr Oros) [1637528]
- [wireless] mt76x2: fix mrr idx/count estimation in mt76x2_mac_fill_tx_status() (Petr Oros) [1637528]
- [wireless] ath10k: transmit queued frames after processing rx packets (Petr Oros) [1637528]
- [wireless] ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock (Petr Oros) [1637528]
- [wireless] ath10k: use locked skb_dequeue for rx completions (Petr Oros) [1637528]
- [wireless] ath10k: sdio: set skb len for all rx packets (Petr Oros) [1637528]
- [wireless] ath10k: sdio: use same endpoint id for all packets in a bundle (Petr Oros) [1637528]
- [wireless] iwlwifi: cancel the injective function between hw pointers to tfd entry index (Petr Oros) [1637528]
- [wireless] ath10k: disable bundle mgmt tx completion event support (Petr Oros) [1637528]
- [wireless] ath10k: prevent active scans on potential unusable channels (Petr Oros) [1637528]
- [wireless] ath9k_hw: fix channel maximum power level test (Petr Oros) [1637528]
- [wireless] ath9k: report tx status on EOSP (Petr Oros) [1637528]
- [wireless] iwlwifi: pcie: don't access periphery registers when not available (Petr Oros) [1637528]
- [wireless] brcmfmac: fix brcmf_wiphy_wowl_params() NULL pointer dereference (Petr Oros) [1637528]
- [netdrv] be2net: don't flip hw_features when VXLANs are added/deleted (Petr Oros) [1637133]
- [netdrv] be2net: Fix memory leak in be_cmd_get_profile_config() (Petr Oros) [1637133]
- [netdrv] be2net: Mark expected switch fall-through (Petr Oros) [1637133]
- [netdrv] be2net: fix spelling mistake "seqence" -> "sequence" (Petr Oros) [1637133]
- [netdrv] be2net: Update the driver version to 12.0.0.0 (Petr Oros) [1637133]
- [netdrv] be2net: gather debug info and reset adapter (only for Lancer) on a tx-timeout (Petr Oros) [1637133]
- [netdrv] be2net: move rss_flags field in rss_info to ensure proper alignment (Petr Oros) [1637133]
- [netdrv] be2net: re-order fields in be_error_recovert to avoid hole (Petr Oros) [1637133]
- [netdrv] be2net: remove unused tx_jiffies field from be_tx_stats (Petr Oros) [1637133]
- [netdrv] be2net: move txcp field in be_tx_obj to eliminate holes in the struct (Petr Oros) [1637133]
- [netdrv] be2net: reorder fields in be_eq_obj structure (Petr Oros) [1637133]
- [netdrv] be2net: remove desc field from be_eq_obj (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old custom busy-poll fields (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old AIC info (Petr Oros) [1637133]
- [x86] x86/spec_ctrl/compat: Call IBRS_ENTRY only after valid kernel stack (Waiman Long) [1636843]
- [acpi] ACPI/PPTT: Handle architecturally unknown cache types (Jeremy Linton) [1636567]
- [base] drivers: base: cacheinfo: Do not populate sysfs for unknown cache types (Jeremy Linton) [1636567]
- [fs] getxattr: use correct xattr length (Lukas Czerner) [1637049]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1636651]
- [x86] x86/boot: Fix kexec booting failure in the SEV bit detection code (Kairui Song) [1632514]
- [scsi] scsi: megaraid_sas: driver version upgrade (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Support FW provided TM timeout values (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Return immediately from wait_for_adapter_operational after kill adapter (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Update controller info during resume (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Do not do Kill adapter if GET_CTRL_INFO times out (Tomas Henzl) [1635565]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix re-using LoopID when handle is in use (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix duplicate switch database entries (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix NVMe session hang on unload (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix iIDMA error (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix stalled relogin (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix unintended Logout (Himanshu Madhani) [1633373]
- [powerpc] powerpc/pseries: Disable CPU hotplug across migrations (Steve Best) [1633587]
- [block] blk-mq: I/O and timer unplugs are inverted in blktrace (Ming Lei) [1634330]
- [block] block: fix deadline elevator drain for zoned block devices (Ming Lei) [1634333]
- [block] blk-mq: Allow blocking queue tag iter callbacks (Ming Lei) [1634328]
- [block] block: use nanosecond resolution for iostat (Ming Lei) [1634329]
- [block] null_blk: fix zoned support for non-rq based operation (Ming Lei) [1634324]
- [block] blk-cgroup: increase number of supported policies (Ming Lei) [1634335]
- [block] block: bfq: swap puts in bfqg_and_blkg_put (Ming Lei) [1634334]
- [block] block: don't warn when doing fsync on read-only devices (Ming Lei) [1634331]
- [block] blkcg: use tryget logic when associating a blkg with a bio (Ming Lei) [1634332]
- [block] blkcg: delay blkg destruction until after writeback has (Ming Lei) [1634332]
- [block] Revert "blk-throttle: fix race between (Ming Lei) [1634332]
- [block] blk-wbt: remove dead code (Ming Lei) [1634326]
- [block] blk-wbt: improve waking of tasks (Ming Lei) [1634326]
- [block] blk-wbt: abstract out end IO completion handler (Ming Lei) [1634326]

* Tue Oct 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-23.el8]
- [dma] driver/dma/ioat: Call del_timer_sync() without holding prep_lock (Waiman Long) [1607654]
- [netdrv] bnxt_en: Fix VF mac address regression (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Clean up unused functions (Jonathan Toppins) [1635846]
- [fs] fsnotify: fix ignore mask logic in fsnotify() (Lukas Czerner) [1635537]
- [net] net/af_iucv: locate IUCV header via skb_network_header() (Philipp Rudo) [1635332]
- [net] net/af_iucv: drop inbound packets with invalid flags (Philipp Rudo) [1635332]
- [net] net/af_iucv: fix skb handling on HiperTransport xmit error (Philipp Rudo) [1635332]
- [hid] HID: i2c-hid: Fix flooded incomplete report after S3 on Rayd touchscreen (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Make acpi_gsb_i2c_read_bytes() check i2c_transfer return value (David Arcari) [1635746]
- [i2c] i2c: designware: Re-init controllers with pm_disabled set on resume (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Properly set status byte to 0 for multi-byte writes (David Arcari) [1635746]
- [fs] fs/quota: Fix spectre gadget in do_quotactl (Lukas Czerner) [1635521]
- [fs] xfs: fix error handling in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove invalid log recovery first/last cycle check (Brian Foster) [1633171]
- [fs] xfs: validate inode di_forkoff (Brian Foster) [1633171]
- [fs] xfs: skip delalloc COW blocks in xfs_reflink_end_cow (Brian Foster) [1633171]
- [fs] xfs: don't treat unknown di_flags2 as corruption in scrub (Brian Foster) [1633171]
- [fs] xfs: remove duplicated include from alloc.c (Brian Foster) [1633171]
- [fs] xfs: don't bring in extents in xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak in xfs_reflink_allocate_cow() (Brian Foster) [1633171]
- [fs] xfs: avoid lockdep false positives in xfs_trans_alloc (Brian Foster) [1633171]
- [fs] xfs: refactor xfs_buf_log_item reference count handling (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_trans_brelse() (Brian Foster) [1633171]
- [fs] xfs: don't unlock invalidated buf on aborted tx commit (Brian Foster) [1633171]
- [fs] xfs: remove last of unnecessary xfs_defer_cancel() callers (Brian Foster) [1633171]
- [fs] xfs: don't crash the vfs on a garbage inline symlink (Brian Foster) [1633171]
- [fs] iomap: set page dirty after partial delalloc on mkwrite (Brian Foster) [1633171]
- [fs] xfs: sanity check ag header values in xrep_calc_ag_resblks (Brian Foster) [1633171]
- [fs] xfs: recalculate summary counters at mount time if icount is bad (Brian Foster) [1633171]
- [fs] xfs: fix a null pointer dereference in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove b_last_holder & associated macros (Brian Foster) [1633171]
- [fs] xfs: repair the AGI (Brian Foster) [1633171]
- [fs] xfs: repair the AGFL (Brian Foster) [1633171]
- [fs] xfs: repair the AGF (Brian Foster) [1633171]
- [fs] xfs: remove dead error handling code in xfs_dquot_disk_alloc() (Brian Foster) [1633171]
- [fs] xfs: use WRITE_ONCE to update if_seq (Brian Foster) [1633171]
- [fs] xfs: fix a comment in xfs_log_reserve (Brian Foster) [1633171]
- [fs] xfs: only validate summary counts on primary superblock (Brian Foster) [1633171]
- [fs] xfs: substitute spaces with tabs (Brian Foster) [1633171]
- [fs] xfs: fold dfops into the transaction (Brian Foster) [1633171]
- [fs] xfs: always defer agfl block frees (Brian Foster) [1633171]
- [fs] xfs: pass transaction to xfs_defer_add() (Brian Foster) [1633171]
- [fs] xfs: replace xfs_defer_ops ->dop_pending with on-stack list (Brian Foster) [1633171]
- [fs] xfs: cancel dfops on xfs_defer_finish() error (Brian Foster) [1633171]
- [fs] xfs: clean out superfluous dfops dop params/vars (Brian Foster) [1633171]
- [fs] xfs: drop dop param from xfs_defer_op_type ->finish_item() callback (Brian Foster) [1633171]
- [fs] xfs: automatic dfops inode relogging (Brian Foster) [1633171]
- [fs] xfs: automatic dfops buffer relogging (Brian Foster) [1633171]
- [fs] xfs: add missing defer ijoins for held inodes (Brian Foster) [1633171]
- [fs] xfs: replace dop_low with transaction flag (Brian Foster) [1633171]
- [fs] xfs: pass transaction to dfops reset/move helpers (Brian Foster) [1633171]
- [fs] xfs: remove unused __xfs_defer_cancel() internal helper (Brian Foster) [1633171]
- [fs] xfs: use transaction for intent recovery instead of raw dfops (Brian Foster) [1633171]
- [fs] xfs: refactor internal dfops initialization (Brian Foster) [1633171]
- [fs] xfs: check da node magic in _node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: use a local variable for magic number in xfs_da3_node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: refactor log recovery check (Brian Foster) [1633171]
- [fs] xfs: move extent busy tree initialization to xfs_initialize_perag (Brian Foster) [1633171]
- [fs] xfs: avoid COW fork extent lookups in writeback if the fork didn't change (Brian Foster) [1633171]
- [fs] xfs: maintain a sequence count for inode fork manipulations (Brian Foster) [1633171]
- [fs] xfs: check for unknown v5 feature bits in superblock write verifier (Brian Foster) [1633171]
- [fs] xfs: verify icount in superblock write (Brian Foster) [1633171]
- [fs] libxfs: add more bounds checking to sb sanity checks (Brian Foster) [1633171]
- [fs] xfs: refactor superblock verifiers (Brian Foster) [1633171]
- [fs] xfs: refactor the xrep_extent_list into xfs_bitmap (Brian Foster) [1633171]
- [fs] xfs: introduce a new xfs_inode_has_cow_data helper (Brian Foster) [1633171]
- [fs] xfs: remove the xfs_ifork_t typedef (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_idata_realloc (Brian Foster) [1633171]
- [fs] xfs: remove if_real_bytes (Brian Foster) [1633171]
- [fs] xfs: move the repair extent list into its own file (Brian Foster) [1633171]
- [fs] xfs: pass transaction lock while setting up agresv on cyclic metadata (Brian Foster) [1633171]
- [fs] xfs: remove deprecated barrier/nobarrier mount (Brian Foster) [1633171]
- [fs] xfs: clean up IRELE/iput callsites (Brian Foster) [1633171]
- [fs] xfs: kill IHOLD (Brian Foster) [1633171]
- [fs] xfs: bypass final dfops roll in trans commit path (Brian Foster) [1633171]
- [fs] xfs: drop unnecessary xfs_defer_finish() dfops parameter (Brian Foster) [1633171]
- [fs] xfs: remove unnecessary dfops init calls in xattr code (Brian Foster) [1633171]
- [fs] xfs: remove all boilerplate defer init/finish code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops during (b|c)ui recovery (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in attr code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in cow blocks cancel (Brian Foster) [1633171]
- [fs] xfs: support embedded dfops in transaction (Brian Foster) [1633171]
- [fs] xfs: pack holes in xfs_defer_ops and xfs_trans (Brian Foster) [1633171]
- [fs] xfs: reset dfops to initial state after finish (Brian Foster) [1633171]
- [fs] xfs: remove unused deferred ops committed field (Brian Foster) [1633171]
- [fs] xfs: make deferred processing safe for embedded dfops (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak on remote attr set/remove failure (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in log recovery intent processing (Brian Foster) [1633171]
- [fs] xfs: pull up dfops from xfs_itruncate_extents() (Brian Foster) [1633171]
- [fs] xfs: force summary counter recalc at next mount (Brian Foster) [1633171]
- [fs] xfs: refactor unmount record write (Brian Foster) [1633171]
- [fs] xfs: detect and fix bad summary counts at mount (Brian Foster) [1633171]
- [fs] xfs: fix indentation and other whitespace problems in scrub/repair (Brian Foster) [1633171]
- [fs] xfs: shorten struct xfs_scrub_context to struct xfs_scrub (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_repair_ prefix to xrep_ (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_scrub_ prefix (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_btree_del_cursor callers (Brian Foster) [1633171]
- [fs] xfs: trivial xfs_btree_del_cursor cleanups (Brian Foster) [1633171]
- [fs] xfs: return from _defer_finish with a clean transaction (Brian Foster) [1633171]
- [fs] xfs: check leaf attribute block freemap in verifier (Brian Foster) [1633171]
- [fs] libxfs: Fix a couple of sparse complaintis (Brian Foster) [1633171]
- [fs] xfs: use swap macro in xfs_dir2_leafn_rebalance (Brian Foster) [1633171]
- [fs] xfs_bmap_util: use swap macro (Brian Foster) [1633171]
- [fs] xfs_attr_leaf: use swap macro in xfs_attr3_leaf_rebalance (Brian Foster) [1633171]
- [fs] xfs: don't assume a left rmap when allocating a new rmap (Brian Foster) [1633171]
- [fs] xfs: kill __xfs_buf_submit_common() (Brian Foster) [1633171]
- [fs] xfs: combine (a)sync buffer submission apis (Brian Foster) [1633171]
- [fs] xfs: use sync buffer I/O for sync delwri queue submission (Brian Foster) [1633171]
- [fs] xfs: refactor buffer submission into a common helper (Brian Foster) [1633171]
- [fs] xfs: remove xfs_defer_init() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in inode inactivate (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in extent swap (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in reflink cow block cancel (Brian Foster) [1633171]
- [fs] xfs: replace no-op firstblock init with ->t_firstblock (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dq alloc (Brian Foster) [1633171]
- [fs] xfs: remove xfs_alloc_arg firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur private firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove bmap format helpers firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove bmap extent add helper firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmalloca firstblock field (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in bmap extent split (Brian Foster) [1633171]
- [fs] xfs: remove bmap insert/collapse firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in insert/collapse range (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xfs_bmapi_remap() (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xattr ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in attrfork add (Brian Foster) [1633171]
- [fs] xfs: remove firstblock param from xfs dir ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dir ops (Brian Foster) [1633171]
- [fs] xfs: add firstblock field to xfs_trans (Brian Foster) [1633171]
- [fs] xfs: allow null firstblock in xfs_bmapi_write() when tp is null (Brian Foster) [1633171]
- [fs] xfs: refactor dfops init to attach to transaction (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in reflink cow recover path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in cancel cow blocks operation (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for rmap extent swap operations (Brian Foster) [1633171]
- [fs] xfs: remove unused btree cursor bc_private.a.dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur bmbt dfops field (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from internal bmap extent helpers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for collapse/insert range operations (Brian Foster) [1633171]
- [fs] xfs: remove struct xfs_bmalloca dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_remap() dfops param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in dqalloc transaction (Brian Foster) [1633171]
- [fs] xfs: replace xfs_da_args->dfops accesses with ->t_dfops and remove (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in extent split tx and remove param (Brian Foster) [1633171]
- [fs] xfs: remove dfops param in attr fork add path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for attr set/remove operations (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for recovery of (b|c)ui log items (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from high level dirname calls (Brian Foster) [1633171]
- [fs] xfs: remove dfops parameter from ifree call stack (Brian Foster) [1633171]
- [fs] xfs: rename xfs_trans ->t_agfl_dfops to ->t_dfops (Brian Foster) [1633171]
- [fs] xfs: cow unwritten conversion uses uninitialized dfops (Brian Foster) [1633171]
- [fs] xfs: update my copyrights for the writeback and iomap code (Brian Foster) [1633171]
- [fs] xfs: add support for sub-pagesize writeback without buffer_heads (Brian Foster) [1633171]
- [fs] xfs: allow writeback on pages without buffer heads (Brian Foster) [1633171]
- [fs] xfs: refactor the tail of xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_start_page_writeback (Brian Foster) [1633171]
- [fs] xfs: move all writeback buffer_head manipulation into xfs_map_at_offset (Brian Foster) [1633171]
- [fs] xfs: don't look at buffer heads in xfs_add_to_ioend (Brian Foster) [1633171]
- [fs] xfs: remove the imap_valid flag (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_map_blocks by using xfs_iext_lookup_extent directly (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_find_cow_mapping (Brian Foster) [1633171]
- [fs] xfs: remove the now unused XFS_BMAPI_IGSTATE flag (Brian Foster) [1633171]
- [fs] xfs: make xfs_writepage_map extent map centric (Brian Foster) [1633171]
- [fs] xfs: rename the offset variable in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_map_cow (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_trim_irec_to_next_cow (Brian Foster) [1633171]
- [fs] xfs: don't use XFS_BMAPI_IGSTATE in xfs_map_blocks (Brian Foster) [1633171]
- [fs] xfs: don't clear imap_valid for a non-uptodate buffers (Brian Foster) [1633171]
- [fs] xfs: do not set the page uptodate in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: move locking into xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_aops_discard_page (Brian Foster) [1633171]
- [fs] xfs: use iomap for blocksize == PAGE_SIZE readpage and readpages (Brian Foster) [1633171]
- [fs] iomap: fix WARN_ON_ONCE on uninitialized variable (Brian Foster) [1633171]
- [fs] iomap: Switch to offset_in_page for clarity (Brian Foster) [1633171]
- [fs] iomap: add support for sub-pagesize buffered I/O without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add inline data support to iomap_readpage_actor (Brian Foster) [1633171]
- [fs] iomap: support direct I/O to inline data (Brian Foster) [1633171]
- [fs] iomap: refactor iomap_dio_actor (Brian Foster) [1633171]
- [fs] iomap: add initial support for writes without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add an iomap-based readpage and readpages implementation (Brian Foster) [1633171]
- [fs] iomap: add private pointer to struct iomap (Brian Foster) [1633171]
- [fs] iomap: add a page_done callback (Brian Foster) [1633171]
- [fs] iomap: generic inline data handling (Brian Foster) [1633171]
- [fs] iomap: complete partial direct I/O writes synchronously (Brian Foster) [1633171]
- [fs] iomap: mark newly allocated buffer heads as new (Brian Foster) [1633171]
- [fs] fs: factor out a __generic_write_end helper (Brian Foster) [1633171]
- [netdrv] amd-xgbe: mark driver as tech preview (David Arcari) [1633209]
- [fs] ext4, dax: set ext4_dax_aops for dax files (Lukas Czerner) [1633239]
- [fs] ext4, dax: add ext4_bmap to ext4_dax_aops (Lukas Czerner) [1633239]
- [fs] ext4: don't mark mmp buffer head dirty (Lukas Czerner) [1633239]
- [fs] ext4: show test_dummy_encryption mount option in /proc/mounts (Lukas Czerner) [1633239]
- [fs] ext4: fix online resizing for bigalloc file systems with a 1k block size (Lukas Czerner) [1633239]
- [fs] ext4: fix online resize's handling of a too-small final block group (Lukas Czerner) [1633239]
- [fs] ext4: recalucate superblock checksum after updating free blocks/inodes (Lukas Czerner) [1633239]
- [fs] ext4: avoid arithemetic overflow that can trigger a BUG (Lukas Czerner) [1633239]
- [fs] ext4: avoid divide by zero fault when deleting corrupted inline directories (Lukas Czerner) [1633239]
- [fs] ext4: check to make sure the rename(2)'s destination is not freed (Lukas Czerner) [1633239]
- [fs] ext4: remove unneeded variable "err" in ext4_mb_release_inode_pa() (Lukas Czerner) [1633239]
- [fs] ext4: fix spectre gadget in ext4_mb_regular_allocator() (Lukas Czerner) [1633239]
- [fs] ext4: check for NUL characters in extended attribute's name (Lukas Czerner) [1633239]
- [fs] ext4: use ext4_warning() for sb_getblk failure (Lukas Czerner) [1633239]
- [fs] ext4: fix race when setting the bitmap corrupted flag (Lukas Czerner) [1633239]
- [fs] ext4: reset error code in ext4_find_entry in fallback (Lukas Czerner) [1633239]
- [fs] ext4: check allocation failure when duplicating "data" in ext4_remount() (Lukas Czerner) [1633239]
- [fs] ext4: sysfs: print ext4_super_block fields as little-endian (Lukas Czerner) [1633239]
- [firmware] efi/x86: Handle page faults occurring while running EFI runtime services (Bhupesh Sharma) [1627557]
- [firmware] efi: Make efi_rts_work accessible to efi page fault handler (Bhupesh Sharma) [1627557]
- [firmware] efi: Remove the declaration of efi_late_init() as the function is unused (Bhupesh Sharma) [1627557]
- [firmware] efi: Use a work queue to invoke EFI Runtime Services (Bhupesh Sharma) [1627557]
- [firmware] efi/x86: Use non-blocking SetVariable() for efi_delete_dummy_variable() (Bhupesh Sharma) [1627557]
- [fs] gfs2: Special-case rindex for gfs2_grow (Robert S Peterson) [1628360]
- [fs] GFS2: Fix recovery issues for spectators (Robert S Peterson) [1628298]

* Fri Oct 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-22.el8]
- [powerpc] powerpc/pkeys: Fix reading of ibm, processor-storage-keys property (Steve Best) [1633551]
- [powerpc] powerpc/pseries: Remove unneeded uses of dlpar work queue (Steve Best) [1633544]
- [powerpc] powerpc/pseries: Remove prrn_work workqueue (Steve Best) [1633544]
- [pci] ACPI / hotplug / PCI: Don't scan for non-hotplug bridges if slot is not bridge (Myron Stowe) [1634816]
- [pci] PCI: Fix enabling of PASID on RC integrated endpoints (Myron Stowe) [1634816]
- [pci] IB/hfi1,PCI: Allow bus reset while probing (Myron Stowe) [1634816]
- [pci] PCI: Fix faulty logic in pci_reset_bus() (Myron Stowe) [1634816]
- [pci] PCI: pciehp: Fix hot-add vs powerfault detection order (Myron Stowe) [1634816]
- [pci] Revert "PCI: Add ACS quirk for Intel 300 series" (Myron Stowe) [1634816]
- [powerpc] powerpc/numa: Use associativity if VPHN hcall is successful (Steve Best) [1633569]
- [pci] PCI: vmd: White list for fast interrupt handlers (Myron Stowe) [1632816]
- [pci] PCI: Add function 1 DMA alias quirk for Marvell 88SS9183 (Myron Stowe) [1632816]
- [pci] PCI: Rename pci_try_reset_bus() to pci_reset_bus() (Myron Stowe) [1632816]
- [pci] PCI: Deprecate pci_reset_bus() and pci_reset_slot() functions (Myron Stowe) [1632816]
- [pci] PCI: Unify try slot and bus reset API (Myron Stowe) [1632816]
- [pci] PCI: Hide pci_reset_bridge_secondary_bus() from drivers (Myron Stowe) [1632816]
- [pci] IB/hfi1: Use pci_try_reset_bus() for initiating PCI Secondary Bus Reset (Myron Stowe) [1632816]
- [pci] PCI: Handle error return from pci_reset_bridge_secondary_bus() (Myron Stowe) [1632816]
- [pci] PCI/IOV: Tidy pci_sriov_set_totalvfs() (Myron Stowe) [1632816]
- [pci] PCI: Enable PASID only if entire path supports End-End TLP prefixes (Myron Stowe) [1632816]
- [pci] PCI: Expand documentation for pci_add_dma_alias() (Myron Stowe) [1632816]
- [pci] PCI: Add DMA alias quirk for Microsemi Switchtec NTB (Myron Stowe) [1632816]
- [pci] switchtec: Use generic PCI Vendor ID and Class Code (Myron Stowe) [1632816]
- [pci] PCI: Make pci_get_rom_size() static (Myron Stowe) [1632816]
- [pci] PCI: Add check code for last image indicator not set (Myron Stowe) [1632816]
- [pci] PCI: Avoid accessing memory outside the ROM BAR (Myron Stowe) [1632816]
- [pci] PCI: Make early dump functionality generic (Myron Stowe) [1632816]
- [pci] PCI: Cleanup PCI_REBAR_CTRL_BAR_SHIFT handling (Myron Stowe) [1632816]
- [pci] PCI: Restore resized BAR state on resume (Myron Stowe) [1632816]
- [pci] PCI: Clean up resource allocation in devm_of_pci_get_host_bridge_resources() (Myron Stowe) [1632816]
- [pci] PCI: Add ACS Redirect disable quirk for Intel Sunrise Point (Myron Stowe) [1632816]
- [pci] PCI: Add device-specific ACS Redirect disable infrastructure (Myron Stowe) [1632816]
- [pci] PCI: Convert device-specific ACS quirks from NULL termination to ARRAY_SIZE (Myron Stowe) [1632816]
- [pci] PCI: Add "pci=disable_acs_redir=" parameter for peer-to-peer support (Myron Stowe) [1632816]
- [pci] PCI: Allow specifying devices using a base bus and path of devfns (Myron Stowe) [1632816]
- [pci] PCI: Make specifying PCI devices in kernel parameters reusable (Myron Stowe) [1632816]
- [pci] PCI: Hide ACS quirk declarations inside PCI core (Myron Stowe) [1632816]
- [pci] PCI: Document ACPI description of PCI host bridges (Myron Stowe) [1632816]
- [pci] PCI/MSI: Set IRQCHIP_ONESHOT_SAFE for PCI-MSI irqchips (Myron Stowe) [1632816]
- [pci] PCI: Limit config space size for Netronome NFP5000 (Myron Stowe) [1632816]
- [pci] PCI: Add PCI_DEVICE_DATA() macro to fully describe device ID entry (Myron Stowe) [1632816]
- [pci] PCI: Unify PCI and normal DMA direction definitions (Myron Stowe) [1632816]
- [pci] PCI: Use IRQF_ONESHOT if pci_request_irq() called with no handler (Myron Stowe) [1632816]
- [pci] PCI: Call dma_debug_add_bus() for pci_bus_type from PCI core (Myron Stowe) [1632816]
- [pci] PCI: Mark fall-through switch cases before enabling -Wimplicit-fallthrough (Myron Stowe) [1632816]

* Thu Oct 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-21.el8]
- [s390] s390/sclp: Allow to request adapter reset (Philipp Rudo) [1635273]
- [char] ipmi: Fix NULL pointer dereference in ssif_probe (Tony Camuso) [1635366]
- [char] ipmi: Fix I2C client removal in the SSIF driver (Tony Camuso) [1635366]
- [char] ipmi: kcs_bmc: don't change device name (Tony Camuso) [1635366]
- [kernel] timers: Clear timer_base::must_forward_clk with timer_base::lock held (Waiman Long) [1632820]
- [pci] switchtec: Fix Spectre v1 vulnerability (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Prevent state corruption on error rollback (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Adjust misplaced smb() in cpuhp_thread_fun() (Waiman Long) [1632820]
- [base] memory_hotplug: fix kernel_panic on offline page processing (Waiman Long) [1632820]
- [mm] mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is not supported (Waiman Long) [1632820]
- [lib] debugobjects: Make stack check warning more informative (Waiman Long) [1632820]
- [fs] fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot() (Waiman Long) [1632820]
- [x86] x86/process: Don't mix user/kernel regs in 64bit __show_regs() (Waiman Long) [1632820]
- [x86] x86/dumpstack: Don't dump kernel memory based on usermode RIP (Waiman Long) [1632820]
- [x86] x86: Avoid pr_cont() in show_opcodes() (Waiman Long) [1632820]
- [x86] x86/entry/64: Wipe KASAN stack shadow before rewind_stack_do_exit() (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+ (Waiman Long) [1632820]
- [x86] x86/spectre: Add missing family 6 check to microcode check (Waiman Long) [1632820]
- [x86] x86/nmi: Fix NMI uaccess race against CR3 switching (Waiman Long) [1632820]
- [x86] x86/vdso: Fix lsl operand order (Waiman Long) [1632820]
- [x86] x86/vdso: Fix vDSO build if a retpoline is emitted (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Suggest what to do on systems with too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix off-by-one error when warning that system has too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Exempt zeroed PTEs from inversion (Waiman Long) [1632820]
- [x86] x86/mm/pti: Clear Global bit more aggressively (Waiman Long) [1632820]
- [x86] x86/paravirt: Fix spectre-v2 mitigations for paravirt guests (Waiman Long) [1632820]
- [target] scsi: target: iscsi: Use bin2hex instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}
- [target] scsi: target: iscsi: Use hex2bin instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}

* Wed Oct 03 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-20.el8]
- [netdrv] ibmvnic: Include missing return code checks in reset function (Steve Best) [1633553]
- [netdrv] ibmvnic: Update firmware error reporting with cause string (Steve Best) [1633553]
- [netdrv] ibmvnic: Remove code to request error information (Steve Best) [1633553]
- [s390] s390/qeth: remove duplicated carrier state tracking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up drop conditions for received cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-indent qeth_check_ipa_data() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consume local address events (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove various redundant code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove CARD_FROM_CDEV helper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: pass card pointer in iob callback (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-use qeth_notify_skbs() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove additional skb refcount (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: replace open-coded skb_queue_walk() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: on gdev release, reset drvdata (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix discipline unload after setup error (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use DEFINE_MUTEX for qeth_mod_mutex (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: convert layer attribute to enum (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce 0-initializing when building IPA cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune spinlocks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix typo in return value (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: invoke softirqs after napi_schedule() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: uninstall IRQ handler on device removal (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_hdr_chk_and_bounce() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: prepare for copy-free TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: check size of required HW header cache object (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix up protocol headers early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: limit csum offload erratum to L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_get_elements_no() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused L3 xmit code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: run non-offload L3 traffic over common xmit path (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: move L2 xmit code to core module (Hendrik Brueckner) [1633841]
- [s390] s390/qdio: reset old sbal_state flags (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't dump past end of unknown HW header (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use vzalloc for QUERY OAT buffer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: switch on SG by default for IQD devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: indicate error when netdev allocation fails (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use true and false for boolean values (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't restrict qeth_card to DMA memory (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up card initialization (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: do basic setup for data channel (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use qeth_setup_ccw() to set up all CCWs (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce hard-coded access to ccw channels (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: extract helper for MPC protocol type (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up L2 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add support for constrained HW headers (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: merge linearize-check into HW header construction (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add statistics for consumed buffer elements (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use core MTU range checking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: simplify max MTU handling (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't cache HW port number (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: allocate netdevice early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove redundant netif_carrier_ok() checks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reset layer2 attribute on layer switch (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix race in used-buffer accounting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up IPv4 OSA xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up L3 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add a L3 xmit wrapper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: increase GSO max size for eligible L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up exported symbols (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consolidate ccwgroup driver definition (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up Output Queue selection (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune RX modesetting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused buffer->aob pointer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: various buffer management cleanups (Hendrik Brueckner) [1633841]
- [powerpc] powerpc: Avoid code patching freed init sections (Steve Best) [1633545]
- [powerpc] powerpc/tm: Fix userspace r13 corruption (Steve Best) [1633543]
- [powerpc] powerpc/tm: Avoid possible userspace r1 corruption on reclaim (Steve Best) [1633543]
- [drm] drm/i915/cfl: Add a new CFL PCI ID (Rob Clark) [1626883]
- [drm] drm/i915/aml: Introducing Amber Lake platform (Rob Clark) [1626883]
- [drm] drm/i915/whl: Introducing Whiskey Lake platform (Rob Clark) [1626883]
- [char] ipmi: Move BT capabilities detection to the detect call (Frank Ramsay) [1618774]
- [char] ipmi: Rework SMI registration failure (Frank Ramsay) [1618774]

* Tue Oct 02 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-19.el8]
- [s390] s390: detect etoken facility (Thomas Huth) [1634069]
- [s390] s390/lib: use expoline for all bcr instructions (Thomas Huth) [1634069]
- [documentation] vm.txt: Adding 'nr_hugepages_mempolicy' parameter description (Prashant Dhamdhere) [1626547]

* Mon Oct 01 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-18.el8]
- [scsi] scsi: ipr: System hung while dlpar adding primary ipr adapter back (Steve Best) [1633217]
- [target] scsi: iscsi: target: Don't use stack buffer for scatterlist (Maurizio Lombardi) [1631342]
- [rpmspec] Forward port weak-modules support from RHEL 7 to RHEL 8 ("Herton R. Krzesinski") [1596884]
- [fs] xfs: Close race between direct IO and xfs_break_layouts() (Eric Sandeen) [1622191]
- [fs] xfs: remove unused iolock arg from xfs_break_dax_layouts (Eric Sandeen) [1622191]
- [fs] ext4: Close race between direct IO and ext4_break_layouts() (Eric Sandeen) [1616303]
- [fs] ext4: handle layout changes to pinned DAX mappings (Eric Sandeen) [1614154]
- [fs] dax: dax_layout_busy_page() warn on !exceptional (Eric Sandeen) [1614154]
- [fs] dax: mark tech preview (Eric Sandeen) [1627455]
- [mm] usercopy: Allow boot cmdline disabling of hardening (Christoph von Recklinghausen) [1589928]

* Thu Sep 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-17.el8]
- [s390] s390/crypto: Fix return code checking in cbc_paes_crypt() (Philipp Rudo) [1633266]
- [drm] amd/display/dc/basics/logger.c: fix build error with CONFIG_FORTIFY_SOURCE=y ("Herton R. Krzesinski") [1548068]
- [acpi] ACPICA: AML Parser: skip opcodes that open a scope upon parse failure (Jeremy Linton) [1609885]
- [acpi] ACPICA: ACPICA: add status check for acpi_hw_read before assigning return value (Jeremy Linton) [1609885]
- [acpi] ACPICA: AML Parser: ignore all exceptions resulting from incorrect AML during table load (Jeremy Linton) [1609885]
- [rpmspec] spec: Add missing BuildRequires for bpftool (Jiri Olsa) [1632756]
- [powerpc] KVM: PPC: Avoid marking DMA-mapped pages dirty in real mode (David Gibson) [1628412]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels on demand (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Rework TCE level allocation (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Add indirect levels to it_userspace (David Gibson) [1628412]
- [powerpc] KVM: PPC: Make iommu_table::it_userspace big endian (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Move TCE manupulation code to its own file (David Gibson) [1628412]
- [net] net_sched: fix NULL pointer dereference when delete tcindex filter (Andrea Claudi) [1627648]
- [net] net_sched: Fix missing res info when create new tc_index filter (Andrea Claudi) [1627648]
- [samples] samples/bpf: xdpsock: order memory on AArch64 (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu load balance like Suricata (Jesper Brouer) [1615959]
- [samples] samples/bpf: add Paul Hsieh's (LGPL 2.1) hash function SuperFastHash (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu handle parsing of double VLAN tagged packets (Jesper Brouer) [1615959]
- [samples] samples/bpf: all XDP samples should unload xdp/bpf prog on SIGTERM (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_rxq_info action XDP_TX must adjust MAC-addrs (Jesper Brouer) [1615959]
- [samples] samples/bpf: extend xdp_rxq_info to read packet payload (Jesper Brouer) [1615959]
- [powerpc] KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix() (David Gibson) [1625498]
- [net] igmp: fix incorrect unsolicit report count after link down and up (Hangbin Liu) [1625538]
- [net] igmp: fix incorrect unsolicit report count when join group (Hangbin Liu) [1625538]
- [netdrv] cxgb4: update 1.20.8.0 as the latest firmware supported (Arjun Vynipadath) [1622555]
- [virt] svm: nested virt support off by default (Bandan Das) [1571993]

* Wed Sep 26 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-16.el8]
- [powerpc] KVM: PPC: Book3S HV: Don't use compound_order to determine host mapping size (David Gibson) [1625860]
- [virt] arm64: KVM: Remove pgd_lock (Wei Huang) [1627474]
- [virt] KVM: Remove obsolete kvm_unmap_hva notifier backend (Wei Huang) [1627474]
- [virt] arm64: KVM: Only force FPEXC32_EL2.EN if trapping FPSIMD (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Clean dcache to PoC when changing PTE due to CoW (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PTE entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PMD entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Move DEBUG_SPINLOCK_BUG_ON to vgic.h (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Do not use spin_lock_irqsave/restore with irq disabled (Wei Huang) [1627474]
- [virt] KVM: arm: vgic-v3: Add support for ICC_SGI0R and ICC_ASGI1R accesses (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-v3: Add support for ICC_SGI0R_EL1 and ICC_ASGI1R_EL1 accesses (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-v3: Add core support for Group0 SGIs (Wei Huang) [1627474]
- [virt] KVM: arm64: Remove non-existent AArch32 ICC_SGI1R encoding (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix lost IRQs from emulated physcial timer when blocked (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix potential loss of ptimer interrupts (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Fix possible spectre-v1 write in vgic_mmio_write_apr() (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Update documentation of the GIC devices wrt IIDR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Let userspace opt-in to writable v2 IGROUPR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Allow configuration of interrupt groups (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Return error on incompatible uaccess GICD_IIDR writes (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Permit uaccess writes to return errors (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Signal IRQs using their configured group (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Add group field to struct irq (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: GICv2 IGROUPR should read as zero (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Keep track of implementation revision (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Define GICD_IIDR fields for GICv2 and GIv3 (Wei Huang) [1627474]
- [virt] arm64: KVM: Cleanup tpidr_el2 init on non-VHE (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-debug: Show LPI status (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-its: Remove VLA usage (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix vgic init race (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Enable adaptative WFE trapping (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Remove unnecessary CMOs when creating HYP page tables (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Stop using the kernel's (pmd, pud, pgd)_populate helpers (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Consolidate page-table accessors (Wei Huang) [1627474]
- [virt] arm64: KVM: Avoid marking pages as XN in Stage-2 if CTR_EL0.DIC is set (Wei Huang) [1627474]
- [tools] radix tree test suite: Enable ubsan (Waiman Long) [1630244]
- [tools] radix tree test suite: Fix compilation (Waiman Long) [1630244]
- [block] blk-wbt: don't maintain inflight counts if disabled (Ming Lei) [1622790]
- [block] blk-wbt: fix has-sleeper queueing check (Ming Lei) [1622790]
- [block] blk-wbt: use wq_has_sleeper() for wq active check (Ming Lei) [1622790]
- [block] blk-wbt: move disable check into get_limit() (Ming Lei) [1622790]
- [block] block/DAC960.c: make some arrays static const, shrinks object (Ming Lei) [1622790]
- [block] blk-mq: sync the update nr_hw_queues with (Ming Lei) [1617959]
- [block] blk-mq: init hctx sched after update ctx and hctx mapping (Ming Lei) [1617959]
- [block] block: remove duplicate initialization (Ming Lei) [1622790]
- [block] tracing/blktrace: Fix to allow setting same value (Ming Lei) [1622790]
- [block] pktcdvd: fix setting of 'ret' error return for a few cases (Ming Lei) [1622790]
- [block] block: change return type to bool (Ming Lei) [1622790]
- [block] block, bfq: return nbytes and not zero from struct cftype (Ming Lei) [1622790]
- [block] block, bfq: improve code of bfq_bfqq_charge_time (Ming Lei) [1622790]
- [block] block, bfq: reduce write overcharge (Ming Lei) [1622790]
- [block] block, bfq: always update the budget of an entity when needed (Ming Lei) [1622790]
- [block] block, bfq: readd missing reset of parent-entity service (Ming Lei) [1622790]
- [block] block: don't warn for flush on read-only device (Ming Lei) [1622809]

* Tue Sep 25 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-15.el8]
- [kernel] locking/rwsem: Make owner store task pointer of last owning reader (Waiman Long) [1631842]
- [kernel] locking/rwsem: Exit read lock slowpath if queue empty & no writer (Waiman Long) [1631842]
- [x86] x86/microcode: Update the new microcode revision unconditionally (Prarit Bhargava) [1630931]
- [x86] x86/microcode: Make sure boot_cpu_data.microcode is up-to-date (Prarit Bhargava) [1630931]
- [arm64] arm64: tlb: Provide forward declaration of tlb_flush() before including tlb.h (Waiman Long) [1630521]
- [x86] x86/mm: Only use tlb_remove_table() for paravirt (Waiman Long) [1630521]
- [mm] mm: mmu_notifier fix for tlb_end_vma (Waiman Long) [1630521]
- [mm] mm/tlb, x86/mm: Support invalidating TLB caches for RCU_TABLE_FREE (Waiman Long) [1630521]
- [mm] mm/tlb: Remove tlb_remove_table() non-concurrent condition (Waiman Long) [1630521]
- [mm] mm: move tlb_table_flush to tlb_flush_mmu_free (Waiman Long) [1630521]
- [kernel] clocksource: Revert Remove kthread (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Retain tick when shallow state is selected (Waiman Long) [1628402]
- [cpufreq] cpufreq: governor: Avoid accessing invalid governor_data (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Handle stopped tick more aggressively (Waiman Long) [1628402]
- [kernel] sched: idle: Avoid retaining the tick when it has been stopped (Waiman Long) [1628402]
- [net] netfilter: xt_hashlimit: do not crash when reading proc file (Florian Westphal) [1630131]
- [x86] x86/boot/KASLR: Skip specified number of 1GB huge pages when doing physical randomization (KASLR) (Baoquan He) [1564824]
- [x86] x86/boot/KASLR: Add two new functions for 1GB huge pages handling (Baoquan He) [1564824]
- [mfd] mfd: intel-lpss: Add Ice Lake PCI IDs (Gopal Tiwari) [1483477]
- [mmc] mmc: sdhci-pci: Add support for Intel ICP (Gopal Tiwari) [1483496]

* Mon Sep 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-14.el8]
- [mm] mm: get rid of vmacache_flush_all() entirely (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm, vmacache: hash addresses based on pmd (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm: Allocate the mm_cpumask (mm->cpu_bitmap) dynamically based on nr_cpu_ids (Waiman Long) [1631297] {CVE-2018-17182}
- [infiniband] IB/hfi1: Invalid NUMA node information can cause a divide by zero (Alex Estrin) [1622222]
- [nvdimm] libnvdimm: Export max available extent (Jeff Moyer) [1627874]
- [nvdimm] libnvdimm: Use max contiguous area for namespace size (Jeff Moyer) [1627874]
- [netdrv] ice: Fix and update driver version string (Jonathan Toppins) [1611786]
- [netdrv] ice: Introduce SERVICE_DIS flag and service routine functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable VSI Rx/Tx pruning only when VLAN 0 is active (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable firmware logging during device initialization (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement ice_bridge_getlink and ice_bridge_setlink (Jonathan Toppins) [1611786]
- [netdrv] ice: Add support for Tx hang, Tx timeout and malicious driver detection (Jonathan Toppins) [1611786]
- [netdrv] ice: Clean up register file (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement handlers for ethtool PHY/link operations (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor VSI allocation, deletion and rebuild flow (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor switch rule management structures and functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Code optimization for ice_fill_sw_rule() (Jonathan Toppins) [1611786]
- [netdrv] ice: Prevent control queue operations during reset (Jonathan Toppins) [1611786]
- [netdrv] ice: Update request resource command to latest specification (Jonathan Toppins) [1611786]
- [netdrv] ice: Updates to Tx scheduler code (Jonathan Toppins) [1611786]
- [netdrv] ice: Rework flex descriptor programming (Jonathan Toppins) [1611786]
- [netdrv] net/mlx5: Fix SQ offset in QPs with small RQ (Alaa Hleihel) [1623367]
- [x86] x86/spec_ctrl: Make IBRS code work with SSBD mitigation (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Auto-enable IBRS on Skylake (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Extend spectre_v2 boot option to support IBRS (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Boot time IBRS initialization (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Add IBRS code to the 64-bit assembly entry code (Waiman Long) [1565180]
- [x86] x86/cpufeatures: Increase NCAPINTS for future extension (Waiman Long) [1565180]
- [netdrv] ice: Trivial formatting fixes (Jonathan Toppins) [1611783]
- [netdrv] ice: Change struct members from bool to u8 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix potential return of uninitialized value (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix a few null pointer dereference issues (Jonathan Toppins) [1611783]
- [netdrv] ice: Update to interrupts enabled in OICR (Jonathan Toppins) [1611783]
- [netdrv] ice: Set VLAN flags correctly (Jonathan Toppins) [1611783]
- [netdrv] ice: Use order_base_2 to calculate higher power of 2 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix bugs in control queue processing (Jonathan Toppins) [1611783]
- [netdrv] ice: Clean control queues only when they are initialized (Jonathan Toppins) [1611783]
- [netdrv] ice: Report stats for allocated queues via ethtool stats (Jonathan Toppins) [1611783]
- [netdrv] ice: Cleanup magic number (Jonathan Toppins) [1611783]
- [netdrv] ice: Remove unnecessary node owner check (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix multiple static analyser warnings (Jonathan Toppins) [1611783]
- [virt] KVM: VMX: fixes for vmentry_l1d_flush module parameter (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with interrupts disabled (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] x86/kvm/vmx: Fix coding style in vmx_setup_l1d_flush() (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Support Enhanced IBRS on future CPUs (Waiman Long) [1614144]
- [x86] x86/speculation: Protect against userspace-userspace spectreRSB (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Remove SPECTRE_V2_IBRS in enum spectre_v2_mitigation (Waiman Long) [1616248] {CVE-2018-15572}
- [cpufreq] cpufreq: Fix a circular lock dependency problem (Waiman Long) [1599154]
- [kernel] cpu/hotplug: Add a cpus_read_trylock() function (Waiman Long) [1599154]
- [virt] xen/spinlock: Don't use pvqspinlock if only 1 vCPU (Waiman Long) [1618486]

* Thu Sep 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-13.el8]
- [mailbox] mailbox: PCC: handle parse error (David Arcari) [1630382]
- [hv] vmbus: don't return values for uninitalized channels (Vitaly Kuznetsov) [1617954]
- [mm] kernel/memremap, kasan: make ZONE_DEVICE with work with KASAN (Bill O'Donnell) [1629578]
- [mm] mm: fix BUG_ON() in vmf_insert_pfn_pud() from VM_MIXEDMAP removal (Jeff Moyer) [1622171]
- [mm] dax: remove VM_MIXEDMAP for fsdax and device dax (Jeff Moyer) [1622171]

* Wed Sep 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-12.el8]
- [i2c] i2c: i801: fix DNV's SMBCTRL register offset (David Arcari) [1628861]
- [fs] ceph: avoid a use-after-free in ceph_destroy_options() (Ilya Dryomov) [1629884]
- [fs] ceph: fix incorrect use of strncpy (Ilya Dryomov) [1629884]
- [block] rbd: support cloning across namespaces (Ilya Dryomov) [1629884]
- [block] rbd: factor out get_parent_info() (Ilya Dryomov) [1629884]
- [block] rbd: support for images within namespaces (Ilya Dryomov) [1629884]
- [block] rbd: pass rbd_spec into parse_rbd_opts_token() (Ilya Dryomov) [1629884]
- [net] libceph: weaken sizeof check in ceph_x_verify_authorizer_reply() (Ilya Dryomov) [1629884]
- [net] libceph: check authorizer reply/challenge length before reading (Ilya Dryomov) [1629884]
- [net] libceph: implement CEPHX_V2 calculation mode (Ilya Dryomov) [1629884]
- [net] libceph: add authorizer challenge (Ilya Dryomov) [1629884]
- [net] libceph: factor out encrypt_authorizer() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __ceph_x_decrypt() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __prepare_write_connect() (Ilya Dryomov) [1629884]
- [net] libceph: store ceph_auth_handshake pointer in ceph_connection (Ilya Dryomov) [1629884]
- [pci] PCI: pciehp: Deduplicate presence check on probe & resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid implicit fallthroughs in switch statements (Myron Stowe) [1583983]
- [pci] PCI: Whitelist Thunderbolt ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: Whitelist native hotplug ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: sysfs: Resume to D0 on function reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume parent to D0 on config space access (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume to D0 on enable/disable (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Support interrupts sent from D3hot (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Obey compulsory command delay after resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Clear spurious events earlier on resume (Myron Stowe) [1583983]
- [pci] PCI: portdrv: Deduplicate PM callback iterator (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid slot access during reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Always enable occupied slot on probe (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Become resilient to missed events (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Tolerate initially unstable link (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_enable/disable_slot() static (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop enable/disable lock (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Enable/disable exclusively from IRQ thread (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Track enable/disable status (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Publish to user space last on probe (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Demidlayer registration with the core (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop slot workqueue (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Handle events synchronously (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Stop blinking on slot enable failure (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded polling (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded IRQ (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Document struct slot and struct controller (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_unconfigure_device() void (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop unnecessary NULL pointer check (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix unprotected list iteration in IRQ handler (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix use-after-free on unplug (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Don't leak pci_slot on registration failure (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Delete skeleton driver (Myron Stowe) [1583983]
- [netdrv] be2net: Use Kconfig flag to support for enabling/disabling adapters (Petr Oros) [1611768]
- [acpi] ACPICA: Reference Counts: increase max to 0x4000 for large servers (Frank Ramsay) [1618760]

* Tue Sep 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-11.el8]
- [net] udp6: add missing checks on edumux packet processing (Paolo Abeni) [1625954]
- [net] udp4: fix IP_CMSG_CHECKSUM for connected sockets (Paolo Abeni) [1625954]
- [s390] s390/pci: fix out of bounds access during irq setup (Hendrik Brueckner) [1627462]
- [nvdimm] libnvdimm: fix ars_status output length calculation (Jeff Moyer) [1616307]

* Mon Sep 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-10.el8]
- [scsi] scsi: lpfc: Correct MDS diag and nvmet configuration (Dick Kennedy) [1628323]
- [iommu] iommu/arm-smmu: workaround DMA mode issues (Mark Salter) [1624077]
- [x86] x86/microcode: Allow late microcode loading with SMT disabled (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] tools headers: Synchronise x86 cpufeatures.h for L1TF additions (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/kmmio: Make the tracer robust against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/pat: Make set_memory_np() L1TF safe (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Invert all not present mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Fix SMT supported evaluation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] KVM: VMX: Tell the nested hypervisor to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Simplify sysfs report of VMX L1TF vulnerability (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Remove Yonah processors from not vulnerable list (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d from vmx_handle_external_intr() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86: Don't include linux/irq.h from asm/hardirq.h (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Demote irq_cpustat_t::__softirq_pending to u16 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with 'vmx_l1d_flush_cond' (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d to true from vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: detect SMT disabled by BIOS (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Fix typos (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED architectures (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation: Add section about CPU vulnerabilities (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs, kvm: Introduce boot-time control of L1TF mitigations (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Expose SMT control init function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Allow runtime control of L1D flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Serialize L1D flush parameter setter (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Add static key for flush always (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Move l1tf setup function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/l1tf: Handle EPT disabled state proper (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Drop L1TF MSR list approach (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/litf: Introduce vmx status variable (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Online siblings when SMT control is turned on (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER only MSRs (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number accounting (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add find_msr() helper function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Split the VMX MSR LOAD structures to have an host/guest numbers (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush logic (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D MSR based flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush algorithm (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add module argument for L1TF mitigation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being present (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Boot HT siblings at least once (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Revert "x86/apic: Ignore secondary threads if nosmt=force" (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Fix up pte->pfn conversion for PAE (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PAE swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Move TOPOEXT reenablement before reading smp_num_siblings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpufeatures: Add detection of L1D cache flush support (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Extend 64bit swap file size limit (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/apic: Ignore secondary threads if nosmt=force (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Do not check CPUID max ext level before parsing SMP info (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/intel: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/topology: Provide detect_extended_topology_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/common: Provide detect_ht_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Remove the pointless detect_ht() call (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu: Remove the pointless CPU printout (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Provide knobs to control SMT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Split do_cpu_down() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Make bringup/teardown of smp threads symmetric (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/topology: Provide topology_smt_supported() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/smp: Provide topology_is_primary_thread() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] sched/smt: Update sched_smt_present at runtime (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs: Move the l1tf function and define pr_fmt properly (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Limit swap file size to MAX_PA/2 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Disallow non privileged high MMIO PROT_NONE mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Add sysfs reporting for l1tf (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make sure the first page is always reserved (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Change order of offset/type in swap entry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}

* Thu Sep 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-9.el8]
- [pci] PCI/DPC: Remove indirection waiting for inactive link (Myron Stowe) [1485556]
- [pci] PCI/DPC: Use threaded IRQ for bottom half handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Print AER status in DPC event handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Remove rp_pio_status from dpc struct (Myron Stowe) [1485556]
- [pci] PCI/DPC: Defer event handling to work queue (Myron Stowe) [1485556]
- [pci] PCI/DPC: Leave interrupts enabled while handling event (Myron Stowe) [1485556]
- [net] net/mlx5e: Offload TC matching on tos/ttl for ip tunnels (Erez Alfasi) [1615121]
- [net] net/mlx5e: Support setup of tos and ttl for tunnel key TC action offload (Erez Alfasi) [1615121]
- [net] net/mlx5e: Use ttl from route lookup on tc encap offload only if needed (Erez Alfasi) [1615121]
- [net] net/sched: cls_flower: Support matching on ip tos and ttl for tunnels (Erez Alfasi) [1615121]
- [net] flow_dissector: Dissect tos and ttl from the tunnel info (Erez Alfasi) [1615121]
- [net] net/sched: tunnel_key: Allow to set tos and ttl for tc based ip tunnels (Erez Alfasi) [1615121]
- [net] net/sched: act_tunnel_key: disambiguate metadata dst error cases (Erez Alfasi) [1615121]
- [net] net/sched: add tunnel option support to act_tunnel_key (Erez Alfasi) [1615121]
- [iommu] iommu/amd: Add support for IOMMU XT mode (Suravee Suthikulpanit) [1504485]
- [iommu] iommu/amd: Add support for higher 64-bit IOMMU Control Register (Suravee Suthikulpanit) [1504485]
- [x86] x86: irq_remapping: Move irq remapping mode enum (Suravee Suthikulpanit) [1504485]
- [firmware] dcdbas: Add support for WSMT ACPI table (Charles Rose) [1502286]

* Wed Sep 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-8.el8]
- [documentation] scsi: documentation: add scsi_mod.use_blk_mq to scsi-parameters (Ewan Milne) [1600014]
- [scsi] scsi: core: Update SCSI_MQ_DEFAULT help text to match default (Ewan Milne) [1600014]
- [scsi] scsi: core: switch to scsi-mq by default (Ewan Milne) [1600014]
- [pci] PCI: Match Root Port's MPS to endpoint's MPSS as necessary (Myron Stowe) [1502324]
- [pci] PCI: Skip MPS logic for Virtual Functions (VFs) (Myron Stowe) [1502324]
- [pci] PCI: Check for PCIe Link downtraining (Myron Stowe) [1502324]
- [pci] PCI: Workaround IDT switch ACS Source Validation erratum (Myron Stowe) [1502324]
- [of] OF: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [iommu] iommu/dma: Respect bus DMA limit for IOVAs (Mark Salter) [1581822]
- [of] of/device: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [kernel] dma-mapping: Generalise dma_32bit_limit flag (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Support address size limit for root complexes (Mark Salter) [1581822]
- [of] of/platform: Initialise default DMA masks (Mark Salter) [1581822]
- [net] Bluetooth: hidp: buffer overflow in hidp_process_report (Gopal Tiwari) [1623073] {CVE-2018-9363}
- [irqchip] irqchip/gic-v3-its: Reduce minimum LPI allocation to 1 for PCI devices (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Honor hypervisor enforced LPI range (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3: Expose GICD_TYPER in the rdist structure (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Drop chunk allocation compatibility (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Move minimum LPI requirements to individual busses (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Use full range of LPIs (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Refactor LPI allocator (Mark Salter) [1550500]

* Tue Sep 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-7.el8]
- [netdrv] hv_netvsc: Fix a deadlock by getting rtnl lock earlier in netvsc_probe() (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: ignore devices that are not PCI (Vitaly Kuznetsov) [1625609]
- [netdrv] hv/netvsc: Fix NULL dereference at single queue mode fallback (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: Add per-cpu ethtool stats for netvsc (Vitaly Kuznetsov) [1625609]
- [pci] PCI: shpchp: Separate existence of SHPC and permission to use it (Steve Best) [1622953]
- [powerpc] KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function (David Gibson) [1625513]
- [kernel] rh_kabi: Add macros to size and extend structs (Prarit Bhargava) [1564570]
- [pci] PCI: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] iwlwifi: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] ath9k: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [netdrv] igb: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [pci] PCI/ASPM: Convert to use sysfs_match_string() helper (Myron Stowe) [1622672]
- [virt] KVM: s390: Properly lock mm context allow_gmap_hpage_1m setting (Thomas Huth) [1623513]
- [virt] KVM: s390: vsie: copy wrapping keys to right place (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix pfmf and conditional skey emulation (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix storage attributes migration with memory slots (Thomas Huth) [1623513]
- [virt] KVM: s390: a utility function for migration (Thomas Huth) [1623513]

* Mon Sep 10 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-6.el8]
- [lib] vsprintf: Add command line option debug_boot_weak_hash (Prarit Bhargava) [1625687]
- [netdrv] i40e: Fix for Tx timeouts when interface is brought up if DCB is enabled (Stefan Assmann) [1616147]
- [misc] ocxl: Fix page fault handler in case of fault on dying process (Steve Best) [1624644]
- [edac] EDAC, sb_edac: Add support for systems with segmented PCI buses (Aristeu Rozanski) [1621849]
- [netdrv] xen-netfront: fix warn message as irq device name has '/' (Vitaly Kuznetsov) [1576160]
- [arm64] arm64, kaslr: export offset in VMCOREINFO ELF notes (Bhupesh Sharma) [1624246]
- [rpmspec] redhat: Move gfs2 and dlm out of kernel-modules-extra (Andrew Price) [1623511]
- [powerpc] powerpc/topology: Get topology for shared processors at boot (Steve Best) [1620039]
- [fs] gfs2: Don't set GFS2_RDF_UPTODATE when the lvb is updated (Robert S Peterson) [1622057]
- [fs] gfs2: improve debug information when lvb mismatches are found (Robert S Peterson) [1622057]
- [fs] gfs2: cleanup: call gfs2_rgrp_ondisk2lvb from gfs2_rgrp_out (Robert S Peterson) [1622057]
- [x86] Fix x86 32-bit invalid cpu boot failure message (Prarit Bhargava) [1571456]
- [net] net/ipv6: init ip6 anycast rt->dst.input as ip6_input (Hangbin Liu) [1615671]
- [pci] PCI/AER: Don't clear AER bits if error handling is Firmware-First (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove duplicate PCI_EXP_AER_FLAGS definition (Myron Stowe) [1621933]
- [pci] PCI/portdrv: Remove pcie_portdrv_err_handler.slot_reset (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_COR handling (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_FATAL and ERR_NONFATAL (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove ERR_FATAL code from ERR_NONFATAL path (Myron Stowe) [1621933]
- [pci] PCI/AER: Factor out ERR_NONFATAL status bit clearing (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_NONFATAL bits during non-fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_FATAL status bits during fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Honor "pcie_ports=native" even if HEST sets FIRMWARE_FIRST (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes for rootport cumulative stats (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes to provide AER stats and breakdown (Myron Stowe) [1621933]
- [pci] PCI/AER: Define aer_stats structure for AER capable devices (Myron Stowe) [1621933]
- [pci] PCI/AER: Move internal declarations to drivers/pci/pci.h (Myron Stowe) [1621933]
- [pci] PCI/AER: Adopt lspci names for AER error decoding (Myron Stowe) [1621933]
- [pci] PCI/AER: Expose internal API for obtaining AER information (Myron Stowe) [1621933]
- [kernel] rcu: Make expedited GPs handle CPU 0 being offline (Gustavo Duarte) [1610262]
- [rpmspec] Generate BootLoaderSpec config fragments ("Herton R. Krzesinski") [1619766]

* Wed Aug 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-5.el8]
- [net] erspan: set erspan_ver to 1 by default when adding an erspan dev (Xin Long) [1619118]
- [hv] x86/hyper-v: Fix wrong merge conflict resolution (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check cpumask_to_vpset() return value in hyperv_flush_tlb_others_ex() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Trace PV IPI send (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_SEND_IPI hypercall when possible (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use 'fast' hypercall for HVCALL_SEND_IPI (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Implement hv_do_fast_hypercall16 (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_FLUSH_VIRTUAL_ADDRESS_(LIST, SPACE) hypercalls when possible (Vitaly Kuznetsov) [1597652]
- [netdrv] xen-netfront: fix queue name setting (Vitaly Kuznetsov) [1576160]
- [scsi] lfpc: add Lancer FCoE to the removed devices (Tomas Henzl) [1602033]
- [scsi] megaraid_sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] aacraid: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla4xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] lpfc: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla2xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] mpt3sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] be2iscsi: add removed id table (Tomas Henzl) [1602033]
- [scsi] rh_taint, pci : add information about removed hardware (Tomas Henzl) [1602033]
- [kernel] kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl) [1602033]
- [net] sunrpc: Change rpc_print_iostats to rpc_clnt_show_stats and handle rpc_clnt clones (Dave Wysochanski) [1610373]
- [net] sunrpc: Add _add_rpc_iostats() to add rpc_iostats metrics (Dave Wysochanski) [1610373]
- [net] sunrpc: add _print_rpc_iostats() to output metrics for one RPC op (Dave Wysochanski) [1610373]

* Mon Aug 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-4.el8]
- [net] xdp: exclude XDP from kABI guarantee (Jiri Benc) [1568551]
- [kernel] rh_kabi: introduce RH_KABI_EXCLUDE (Jiri Benc) [1568551]
- [powerpc] powerpc/powernv/pci: Work around races in PCI bridge enabling (Steve Best) [1620035]
- [block] blk-wbt: fix IO hang in wbt_wait() (Ming Lei) [1614198]
- [block] blkcg: Make blkg_root_lookup() work for queues in bypass mode (Ming Lei) [1614198]
- [block] null_blk: add lock drop/acquire annotation (Ming Lei) [1614198]
- [block] Blk-throttle: reduce tail io latency when iops limit is (Ming Lei) [1614198]
- [block] block: paride: pd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] block: Ensure that a request queue is dissociated from the (Ming Lei) [1614198]
- [block] block: Introduce blk_exit_queue() (Ming Lei) [1614198]
- [block] blkcg: Introduce blkg_root_lookup() (Ming Lei) [1614198]
- [block] block: Remove two superfluous #include directives (Ming Lei) [1614198]
- [block] blk-mq: count the hctx as active before allocating tag (Ming Lei) [1614198]
- [block] block: bvec_nr_vecs() returns value for wrong slab (Ming Lei) [1614198]
- [block] drivers/block/drbd: remove the null check for (Ming Lei) [1614198]
- [block] drivers/block/aoe/aoedev: NULL check is not needed for (Ming Lei) [1614198]
- [block] drivers/block/mtip32xx: remove the null check for (Ming Lei) [1614198]
- [block] cfq: Suppress compiler warnings about comparisons (Ming Lei) [1614198]
- [block] cfq: Annotate fall-through in a switch statement (Ming Lei) [1614198]
- [block] blk-wbt: Avoid lock contention and thundering herd issue in (Ming Lei) [1590363]
- [block] target/loop: depend on SCSI (Ming Lei) [1614198]
- [block] xen-blkfront: use true and false for boolean values (Ming Lei) [1614198]
- [block] lightnvm: remove minor version check for 2.0 (Ming Lei) [1614198]
- [block] scsi: Check sense buffer size at build time (Ming Lei) [1614198]
- [block] libata-scsi: Move sense buffers onto stack (Ming Lei) [1614198]
- [block] cdrom: Use struct scsi_sense_hdr internally (Ming Lei) [1614198]
- [block] ide-cd: Remove redundant sense buffer (Ming Lei) [1614198]
- [block] block: Switch struct packet_command to use struct (Ming Lei) [1614198]
- [block] target: don't depend on SCSI (Ming Lei) [1614198]
- [block] scsi: build scsi_common.o for all scsi passthrough request (Ming Lei) [1614198]
- [block] scsi: cxlflash: Drop unused sense buffers (Ming Lei) [1614198]
- [block] ide-cd: Drop unused sense buffers (Ming Lei) [1614198]
- [block] blk-mq: fix updating tags depth (Ming Lei) [1611900]
- [block] block: really disable runtime-pm for blk-mq (Ming Lei) [1611902]
- [block] aoe: mark expected switch fall-through (Ming Lei) [1614198]
- [block] block: make iolatency avg_lat exponentially decay (Ming Lei) [1614198]
- [block] blk-cgroup: clear the throttle queue on fork (Ming Lei) [1614198]
- [block] blk-cgroup: hold the queue ref during throttling (Ming Lei) [1614198]
- [block] blk-iolatency: fix blkg leak in timer_fn (Ming Lei) [1614198]
- [block] block/bsg-lib: use PTR_ERR_OR_ZERO to simplify the flow path (Ming Lei) [1614198]
- [block] t10-pi: provide empty t10_pi_complete() for (Ming Lei) [1614198]
- [block] block: blk_init_allocated_queue() set q->fq as NULL in the (Ming Lei) [1614198]
- [block] nvme: use blk API to remap ref tags for IOs with metadata (Ming Lei) [1614198]
- [block] block: move dif_prepare/dif_complete functions to block layer (Ming Lei) [1614198]
- [block] block: move ref_tag calculation func to the block layer (Ming Lei) [1614198]
- [block] block: don't account for split bio's size in cgroup stats (Ming Lei) [1614198]
- [block] pktcdvd: Fix possible Spectre-v1 for pkt_devs (Ming Lei) [1614198]
- [block] partitions/aix: append null character to print data from disk (Ming Lei) [1614198]
- [block] partitions/aix: fix usage of uninitialized lv_info and lvname (Ming Lei) [1614198]
- [block] readahead: stricter check for bdi io_pages (Ming Lei) [1614198]
- [block] scsi: virtio_scsi: fix pi_bytes(out, in) on 4 KiB block size (Ming Lei) [1614198]
- [block] block: move bio_integrity_(intervals, bytes) into blkdev.h (Ming Lei) [1614198]
- [block] xen/blkfront: remove unused macros (Ming Lei) [1614198]
- [block] block: allow max_discard_segments to be stacked (Ming Lei) [1614198]
- [block] block: unexport bio_clone_bioset (Ming Lei) [1614198]
- [block] md: remove a bogus comment (Ming Lei) [1614198]
- [block] block: remove bio_clone_kmalloc (Ming Lei) [1614198]
- [block] exofs: use bio_clone_fast in _write_mirror (Ming Lei) [1614198]
- [block] bcache: don't clone bio in bch_data_verify (Ming Lei) [1614198]
- [block] block: bio_set_pages_dirty can't see NULL bv_page in a valid (Ming Lei) [1614198]
- [block] block: simplify bio_check_pages_dirty (Ming Lei) [1614198]
- [block] block: Rename the null_blk_mod kernel module back into (Ming Lei) [1614198]
- [block] blk-mq: fail the request in case issue failure (Ming Lei) [1614305]
- [block] blk-rq-qos: make depth comparisons unsigned (Ming Lei) [1614198]
- [block] blkcg: Track DISCARD statistics and output them in cgroup (Ming Lei) [1614198]
- [block] block: Track DISCARD statistics and output them in stat and (Ming Lei) [1614198]
- [block] block: Add and use op_stat_group() for indexing disk_stat (Ming Lei) [1614198]
- [block] block: Define and use STAT_READ and STAT_WRITE (Ming Lei) [1614198]
- [block] block: Add part_stat_read_accum to read across field entries (Ming Lei) [1614198]
- [block] block: make bdev_ops->rw_page() take a REQ_OP instead of bool (Ming Lei) [1614198]
- [block] pktcdvd: remove assignment in if condition (Ming Lei) [1614198]
- [block] blk-mq: issue directly if hw queue isn't busy in case of (Ming Lei) [1614305]
- [block] blk-iolatency: truncate our current time (Ming Lei) [1614198]
- [block] blk-iolatency: don't change the latency window (Ming Lei) [1614198]
- [block] block: remove blkdev_entry_to_request() macro (Ming Lei) [1614198]
- [block] block: skd: Use pad printk format for dma_addr_t values (Ming Lei) [1614198]
- [block] bsg: remove read/write support (Ming Lei) [1614198]
- [block] blk-iolatency: fix max_depth comparisons (Ming Lei) [1614198]
- [block] block: iolatency: avoid 64-bit division (Ming Lei) [1614198]
- [block] block/DAC960.c: fix defined but not used build warnings (Ming Lei) [1614198]
- [block] null_blk: add zone support (Ming Lei) [1614198]
- [block] null_blk: move shared definitions to header file (Ming Lei) [1614198]
- [block] block: Add default switch case to blk_pm_allow_request() to (Ming Lei) [1614198]
- [block] block: fix infinite loop if the device loses discard (Ming Lei) [1614198]
- [block] block, mm: remove unnecessary __GFP_HIGH flag (Ming Lei) [1614198]
- [block] null_blk: remove NULLB_DEV_FL_CONFIGURED on turning off nullb (Ming Lei) [1614198]
- [block] mm: skip readahead if the cgroup is congested (Ming Lei) [1614198]
- [block] Documentation: add a doc for blk-iolatency (Ming Lei) [1614198]
- [block] block: introduce blk-iolatency io controller (Ming Lei) [1614198]
- [block] rq-qos: introduce dio_bio callback (Ming Lei) [1614198]
- [block] block: remove external dependency on wbt_flags (Ming Lei) [1614198]
- [block] blk-rq-qos: refactor out common elements of blk-wbt (Ming Lei) [1614198]
- [block] blk-stat: export helpers for modifying blk_rq_stat (Ming Lei) [1614198]
- [block] memcontrol: schedule throttling if we are congested (Ming Lei) [1614198]
- [block] blkcg: add generic throttling mechanism (Ming Lei) [1614198]
- [block] swap, blkcg: issue swap io with the appropriate context (Ming Lei) [1614198]
- [block] blk: introduce REQ_SWAP (Ming Lei) [1614198]
- [block] blk-cgroup: allow controllers to output their own stats (Ming Lei) [1614198]
- [block] block: introduce bio_issue_as_root_blkg (Ming Lei) [1614198]
- [block] block: add bi_blkg to the bio for cgroups (Ming Lei) [1614198]
- [block] blk-mq: dequeue request one by one from sw queue if hctx is (Ming Lei) [1614305]
- [block] block/loop: mark expected switch fall-through (Ming Lei) [1614198]
- [block] drbd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] blk-mq: only attempt to merge bio if there is rq in sw queue (Ming Lei) [1614305]
- [block] blk-mq: use list_splice_tail_init() to insert requests (Ming Lei) [1614305]
- [block] blk-mq: fix typo in a function comment (Ming Lei) [1614198]
- [block] blk-mq: code clean-up by adding an API to clear set->mq_map (Ming Lei) [1614198]
- [block] paride: remove redundant variable n (Ming Lei) [1614198]
- [block] partitions/ldm: remove redundant pointer dgrp (Ming Lei) [1614198]
- [block] loop: remove redundant pointer inode (Ming Lei) [1614198]
- [block] block/floppy: remove redundant variable dflags (Ming Lei) [1614198]
- [block] Block: blk-throttle: set low_valid immediately once one (Ming Lei) [1614198]
- [block] Blktrace: bail out early if block debugfs is not configured (Ming Lei) [1614198]
- [block] block: Document how blk_update_request() handles (Ming Lei) [1614198]
- [block] drbd: Do not redefine __must_hold() (Ming Lei) [1614198]
- [block] blk-mq: avoid to synchronize rcu inside blk_cleanup_queue() (Ming Lei) [1597067]
- [block] blk-mq: remove synchronize_rcu() from (Ming Lei) [1597067]
- [block] blk-mq: introduce new lock for protecting hctx->dispatch_wait (Ming Lei) [1597067]
- [block] blk-mq: don't pass **hctx to blk_mq_mark_tag_wait() (Ming Lei) [1597067]
- [block] blk-mq: cleanup blk_mq_get_driver_tag() (Ming Lei) [1597067]
- [block] block, bfq: give a better name to bfq_bfqq_may_idle (Ming Lei) [1614198]
- [block] block, bfq: fix service being wrongly set to zero in case of (Ming Lei) [1614198]
- [block] block, bfq: do not expire a queue that will deserve dispatch (Ming Lei) [1614198]
- [block] block, bfq: add/remove entity weights correctly (Ming Lei) [1614198]
- [block] block: Make struct request_queue smaller for (Ming Lei) [1614198]
- [block] block: Inline blk_queue_nr_zones() (Ming Lei) [1614198]
- [block] block: Remove bdev_nr_zones() (Ming Lei) [1614198]
- [block] include/uapi/linux/blkzoned.h: Remove a superfluous __packed (Ming Lei) [1614198]
- [block] block: Remove a superfluous cast from blkdev_report_zones() (Ming Lei) [1614198]

* Fri Aug 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-3.el8]
- [net] tls: mark as Tech Preview (Sabrina Dubroca) [1570255]
- [pci] PCI/VPD: Check for VPD access completion before checking for timeout (Myron Stowe) [1618820]
- [rpmspec] redhat: remove bootwrapper subpackage (Gustavo Duarte) [1578399]
- [virt] kvm: x86: Set highest physical address bits in non-present/reserved SPTEs (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Use CC_SET()/CC_OUT in arch/x86/kvm/vmx.c (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement PV IPIs in linux guest (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Add kvm hypervisor init time platform setup callback (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement "send IPI" hypercall (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Move X86_CR4_OSXSAVE check into kvm_valid_sregs() (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Skip pae_root shadow allocation if tdp enabled (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Combine flushing remote tlb in mmu_set_spte() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_BASE when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_SEL when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: always initialize HOST_(FS, GS)_BASE to zero during setup (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: move struct host_state usage to struct loaded_vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: compute need to reload FS/GS/LDT on demand (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: remove a misleading comment regarding vmcs02 fields (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: rename __vmx_load_host_state() and vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: add dedicated utility to access guest's kernel_gs_base (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: track host_state.loaded using a loaded_vmcs pointer (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: refactor segmentation code in vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault priority for VMX operations (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault vector for VMX operation at CPL > 0 (Paolo Bonzini) [1614808]
- [virt] KVM: try __get_user_pages_fast even if not in atomic context (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: Add tlb_remote_flush callback support (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Add tlb remote flush callback in kvm_x86_ops (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add hyperv_nested_flush_guest_mapping ftrace support (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add flush HvFlushGuestPhysicalAddressSpace hypercall support (Paolo Bonzini) [1614808]
- [virt] x86/kvm: Don't use pvqspinlock code if only 1 vCPU (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Simplify __kvm_sync_page() function (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Remove CR3_PCID_INVD flag (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add multi-entry LRU cache for previous CR3s (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Flush only affected TLB entries in kvm_mmu_invlpg* (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip shadow page resync on CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support selectively freeing either current or previous MMU root (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add a root_hpa parameter to kvm_mmu->invlpg() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip TLB flush on fast CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: vmx: Support INVPCID in shadow paging mode (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Propagate guest PCIDs to host PCIDs (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add ability to skip TLB flush when switching CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Use fast CR3 switch for nested VMX (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support resetting the MMU context without resetting roots (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add support for fast CR3 switch across different MMU modes (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce KVM_REQ_LOAD_CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce kvm_mmu_calc_root_page_role() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add fast CR3 switch code path (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Avoid taking MMU lock in kvm_mmu_sync_roots if no sync is needed (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Make sync_page() flush remote TLBs once only (Paolo Bonzini) [1614808]
- [virt] KVM: MMU: drop vcpu param in gpte_access (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Separate logic allocating shadow vmcs to a function (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Mark vmcs header as shadow in case alloc_vmcs_cpu() allocate shadow vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Expose VMCS shadowing to L1 guest (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Do not forward VMREAD/VMWRITE VMExits to L1 if required so by vmcs12 vmread/vmwrite bitmaps (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: vmread/vmwrite: Use shadow vmcs12 if running L2 (Paolo Bonzini) [1614808]
- [virt] KVM: selftests: add tests for shadow VMCS save/restore (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: include shadow vmcs12 in nested state (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Cache shadow vmcs12 on VMEntry and flush to memory on VMExit (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing VMCS link pointer (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing controls (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Introduce nested_cpu_has_shadow_vmcs() (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Fail VMLAUNCH and VMRESUME on shadow VMCS (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Allow VMPTRLD for shadow VMCS if vCPU supports VMCS shadowing (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Change vmcs12(read, write)_any() to receive vmcs12 as parameter (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Create struct for VMCS header (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add test for nested state save/restore (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Introduce KVM_CAP_NESTED_STATE (Paolo Bonzini) [1614808]
- [virt] KVM: x86: do not load vmcs12 pages while still in SMM (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add basic test for state save and restore (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: ensure vcpu file is released (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: actually use all of lib/vmx.c (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: create a GDT and TSS (Paolo Bonzini) [1614808]
- [virt] KVM: x86: ensure all MSRs can always be KVM_GET/SET_MSR'd (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: remove save/restore of host BNDCGFS MSR (Paolo Bonzini) [1614808]
- [virt] KVM: Switch 'requests' to be 64-bit (explicitly) (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add cr4_cpuid_sync_test (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Read kvm->arch.emul_smt_mode under kvm->lock (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Allow creating max number of VCPUs on POWER9 (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Pack VCORE IDs to access full VCPU ID space (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Fix constant size warning (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Add of_node_put() in success path (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S: Fix matching of hardware and emulated TCE tables (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Remove mmio_vsx_tx_sx_enabled in KVM MMIO emulation (Paolo Bonzini) [1614808]

* Fri Aug 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-2.el8]
- [net] tcp: Add tcp_clamp_rto_to_user_timeout() helper to improve accuracy (Michael Cambria) [1605024]
- [net] tcp: Add tcp_retransmit_stamp() helper routine (Michael Cambria) [1605024]
- [net] tcp: convert icsk_user_timeout from jiffies to msecs (Michael Cambria) [1605024]
- [kernel] Revert sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Lauro Ramos Venancio) [1585746]
- [kernel] redhat: makefile: adjust KBUILD_CFLAGS to reflect kernel.spec for powerpc builds (Gustavo Duarte) [1582568]
- [rpmspec] redhat: spec: build ppc64le kernel with -O3 (Gustavo Duarte) [1582568]
- [scsi] scsi: csiostor: update csio_get_flash_params() (Arjun Vynipadath) [1503574]
- [scsi] csiostor: Add a soft dep on cxgb4 driver (Arjun Vynipadath) [1503574]
- [firmware] dell_rbu: make firmware payload memory uncachable (Charles Rose) [1584401]

* Mon Aug 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-1.el8]
- [scsi] scsi: lpfc: update driver version to 12.0.0.6 (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Remove lpfc_enable_pbde as module parameter (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Correct LCB ACCept payload (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Limit tracking of tgt queue depth in fast path (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix driver crash when re-registering NVME rports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix list corruption on the completion queue (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix sysfs Speed value on CNA ports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix ELS abort on SLI-3 adapters (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: remove null check on nvmebuf (Dick Kennedy) [1613913]
- [arm64] arm64: fix ACPI dependencies (Bhupesh Sharma) [1556832]
- [arm64] arm64: acpi: fix alignment fault in accessing ACPI (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: map UEFI memory map even w/o runtime services enabled (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: preserve early mapping of UEFI memory map longer for BGRT (Bhupesh Sharma) [1556832]
- [acpi] drivers: acpi: add dependency of EFI for arm64 (Bhupesh Sharma) [1556832]
- [arm64] arm64: export memblock_reserve()d regions via /proc/iomem (Bhupesh Sharma) [1556832]
- [arm64] arm64: kconfig: Ensure spinlock fastpaths are inlined if !PREEMPT (Waiman Long) [1607924]
- [arm64] arm64: locking: Replace ticket lock implementation with qspinlock (Waiman Long) [1607924]
- [arm64] arm64: barrier: Implement smp_cond_load_relaxed (Waiman Long) [1607924]
- [scsi] scsi: lpfc: Revise copyright for new company language (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: update driver version to 12.0.0.5 (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: devloss timeout race condition caused null pointer reference (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix NVME Target crash in defer rcv logic (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Support duration field in Link Cable Beacon V1 command (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Make PBDE optimizations configurable (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix abort error path for NVMET (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix panic if driver unloaded when port is offline (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix driver not setting dpp bits correctly in doorbell word (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Add Buffer overflow check, when nvme_info larger than PAGE_SIZE (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: use monotonic timestamps for statistics (Dick Kennedy) [1600946]
- [x86] mark intel knights landing and knights mill unsupported (David Arcari) [1610493]
- [netdrv] igb: Remove superfluous reset to PHY and page 0 selection (Corinna Vinschen) [1612824]
- [tools] selftests/powerpc: Fix ptrace-pkey for default execute permission change (Steve Best) [1498799]
- [tools] selftests/powerpc: Fix core-pkey for default execute permission change (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: make protection key 0 less special (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Preallocate execute-only key (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Fix calculation of total pkeys (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Save the pkey registers before fork (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: key allocation/deallocation must not change pkey registers (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Deny read/write/execute by default (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Give all threads control of their key permissions (Steve Best) [1498799]
- [s390] KVM: s390: Add huge page enablement control (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page gmap linking support (David Hildenbrand) [1508102]
- [s390] s390/mm: hugetlb pages within a gmap can not be freed (David Hildenbrand) [1508102]
- [s390] KVM: s390: Beautify skey enable check (David Hildenbrand) [1508102]
- [s390] KVM: s390: Add skey emulation fault handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge pmd storage key handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear skeys for newly mapped huge guest pmds (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear huge page storage keys on enable_skey (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page dirty sync support (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd invalidation and clearing (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd notification bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd linking (David Hildenbrand) [1508102]
- [s390] s390/mm: Abstract gmap notify bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Make gmap_protect_range more modular (David Hildenbrand) [1508102]
- [s390] KVM: s390: Replace clear_user with kvm_clear_guest (David Hildenbrand) [1508102]
- [hwmon] hwmon: (ibmpowernv) Add attributes to enable/disable sensor groups (Steve Best) [1524684]
- [powerpc] powerpc/powernv: Add support to enable sensor groups (Steve Best) [1524684]
- [net] net/smc: improve delete link processing (Hendrik Brueckner) [1548452]
- [net] net/smc: provide fallback reason code (Hendrik Brueckner) [1548452]
- [net] net/smc: use correct vlan gid of RoCE device (Hendrik Brueckner) [1548452]
- [net] net/smc: fewer parameters for smc_llc_send_confirm_link() (Hendrik Brueckner) [1548452]
- [net] net/smc: remove local variable page in smc_rx_splice() (Hendrik Brueckner) [1548452]
- [net] net/smc: use DECLARE_BITMAP for rtokens_used_mask (Hendrik Brueckner) [1548452]
- [net] net/smc: add function to get link group from link (Hendrik Brueckner) [1548452]
- [net] net/smc: eliminate cursor read and write calls (Hendrik Brueckner) [1548452]
- [net] net/smc: provide smc mode in smc_diag.c (Hendrik Brueckner) [1548452]
- [s390] s390/ism: add device driver for internal shared memory (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D diag support (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in af_smc (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in data transfer (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in CLC messages (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add base infrastructure for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support (Hendrik Brueckner) [1548452]
- [net] net/smc: determine port attributes independent from pnet table (Hendrik Brueckner) [1548452]
- [x86] mark whiskey-lake processor supported (David Arcari) [1609604]
- [s390] KVM: s390: add etoken support for guests (Thomas Huth) [1612110]
- [char] ipmi: do not configure ipmi for HPE m400 (Tony Camuso) [1583537]
- [scsi] scsi: ipr: Format HCAM overlay ID 0x41 (Steve Best) [1498222]
- [x86] x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC unwinder (Joe Lawrence) [1587952]
- [x86] x86/unwind/orc: Detect the end of the stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not fail for ORC with regs on stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Clarify the reliable success paths (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not unwind after user regs (Joe Lawrence) [1587952]
- [infiniband] IB/rxe: Mark Soft-RoCE Transport driver as tech-preview (Don Dutile) [1605216]
- [scsi] scsi: smartpqi: bump driver version to 1.1.4-130 (Don Brace) [1503736]
- [scsi] scsi: smartpqi: fix critical ARM issue reading PQI index registers (Don Brace) [1503736]
- [scsi] scsi: smartpqi: add inspur advantech ids (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve error checking for sync requests (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve handling for sync requests (Don Brace) [1503736]
- [netdrv] ice: mark driver as tech-preview (Jonathan Toppins) [1495347]
- [init] init/Kconfig: remove EXPERT from CHECKPOINT_RESTORE (Adrian Reber) [1568995 1557617 1525389]
- [scsi] be2iscsi: remove BE3 family support (Maurizio Lombardi) [1598366]
- [x86] update rh_check_supported processor list (David Arcari) [1595918]
- [kernel] kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- [pci] add pci_hw_vendor_status() (Maurizio Lombardi) [1590829]
- [ata] ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter) [1563590]
- [pci] Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter) [1563590]
- [kernel] bpf: set default values for bpf_jit_harden and bpf_jit_kallsyms (Eugene Syromiatnikov) [1569061]
- [kernel] bpf: Add tech preview taint for syscall (Eugene Syromiatnikov) [1559877]
- [kernel] bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- [kernel] add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- [tools] perf tests: Add Python 3 support to attr.py ("Herton R. Krzesinski") [1561505]
- [tools] perf scripts python: Add Python 3 support to stat-cpi.py ("Herton R. Krzesinski") [1561505]
- [kernel] kdump: fix a grammar issue in a kernel message (Dave Young) [1507353]
- [scripts] tags.sh: Ignore redhat/rpm (Prarit Bhargava) [1582586]
- [kernel] put RHEL info into generated headers (Prarit Bhargava) [1544999]
- [kernel] kdump: add support for crashkernel=auto (Dave Young) [1507353]
- [kernel] kdump: round up the total memory size to 128M for crashkernel reservation (Dave Young) [1507353]
- [arm64] acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- [acpi] aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- [acpi] ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- [x86] add rh_check_supported (David Arcari) [1565717]
- [scsi] qla2xxx: Remove PCI IDs of deprecated adapter (Himanshu Madhani) [1572233]
- [scsi] be2iscsi: remove unsupported device IDs (Chris Leech) [1574502]
- [scsi] Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy) [1572321]
- [scsi] hpsa: modify hpsa driver version (Joseph Szczypek) [1471185]
- [scsi] hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek) [1471185]
- [kernel] rh_taint: add support for marking driver as unsupported (Jonathan Toppins) [1565704]
- [kernel] rh_taint: add support (David Arcari) [1565704]
- [scsi] qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis) [1518874]
- [scsi] aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta) [1495307]
- [scsi] megaraid_sas: remove deprecated pci-ids (Tomas Henzl) [1509329]
- [scsi] mpt*: remove certain deprecated pci-ids (Tomas Henzl) [1511953]
- [kernel] modules: add rhelversion MODULE_INFO tag (Prarit Bhargava) [1544999]
- [acpi] ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- [rpmspec] compute content hash for kernel-headers (Rafael Aquini) [1613003]
- [rpmspec] compress modules on all architectures ("Herton R. Krzesinski") [1614556]
- [rpmspec] add gcov rpm packaging support (Jan Stancek) [1601733]
- [rpmspec] don't ship spdxcheck.py (Jakub Racek)
- [rpmspec] clean stray bpf files (Jakub Racek) [1593309]
- [rpmspec] Copy symvers.gz to /lib/modules (Eugene Syromiatnikov) [1609695]
- [rpmspec] Add kabi-dup related code into specfile (Petr Oros) [1585672]
- [rpmspec] kernel spec: Add and enable kabi check (Petr Oros) [1585672]
- [rpmspec] Enable warning checks for configs in rpm build (Prarit Bhargava) [1589858]
- [rpmspec] remove workaround for rst2man-3 from python3-docutils ("Herton R. Krzesinski") [1602148]
- [rpmspec] fix dist tag used for hardlink in kernel-devel post ("Herton R. Krzesinski") [1596397]
- [scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override (Prarit Bhargava) [1595727]
- [rpmspec] drop kernel package dependency on python2 ("Herton R. Krzesinski") [1561505]
- [kernel] Makefile: Move RHEL definitions down (Jakub Racek) [1576568]
- [rpmspec] eBPF: Add bpftool package to spec file (Jerome Marchand) [1559607]
- [rpmspec] fix conflicts with COPYING file while installing newer 4.17 kernel ("Herton R. Krzesinski") [1579563]
- [rpmspec] do not build kernel meta-package on noarch ("Herton R. Krzesinski") [1579512]
- [rpmspec] kernel spec: remove copy of arch/x86/purgatory/sha256.* ("Herton R. Krzesinski")
- [rpmspec] spec: Add new arch/powerpc/kernel/module.lds file to kernel-devel rpm (Steve Best) [1572553]
- [rpmspec] kernel spec: fix recent build errors from brp-mangle-shebangs ("Herton R. Krzesinski") [1575966]
- [rpmspec] Add i386 to ExclusiveArch to fix noarch package build ("Herton R. Krzesinski") [1575152]
- [rpmspec] Build kernel-abi-whitelists package (Petr Oros) [1571189]
- [rpmspec] kernel spec: build bzImage for s390 (Hendrik Brueckner) [1570041]
- [rpmspec] kernel spec: arm64: package module.lds in kernel-devel (Mark Salter) [1569014]
- [rpmspec] Re-enable debuginfo packages and fix build with current dist tag ("Herton R. Krzesinski") [1568901]
- [rpmspec] kernel spec: build kernel-debug on all architectures ("Herton R. Krzesinski") [1567367]
- [rpmspec] don't build kernel meta-package if we are only building kernel headers ("Herton R. Krzesinski")
- [rpmspec] remove use_vdso macro ("Herton R. Krzesinski")
- [rpmspec] build perf and tools man pages instead of relying on a separate tarball ("Herton R. Krzesinski")
- [rpmspec] disable debug build if arch is in nobuildarches list ("Herton R. Krzesinski")
- [rpmspec] remove fedora changelog from spec file ("Herton R. Krzesinski")
- [rpmspec] only support ppc64le builds ("Herton R. Krzesinski")
- [rpmspec] remove x86 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove arm 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove configuration generation support from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] remove broken out patches from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] import kernel spec from rhel8 bootstrap dist-git ("Herton R. Krzesinski")

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
